"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ContentLabelTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ContentLabelType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContentLabelType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ContentLabelTypeEnum.ContentLabelType.V(0)
        UNKNOWN = ContentLabelTypeEnum.ContentLabelType.V(1)
        SEXUALLY_SUGGESTIVE = ContentLabelTypeEnum.ContentLabelType.V(2)
        BELOW_THE_FOLD = ContentLabelTypeEnum.ContentLabelType.V(3)
        PARKED_DOMAIN = ContentLabelTypeEnum.ContentLabelType.V(4)
        JUVENILE = ContentLabelTypeEnum.ContentLabelType.V(6)
        PROFANITY = ContentLabelTypeEnum.ContentLabelType.V(7)
        TRAGEDY = ContentLabelTypeEnum.ContentLabelType.V(8)
        VIDEO = ContentLabelTypeEnum.ContentLabelType.V(9)
        VIDEO_RATING_DV_G = ContentLabelTypeEnum.ContentLabelType.V(10)
        VIDEO_RATING_DV_PG = ContentLabelTypeEnum.ContentLabelType.V(11)
        VIDEO_RATING_DV_T = ContentLabelTypeEnum.ContentLabelType.V(12)
        VIDEO_RATING_DV_MA = ContentLabelTypeEnum.ContentLabelType.V(13)
        VIDEO_NOT_YET_RATED = ContentLabelTypeEnum.ContentLabelType.V(14)
        EMBEDDED_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(15)
        LIVE_STREAMING_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(16)
        SOCIAL_ISSUES = ContentLabelTypeEnum.ContentLabelType.V(17)
    class ContentLabelType(metaclass=_ContentLabelType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ContentLabelTypeEnum.ContentLabelType.V(0)
    UNKNOWN = ContentLabelTypeEnum.ContentLabelType.V(1)
    SEXUALLY_SUGGESTIVE = ContentLabelTypeEnum.ContentLabelType.V(2)
    BELOW_THE_FOLD = ContentLabelTypeEnum.ContentLabelType.V(3)
    PARKED_DOMAIN = ContentLabelTypeEnum.ContentLabelType.V(4)
    JUVENILE = ContentLabelTypeEnum.ContentLabelType.V(6)
    PROFANITY = ContentLabelTypeEnum.ContentLabelType.V(7)
    TRAGEDY = ContentLabelTypeEnum.ContentLabelType.V(8)
    VIDEO = ContentLabelTypeEnum.ContentLabelType.V(9)
    VIDEO_RATING_DV_G = ContentLabelTypeEnum.ContentLabelType.V(10)
    VIDEO_RATING_DV_PG = ContentLabelTypeEnum.ContentLabelType.V(11)
    VIDEO_RATING_DV_T = ContentLabelTypeEnum.ContentLabelType.V(12)
    VIDEO_RATING_DV_MA = ContentLabelTypeEnum.ContentLabelType.V(13)
    VIDEO_NOT_YET_RATED = ContentLabelTypeEnum.ContentLabelType.V(14)
    EMBEDDED_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(15)
    LIVE_STREAMING_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(16)
    SOCIAL_ISSUES = ContentLabelTypeEnum.ContentLabelType.V(17)
    def __init__(
        self,
    ) -> None: ...

global___ContentLabelTypeEnum = ContentLabelTypeEnum
