"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaBundleErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaBundleError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaBundleError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaBundleErrorEnum.MediaBundleError.V(0)
        UNKNOWN = MediaBundleErrorEnum.MediaBundleError.V(1)
        BAD_REQUEST = MediaBundleErrorEnum.MediaBundleError.V(3)
        DOUBLECLICK_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(4)
        EXTERNAL_URL_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(5)
        FILE_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(6)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
            MediaBundleErrorEnum.MediaBundleError.V(7)
        )
        INVALID_INPUT = MediaBundleErrorEnum.MediaBundleError.V(8)
        INVALID_MEDIA_BUNDLE = MediaBundleErrorEnum.MediaBundleError.V(9)
        INVALID_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(10)
        INVALID_MIME_TYPE = MediaBundleErrorEnum.MediaBundleError.V(11)
        INVALID_PATH = MediaBundleErrorEnum.MediaBundleError.V(12)
        INVALID_URL_REFERENCE = MediaBundleErrorEnum.MediaBundleError.V(13)
        MEDIA_DATA_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(14)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(15)
        SERVER_ERROR = MediaBundleErrorEnum.MediaBundleError.V(16)
        STORAGE_ERROR = MediaBundleErrorEnum.MediaBundleError.V(17)
        SWIFFY_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(18)
        TOO_MANY_FILES = MediaBundleErrorEnum.MediaBundleError.V(19)
        UNEXPECTED_SIZE = MediaBundleErrorEnum.MediaBundleError.V(20)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
            MediaBundleErrorEnum.MediaBundleError.V(21)
        )
        UNSUPPORTED_HTML5_FEATURE = MediaBundleErrorEnum.MediaBundleError.V(22)
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaBundleErrorEnum.MediaBundleError.V(
            23
        )
        CUSTOM_EXIT_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(24)
    class MediaBundleError(metaclass=_MediaBundleError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaBundleErrorEnum.MediaBundleError.V(0)
    UNKNOWN = MediaBundleErrorEnum.MediaBundleError.V(1)
    BAD_REQUEST = MediaBundleErrorEnum.MediaBundleError.V(3)
    DOUBLECLICK_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(4)
    EXTERNAL_URL_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(5)
    FILE_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(6)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
        MediaBundleErrorEnum.MediaBundleError.V(7)
    )
    INVALID_INPUT = MediaBundleErrorEnum.MediaBundleError.V(8)
    INVALID_MEDIA_BUNDLE = MediaBundleErrorEnum.MediaBundleError.V(9)
    INVALID_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(10)
    INVALID_MIME_TYPE = MediaBundleErrorEnum.MediaBundleError.V(11)
    INVALID_PATH = MediaBundleErrorEnum.MediaBundleError.V(12)
    INVALID_URL_REFERENCE = MediaBundleErrorEnum.MediaBundleError.V(13)
    MEDIA_DATA_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(14)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(15)
    SERVER_ERROR = MediaBundleErrorEnum.MediaBundleError.V(16)
    STORAGE_ERROR = MediaBundleErrorEnum.MediaBundleError.V(17)
    SWIFFY_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(18)
    TOO_MANY_FILES = MediaBundleErrorEnum.MediaBundleError.V(19)
    UNEXPECTED_SIZE = MediaBundleErrorEnum.MediaBundleError.V(20)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
        MediaBundleErrorEnum.MediaBundleError.V(21)
    )
    UNSUPPORTED_HTML5_FEATURE = MediaBundleErrorEnum.MediaBundleError.V(22)
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaBundleErrorEnum.MediaBundleError.V(23)
    CUSTOM_EXIT_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___MediaBundleErrorEnum = MediaBundleErrorEnum
