"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AppPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AppPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AppPlaceholderFieldEnum.AppPlaceholderField.V(0)
        UNKNOWN = AppPlaceholderFieldEnum.AppPlaceholderField.V(1)
        STORE = AppPlaceholderFieldEnum.AppPlaceholderField.V(2)
        ID = AppPlaceholderFieldEnum.AppPlaceholderField.V(3)
        LINK_TEXT = AppPlaceholderFieldEnum.AppPlaceholderField.V(4)
        URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(5)
        FINAL_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(6)
        FINAL_MOBILE_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(7)
        TRACKING_URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(8)
        FINAL_URL_SUFFIX = AppPlaceholderFieldEnum.AppPlaceholderField.V(9)
    class AppPlaceholderField(metaclass=_AppPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AppPlaceholderFieldEnum.AppPlaceholderField.V(0)
    UNKNOWN = AppPlaceholderFieldEnum.AppPlaceholderField.V(1)
    STORE = AppPlaceholderFieldEnum.AppPlaceholderField.V(2)
    ID = AppPlaceholderFieldEnum.AppPlaceholderField.V(3)
    LINK_TEXT = AppPlaceholderFieldEnum.AppPlaceholderField.V(4)
    URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(5)
    FINAL_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(6)
    FINAL_MOBILE_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(7)
    TRACKING_URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(8)
    FINAL_URL_SUFFIX = AppPlaceholderFieldEnum.AppPlaceholderField.V(9)
    def __init__(
        self,
    ) -> None: ...

global___AppPlaceholderFieldEnum = AppPlaceholderFieldEnum
