"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyValidationParameterErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyValidationParameterError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyValidationParameterError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(0)
        )
        UNKNOWN = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(1)
        UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(2)
        )
        UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(3)
        )
        CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(4)
        )
    class PolicyValidationParameterError(metaclass=_PolicyValidationParameterError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(0)
    UNKNOWN = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(1)
    UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(2)
    )
    UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(3)
    )
    CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___PolicyValidationParameterErrorEnum = PolicyValidationParameterErrorEnum
