"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2
import google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TagSnippet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    PAGE_FORMAT_FIELD_NUMBER: builtins.int
    GLOBAL_SITE_TAG_FIELD_NUMBER: builtins.int
    EVENT_SNIPPET_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2.TrackingCodeTypeEnum.TrackingCodeType.V = (
        ...
    )
    page_format: google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2.TrackingCodePageFormatEnum.TrackingCodePageFormat.V = (
        ...
    )
    global_site_tag: typing.Text = ...
    event_snippet: typing.Text = ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2.TrackingCodeTypeEnum.TrackingCodeType.V = ...,
        page_format: google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2.TrackingCodePageFormatEnum.TrackingCodePageFormat.V = ...,
        global_site_tag: typing.Text = ...,
        event_snippet: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
            "page_format",
            b"page_format",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_event_snippet", b"_event_snippet"],
    ) -> typing_extensions.Literal["event_snippet"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_global_site_tag", b"_global_site_tag"],
    ) -> typing_extensions.Literal["global_site_tag"]: ...

global___TagSnippet = TagSnippet
