"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelPriceBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelPriceBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HotelPriceBucket.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelPriceBucketEnum.HotelPriceBucket.V(0)
        UNKNOWN = HotelPriceBucketEnum.HotelPriceBucket.V(1)
        LOWEST_UNIQUE = HotelPriceBucketEnum.HotelPriceBucket.V(2)
        LOWEST_TIED = HotelPriceBucketEnum.HotelPriceBucket.V(3)
        NOT_LOWEST = HotelPriceBucketEnum.HotelPriceBucket.V(4)
        ONLY_PARTNER_SHOWN = HotelPriceBucketEnum.HotelPriceBucket.V(5)
    class HotelPriceBucket(metaclass=_HotelPriceBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelPriceBucketEnum.HotelPriceBucket.V(0)
    UNKNOWN = HotelPriceBucketEnum.HotelPriceBucket.V(1)
    LOWEST_UNIQUE = HotelPriceBucketEnum.HotelPriceBucket.V(2)
    LOWEST_TIED = HotelPriceBucketEnum.HotelPriceBucket.V(3)
    NOT_LOWEST = HotelPriceBucketEnum.HotelPriceBucket.V(4)
    ONLY_PARTNER_SHOWN = HotelPriceBucketEnum.HotelPriceBucket.V(5)
    def __init__(
        self,
    ) -> None: ...

global___HotelPriceBucketEnum = HotelPriceBucketEnum
