"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserListError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListErrorEnum.UserListError.V(0)
        UNKNOWN = UserListErrorEnum.UserListError.V(1)
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = (
            UserListErrorEnum.UserListError.V(2)
        )
        CONCRETE_TYPE_REQUIRED = UserListErrorEnum.UserListError.V(3)
        CONVERSION_TYPE_ID_REQUIRED = UserListErrorEnum.UserListError.V(4)
        DUPLICATE_CONVERSION_TYPES = UserListErrorEnum.UserListError.V(5)
        INVALID_CONVERSION_TYPE = UserListErrorEnum.UserListError.V(6)
        INVALID_DESCRIPTION = UserListErrorEnum.UserListError.V(7)
        INVALID_NAME = UserListErrorEnum.UserListError.V(8)
        INVALID_TYPE = UserListErrorEnum.UserListError.V(9)
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = (
            UserListErrorEnum.UserListError.V(10)
        )
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND = UserListErrorEnum.UserListError.V(11)
        NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(12)
        NEW_CONVERSION_TYPE_NAME_REQUIRED = UserListErrorEnum.UserListError.V(13)
        CONVERSION_TYPE_NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(14)
        OWNERSHIP_REQUIRED_FOR_SET = UserListErrorEnum.UserListError.V(15)
        USER_LIST_MUTATE_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(16)
        INVALID_RULE = UserListErrorEnum.UserListError.V(17)
        INVALID_DATE_RANGE = UserListErrorEnum.UserListError.V(27)
        CAN_NOT_MUTATE_SENSITIVE_USERLIST = UserListErrorEnum.UserListError.V(28)
        MAX_NUM_RULEBASED_USERLISTS = UserListErrorEnum.UserListError.V(29)
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT = UserListErrorEnum.UserListError.V(30)
        APP_ID_NOT_SET = UserListErrorEnum.UserListError.V(31)
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = UserListErrorEnum.UserListError.V(
            32
        )
        ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = (
            UserListErrorEnum.UserListError.V(33)
        )
        RULE_TYPE_IS_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(34)
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = (
            UserListErrorEnum.UserListError.V(35)
        )
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = (
            UserListErrorEnum.UserListError.V(36)
        )
    class UserListError(metaclass=_UserListError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListErrorEnum.UserListError.V(0)
    UNKNOWN = UserListErrorEnum.UserListError.V(1)
    EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = (
        UserListErrorEnum.UserListError.V(2)
    )
    CONCRETE_TYPE_REQUIRED = UserListErrorEnum.UserListError.V(3)
    CONVERSION_TYPE_ID_REQUIRED = UserListErrorEnum.UserListError.V(4)
    DUPLICATE_CONVERSION_TYPES = UserListErrorEnum.UserListError.V(5)
    INVALID_CONVERSION_TYPE = UserListErrorEnum.UserListError.V(6)
    INVALID_DESCRIPTION = UserListErrorEnum.UserListError.V(7)
    INVALID_NAME = UserListErrorEnum.UserListError.V(8)
    INVALID_TYPE = UserListErrorEnum.UserListError.V(9)
    CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = (
        UserListErrorEnum.UserListError.V(10)
    )
    INVALID_USER_LIST_LOGICAL_RULE_OPERAND = UserListErrorEnum.UserListError.V(11)
    NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(12)
    NEW_CONVERSION_TYPE_NAME_REQUIRED = UserListErrorEnum.UserListError.V(13)
    CONVERSION_TYPE_NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(14)
    OWNERSHIP_REQUIRED_FOR_SET = UserListErrorEnum.UserListError.V(15)
    USER_LIST_MUTATE_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(16)
    INVALID_RULE = UserListErrorEnum.UserListError.V(17)
    INVALID_DATE_RANGE = UserListErrorEnum.UserListError.V(27)
    CAN_NOT_MUTATE_SENSITIVE_USERLIST = UserListErrorEnum.UserListError.V(28)
    MAX_NUM_RULEBASED_USERLISTS = UserListErrorEnum.UserListError.V(29)
    CANNOT_MODIFY_BILLABLE_RECORD_COUNT = UserListErrorEnum.UserListError.V(30)
    APP_ID_NOT_SET = UserListErrorEnum.UserListError.V(31)
    USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = UserListErrorEnum.UserListError.V(32)
    ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = (
        UserListErrorEnum.UserListError.V(33)
    )
    RULE_TYPE_IS_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(34)
    CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = (
        UserListErrorEnum.UserListError.V(35)
    )
    CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = (
        UserListErrorEnum.UserListError.V(36)
    )
    def __init__(
        self,
    ) -> None: ...

global___UserListErrorEnum = UserListErrorEnum
