"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NegativeGeoTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _NegativeGeoTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NegativeGeoTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(0)
        UNKNOWN = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(1)
        PRESENCE_OR_INTEREST = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(4)
        PRESENCE = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(5)
    class NegativeGeoTargetType(metaclass=_NegativeGeoTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(0)
    UNKNOWN = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(1)
    PRESENCE_OR_INTEREST = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(4)
    PRESENCE = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___NegativeGeoTargetTypeEnum = NegativeGeoTargetTypeEnum
