"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignServingStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignServingStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignServingStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignServingStatusEnum.CampaignServingStatus.V(0)
        UNKNOWN = CampaignServingStatusEnum.CampaignServingStatus.V(1)
        SERVING = CampaignServingStatusEnum.CampaignServingStatus.V(2)
        NONE = CampaignServingStatusEnum.CampaignServingStatus.V(3)
        ENDED = CampaignServingStatusEnum.CampaignServingStatus.V(4)
        PENDING = CampaignServingStatusEnum.CampaignServingStatus.V(5)
        SUSPENDED = CampaignServingStatusEnum.CampaignServingStatus.V(6)
    class CampaignServingStatus(metaclass=_CampaignServingStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignServingStatusEnum.CampaignServingStatus.V(0)
    UNKNOWN = CampaignServingStatusEnum.CampaignServingStatus.V(1)
    SERVING = CampaignServingStatusEnum.CampaignServingStatus.V(2)
    NONE = CampaignServingStatusEnum.CampaignServingStatus.V(3)
    ENDED = CampaignServingStatusEnum.CampaignServingStatus.V(4)
    PENDING = CampaignServingStatusEnum.CampaignServingStatus.V(5)
    SUSPENDED = CampaignServingStatusEnum.CampaignServingStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___CampaignServingStatusEnum = CampaignServingStatusEnum
