"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdServingOptimizationStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdServingOptimizationStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdServingOptimizationStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(0)
        UNKNOWN = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(1)
        OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(2)
        CONVERSION_OPTIMIZE = (
            AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(3)
        )
        ROTATE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(4)
        ROTATE_INDEFINITELY = (
            AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(5)
        )
        UNAVAILABLE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(6)
    class AdServingOptimizationStatus(metaclass=_AdServingOptimizationStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(0)
    UNKNOWN = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(1)
    OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(2)
    CONVERSION_OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(
        3
    )
    ROTATE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(4)
    ROTATE_INDEFINITELY = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(
        5
    )
    UNAVAILABLE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AdServingOptimizationStatusEnum = AdServingOptimizationStatusEnum
