"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AffiliateLocationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AffiliateLocationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AffiliateLocationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(0)
        )
        UNKNOWN = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(1)
        )
        BUSINESS_NAME = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(2)
        )
        ADDRESS_LINE_1 = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(3)
        )
        ADDRESS_LINE_2 = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(4)
        )
        CITY = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(5)
        )
        PROVINCE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(6)
        )
        POSTAL_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(7)
        )
        COUNTRY_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(8)
        )
        PHONE_NUMBER = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(9)
        )
        LANGUAGE_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                10
            )
        )
        CHAIN_ID = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                11
            )
        )
        CHAIN_NAME = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                12
            )
        )
    class AffiliateLocationPlaceholderField(
        metaclass=_AffiliateLocationPlaceholderField
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(0)
    )
    UNKNOWN = AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
        1
    )
    BUSINESS_NAME = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(2)
    )
    ADDRESS_LINE_1 = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(3)
    )
    ADDRESS_LINE_2 = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(4)
    )
    CITY = AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(5)
    PROVINCE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(6)
    )
    POSTAL_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(7)
    )
    COUNTRY_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(8)
    )
    PHONE_NUMBER = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(9)
    )
    LANGUAGE_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(10)
    )
    CHAIN_ID = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(11)
    )
    CHAIN_NAME = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___AffiliateLocationPlaceholderFieldEnum = AffiliateLocationPlaceholderFieldEnum
