"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class InteractionEventTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _InteractionEventType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            InteractionEventType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = InteractionEventTypeEnum.InteractionEventType.V(0)
        UNKNOWN = InteractionEventTypeEnum.InteractionEventType.V(1)
        CLICK = InteractionEventTypeEnum.InteractionEventType.V(2)
        ENGAGEMENT = InteractionEventTypeEnum.InteractionEventType.V(3)
        VIDEO_VIEW = InteractionEventTypeEnum.InteractionEventType.V(4)
        NONE = InteractionEventTypeEnum.InteractionEventType.V(5)
    class InteractionEventType(metaclass=_InteractionEventType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = InteractionEventTypeEnum.InteractionEventType.V(0)
    UNKNOWN = InteractionEventTypeEnum.InteractionEventType.V(1)
    CLICK = InteractionEventTypeEnum.InteractionEventType.V(2)
    ENGAGEMENT = InteractionEventTypeEnum.InteractionEventType.V(3)
    VIDEO_VIEW = InteractionEventTypeEnum.InteractionEventType.V(4)
    NONE = InteractionEventTypeEnum.InteractionEventType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___InteractionEventTypeEnum = InteractionEventTypeEnum
