"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2
import google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2
import google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FrequencyCapEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    CAP_FIELD_NUMBER: builtins.int
    @property
    def key(self) -> global___FrequencyCapKey: ...
    @property
    def cap(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        key: typing.Optional[global___FrequencyCapKey] = ...,
        cap: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["cap", b"cap", "key", b"key"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["cap", b"cap", "key", b"key"]
    ) -> None: ...

global___FrequencyCapEntry = FrequencyCapEntry

class FrequencyCapKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEVEL_FIELD_NUMBER: builtins.int
    EVENT_TYPE_FIELD_NUMBER: builtins.int
    TIME_UNIT_FIELD_NUMBER: builtins.int
    TIME_LENGTH_FIELD_NUMBER: builtins.int
    level: google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2.FrequencyCapLevelEnum.FrequencyCapLevel.V = (
        ...
    )
    event_type: google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2.FrequencyCapEventTypeEnum.FrequencyCapEventType.V = (
        ...
    )
    time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = (
        ...
    )
    @property
    def time_length(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        level: google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2.FrequencyCapLevelEnum.FrequencyCapLevel.V = ...,
        event_type: google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2.FrequencyCapEventTypeEnum.FrequencyCapEventType.V = ...,
        time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = ...,
        time_length: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["time_length", b"time_length"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "event_type",
            b"event_type",
            "level",
            b"level",
            "time_length",
            b"time_length",
            "time_unit",
            b"time_unit",
        ],
    ) -> None: ...

global___FrequencyCapKey = FrequencyCapKey
