"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductBiddingCategoryStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductBiddingCategoryStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(0)
        UNKNOWN = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(1)
        ACTIVE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(2)
        OBSOLETE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(3)
    class ProductBiddingCategoryStatus(metaclass=_ProductBiddingCategoryStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(0)
    UNKNOWN = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(1)
    ACTIVE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(2)
    OBSOLETE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ProductBiddingCategoryStatusEnum = ProductBiddingCategoryStatusEnum
