"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdStrengthEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdStrength(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdStrength.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdStrengthEnum.AdStrength.V(0)
        UNKNOWN = AdStrengthEnum.AdStrength.V(1)
        PENDING = AdStrengthEnum.AdStrength.V(2)
        NO_ADS = AdStrengthEnum.AdStrength.V(3)
        POOR = AdStrengthEnum.AdStrength.V(4)
        AVERAGE = AdStrengthEnum.AdStrength.V(5)
        GOOD = AdStrengthEnum.AdStrength.V(6)
        EXCELLENT = AdStrengthEnum.AdStrength.V(7)
    class AdStrength(metaclass=_AdStrength):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdStrengthEnum.AdStrength.V(0)
    UNKNOWN = AdStrengthEnum.AdStrength.V(1)
    PENDING = AdStrengthEnum.AdStrength.V(2)
    NO_ADS = AdStrengthEnum.AdStrength.V(3)
    POOR = AdStrengthEnum.AdStrength.V(4)
    AVERAGE = AdStrengthEnum.AdStrength.V(5)
    GOOD = AdStrengthEnum.AdStrength.V(6)
    EXCELLENT = AdStrengthEnum.AdStrength.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AdStrengthEnum = AdStrengthEnum
