"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyReviewStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyReviewStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyReviewStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyReviewStatusEnum.PolicyReviewStatus.V(0)
        UNKNOWN = PolicyReviewStatusEnum.PolicyReviewStatus.V(1)
        REVIEW_IN_PROGRESS = PolicyReviewStatusEnum.PolicyReviewStatus.V(2)
        REVIEWED = PolicyReviewStatusEnum.PolicyReviewStatus.V(3)
        UNDER_APPEAL = PolicyReviewStatusEnum.PolicyReviewStatus.V(4)
        ELIGIBLE_MAY_SERVE = PolicyReviewStatusEnum.PolicyReviewStatus.V(5)
    class PolicyReviewStatus(metaclass=_PolicyReviewStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyReviewStatusEnum.PolicyReviewStatus.V(0)
    UNKNOWN = PolicyReviewStatusEnum.PolicyReviewStatus.V(1)
    REVIEW_IN_PROGRESS = PolicyReviewStatusEnum.PolicyReviewStatus.V(2)
    REVIEWED = PolicyReviewStatusEnum.PolicyReviewStatus.V(3)
    UNDER_APPEAL = PolicyReviewStatusEnum.PolicyReviewStatus.V(4)
    ELIGIBLE_MAY_SERVE = PolicyReviewStatusEnum.PolicyReviewStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___PolicyReviewStatusEnum = PolicyReviewStatusEnum
