"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdvertisingChannelSubTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdvertisingChannelSubType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdvertisingChannelSubType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(0)
        UNKNOWN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(1)
        SEARCH_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(2)
        DISPLAY_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            3
        )
        SEARCH_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(4)
        DISPLAY_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(5)
        SHOPPING_SMART_ADS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            6
        )
        DISPLAY_GMAIL_AD = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(7)
        DISPLAY_SMART_CAMPAIGN = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(8)
        )
        VIDEO_OUTSTREAM = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(9)
        VIDEO_ACTION = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(10)
        VIDEO_NON_SKIPPABLE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            11
        )
        APP_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(12)
        APP_CAMPAIGN_FOR_ENGAGEMENT = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(13)
        )
        LOCAL_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(14)
        SHOPPING_COMPARISON_LISTING_ADS = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(15)
        )
        SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(16)
        VIDEO_SEQUENCE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(17)
    class AdvertisingChannelSubType(metaclass=_AdvertisingChannelSubType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(0)
    UNKNOWN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(1)
    SEARCH_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(2)
    DISPLAY_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(3)
    SEARCH_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(4)
    DISPLAY_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(5)
    SHOPPING_SMART_ADS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(6)
    DISPLAY_GMAIL_AD = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(7)
    DISPLAY_SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
        8
    )
    VIDEO_OUTSTREAM = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(9)
    VIDEO_ACTION = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(10)
    VIDEO_NON_SKIPPABLE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(11)
    APP_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(12)
    APP_CAMPAIGN_FOR_ENGAGEMENT = (
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(13)
    )
    LOCAL_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(14)
    SHOPPING_COMPARISON_LISTING_ADS = (
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(15)
    )
    SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(16)
    VIDEO_SEQUENCE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(17)
    def __init__(
        self,
    ) -> None: ...

global___AdvertisingChannelSubTypeEnum = AdvertisingChannelSubTypeEnum
