"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryLevelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductBiddingCategoryLevel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductBiddingCategoryLevel.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(0)
        UNKNOWN = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(1)
        LEVEL1 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(2)
        LEVEL2 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(3)
        LEVEL3 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(4)
        LEVEL4 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(5)
        LEVEL5 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(6)
    class ProductBiddingCategoryLevel(metaclass=_ProductBiddingCategoryLevel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(0)
    UNKNOWN = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(1)
    LEVEL1 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(2)
    LEVEL2 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(3)
    LEVEL3 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(4)
    LEVEL4 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(5)
    LEVEL5 = ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ProductBiddingCategoryLevelEnum = ProductBiddingCategoryLevelEnum
