"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupBidModifierErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupBidModifierError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupBidModifierError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(0)
        UNKNOWN = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(1)
        CRITERION_ID_NOT_SUPPORTED = (
            AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(2)
        )
        CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER = (
            AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(3)
        )
    class AdGroupBidModifierError(metaclass=_AdGroupBidModifierError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(0)
    UNKNOWN = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(1)
    CRITERION_ID_NOT_SUPPORTED = AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(
        2
    )
    CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER = (
        AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V(3)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupBidModifierErrorEnum = AdGroupBidModifierErrorEnum
