"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MutateErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MutateError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MutateError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MutateErrorEnum.MutateError.V(0)
        UNKNOWN = MutateErrorEnum.MutateError.V(1)
        RESOURCE_NOT_FOUND = MutateErrorEnum.MutateError.V(3)
        ID_EXISTS_IN_MULTIPLE_MUTATES = MutateErrorEnum.MutateError.V(7)
        INCONSISTENT_FIELD_VALUES = MutateErrorEnum.MutateError.V(8)
        MUTATE_NOT_ALLOWED = MutateErrorEnum.MutateError.V(9)
        RESOURCE_NOT_IN_GOOGLE_ADS = MutateErrorEnum.MutateError.V(10)
        RESOURCE_ALREADY_EXISTS = MutateErrorEnum.MutateError.V(11)
        RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = MutateErrorEnum.MutateError.V(12)
        RESOURCE_READ_ONLY = MutateErrorEnum.MutateError.V(13)
    class MutateError(metaclass=_MutateError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MutateErrorEnum.MutateError.V(0)
    UNKNOWN = MutateErrorEnum.MutateError.V(1)
    RESOURCE_NOT_FOUND = MutateErrorEnum.MutateError.V(3)
    ID_EXISTS_IN_MULTIPLE_MUTATES = MutateErrorEnum.MutateError.V(7)
    INCONSISTENT_FIELD_VALUES = MutateErrorEnum.MutateError.V(8)
    MUTATE_NOT_ALLOWED = MutateErrorEnum.MutateError.V(9)
    RESOURCE_NOT_IN_GOOGLE_ADS = MutateErrorEnum.MutateError.V(10)
    RESOURCE_ALREADY_EXISTS = MutateErrorEnum.MutateError.V(11)
    RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = MutateErrorEnum.MutateError.V(12)
    RESOURCE_READ_ONLY = MutateErrorEnum.MutateError.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MutateErrorEnum = MutateErrorEnum
