"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    PINNED_FIELD_FIELD_NUMBER: builtins.int
    pinned_field: google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = (
        ...
    )
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        pinned_field: google.ads.google_ads.v4.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "pinned_field", b"pinned_field", "text", b"text"
        ],
    ) -> None: ...

global___AdTextAsset = AdTextAsset

class AdImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdImageAsset = AdImageAsset

class AdVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    @property
    def asset(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        asset: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["asset", b"asset"]
    ) -> None: ...

global___AdMediaBundleAsset = AdMediaBundleAsset
