"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BatchJobErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BatchJobError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BatchJobError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BatchJobErrorEnum.BatchJobError.V(0)
        UNKNOWN = BatchJobErrorEnum.BatchJobError.V(1)
        CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = BatchJobErrorEnum.BatchJobError.V(
            2
        )
        EMPTY_OPERATIONS = BatchJobErrorEnum.BatchJobError.V(3)
        INVALID_SEQUENCE_TOKEN = BatchJobErrorEnum.BatchJobError.V(4)
        RESULTS_NOT_READY = BatchJobErrorEnum.BatchJobError.V(5)
        INVALID_PAGE_SIZE = BatchJobErrorEnum.BatchJobError.V(6)
        CAN_ONLY_REMOVE_PENDING_JOB = BatchJobErrorEnum.BatchJobError.V(7)
    class BatchJobError(metaclass=_BatchJobError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BatchJobErrorEnum.BatchJobError.V(0)
    UNKNOWN = BatchJobErrorEnum.BatchJobError.V(1)
    CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = BatchJobErrorEnum.BatchJobError.V(2)
    EMPTY_OPERATIONS = BatchJobErrorEnum.BatchJobError.V(3)
    INVALID_SEQUENCE_TOKEN = BatchJobErrorEnum.BatchJobError.V(4)
    RESULTS_NOT_READY = BatchJobErrorEnum.BatchJobError.V(5)
    INVALID_PAGE_SIZE = BatchJobErrorEnum.BatchJobError.V(6)
    CAN_ONLY_REMOVE_PENDING_JOB = BatchJobErrorEnum.BatchJobError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___BatchJobErrorEnum = BatchJobErrorEnum
