"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.conversion_action_pb2
import grpc

from .conversion_action_service_pb2 import *

class ConversionActionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetConversionAction(
        self,
        request: global___GetConversionActionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.conversion_action_pb2.ConversionAction: ...
    def MutateConversionActions(
        self,
        request: global___MutateConversionActionsRequest,
    ) -> global___MutateConversionActionsResponse: ...

class ConversionActionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetConversionAction(
        self,
        request: global___GetConversionActionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.conversion_action_pb2.ConversionAction: ...
    @abc.abstractmethod
    def MutateConversionActions(
        self,
        request: global___MutateConversionActionsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateConversionActionsResponse: ...

def add_ConversionActionServiceServicer_to_server(
    servicer: ConversionActionServiceServicer, server: grpc.Server
) -> None: ...
