"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PromotionPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PromotionPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PromotionPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(0)
        UNKNOWN = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(1)
        PROMOTION_TARGET = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(2)
        DISCOUNT_MODIFIER = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(3)
        PERCENT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(4)
        MONEY_AMOUNT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(5)
        PROMOTION_CODE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(6)
        ORDERS_OVER_AMOUNT = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(
            7
        )
        PROMOTION_START = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(8)
        PROMOTION_END = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(9)
        OCCASION = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(10)
        FINAL_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(11)
        FINAL_MOBILE_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(
            12
        )
        TRACKING_URL = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(13)
        LANGUAGE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(14)
        FINAL_URL_SUFFIX = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(15)
    class PromotionPlaceholderField(metaclass=_PromotionPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(0)
    UNKNOWN = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(1)
    PROMOTION_TARGET = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(2)
    DISCOUNT_MODIFIER = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(3)
    PERCENT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(4)
    MONEY_AMOUNT_OFF = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(5)
    PROMOTION_CODE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(6)
    ORDERS_OVER_AMOUNT = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(7)
    PROMOTION_START = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(8)
    PROMOTION_END = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(9)
    OCCASION = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(10)
    FINAL_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(11)
    FINAL_MOBILE_URLS = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(12)
    TRACKING_URL = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(13)
    LANGUAGE = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(14)
    FINAL_URL_SUFFIX = PromotionPlaceholderFieldEnum.PromotionPlaceholderField.V(15)
    def __init__(
        self,
    ) -> None: ...

global___PromotionPlaceholderFieldEnum = PromotionPlaceholderFieldEnum
