"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .conversion_upload_service_pb2 import *

class ConversionUploadServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadClickConversions(
        self,
        request: global___UploadClickConversionsRequest,
    ) -> global___UploadClickConversionsResponse: ...
    def UploadCallConversions(
        self,
        request: global___UploadCallConversionsRequest,
    ) -> global___UploadCallConversionsResponse: ...

class ConversionUploadServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadClickConversions(
        self,
        request: global___UploadClickConversionsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadClickConversionsResponse: ...
    @abc.abstractmethod
    def UploadCallConversions(
        self,
        request: global___UploadCallConversionsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadCallConversionsResponse: ...

def add_ConversionUploadServiceServicer_to_server(
    servicer: ConversionUploadServiceServicer, server: grpc.Server
) -> None: ...
