"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetErrorEnum.AssetError.V(0)
        UNKNOWN = AssetErrorEnum.AssetError.V(1)
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(13)
        DUPLICATE_ASSET = AssetErrorEnum.AssetError.V(3)
        DUPLICATE_ASSET_NAME = AssetErrorEnum.AssetError.V(4)
        ASSET_DATA_IS_MISSING = AssetErrorEnum.AssetError.V(5)
        CANNOT_MODIFY_ASSET_NAME = AssetErrorEnum.AssetError.V(6)
        FIELD_INCOMPATIBLE_WITH_ASSET_TYPE = AssetErrorEnum.AssetError.V(7)
        INVALID_CALL_TO_ACTION_TEXT = AssetErrorEnum.AssetError.V(8)
        LEAD_FORM_INVALID_FIELDS_COMBINATION = AssetErrorEnum.AssetError.V(9)
        LEAD_FORM_MISSING_AGREEMENT = AssetErrorEnum.AssetError.V(10)
        INVALID_ASSET_STATUS = AssetErrorEnum.AssetError.V(11)
        FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(12)
    class AssetError(metaclass=_AssetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetErrorEnum.AssetError.V(0)
    UNKNOWN = AssetErrorEnum.AssetError.V(1)
    CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(13)
    DUPLICATE_ASSET = AssetErrorEnum.AssetError.V(3)
    DUPLICATE_ASSET_NAME = AssetErrorEnum.AssetError.V(4)
    ASSET_DATA_IS_MISSING = AssetErrorEnum.AssetError.V(5)
    CANNOT_MODIFY_ASSET_NAME = AssetErrorEnum.AssetError.V(6)
    FIELD_INCOMPATIBLE_WITH_ASSET_TYPE = AssetErrorEnum.AssetError.V(7)
    INVALID_CALL_TO_ACTION_TEXT = AssetErrorEnum.AssetError.V(8)
    LEAD_FORM_INVALID_FIELDS_COMBINATION = AssetErrorEnum.AssetError.V(9)
    LEAD_FORM_MISSING_AGREEMENT = AssetErrorEnum.AssetError.V(10)
    INVALID_ASSET_STATUS = AssetErrorEnum.AssetError.V(11)
    FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE = AssetErrorEnum.AssetError.V(12)
    def __init__(
        self,
    ) -> None: ...

global___AssetErrorEnum = AssetErrorEnum
