"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductTypeLevelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductTypeLevel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ProductTypeLevel.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductTypeLevelEnum.ProductTypeLevel.V(0)
        UNKNOWN = ProductTypeLevelEnum.ProductTypeLevel.V(1)
        LEVEL1 = ProductTypeLevelEnum.ProductTypeLevel.V(7)
        LEVEL2 = ProductTypeLevelEnum.ProductTypeLevel.V(8)
        LEVEL3 = ProductTypeLevelEnum.ProductTypeLevel.V(9)
        LEVEL4 = ProductTypeLevelEnum.ProductTypeLevel.V(10)
        LEVEL5 = ProductTypeLevelEnum.ProductTypeLevel.V(11)
    class ProductTypeLevel(metaclass=_ProductTypeLevel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductTypeLevelEnum.ProductTypeLevel.V(0)
    UNKNOWN = ProductTypeLevelEnum.ProductTypeLevel.V(1)
    LEVEL1 = ProductTypeLevelEnum.ProductTypeLevel.V(7)
    LEVEL2 = ProductTypeLevelEnum.ProductTypeLevel.V(8)
    LEVEL3 = ProductTypeLevelEnum.ProductTypeLevel.V(9)
    LEVEL4 = ProductTypeLevelEnum.ProductTypeLevel.V(10)
    LEVEL5 = ProductTypeLevelEnum.ProductTypeLevel.V(11)
    def __init__(
        self,
    ) -> None: ...

global___ProductTypeLevelEnum = ProductTypeLevelEnum
