"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import typing

from .google_ads_service_pb2 import *

class GoogleAdsServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def Search(
        self,
        request: global___SearchGoogleAdsRequest,
    ) -> global___SearchGoogleAdsResponse: ...
    def SearchStream(
        self,
        request: global___SearchGoogleAdsStreamRequest,
    ) -> typing.Iterator[global___SearchGoogleAdsStreamResponse]: ...
    def Mutate(
        self,
        request: global___MutateGoogleAdsRequest,
    ) -> global___MutateGoogleAdsResponse: ...

class GoogleAdsServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Search(
        self,
        request: global___SearchGoogleAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___SearchGoogleAdsResponse: ...
    @abc.abstractmethod
    def SearchStream(
        self,
        request: global___SearchGoogleAdsStreamRequest,
        context: grpc.ServicerContext,
    ) -> typing.Iterator[global___SearchGoogleAdsStreamResponse]: ...
    @abc.abstractmethod
    def Mutate(
        self,
        request: global___MutateGoogleAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateGoogleAdsResponse: ...

def add_GoogleAdsServiceServicer_to_server(
    servicer: GoogleAdsServiceServicer, server: grpc.Server
) -> None: ...
