"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetLinkError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetLinkErrorEnum.AssetLinkError.V(0)
        UNKNOWN = AssetLinkErrorEnum.AssetLinkError.V(1)
        PINNING_UNSUPPORTED = AssetLinkErrorEnum.AssetLinkError.V(2)
        UNSUPPORTED_FIELD_TYPE = AssetLinkErrorEnum.AssetLinkError.V(3)
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = AssetLinkErrorEnum.AssetLinkError.V(4)
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = (
            AssetLinkErrorEnum.AssetLinkError.V(5)
        )
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = AssetLinkErrorEnum.AssetLinkError.V(6)
        IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE = (
            AssetLinkErrorEnum.AssetLinkError.V(7)
        )
        INVALID_PINNED_FIELD = AssetLinkErrorEnum.AssetLinkError.V(8)
        MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE = AssetLinkErrorEnum.AssetLinkError.V(9)
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION = (
            AssetLinkErrorEnum.AssetLinkError.V(10)
        )
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK = (
            AssetLinkErrorEnum.AssetLinkError.V(11)
        )
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION = (
            AssetLinkErrorEnum.AssetLinkError.V(12)
        )
        YOUTUBE_VIDEO_REMOVED = AssetLinkErrorEnum.AssetLinkError.V(13)
        YOUTUBE_VIDEO_TOO_LONG = AssetLinkErrorEnum.AssetLinkError.V(14)
        YOUTUBE_VIDEO_TOO_SHORT = AssetLinkErrorEnum.AssetLinkError.V(15)
    class AssetLinkError(metaclass=_AssetLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetLinkErrorEnum.AssetLinkError.V(0)
    UNKNOWN = AssetLinkErrorEnum.AssetLinkError.V(1)
    PINNING_UNSUPPORTED = AssetLinkErrorEnum.AssetLinkError.V(2)
    UNSUPPORTED_FIELD_TYPE = AssetLinkErrorEnum.AssetLinkError.V(3)
    FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = AssetLinkErrorEnum.AssetLinkError.V(4)
    FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = AssetLinkErrorEnum.AssetLinkError.V(5)
    INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = AssetLinkErrorEnum.AssetLinkError.V(6)
    IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE = AssetLinkErrorEnum.AssetLinkError.V(7)
    INVALID_PINNED_FIELD = AssetLinkErrorEnum.AssetLinkError.V(8)
    MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE = AssetLinkErrorEnum.AssetLinkError.V(9)
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION = (
        AssetLinkErrorEnum.AssetLinkError.V(10)
    )
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK = (
        AssetLinkErrorEnum.AssetLinkError.V(11)
    )
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION = (
        AssetLinkErrorEnum.AssetLinkError.V(12)
    )
    YOUTUBE_VIDEO_REMOVED = AssetLinkErrorEnum.AssetLinkError.V(13)
    YOUTUBE_VIDEO_TOO_LONG = AssetLinkErrorEnum.AssetLinkError.V(14)
    YOUTUBE_VIDEO_TOO_SHORT = AssetLinkErrorEnum.AssetLinkError.V(15)
    def __init__(
        self,
    ) -> None: ...

global___AssetLinkErrorEnum = AssetLinkErrorEnum
