"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.distance_view_pb2
import grpc

from .distance_view_service_pb2 import *

class DistanceViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetDistanceView(
        self,
        request: global___GetDistanceViewRequest,
    ) -> google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView: ...

class DistanceViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDistanceView(
        self,
        request: global___GetDistanceViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView: ...

def add_DistanceViewServiceServicer_to_server(
    servicer: DistanceViewServiceServicer, server: grpc.Server
) -> None: ...
