"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryLocaleAvailabilityModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionCategoryLocaleAvailabilityMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CriterionCategoryLocaleAvailabilityMode.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            0
        )
        UNKNOWN = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            1
        )
        ALL_LOCALES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            2
        )
        COUNTRY_AND_ALL_LANGUAGES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            3
        )
        LANGUAGE_AND_ALL_COUNTRIES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            4
        )
        COUNTRY_AND_LANGUAGE = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            5
        )
    class CriterionCategoryLocaleAvailabilityMode(
        metaclass=_CriterionCategoryLocaleAvailabilityMode
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        0
    )
    UNKNOWN = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        1
    )
    ALL_LOCALES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        2
    )
    COUNTRY_AND_ALL_LANGUAGES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        3
    )
    LANGUAGE_AND_ALL_COUNTRIES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        4
    )
    COUNTRY_AND_LANGUAGE = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        5
    )
    def __init__(
        self,
    ) -> None: ...

global___CriterionCategoryLocaleAvailabilityModeEnum = (
    CriterionCategoryLocaleAvailabilityModeEnum
)
