"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraft(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    DRAFT_ID_FIELD_NUMBER: builtins.int
    BASE_CAMPAIGN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DRAFT_CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HAS_EXPERIMENT_RUNNING_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    draft_id: builtins.int = ...
    base_campaign: typing.Text = ...
    name: typing.Text = ...
    draft_campaign: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = (
        ...
    )
    has_experiment_running: builtins.bool = ...
    long_running_operation: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        draft_id: builtins.int = ...,
        base_campaign: typing.Text = ...,
        name: typing.Text = ...,
        draft_campaign: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = ...,
        has_experiment_running: builtins.bool = ...,
        long_running_operation: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_base_campaign", b"_base_campaign"],
    ) -> typing_extensions.Literal["base_campaign"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_draft_campaign", b"_draft_campaign"],
    ) -> typing_extensions.Literal["draft_campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_draft_id", b"_draft_id"]
    ) -> typing_extensions.Literal["draft_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_experiment_running", b"_has_experiment_running"
        ],
    ) -> typing_extensions.Literal["has_experiment_running"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions.Literal["long_running_operation"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___CampaignDraft = CampaignDraft
