"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PositiveGeoTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PositiveGeoTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PositiveGeoTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(0)
        UNKNOWN = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(1)
        PRESENCE_OR_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(5)
        SEARCH_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(6)
        PRESENCE = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(7)
    class PositiveGeoTargetType(metaclass=_PositiveGeoTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(0)
    UNKNOWN = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(1)
    PRESENCE_OR_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(5)
    SEARCH_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(6)
    PRESENCE = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PositiveGeoTargetTypeEnum = PositiveGeoTargetTypeEnum
