"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionSettingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionSettingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtensionSettingError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionSettingErrorEnum.ExtensionSettingError.V(0)
        UNKNOWN = ExtensionSettingErrorEnum.ExtensionSettingError.V(1)
        EXTENSIONS_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(2)
        FEED_TYPE_EXTENSION_TYPE_MISMATCH = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(3)
        )
        INVALID_FEED_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(4)
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(5)
        )
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(6)
        )
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(7)
        )
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(8)
        )
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(9)
        )
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(10)
        )
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(11)
        )
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(12)
        )
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(13)
        )
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(14)
        )
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(15)
        )
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(16)
        )
        VALUE_OUT_OF_RANGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(17)
        CANNOT_SET_FIELD_WITH_FINAL_URLS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(18)
        )
        FINAL_URLS_NOT_SET = ExtensionSettingErrorEnum.ExtensionSettingError.V(19)
        INVALID_PHONE_NUMBER = ExtensionSettingErrorEnum.ExtensionSettingError.V(20)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(21)
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(22)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(23)
        )
        DISALLOWED_NUMBER_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(24)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(25)
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(26)
        )
        INVALID_COUNTRY_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(27)
        INVALID_CALL_CONVERSION_TYPE_ID = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(28)
        )
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(69)
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(30)
        )
        INVALID_APP_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(31)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(32)
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(33)
        )
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(34)
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(35)
        )
        MISSING_FIELD = ExtensionSettingErrorEnum.ExtensionSettingError.V(36)
        INCONSISTENT_CURRENCY_CODES = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            37
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(38)
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(39)
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(40)
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(41)
        )
        UNSUPPORTED_VALUE = ExtensionSettingErrorEnum.ExtensionSettingError.V(42)
        INVALID_DEVICE_PREFERENCE = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            43
        )
        INVALID_SCHEDULE_END = ExtensionSettingErrorEnum.ExtensionSettingError.V(45)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(47)
        )
        OVERLAPPING_SCHEDULES_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(48)
        )
        SCHEDULE_END_NOT_AFTER_START = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(49)
        )
        TOO_MANY_SCHEDULES_PER_DAY = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            50
        )
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(51)
        )
        INVALID_SNIPPETS_HEADER = ExtensionSettingErrorEnum.ExtensionSettingError.V(52)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(53)
        )
        CAMPAIGN_TARGETING_MISMATCH = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            54
        )
        CANNOT_OPERATE_ON_REMOVED_FEED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(55)
        )
        EXTENSION_TYPE_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(56)
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(57)
        )
        START_DATE_AFTER_END_DATE = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            58
        )
        INVALID_PRICE_FORMAT = ExtensionSettingErrorEnum.ExtensionSettingError.V(59)
        PROMOTION_INVALID_TIME = ExtensionSettingErrorEnum.ExtensionSettingError.V(60)
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(61)
        )
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(62)
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(63)
        )
        INVALID_LANGUAGE_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(64)
        UNSUPPORTED_LANGUAGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(65)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(66)
        )
        EXTENSION_SETTING_UPDATE_IS_A_NOOP = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(67)
        )
        DISALLOWED_TEXT = ExtensionSettingErrorEnum.ExtensionSettingError.V(68)
    class ExtensionSettingError(metaclass=_ExtensionSettingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionSettingErrorEnum.ExtensionSettingError.V(0)
    UNKNOWN = ExtensionSettingErrorEnum.ExtensionSettingError.V(1)
    EXTENSIONS_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(2)
    FEED_TYPE_EXTENSION_TYPE_MISMATCH = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(3)
    )
    INVALID_FEED_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(4)
    INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(5)
    )
    CANNOT_CHANGE_FEED_ITEM_ON_CREATE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(6)
    )
    CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(7)
    )
    NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(8)
    )
    NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(9)
    )
    NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(10)
    )
    AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(11)
    )
    CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(12)
    )
    CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(13)
    )
    AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(14)
    )
    CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(15)
    )
    CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(16)
    )
    VALUE_OUT_OF_RANGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(17)
    CANNOT_SET_FIELD_WITH_FINAL_URLS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(18)
    )
    FINAL_URLS_NOT_SET = ExtensionSettingErrorEnum.ExtensionSettingError.V(19)
    INVALID_PHONE_NUMBER = ExtensionSettingErrorEnum.ExtensionSettingError.V(20)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(21)
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(22)
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        23
    )
    DISALLOWED_NUMBER_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(24)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(25)
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        26
    )
    INVALID_COUNTRY_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(27)
    INVALID_CALL_CONVERSION_TYPE_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        28
    )
    CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(69)
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(30)
    )
    INVALID_APP_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(31)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(32)
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(33)
    )
    REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(34)
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(35)
    )
    MISSING_FIELD = ExtensionSettingErrorEnum.ExtensionSettingError.V(36)
    INCONSISTENT_CURRENCY_CODES = ExtensionSettingErrorEnum.ExtensionSettingError.V(37)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(38)
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(39)
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(40)
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(41)
    )
    UNSUPPORTED_VALUE = ExtensionSettingErrorEnum.ExtensionSettingError.V(42)
    INVALID_DEVICE_PREFERENCE = ExtensionSettingErrorEnum.ExtensionSettingError.V(43)
    INVALID_SCHEDULE_END = ExtensionSettingErrorEnum.ExtensionSettingError.V(45)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(47)
    )
    OVERLAPPING_SCHEDULES_NOT_ALLOWED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(48)
    )
    SCHEDULE_END_NOT_AFTER_START = ExtensionSettingErrorEnum.ExtensionSettingError.V(49)
    TOO_MANY_SCHEDULES_PER_DAY = ExtensionSettingErrorEnum.ExtensionSettingError.V(50)
    DUPLICATE_EXTENSION_FEED_ITEM_EDIT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(51)
    )
    INVALID_SNIPPETS_HEADER = ExtensionSettingErrorEnum.ExtensionSettingError.V(52)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(53)
    )
    CAMPAIGN_TARGETING_MISMATCH = ExtensionSettingErrorEnum.ExtensionSettingError.V(54)
    CANNOT_OPERATE_ON_REMOVED_FEED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        55
    )
    EXTENSION_TYPE_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(56)
    INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(57)
    )
    START_DATE_AFTER_END_DATE = ExtensionSettingErrorEnum.ExtensionSettingError.V(58)
    INVALID_PRICE_FORMAT = ExtensionSettingErrorEnum.ExtensionSettingError.V(59)
    PROMOTION_INVALID_TIME = ExtensionSettingErrorEnum.ExtensionSettingError.V(60)
    PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(61)
    )
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(62)
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(63)
    )
    INVALID_LANGUAGE_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(64)
    UNSUPPORTED_LANGUAGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(65)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(66)
    )
    EXTENSION_SETTING_UPDATE_IS_A_NOOP = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(67)
    )
    DISALLOWED_TEXT = ExtensionSettingErrorEnum.ExtensionSettingError.V(68)
    def __init__(
        self,
    ) -> None: ...

global___ExtensionSettingErrorEnum = ExtensionSettingErrorEnum
