"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DistanceBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DistanceBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DistanceBucket.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DistanceBucketEnum.DistanceBucket.V(0)
        UNKNOWN = DistanceBucketEnum.DistanceBucket.V(1)
        WITHIN_700M = DistanceBucketEnum.DistanceBucket.V(2)
        WITHIN_1KM = DistanceBucketEnum.DistanceBucket.V(3)
        WITHIN_5KM = DistanceBucketEnum.DistanceBucket.V(4)
        WITHIN_10KM = DistanceBucketEnum.DistanceBucket.V(5)
        WITHIN_15KM = DistanceBucketEnum.DistanceBucket.V(6)
        WITHIN_20KM = DistanceBucketEnum.DistanceBucket.V(7)
        WITHIN_25KM = DistanceBucketEnum.DistanceBucket.V(8)
        WITHIN_30KM = DistanceBucketEnum.DistanceBucket.V(9)
        WITHIN_35KM = DistanceBucketEnum.DistanceBucket.V(10)
        WITHIN_40KM = DistanceBucketEnum.DistanceBucket.V(11)
        WITHIN_45KM = DistanceBucketEnum.DistanceBucket.V(12)
        WITHIN_50KM = DistanceBucketEnum.DistanceBucket.V(13)
        WITHIN_55KM = DistanceBucketEnum.DistanceBucket.V(14)
        WITHIN_60KM = DistanceBucketEnum.DistanceBucket.V(15)
        WITHIN_65KM = DistanceBucketEnum.DistanceBucket.V(16)
        BEYOND_65KM = DistanceBucketEnum.DistanceBucket.V(17)
        WITHIN_0_7MILES = DistanceBucketEnum.DistanceBucket.V(18)
        WITHIN_1MILE = DistanceBucketEnum.DistanceBucket.V(19)
        WITHIN_5MILES = DistanceBucketEnum.DistanceBucket.V(20)
        WITHIN_10MILES = DistanceBucketEnum.DistanceBucket.V(21)
        WITHIN_15MILES = DistanceBucketEnum.DistanceBucket.V(22)
        WITHIN_20MILES = DistanceBucketEnum.DistanceBucket.V(23)
        WITHIN_25MILES = DistanceBucketEnum.DistanceBucket.V(24)
        WITHIN_30MILES = DistanceBucketEnum.DistanceBucket.V(25)
        WITHIN_35MILES = DistanceBucketEnum.DistanceBucket.V(26)
        WITHIN_40MILES = DistanceBucketEnum.DistanceBucket.V(27)
        BEYOND_40MILES = DistanceBucketEnum.DistanceBucket.V(28)
    class DistanceBucket(metaclass=_DistanceBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DistanceBucketEnum.DistanceBucket.V(0)
    UNKNOWN = DistanceBucketEnum.DistanceBucket.V(1)
    WITHIN_700M = DistanceBucketEnum.DistanceBucket.V(2)
    WITHIN_1KM = DistanceBucketEnum.DistanceBucket.V(3)
    WITHIN_5KM = DistanceBucketEnum.DistanceBucket.V(4)
    WITHIN_10KM = DistanceBucketEnum.DistanceBucket.V(5)
    WITHIN_15KM = DistanceBucketEnum.DistanceBucket.V(6)
    WITHIN_20KM = DistanceBucketEnum.DistanceBucket.V(7)
    WITHIN_25KM = DistanceBucketEnum.DistanceBucket.V(8)
    WITHIN_30KM = DistanceBucketEnum.DistanceBucket.V(9)
    WITHIN_35KM = DistanceBucketEnum.DistanceBucket.V(10)
    WITHIN_40KM = DistanceBucketEnum.DistanceBucket.V(11)
    WITHIN_45KM = DistanceBucketEnum.DistanceBucket.V(12)
    WITHIN_50KM = DistanceBucketEnum.DistanceBucket.V(13)
    WITHIN_55KM = DistanceBucketEnum.DistanceBucket.V(14)
    WITHIN_60KM = DistanceBucketEnum.DistanceBucket.V(15)
    WITHIN_65KM = DistanceBucketEnum.DistanceBucket.V(16)
    BEYOND_65KM = DistanceBucketEnum.DistanceBucket.V(17)
    WITHIN_0_7MILES = DistanceBucketEnum.DistanceBucket.V(18)
    WITHIN_1MILE = DistanceBucketEnum.DistanceBucket.V(19)
    WITHIN_5MILES = DistanceBucketEnum.DistanceBucket.V(20)
    WITHIN_10MILES = DistanceBucketEnum.DistanceBucket.V(21)
    WITHIN_15MILES = DistanceBucketEnum.DistanceBucket.V(22)
    WITHIN_20MILES = DistanceBucketEnum.DistanceBucket.V(23)
    WITHIN_25MILES = DistanceBucketEnum.DistanceBucket.V(24)
    WITHIN_30MILES = DistanceBucketEnum.DistanceBucket.V(25)
    WITHIN_35MILES = DistanceBucketEnum.DistanceBucket.V(26)
    WITHIN_40MILES = DistanceBucketEnum.DistanceBucket.V(27)
    BEYOND_40MILES = DistanceBucketEnum.DistanceBucket.V(28)
    def __init__(
        self,
    ) -> None: ...

global___DistanceBucketEnum = DistanceBucketEnum
