"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2
import google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2
import google.ads.google_ads.v6.proto.enums.time_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudgetProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_FIELD_NUMBER: builtins.int
    PROPOSAL_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROPOSED_NAME_FIELD_NUMBER: builtins.int
    APPROVED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
    PROPOSED_NOTES_FIELD_NUMBER: builtins.int
    CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVAL_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_START_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    billing_setup: typing.Text = ...
    account_budget: typing.Text = ...
    proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V = (
        ...
    )
    proposed_name: typing.Text = ...
    approved_start_date_time: typing.Text = ...
    proposed_purchase_order_number: typing.Text = ...
    proposed_notes: typing.Text = ...
    creation_date_time: typing.Text = ...
    approval_date_time: typing.Text = ...
    proposed_start_date_time: typing.Text = ...
    proposed_start_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_end_date_time: typing.Text = ...
    proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    approved_end_date_time: typing.Text = ...
    approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_spending_limit_micros: builtins.int = ...
    proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    approved_spending_limit_micros: builtins.int = ...
    approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        billing_setup: typing.Text = ...,
        account_budget: typing.Text = ...,
        proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = ...,
        status: google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V = ...,
        proposed_name: typing.Text = ...,
        approved_start_date_time: typing.Text = ...,
        proposed_purchase_order_number: typing.Text = ...,
        proposed_notes: typing.Text = ...,
        creation_date_time: typing.Text = ...,
        approval_date_time: typing.Text = ...,
        proposed_start_date_time: typing.Text = ...,
        proposed_start_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_end_date_time: typing.Text = ...,
        proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        approved_end_date_time: typing.Text = ...,
        approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_spending_limit_micros: builtins.int = ...,
        proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        approved_spending_limit_micros: builtins.int = ...,
        approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_account_budget",
            b"_account_budget",
            "_approval_date_time",
            b"_approval_date_time",
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_creation_date_time",
            b"_creation_date_time",
            "_id",
            b"_id",
            "_proposed_name",
            b"_proposed_name",
            "_proposed_notes",
            b"_proposed_notes",
            "_proposed_purchase_order_number",
            b"_proposed_purchase_order_number",
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_account_budget",
            b"_account_budget",
            "_approval_date_time",
            b"_approval_date_time",
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_creation_date_time",
            b"_creation_date_time",
            "_id",
            b"_id",
            "_proposed_name",
            b"_proposed_name",
            "_proposed_notes",
            b"_proposed_notes",
            "_proposed_purchase_order_number",
            b"_proposed_purchase_order_number",
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposal_type",
            b"proposal_type",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_account_budget", b"_account_budget"],
    ) -> typing_extensions.Literal["account_budget"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approval_date_time", b"_approval_date_time"
        ],
    ) -> typing_extensions.Literal["approval_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions.Literal["approved_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions.Literal["billing_setup"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_creation_date_time", b"_creation_date_time"
        ],
    ) -> typing_extensions.Literal["creation_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_proposed_name", b"_proposed_name"],
    ) -> typing_extensions.Literal["proposed_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_proposed_notes", b"_proposed_notes"],
    ) -> typing_extensions.Literal["proposed_notes"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_proposed_purchase_order_number", b"_proposed_purchase_order_number"
        ],
    ) -> typing_extensions.Literal["proposed_purchase_order_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions.Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_start_time", b"proposed_start_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_start_date_time", "proposed_start_time_type"
    ]: ...

global___AccountBudgetProposal = AccountBudgetProposal
