"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExperimentStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignExperimentStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignExperimentStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(0)
        UNKNOWN = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(1)
        INITIALIZING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(2)
        INITIALIZATION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(
            8
        )
        ENABLED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(3)
        GRADUATED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(4)
        REMOVED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(5)
        PROMOTING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(6)
        PROMOTION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(9)
        PROMOTED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(7)
        ENDED_MANUALLY = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(10)
    class CampaignExperimentStatus(metaclass=_CampaignExperimentStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(0)
    UNKNOWN = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(1)
    INITIALIZING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(2)
    INITIALIZATION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(8)
    ENABLED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(3)
    GRADUATED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(4)
    REMOVED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(5)
    PROMOTING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(6)
    PROMOTION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(9)
    PROMOTED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(7)
    ENDED_MANUALLY = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(10)
    def __init__(
        self,
    ) -> None: ...

global___CampaignExperimentStatusEnum = CampaignExperimentStatusEnum
