"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AuthenticationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AuthenticationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AuthenticationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AuthenticationErrorEnum.AuthenticationError.V(0)
        UNKNOWN = AuthenticationErrorEnum.AuthenticationError.V(1)
        AUTHENTICATION_ERROR = AuthenticationErrorEnum.AuthenticationError.V(2)
        CLIENT_CUSTOMER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(5)
        CUSTOMER_NOT_FOUND = AuthenticationErrorEnum.AuthenticationError.V(8)
        GOOGLE_ACCOUNT_DELETED = AuthenticationErrorEnum.AuthenticationError.V(9)
        GOOGLE_ACCOUNT_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(
            10
        )
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = (
            AuthenticationErrorEnum.AuthenticationError.V(25)
        )
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = (
            AuthenticationErrorEnum.AuthenticationError.V(12)
        )
        LOGIN_COOKIE_REQUIRED = AuthenticationErrorEnum.AuthenticationError.V(13)
        NOT_ADS_USER = AuthenticationErrorEnum.AuthenticationError.V(14)
        OAUTH_TOKEN_INVALID = AuthenticationErrorEnum.AuthenticationError.V(15)
        OAUTH_TOKEN_EXPIRED = AuthenticationErrorEnum.AuthenticationError.V(16)
        OAUTH_TOKEN_DISABLED = AuthenticationErrorEnum.AuthenticationError.V(17)
        OAUTH_TOKEN_REVOKED = AuthenticationErrorEnum.AuthenticationError.V(18)
        OAUTH_TOKEN_HEADER_INVALID = AuthenticationErrorEnum.AuthenticationError.V(19)
        LOGIN_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(20)
        USER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(22)
        TWO_STEP_VERIFICATION_NOT_ENROLLED = (
            AuthenticationErrorEnum.AuthenticationError.V(23)
        )
        ADVANCED_PROTECTION_NOT_ENROLLED = (
            AuthenticationErrorEnum.AuthenticationError.V(24)
        )
    class AuthenticationError(metaclass=_AuthenticationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AuthenticationErrorEnum.AuthenticationError.V(0)
    UNKNOWN = AuthenticationErrorEnum.AuthenticationError.V(1)
    AUTHENTICATION_ERROR = AuthenticationErrorEnum.AuthenticationError.V(2)
    CLIENT_CUSTOMER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(5)
    CUSTOMER_NOT_FOUND = AuthenticationErrorEnum.AuthenticationError.V(8)
    GOOGLE_ACCOUNT_DELETED = AuthenticationErrorEnum.AuthenticationError.V(9)
    GOOGLE_ACCOUNT_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(10)
    GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = (
        AuthenticationErrorEnum.AuthenticationError.V(25)
    )
    GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = (
        AuthenticationErrorEnum.AuthenticationError.V(12)
    )
    LOGIN_COOKIE_REQUIRED = AuthenticationErrorEnum.AuthenticationError.V(13)
    NOT_ADS_USER = AuthenticationErrorEnum.AuthenticationError.V(14)
    OAUTH_TOKEN_INVALID = AuthenticationErrorEnum.AuthenticationError.V(15)
    OAUTH_TOKEN_EXPIRED = AuthenticationErrorEnum.AuthenticationError.V(16)
    OAUTH_TOKEN_DISABLED = AuthenticationErrorEnum.AuthenticationError.V(17)
    OAUTH_TOKEN_REVOKED = AuthenticationErrorEnum.AuthenticationError.V(18)
    OAUTH_TOKEN_HEADER_INVALID = AuthenticationErrorEnum.AuthenticationError.V(19)
    LOGIN_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(20)
    USER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(22)
    TWO_STEP_VERIFICATION_NOT_ENROLLED = AuthenticationErrorEnum.AuthenticationError.V(
        23
    )
    ADVANCED_PROTECTION_NOT_ENROLLED = AuthenticationErrorEnum.AuthenticationError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___AuthenticationErrorEnum = AuthenticationErrorEnum
