"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupTypeEnum.AdGroupType.V(0)
        UNKNOWN = AdGroupTypeEnum.AdGroupType.V(1)
        SEARCH_STANDARD = AdGroupTypeEnum.AdGroupType.V(2)
        DISPLAY_STANDARD = AdGroupTypeEnum.AdGroupType.V(3)
        SHOPPING_PRODUCT_ADS = AdGroupTypeEnum.AdGroupType.V(4)
        HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(6)
        SHOPPING_SMART_ADS = AdGroupTypeEnum.AdGroupType.V(7)
        VIDEO_BUMPER = AdGroupTypeEnum.AdGroupType.V(8)
        VIDEO_TRUE_VIEW_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(9)
        VIDEO_TRUE_VIEW_IN_DISPLAY = AdGroupTypeEnum.AdGroupType.V(10)
        VIDEO_NON_SKIPPABLE_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(11)
        VIDEO_OUTSTREAM = AdGroupTypeEnum.AdGroupType.V(12)
        SEARCH_DYNAMIC_ADS = AdGroupTypeEnum.AdGroupType.V(13)
        SHOPPING_COMPARISON_LISTING_ADS = AdGroupTypeEnum.AdGroupType.V(14)
        PROMOTED_HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(15)
        VIDEO_RESPONSIVE = AdGroupTypeEnum.AdGroupType.V(16)
    class AdGroupType(metaclass=_AdGroupType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupTypeEnum.AdGroupType.V(0)
    UNKNOWN = AdGroupTypeEnum.AdGroupType.V(1)
    SEARCH_STANDARD = AdGroupTypeEnum.AdGroupType.V(2)
    DISPLAY_STANDARD = AdGroupTypeEnum.AdGroupType.V(3)
    SHOPPING_PRODUCT_ADS = AdGroupTypeEnum.AdGroupType.V(4)
    HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(6)
    SHOPPING_SMART_ADS = AdGroupTypeEnum.AdGroupType.V(7)
    VIDEO_BUMPER = AdGroupTypeEnum.AdGroupType.V(8)
    VIDEO_TRUE_VIEW_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(9)
    VIDEO_TRUE_VIEW_IN_DISPLAY = AdGroupTypeEnum.AdGroupType.V(10)
    VIDEO_NON_SKIPPABLE_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(11)
    VIDEO_OUTSTREAM = AdGroupTypeEnum.AdGroupType.V(12)
    SEARCH_DYNAMIC_ADS = AdGroupTypeEnum.AdGroupType.V(13)
    SHOPPING_COMPARISON_LISTING_ADS = AdGroupTypeEnum.AdGroupType.V(14)
    PROMOTED_HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(15)
    VIDEO_RESPONSIVE = AdGroupTypeEnum.AdGroupType.V(16)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupTypeEnum = AdGroupTypeEnum
