"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LegacyAppInstallAdAppStoreEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LegacyAppInstallAdAppStore(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LegacyAppInstallAdAppStore.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(0)
        UNKNOWN = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(1)
        APPLE_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(2)
        GOOGLE_PLAY = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(3)
        WINDOWS_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(4)
        WINDOWS_PHONE_STORE = (
            LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(5)
        )
        CN_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(6)
    class LegacyAppInstallAdAppStore(metaclass=_LegacyAppInstallAdAppStore):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(0)
    UNKNOWN = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(1)
    APPLE_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(2)
    GOOGLE_PLAY = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(3)
    WINDOWS_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(4)
    WINDOWS_PHONE_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(5)
    CN_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(6)
    def __init__(
        self,
    ) -> None: ...

global___LegacyAppInstallAdAppStoreEnum = LegacyAppInstallAdAppStoreEnum
