"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QualityScoreBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QualityScoreBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            QualityScoreBucket.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QualityScoreBucketEnum.QualityScoreBucket.V(0)
        UNKNOWN = QualityScoreBucketEnum.QualityScoreBucket.V(1)
        BELOW_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(2)
        AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(3)
        ABOVE_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(4)
    class QualityScoreBucket(metaclass=_QualityScoreBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QualityScoreBucketEnum.QualityScoreBucket.V(0)
    UNKNOWN = QualityScoreBucketEnum.QualityScoreBucket.V(1)
    BELOW_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(2)
    AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(3)
    ABOVE_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(4)
    def __init__(
        self,
    ) -> None: ...

global___QualityScoreBucketEnum = QualityScoreBucketEnum
