"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PricePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PricePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PricePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PricePlaceholderFieldEnum.PricePlaceholderField.V(0)
        UNKNOWN = PricePlaceholderFieldEnum.PricePlaceholderField.V(1)
        TYPE = PricePlaceholderFieldEnum.PricePlaceholderField.V(2)
        PRICE_QUALIFIER = PricePlaceholderFieldEnum.PricePlaceholderField.V(3)
        TRACKING_TEMPLATE = PricePlaceholderFieldEnum.PricePlaceholderField.V(4)
        LANGUAGE = PricePlaceholderFieldEnum.PricePlaceholderField.V(5)
        FINAL_URL_SUFFIX = PricePlaceholderFieldEnum.PricePlaceholderField.V(6)
        ITEM_1_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(100)
        ITEM_1_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(101)
        ITEM_1_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(102)
        ITEM_1_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(103)
        ITEM_1_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(104)
        ITEM_1_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            105
        )
        ITEM_2_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(200)
        ITEM_2_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(201)
        ITEM_2_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(202)
        ITEM_2_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(203)
        ITEM_2_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(204)
        ITEM_2_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            205
        )
        ITEM_3_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(300)
        ITEM_3_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(301)
        ITEM_3_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(302)
        ITEM_3_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(303)
        ITEM_3_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(304)
        ITEM_3_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            305
        )
        ITEM_4_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(400)
        ITEM_4_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(401)
        ITEM_4_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(402)
        ITEM_4_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(403)
        ITEM_4_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(404)
        ITEM_4_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            405
        )
        ITEM_5_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(500)
        ITEM_5_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(501)
        ITEM_5_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(502)
        ITEM_5_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(503)
        ITEM_5_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(504)
        ITEM_5_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            505
        )
        ITEM_6_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(600)
        ITEM_6_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(601)
        ITEM_6_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(602)
        ITEM_6_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(603)
        ITEM_6_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(604)
        ITEM_6_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            605
        )
        ITEM_7_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(700)
        ITEM_7_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(701)
        ITEM_7_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(702)
        ITEM_7_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(703)
        ITEM_7_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(704)
        ITEM_7_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            705
        )
        ITEM_8_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(800)
        ITEM_8_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(801)
        ITEM_8_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(802)
        ITEM_8_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(803)
        ITEM_8_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(804)
        ITEM_8_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            805
        )
    class PricePlaceholderField(metaclass=_PricePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PricePlaceholderFieldEnum.PricePlaceholderField.V(0)
    UNKNOWN = PricePlaceholderFieldEnum.PricePlaceholderField.V(1)
    TYPE = PricePlaceholderFieldEnum.PricePlaceholderField.V(2)
    PRICE_QUALIFIER = PricePlaceholderFieldEnum.PricePlaceholderField.V(3)
    TRACKING_TEMPLATE = PricePlaceholderFieldEnum.PricePlaceholderField.V(4)
    LANGUAGE = PricePlaceholderFieldEnum.PricePlaceholderField.V(5)
    FINAL_URL_SUFFIX = PricePlaceholderFieldEnum.PricePlaceholderField.V(6)
    ITEM_1_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(100)
    ITEM_1_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(101)
    ITEM_1_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(102)
    ITEM_1_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(103)
    ITEM_1_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(104)
    ITEM_1_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(105)
    ITEM_2_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(200)
    ITEM_2_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(201)
    ITEM_2_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(202)
    ITEM_2_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(203)
    ITEM_2_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(204)
    ITEM_2_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(205)
    ITEM_3_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(300)
    ITEM_3_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(301)
    ITEM_3_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(302)
    ITEM_3_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(303)
    ITEM_3_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(304)
    ITEM_3_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(305)
    ITEM_4_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(400)
    ITEM_4_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(401)
    ITEM_4_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(402)
    ITEM_4_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(403)
    ITEM_4_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(404)
    ITEM_4_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(405)
    ITEM_5_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(500)
    ITEM_5_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(501)
    ITEM_5_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(502)
    ITEM_5_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(503)
    ITEM_5_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(504)
    ITEM_5_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(505)
    ITEM_6_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(600)
    ITEM_6_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(601)
    ITEM_6_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(602)
    ITEM_6_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(603)
    ITEM_6_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(604)
    ITEM_6_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(605)
    ITEM_7_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(700)
    ITEM_7_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(701)
    ITEM_7_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(702)
    ITEM_7_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(703)
    ITEM_7_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(704)
    ITEM_7_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(705)
    ITEM_8_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(800)
    ITEM_8_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(801)
    ITEM_8_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(802)
    ITEM_8_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(803)
    ITEM_8_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(804)
    ITEM_8_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(805)
    def __init__(
        self,
    ) -> None: ...

global___PricePlaceholderFieldEnum = PricePlaceholderFieldEnum
