"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TextLabel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    background_color: typing.Text = ...
    description: typing.Text = ...
    def __init__(
        self,
        *,
        background_color: typing.Text = ...,
        description: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_background_color", b"_background_color"
        ],
    ) -> typing_extensions.Literal["background_color"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...

global___TextLabel = TextLabel
