"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.offline_user_data_pb2
import google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CreateOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    JOB_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def job(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        job: typing.Optional[
            google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["job", b"job"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "job", b"job"
        ],
    ) -> None: ...

global___CreateOfflineUserDataJobRequest = CreateOfflineUserDataJobRequest

class CreateOfflineUserDataJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___CreateOfflineUserDataJobResponse = CreateOfflineUserDataJobResponse

class GetOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetOfflineUserDataJobRequest = GetOfflineUserDataJobRequest

class RunOfflineUserDataJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___RunOfflineUserDataJobRequest = RunOfflineUserDataJobRequest

class AddOfflineUserDataJobOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ENABLE_PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def enable_partial_failure(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___OfflineUserDataJobOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        enable_partial_failure: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        operations: typing.Optional[
            typing.Iterable[global___OfflineUserDataJobOperation]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "enable_partial_failure", b"enable_partial_failure"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "enable_partial_failure",
            b"enable_partial_failure",
            "operations",
            b"operations",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___AddOfflineUserDataJobOperationsRequest = AddOfflineUserDataJobOperationsRequest

class OfflineUserDataJobOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    REMOVE_ALL_FIELD_NUMBER: builtins.int
    remove_all: builtins.bool = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    @property
    def remove(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove_all: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "remove_all",
            b"remove_all",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove", "remove_all"]: ...

global___OfflineUserDataJobOperation = OfflineUserDataJobOperation

class AddOfflineUserDataJobOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> None: ...

global___AddOfflineUserDataJobOperationsResponse = (
    AddOfflineUserDataJobOperationsResponse
)
