"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_parameter_pb2
import grpc

from .ad_parameter_service_pb2 import *

class AdParameterServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdParameter(
        self,
        request: global___GetAdParameterRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_parameter_pb2.AdParameter: ...
    def MutateAdParameters(
        self,
        request: global___MutateAdParametersRequest,
    ) -> global___MutateAdParametersResponse: ...

class AdParameterServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdParameter(
        self,
        request: global___GetAdParameterRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_parameter_pb2.AdParameter: ...
    @abc.abstractmethod
    def MutateAdParameters(
        self,
        request: global___MutateAdParametersRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdParametersResponse: ...

def add_AdParameterServiceServicer_to_server(
    servicer: AdParameterServiceServicer, server: grpc.Server
) -> None: ...
