"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetImpressionShareLocationEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetImpressionShareLocation(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetImpressionShareLocation.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(
            0
        )
        UNKNOWN = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(1)
        ANYWHERE_ON_PAGE = (
            TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(2)
        )
        TOP_OF_PAGE = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(
            3
        )
        ABSOLUTE_TOP_OF_PAGE = (
            TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(4)
        )
    class TargetImpressionShareLocation(metaclass=_TargetImpressionShareLocation):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(0)
    UNKNOWN = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(1)
    ANYWHERE_ON_PAGE = (
        TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(2)
    )
    TOP_OF_PAGE = TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(3)
    ABSOLUTE_TOP_OF_PAGE = (
        TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___TargetImpressionShareLocationEnum = TargetImpressionShareLocationEnum
