"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.google_ads_field_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetGoogleAdsFieldRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetGoogleAdsFieldRequest = GetGoogleAdsFieldRequest

class SearchGoogleAdsFieldsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERY_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    query: typing.Text = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    def __init__(
        self,
        *,
        query: typing.Text = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "page_size", b"page_size", "page_token", b"page_token", "query", b"query"
        ],
    ) -> None: ...

global___SearchGoogleAdsFieldsRequest = SearchGoogleAdsFieldsRequest

class SearchGoogleAdsFieldsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_RESULTS_COUNT_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    total_results_count: builtins.int = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.resources.google_ads_field_pb2.GoogleAdsField
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.resources.google_ads_field_pb2.GoogleAdsField
            ]
        ] = ...,
        next_page_token: typing.Text = ...,
        total_results_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_results_count",
            b"total_results_count",
        ],
    ) -> None: ...

global___SearchGoogleAdsFieldsResponse = SearchGoogleAdsFieldsResponse
