"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .user_data_service_pb2 import *

class UserDataServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadUserData(
        self,
        request: global___UploadUserDataRequest,
    ) -> global___UploadUserDataResponse: ...

class UserDataServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadUserData(
        self,
        request: global___UploadUserDataRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadUserDataResponse: ...

def add_UserDataServiceServicer_to_server(
    servicer: UserDataServiceServicer, server: grpc.Server
) -> None: ...
