"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(0)
        UNKNOWN = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(1)
        STORE_SALES_UPLOAD_FIRST_PARTY = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(2)
        )
        STORE_SALES_UPLOAD_THIRD_PARTY = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(3)
        )
        CUSTOMER_MATCH_USER_LIST = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(
            4
        )
        CUSTOMER_MATCH_WITH_ATTRIBUTES = (
            OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(5)
        )
    class OfflineUserDataJobType(metaclass=_OfflineUserDataJobType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(0)
    UNKNOWN = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(1)
    STORE_SALES_UPLOAD_FIRST_PARTY = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(2)
    )
    STORE_SALES_UPLOAD_THIRD_PARTY = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(3)
    )
    CUSTOMER_MATCH_USER_LIST = OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(4)
    CUSTOMER_MATCH_WITH_ATTRIBUTES = (
        OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobTypeEnum = OfflineUserDataJobTypeEnum
