"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FunctionParsingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FunctionParsingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FunctionParsingError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FunctionParsingErrorEnum.FunctionParsingError.V(0)
        UNKNOWN = FunctionParsingErrorEnum.FunctionParsingError.V(1)
        NO_MORE_INPUT = FunctionParsingErrorEnum.FunctionParsingError.V(2)
        EXPECTED_CHARACTER = FunctionParsingErrorEnum.FunctionParsingError.V(3)
        UNEXPECTED_SEPARATOR = FunctionParsingErrorEnum.FunctionParsingError.V(4)
        UNMATCHED_LEFT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(5)
        UNMATCHED_RIGHT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(6)
        TOO_MANY_NESTED_FUNCTIONS = FunctionParsingErrorEnum.FunctionParsingError.V(7)
        MISSING_RIGHT_HAND_OPERAND = FunctionParsingErrorEnum.FunctionParsingError.V(8)
        INVALID_OPERATOR_NAME = FunctionParsingErrorEnum.FunctionParsingError.V(9)
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = (
            FunctionParsingErrorEnum.FunctionParsingError.V(10)
        )
        NO_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(11)
        TOO_MANY_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(12)
    class FunctionParsingError(metaclass=_FunctionParsingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FunctionParsingErrorEnum.FunctionParsingError.V(0)
    UNKNOWN = FunctionParsingErrorEnum.FunctionParsingError.V(1)
    NO_MORE_INPUT = FunctionParsingErrorEnum.FunctionParsingError.V(2)
    EXPECTED_CHARACTER = FunctionParsingErrorEnum.FunctionParsingError.V(3)
    UNEXPECTED_SEPARATOR = FunctionParsingErrorEnum.FunctionParsingError.V(4)
    UNMATCHED_LEFT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(5)
    UNMATCHED_RIGHT_BRACKET = FunctionParsingErrorEnum.FunctionParsingError.V(6)
    TOO_MANY_NESTED_FUNCTIONS = FunctionParsingErrorEnum.FunctionParsingError.V(7)
    MISSING_RIGHT_HAND_OPERAND = FunctionParsingErrorEnum.FunctionParsingError.V(8)
    INVALID_OPERATOR_NAME = FunctionParsingErrorEnum.FunctionParsingError.V(9)
    FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = (
        FunctionParsingErrorEnum.FunctionParsingError.V(10)
    )
    NO_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(11)
    TOO_MANY_OPERANDS = FunctionParsingErrorEnum.FunctionParsingError.V(12)
    def __init__(
        self,
    ) -> None: ...

global___FunctionParsingErrorEnum = FunctionParsingErrorEnum
