"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2
import grpc

from .campaign_shared_set_service_pb2 import *

class CampaignSharedSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignSharedSet(
        self,
        request: global___GetCampaignSharedSetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2.CampaignSharedSet: ...
    def MutateCampaignSharedSets(
        self,
        request: global___MutateCampaignSharedSetsRequest,
    ) -> global___MutateCampaignSharedSetsResponse: ...

class CampaignSharedSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignSharedSet(
        self,
        request: global___GetCampaignSharedSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_shared_set_pb2.CampaignSharedSet: ...
    @abc.abstractmethod
    def MutateCampaignSharedSets(
        self,
        request: global___MutateCampaignSharedSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignSharedSetsResponse: ...

def add_CampaignSharedSetServiceServicer_to_server(
    servicer: CampaignSharedSetServiceServicer, server: grpc.Server
) -> None: ...
