"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanNetworkEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanNetwork(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            KeywordPlanNetwork.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(0)
        UNKNOWN = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(1)
        GOOGLE_SEARCH = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(2)
        GOOGLE_SEARCH_AND_PARTNERS = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(3)
    class KeywordPlanNetwork(metaclass=_KeywordPlanNetwork):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(0)
    UNKNOWN = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(1)
    GOOGLE_SEARCH = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(2)
    GOOGLE_SEARCH_AND_PARTNERS = KeywordPlanNetworkEnum.KeywordPlanNetwork.V(3)
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanNetworkEnum = KeywordPlanNetworkEnum
