"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ManagerLinkStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ManagerLinkStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ManagerLinkStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ManagerLinkStatusEnum.ManagerLinkStatus.V(0)
        UNKNOWN = ManagerLinkStatusEnum.ManagerLinkStatus.V(1)
        ACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(2)
        INACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(3)
        PENDING = ManagerLinkStatusEnum.ManagerLinkStatus.V(4)
        REFUSED = ManagerLinkStatusEnum.ManagerLinkStatus.V(5)
        CANCELED = ManagerLinkStatusEnum.ManagerLinkStatus.V(6)
    class ManagerLinkStatus(metaclass=_ManagerLinkStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ManagerLinkStatusEnum.ManagerLinkStatus.V(0)
    UNKNOWN = ManagerLinkStatusEnum.ManagerLinkStatus.V(1)
    ACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(2)
    INACTIVE = ManagerLinkStatusEnum.ManagerLinkStatus.V(3)
    PENDING = ManagerLinkStatusEnum.ManagerLinkStatus.V(4)
    REFUSED = ManagerLinkStatusEnum.ManagerLinkStatus.V(5)
    CANCELED = ManagerLinkStatusEnum.ManagerLinkStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ManagerLinkStatusEnum = ManagerLinkStatusEnum
