"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2
import google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2
import google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = (
        ...
    )
    type: google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def description(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def members(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CustomInterestMember
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        status: google.ads.google_ads.v5.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        type: google.ads.google_ads.v5.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = ...,
        description: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        members: typing.Optional[typing.Iterable[global___CustomInterestMember]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "description", b"description", "id", b"id", "name", b"name"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "description",
            b"description",
            "id",
            b"id",
            "members",
            b"members",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CustomInterest = CustomInterest

class CustomInterestMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEMBER_TYPE_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    member_type: google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = (
        ...
    )
    @property
    def parameter(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        member_type: google.ads.google_ads.v5.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = ...,
        parameter: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["parameter", b"parameter"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "member_type", b"member_type", "parameter", b"parameter"
        ],
    ) -> None: ...

global___CustomInterestMember = CustomInterestMember
