"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FieldMaskErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FieldMaskError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FieldMaskError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FieldMaskErrorEnum.FieldMaskError.V(0)
        UNKNOWN = FieldMaskErrorEnum.FieldMaskError.V(1)
        FIELD_MASK_MISSING = FieldMaskErrorEnum.FieldMaskError.V(5)
        FIELD_MASK_NOT_ALLOWED = FieldMaskErrorEnum.FieldMaskError.V(4)
        FIELD_NOT_FOUND = FieldMaskErrorEnum.FieldMaskError.V(2)
        FIELD_HAS_SUBFIELDS = FieldMaskErrorEnum.FieldMaskError.V(3)
    class FieldMaskError(metaclass=_FieldMaskError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FieldMaskErrorEnum.FieldMaskError.V(0)
    UNKNOWN = FieldMaskErrorEnum.FieldMaskError.V(1)
    FIELD_MASK_MISSING = FieldMaskErrorEnum.FieldMaskError.V(5)
    FIELD_MASK_NOT_ALLOWED = FieldMaskErrorEnum.FieldMaskError.V(4)
    FIELD_NOT_FOUND = FieldMaskErrorEnum.FieldMaskError.V(2)
    FIELD_HAS_SUBFIELDS = FieldMaskErrorEnum.FieldMaskError.V(3)
    def __init__(
        self,
    ) -> None: ...

global___FieldMaskErrorEnum = FieldMaskErrorEnum
