"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DatabaseErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DatabaseError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DatabaseError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DatabaseErrorEnum.DatabaseError.V(0)
        UNKNOWN = DatabaseErrorEnum.DatabaseError.V(1)
        CONCURRENT_MODIFICATION = DatabaseErrorEnum.DatabaseError.V(2)
        DATA_CONSTRAINT_VIOLATION = DatabaseErrorEnum.DatabaseError.V(3)
        REQUEST_TOO_LARGE = DatabaseErrorEnum.DatabaseError.V(4)
    class DatabaseError(metaclass=_DatabaseError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DatabaseErrorEnum.DatabaseError.V(0)
    UNKNOWN = DatabaseErrorEnum.DatabaseError.V(1)
    CONCURRENT_MODIFICATION = DatabaseErrorEnum.DatabaseError.V(2)
    DATA_CONSTRAINT_VIOLATION = DatabaseErrorEnum.DatabaseError.V(3)
    REQUEST_TOO_LARGE = DatabaseErrorEnum.DatabaseError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___DatabaseErrorEnum = DatabaseErrorEnum
