"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExternalConversionSourceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExternalConversionSource(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExternalConversionSource.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(0)
        UNKNOWN = ExternalConversionSourceEnum.ExternalConversionSource.V(1)
        WEBPAGE = ExternalConversionSourceEnum.ExternalConversionSource.V(2)
        ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(3)
        UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(4)
        AD_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(5)
        WEBSITE_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(
            6
        )
        STORE_VISITS = ExternalConversionSourceEnum.ExternalConversionSource.V(7)
        ANDROID_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(8)
        IOS_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(9)
        IOS_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(10)
        APP_UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(11)
        ANDROID_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(12)
        UPLOAD_CALLS = ExternalConversionSourceEnum.ExternalConversionSource.V(13)
        FIREBASE = ExternalConversionSourceEnum.ExternalConversionSource.V(14)
        CLICK_TO_CALL = ExternalConversionSourceEnum.ExternalConversionSource.V(15)
        SALESFORCE = ExternalConversionSourceEnum.ExternalConversionSource.V(16)
        STORE_SALES_CRM = ExternalConversionSourceEnum.ExternalConversionSource.V(17)
        STORE_SALES_PAYMENT_NETWORK = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(18)
        )
        GOOGLE_PLAY = ExternalConversionSourceEnum.ExternalConversionSource.V(19)
        THIRD_PARTY_APP_ANALYTICS = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(20)
        )
        GOOGLE_ATTRIBUTION = ExternalConversionSourceEnum.ExternalConversionSource.V(21)
        STORE_SALES_DIRECT_UPLOAD = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(23)
        )
        STORE_SALES = ExternalConversionSourceEnum.ExternalConversionSource.V(24)
        SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(25)
        GOOGLE_HOSTED = ExternalConversionSourceEnum.ExternalConversionSource.V(27)
        FLOODLIGHT = ExternalConversionSourceEnum.ExternalConversionSource.V(29)
        ANALYTICS_SEARCH_ADS_360 = (
            ExternalConversionSourceEnum.ExternalConversionSource.V(31)
        )
    class ExternalConversionSource(metaclass=_ExternalConversionSource):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(0)
    UNKNOWN = ExternalConversionSourceEnum.ExternalConversionSource.V(1)
    WEBPAGE = ExternalConversionSourceEnum.ExternalConversionSource.V(2)
    ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(3)
    UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(4)
    AD_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(5)
    WEBSITE_CALL_METRICS = ExternalConversionSourceEnum.ExternalConversionSource.V(6)
    STORE_VISITS = ExternalConversionSourceEnum.ExternalConversionSource.V(7)
    ANDROID_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(8)
    IOS_IN_APP = ExternalConversionSourceEnum.ExternalConversionSource.V(9)
    IOS_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(10)
    APP_UNSPECIFIED = ExternalConversionSourceEnum.ExternalConversionSource.V(11)
    ANDROID_FIRST_OPEN = ExternalConversionSourceEnum.ExternalConversionSource.V(12)
    UPLOAD_CALLS = ExternalConversionSourceEnum.ExternalConversionSource.V(13)
    FIREBASE = ExternalConversionSourceEnum.ExternalConversionSource.V(14)
    CLICK_TO_CALL = ExternalConversionSourceEnum.ExternalConversionSource.V(15)
    SALESFORCE = ExternalConversionSourceEnum.ExternalConversionSource.V(16)
    STORE_SALES_CRM = ExternalConversionSourceEnum.ExternalConversionSource.V(17)
    STORE_SALES_PAYMENT_NETWORK = (
        ExternalConversionSourceEnum.ExternalConversionSource.V(18)
    )
    GOOGLE_PLAY = ExternalConversionSourceEnum.ExternalConversionSource.V(19)
    THIRD_PARTY_APP_ANALYTICS = ExternalConversionSourceEnum.ExternalConversionSource.V(
        20
    )
    GOOGLE_ATTRIBUTION = ExternalConversionSourceEnum.ExternalConversionSource.V(21)
    STORE_SALES_DIRECT_UPLOAD = ExternalConversionSourceEnum.ExternalConversionSource.V(
        23
    )
    STORE_SALES = ExternalConversionSourceEnum.ExternalConversionSource.V(24)
    SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(25)
    GOOGLE_HOSTED = ExternalConversionSourceEnum.ExternalConversionSource.V(27)
    FLOODLIGHT = ExternalConversionSourceEnum.ExternalConversionSource.V(29)
    ANALYTICS_SEARCH_ADS_360 = ExternalConversionSourceEnum.ExternalConversionSource.V(
        31
    )
    def __init__(
        self,
    ) -> None: ...

global___ExternalConversionSourceEnum = ExternalConversionSourceEnum
