"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignFeedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignFeedErrorEnum.CampaignFeedError.V(0)
        UNKNOWN = CampaignFeedErrorEnum.CampaignFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            CampaignFeedErrorEnum.CampaignFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(4)
        CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED = (
            CampaignFeedErrorEnum.CampaignFeedError.V(5)
        )
        CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(
            6
        )
        INVALID_PLACEHOLDER_TYPE = CampaignFeedErrorEnum.CampaignFeedError.V(7)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            CampaignFeedErrorEnum.CampaignFeedError.V(8)
        )
        NO_EXISTING_LOCATION_CUSTOMER_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(
            9
        )
    class CampaignFeedError(metaclass=_CampaignFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignFeedErrorEnum.CampaignFeedError.V(0)
    UNKNOWN = CampaignFeedErrorEnum.CampaignFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        CampaignFeedErrorEnum.CampaignFeedError.V(2)
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(4)
    CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED = (
        CampaignFeedErrorEnum.CampaignFeedError.V(5)
    )
    CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(6)
    INVALID_PLACEHOLDER_TYPE = CampaignFeedErrorEnum.CampaignFeedError.V(7)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
        CampaignFeedErrorEnum.CampaignFeedError.V(8)
    )
    NO_EXISTING_LOCATION_CUSTOMER_FEED = CampaignFeedErrorEnum.CampaignFeedError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___CampaignFeedErrorEnum = CampaignFeedErrorEnum
