"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CurrencyConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYMBOL_FIELD_NUMBER: builtins.int
    BILLABLE_UNIT_MICROS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    code: typing.Text = ...
    name: typing.Text = ...
    symbol: typing.Text = ...
    billable_unit_micros: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        code: typing.Text = ...,
        name: typing.Text = ...,
        symbol: typing.Text = ...,
        billable_unit_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "symbol",
            b"symbol",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "symbol",
            b"symbol",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_billable_unit_micros", b"_billable_unit_micros"
        ],
    ) -> typing_extensions.Literal["billable_unit_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_code", b"_code"]
    ) -> typing_extensions.Literal["code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_symbol", b"_symbol"]
    ) -> typing_extensions.Literal["symbol"]: ...

global___CurrencyConstant = CurrencyConstant
