"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QuotaErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QuotaError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QuotaErrorEnum.QuotaError.V(0)
        UNKNOWN = QuotaErrorEnum.QuotaError.V(1)
        RESOURCE_EXHAUSTED = QuotaErrorEnum.QuotaError.V(2)
        ACCESS_PROHIBITED = QuotaErrorEnum.QuotaError.V(3)
        RESOURCE_TEMPORARILY_EXHAUSTED = QuotaErrorEnum.QuotaError.V(4)
    class QuotaError(metaclass=_QuotaError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QuotaErrorEnum.QuotaError.V(0)
    UNKNOWN = QuotaErrorEnum.QuotaError.V(1)
    RESOURCE_EXHAUSTED = QuotaErrorEnum.QuotaError.V(2)
    ACCESS_PROHIBITED = QuotaErrorEnum.QuotaError.V(3)
    RESOURCE_TEMPORARILY_EXHAUSTED = QuotaErrorEnum.QuotaError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___QuotaErrorEnum = QuotaErrorEnum
