"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _KeywordPlanError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KeywordPlanError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = KeywordPlanErrorEnum.KeywordPlanError.V(0)
        UNKNOWN = KeywordPlanErrorEnum.KeywordPlanError.V(1)
        BID_MULTIPLIER_OUT_OF_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(2)
        BID_TOO_HIGH = KeywordPlanErrorEnum.KeywordPlanError.V(3)
        BID_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(4)
        BID_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(5)
        DAILY_BUDGET_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(6)
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = (
            KeywordPlanErrorEnum.KeywordPlanError.V(7)
        )
        INVALID_VALUE = KeywordPlanErrorEnum.KeywordPlanError.V(8)
        KEYWORD_PLAN_HAS_NO_KEYWORDS = KeywordPlanErrorEnum.KeywordPlanError.V(9)
        KEYWORD_PLAN_NOT_ENABLED = KeywordPlanErrorEnum.KeywordPlanError.V(10)
        KEYWORD_PLAN_NOT_FOUND = KeywordPlanErrorEnum.KeywordPlanError.V(11)
        MISSING_BID = KeywordPlanErrorEnum.KeywordPlanError.V(13)
        MISSING_FORECAST_PERIOD = KeywordPlanErrorEnum.KeywordPlanError.V(14)
        INVALID_FORECAST_DATE_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(15)
        INVALID_NAME = KeywordPlanErrorEnum.KeywordPlanError.V(16)
    class KeywordPlanError(metaclass=_KeywordPlanError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = KeywordPlanErrorEnum.KeywordPlanError.V(0)
    UNKNOWN = KeywordPlanErrorEnum.KeywordPlanError.V(1)
    BID_MULTIPLIER_OUT_OF_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(2)
    BID_TOO_HIGH = KeywordPlanErrorEnum.KeywordPlanError.V(3)
    BID_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(4)
    BID_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(5)
    DAILY_BUDGET_TOO_LOW = KeywordPlanErrorEnum.KeywordPlanError.V(6)
    DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = KeywordPlanErrorEnum.KeywordPlanError.V(7)
    INVALID_VALUE = KeywordPlanErrorEnum.KeywordPlanError.V(8)
    KEYWORD_PLAN_HAS_NO_KEYWORDS = KeywordPlanErrorEnum.KeywordPlanError.V(9)
    KEYWORD_PLAN_NOT_ENABLED = KeywordPlanErrorEnum.KeywordPlanError.V(10)
    KEYWORD_PLAN_NOT_FOUND = KeywordPlanErrorEnum.KeywordPlanError.V(11)
    MISSING_BID = KeywordPlanErrorEnum.KeywordPlanError.V(13)
    MISSING_FORECAST_PERIOD = KeywordPlanErrorEnum.KeywordPlanError.V(14)
    INVALID_FORECAST_DATE_RANGE = KeywordPlanErrorEnum.KeywordPlanError.V(15)
    INVALID_NAME = KeywordPlanErrorEnum.KeywordPlanError.V(16)
    def __init__(
        self,
    ) -> None: ...

global___KeywordPlanErrorEnum = KeywordPlanErrorEnum
