"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.shared_set_pb2
import grpc

from .shared_set_service_pb2 import *

class SharedSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetSharedSet(
        self,
        request: global___GetSharedSetRequest,
    ) -> google.ads.google_ads.v5.proto.resources.shared_set_pb2.SharedSet: ...
    def MutateSharedSets(
        self,
        request: global___MutateSharedSetsRequest,
    ) -> global___MutateSharedSetsResponse: ...

class SharedSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSharedSet(
        self,
        request: global___GetSharedSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.shared_set_pb2.SharedSet: ...
    @abc.abstractmethod
    def MutateSharedSets(
        self,
        request: global___MutateSharedSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateSharedSetsResponse: ...

def add_SharedSetServiceServicer_to_server(
    servicer: SharedSetServiceServicer, server: grpc.Server
) -> None: ...
