"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.month_of_year_pb2
import google.ads.google_ads.v4.proto.resources.invoice_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListInvoicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    ISSUE_YEAR_FIELD_NUMBER: builtins.int
    ISSUE_MONTH_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    billing_setup: typing.Text = ...
    issue_year: typing.Text = ...
    issue_month: google.ads.google_ads.v4.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        billing_setup: typing.Text = ...,
        issue_year: typing.Text = ...,
        issue_month: google.ads.google_ads.v4.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "billing_setup",
            b"billing_setup",
            "customer_id",
            b"customer_id",
            "issue_month",
            b"issue_month",
            "issue_year",
            b"issue_year",
        ],
    ) -> None: ...

global___ListInvoicesRequest = ListInvoicesRequest

class ListInvoicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INVOICES_FIELD_NUMBER: builtins.int
    @property
    def invoices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.resources.invoice_pb2.Invoice
    ]: ...
    def __init__(
        self,
        *,
        invoices: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.resources.invoice_pb2.Invoice
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["invoices", b"invoices"]
    ) -> None: ...

global___ListInvoicesResponse = ListInvoicesResponse
