"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            HotelPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(0)
        UNKNOWN = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(1)
        PROPERTY_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(2)
        PROPERTY_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(3)
        DESTINATION_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(4)
        DESCRIPTION = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(5)
        ADDRESS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(6)
        PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(7)
        FORMATTED_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(8)
        SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(10)
        IMAGE_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(11)
        CATEGORY = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(12)
        STAR_RATING = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(13)
        CONTEXTUAL_KEYWORDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(14)
        FINAL_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(15)
        FINAL_MOBILE_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(16)
        TRACKING_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(17)
        ANDROID_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(18)
        SIMILAR_PROPERTY_IDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(19)
        IOS_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(20)
        IOS_APP_STORE_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(21)
    class HotelPlaceholderField(metaclass=_HotelPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(0)
    UNKNOWN = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(1)
    PROPERTY_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(2)
    PROPERTY_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(3)
    DESTINATION_NAME = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(4)
    DESCRIPTION = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(5)
    ADDRESS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(6)
    PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(7)
    FORMATTED_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(8)
    SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(10)
    IMAGE_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(11)
    CATEGORY = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(12)
    STAR_RATING = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(13)
    CONTEXTUAL_KEYWORDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(14)
    FINAL_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(15)
    FINAL_MOBILE_URLS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(16)
    TRACKING_URL = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(17)
    ANDROID_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(18)
    SIMILAR_PROPERTY_IDS = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(19)
    IOS_APP_LINK = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(20)
    IOS_APP_STORE_ID = HotelPlaceholderFieldEnum.HotelPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___HotelPlaceholderFieldEnum = HotelPlaceholderFieldEnum
