"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.placeholder_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedPlaceholderView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placeholder_type: google.ads.google_ads.v4.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placeholder_type: google.ads.google_ads.v4.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "placeholder_type", b"placeholder_type", "resource_name", b"resource_name"
        ],
    ) -> None: ...

global___FeedPlaceholderView = FeedPlaceholderView
