"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyTopicEntryTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyTopicEntryType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyTopicEntryType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(0)
        UNKNOWN = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(1)
        PROHIBITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(2)
        LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(4)
        FULLY_LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(8)
        DESCRIPTIVE = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(5)
        BROADENING = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(6)
        AREA_OF_INTEREST_ONLY = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(7)
    class PolicyTopicEntryType(metaclass=_PolicyTopicEntryType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(0)
    UNKNOWN = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(1)
    PROHIBITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(2)
    LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(4)
    FULLY_LIMITED = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(8)
    DESCRIPTIVE = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(5)
    BROADENING = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(6)
    AREA_OF_INTEREST_ONLY = PolicyTopicEntryTypeEnum.PolicyTopicEntryType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PolicyTopicEntryTypeEnum = PolicyTopicEntryTypeEnum
