"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    start_date: typing.Text = ...
    end_date: typing.Text = ...
    def __init__(
        self,
        *,
        start_date: typing.Text = ...,
        end_date: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "end_date",
            b"end_date",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_end_date", b"_end_date"]
    ) -> typing_extensions.Literal["end_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_date", b"_start_date"]
    ) -> typing_extensions.Literal["start_date"]: ...

global___DateRange = DateRange
