"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemSetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedItemSetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemSetErrorEnum.FeedItemSetError.V(0)
        UNKNOWN = FeedItemSetErrorEnum.FeedItemSetError.V(1)
        FEED_ITEM_SET_REMOVED = FeedItemSetErrorEnum.FeedItemSetError.V(2)
        CANNOT_CLEAR_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(3)
        CANNOT_CREATE_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(4)
        INVALID_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(5)
        DUPLICATE_NAME = FeedItemSetErrorEnum.FeedItemSetError.V(6)
        WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(7)
    class FeedItemSetError(metaclass=_FeedItemSetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemSetErrorEnum.FeedItemSetError.V(0)
    UNKNOWN = FeedItemSetErrorEnum.FeedItemSetError.V(1)
    FEED_ITEM_SET_REMOVED = FeedItemSetErrorEnum.FeedItemSetError.V(2)
    CANNOT_CLEAR_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(3)
    CANNOT_CREATE_DYNAMIC_FILTER = FeedItemSetErrorEnum.FeedItemSetError.V(4)
    INVALID_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(5)
    DUPLICATE_NAME = FeedItemSetErrorEnum.FeedItemSetError.V(6)
    WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE = FeedItemSetErrorEnum.FeedItemSetError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemSetErrorEnum = FeedItemSetErrorEnum
