"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionErrorEnum.ConversionActionError.V(0)
        UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(1)
        DUPLICATE_NAME = ConversionActionErrorEnum.ConversionActionError.V(2)
        DUPLICATE_APP_ID = ConversionActionErrorEnum.ConversionActionError.V(3)
        TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = (
            ConversionActionErrorEnum.ConversionActionError.V(4)
        )
        BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = (
            ConversionActionErrorEnum.ConversionActionError.V(5)
        )
        DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = (
            ConversionActionErrorEnum.ConversionActionError.V(6)
        )
        DATA_DRIVEN_MODEL_EXPIRED = ConversionActionErrorEnum.ConversionActionError.V(7)
        DATA_DRIVEN_MODEL_STALE = ConversionActionErrorEnum.ConversionActionError.V(8)
        DATA_DRIVEN_MODEL_UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(9)
        CREATION_NOT_SUPPORTED = ConversionActionErrorEnum.ConversionActionError.V(10)
    class ConversionActionError(metaclass=_ConversionActionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionErrorEnum.ConversionActionError.V(0)
    UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(1)
    DUPLICATE_NAME = ConversionActionErrorEnum.ConversionActionError.V(2)
    DUPLICATE_APP_ID = ConversionActionErrorEnum.ConversionActionError.V(3)
    TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = (
        ConversionActionErrorEnum.ConversionActionError.V(4)
    )
    BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = (
        ConversionActionErrorEnum.ConversionActionError.V(5)
    )
    DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = (
        ConversionActionErrorEnum.ConversionActionError.V(6)
    )
    DATA_DRIVEN_MODEL_EXPIRED = ConversionActionErrorEnum.ConversionActionError.V(7)
    DATA_DRIVEN_MODEL_STALE = ConversionActionErrorEnum.ConversionActionError.V(8)
    DATA_DRIVEN_MODEL_UNKNOWN = ConversionActionErrorEnum.ConversionActionError.V(9)
    CREATION_NOT_SUPPORTED = ConversionActionErrorEnum.ConversionActionError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionErrorEnum = ConversionActionErrorEnum
