"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2
import grpc

from .ad_group_feed_service_pb2 import *

class AdGroupFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupFeed(
        self,
        request: global___GetAdGroupFeedRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
    def MutateAdGroupFeeds(
        self,
        request: global___MutateAdGroupFeedsRequest,
    ) -> global___MutateAdGroupFeedsResponse: ...

class AdGroupFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupFeed(
        self,
        request: global___GetAdGroupFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
    @abc.abstractmethod
    def MutateAdGroupFeeds(
        self,
        request: global___MutateAdGroupFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupFeedsResponse: ...

def add_AdGroupFeedServiceServicer_to_server(
    servicer: AdGroupFeedServiceServicer, server: grpc.Server
) -> None: ...
