"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_feed_pb2
import grpc

from .customer_feed_service_pb2 import *

class CustomerFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerFeed(
        self,
        request: global___GetCustomerFeedRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed: ...
    def MutateCustomerFeeds(
        self,
        request: global___MutateCustomerFeedsRequest,
    ) -> global___MutateCustomerFeedsResponse: ...

class CustomerFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerFeed(
        self,
        request: global___GetCustomerFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed: ...
    @abc.abstractmethod
    def MutateCustomerFeeds(
        self,
        request: global___MutateCustomerFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerFeedsResponse: ...

def add_CustomerFeedServiceServicer_to_server(
    servicer: CustomerFeedServiceServicer, server: grpc.Server
) -> None: ...
