"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_pb2
import grpc

from .ad_service_pb2 import *

class AdServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAd(
        self,
        request: global___GetAdRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    def MutateAds(
        self,
        request: global___MutateAdsRequest,
    ) -> global___MutateAdsResponse: ...

class AdServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAd(
        self,
        request: global___GetAdRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    @abc.abstractmethod
    def MutateAds(
        self,
        request: global___MutateAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdsResponse: ...

def add_AdServiceServicer_to_server(
    servicer: AdServiceServicer, server: grpc.Server
) -> None: ...
