"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignCriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignCriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignCriterionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignCriterionErrorEnum.CampaignCriterionError.V(0)
        UNKNOWN = CampaignCriterionErrorEnum.CampaignCriterionError.V(1)
        CONCRETE_TYPE_REQUIRED = CampaignCriterionErrorEnum.CampaignCriterionError.V(2)
        INVALID_PLACEMENT_URL = CampaignCriterionErrorEnum.CampaignCriterionError.V(3)
        CANNOT_EXCLUDE_CRITERIA_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(4)
        )
        CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(5)
        )
        CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(6)
        )
        CANNOT_TARGET_AND_EXCLUDE = CampaignCriterionErrorEnum.CampaignCriterionError.V(
            7
        )
        TOO_MANY_OPERATIONS = CampaignCriterionErrorEnum.CampaignCriterionError.V(8)
        OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(9)
        )
        SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(10)
        )
        CANNOT_ADD_EXISTING_FIELD = CampaignCriterionErrorEnum.CampaignCriterionError.V(
            11
        )
        CANNOT_UPDATE_NEGATIVE_CRITERION = (
            CampaignCriterionErrorEnum.CampaignCriterionError.V(12)
        )
    class CampaignCriterionError(metaclass=_CampaignCriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignCriterionErrorEnum.CampaignCriterionError.V(0)
    UNKNOWN = CampaignCriterionErrorEnum.CampaignCriterionError.V(1)
    CONCRETE_TYPE_REQUIRED = CampaignCriterionErrorEnum.CampaignCriterionError.V(2)
    INVALID_PLACEMENT_URL = CampaignCriterionErrorEnum.CampaignCriterionError.V(3)
    CANNOT_EXCLUDE_CRITERIA_TYPE = CampaignCriterionErrorEnum.CampaignCriterionError.V(
        4
    )
    CANNOT_SET_STATUS_FOR_CRITERIA_TYPE = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(5)
    )
    CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(6)
    )
    CANNOT_TARGET_AND_EXCLUDE = CampaignCriterionErrorEnum.CampaignCriterionError.V(7)
    TOO_MANY_OPERATIONS = CampaignCriterionErrorEnum.CampaignCriterionError.V(8)
    OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(9)
    )
    SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(10)
    )
    CANNOT_ADD_EXISTING_FIELD = CampaignCriterionErrorEnum.CampaignCriterionError.V(11)
    CANNOT_UPDATE_NEGATIVE_CRITERION = (
        CampaignCriterionErrorEnum.CampaignCriterionError.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignCriterionErrorEnum = CampaignCriterionErrorEnum
