"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MatchingFunctionOperatorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MatchingFunctionOperator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MatchingFunctionOperator.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(0)
        UNKNOWN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(1)
        IN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(2)
        IDENTITY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(3)
        EQUALS = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(4)
        AND = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(5)
        CONTAINS_ANY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(6)
    class MatchingFunctionOperator(metaclass=_MatchingFunctionOperator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(0)
    UNKNOWN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(1)
    IN = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(2)
    IDENTITY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(3)
    EQUALS = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(4)
    AND = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(5)
    CONTAINS_ANY = MatchingFunctionOperatorEnum.MatchingFunctionOperator.V(6)
    def __init__(
        self,
    ) -> None: ...

global___MatchingFunctionOperatorEnum = MatchingFunctionOperatorEnum
