"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListStringRuleItemOperatorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListStringRuleItemOperator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserListStringRuleItemOperator.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(0)
        )
        UNKNOWN = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(1)
        CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
            2
        )
        EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(3)
        STARTS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(4)
        )
        ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
            5
        )
        NOT_EQUALS = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(6)
        )
        NOT_CONTAINS = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(7)
        )
        NOT_STARTS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(8)
        )
        NOT_ENDS_WITH = (
            UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(9)
        )
    class UserListStringRuleItemOperator(metaclass=_UserListStringRuleItemOperator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(0)
    UNKNOWN = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(1)
    CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(2)
    EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(3)
    STARTS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(4)
    ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(5)
    NOT_EQUALS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(6)
    NOT_CONTAINS = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
        7
    )
    NOT_STARTS_WITH = (
        UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(8)
    )
    NOT_ENDS_WITH = UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V(
        9
    )
    def __init__(
        self,
    ) -> None: ...

global___UserListStringRuleItemOperatorEnum = UserListStringRuleItemOperatorEnum
