"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CITY_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    METRO_FIELD_NUMBER: builtins.int
    MOST_SPECIFIC_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def city(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def metro(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def most_specific(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def region(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        city: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        metro: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        most_specific: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        region: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> None: ...

global___ClickLocation = ClickLocation
