"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BidModifierSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___BidModifierSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpcBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpvBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetCpaSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class TargetRoasSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetRoasSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetRoasSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetRoasSimulationPointList = TargetRoasSimulationPointList

class BidModifierSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    PARENT_CLICKS_FIELD_NUMBER: builtins.int
    PARENT_COST_MICROS_FIELD_NUMBER: builtins.int
    PARENT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_REQUIRED_BUDGET_MICROS_FIELD_NUMBER: builtins.int
    @property
    def bid_modifier(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_biddable_conversions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def parent_biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def parent_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_top_slot_impressions(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_required_budget_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        bid_modifier: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        parent_biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        parent_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        parent_cost_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_required_budget_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        cpc_bid_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    VIEWS_FIELD_NUMBER: builtins.int
    @property
    def cpv_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def views(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        cpv_bid_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        views: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...

global___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def target_cpa_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___TargetCpaSimulationPoint = TargetCpaSimulationPoint

class TargetRoasSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def target_roas(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        target_roas: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___TargetRoasSimulationPoint = TargetRoasSimulationPoint
