"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataDrivenModelStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DataDrivenModelStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DataDrivenModelStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(0)
        UNKNOWN = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(1)
        AVAILABLE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(2)
        STALE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(3)
        EXPIRED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(4)
        NEVER_GENERATED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(5)
    class DataDrivenModelStatus(metaclass=_DataDrivenModelStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(0)
    UNKNOWN = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(1)
    AVAILABLE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(2)
    STALE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(3)
    EXPIRED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(4)
    NEVER_GENERATED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___DataDrivenModelStatusEnum = DataDrivenModelStatusEnum
