"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class JobPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _JobPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            JobPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = JobPlaceholderFieldEnum.JobPlaceholderField.V(0)
        UNKNOWN = JobPlaceholderFieldEnum.JobPlaceholderField.V(1)
        JOB_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(2)
        LOCATION_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(3)
        TITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(4)
        SUBTITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(5)
        DESCRIPTION = JobPlaceholderFieldEnum.JobPlaceholderField.V(6)
        IMAGE_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(7)
        CATEGORY = JobPlaceholderFieldEnum.JobPlaceholderField.V(8)
        CONTEXTUAL_KEYWORDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(9)
        ADDRESS = JobPlaceholderFieldEnum.JobPlaceholderField.V(10)
        SALARY = JobPlaceholderFieldEnum.JobPlaceholderField.V(11)
        FINAL_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(12)
        FINAL_MOBILE_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(14)
        TRACKING_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(15)
        ANDROID_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(16)
        SIMILAR_JOB_IDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(17)
        IOS_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(18)
        IOS_APP_STORE_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(19)
    class JobPlaceholderField(metaclass=_JobPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = JobPlaceholderFieldEnum.JobPlaceholderField.V(0)
    UNKNOWN = JobPlaceholderFieldEnum.JobPlaceholderField.V(1)
    JOB_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(2)
    LOCATION_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(3)
    TITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(4)
    SUBTITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(5)
    DESCRIPTION = JobPlaceholderFieldEnum.JobPlaceholderField.V(6)
    IMAGE_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(7)
    CATEGORY = JobPlaceholderFieldEnum.JobPlaceholderField.V(8)
    CONTEXTUAL_KEYWORDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(9)
    ADDRESS = JobPlaceholderFieldEnum.JobPlaceholderField.V(10)
    SALARY = JobPlaceholderFieldEnum.JobPlaceholderField.V(11)
    FINAL_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(12)
    FINAL_MOBILE_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(14)
    TRACKING_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(15)
    ANDROID_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(16)
    SIMILAR_JOB_IDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(17)
    IOS_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(18)
    IOS_APP_STORE_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(19)
    def __init__(
        self,
    ) -> None: ...

global___JobPlaceholderFieldEnum = JobPlaceholderFieldEnum
