"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LanguageConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGETABLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def targetable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        targetable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "code", b"code", "id", b"id", "name", b"name", "targetable", b"targetable"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "code",
            b"code",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "targetable",
            b"targetable",
        ],
    ) -> None: ...

global___LanguageConstant = LanguageConstant
