"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.ad_asset_pb2
import google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2
import google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2
import google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2
import google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2
import google.ads.google_ads.v6.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TextAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___TextAdInfo = TextAdInfo

class ExpandedTextAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_PART1_FIELD_NUMBER: builtins.int
    HEADLINE_PART2_FIELD_NUMBER: builtins.int
    HEADLINE_PART3_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    headline_part1: typing.Text = ...
    headline_part2: typing.Text = ...
    headline_part3: typing.Text = ...
    description: typing.Text = ...
    description2: typing.Text = ...
    path1: typing.Text = ...
    path2: typing.Text = ...
    def __init__(
        self,
        *,
        headline_part1: typing.Text = ...,
        headline_part2: typing.Text = ...,
        headline_part3: typing.Text = ...,
        description: typing.Text = ...,
        description2: typing.Text = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part1", b"_headline_part1"],
    ) -> typing_extensions.Literal["headline_part1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part2", b"_headline_part2"],
    ) -> typing_extensions.Literal["headline_part2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part3", b"_headline_part3"],
    ) -> typing_extensions.Literal["headline_part3"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___ExpandedTextAdInfo = ExpandedTextAdInfo

class CallOnlyAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    HEADLINE1_FIELD_NUMBER: builtins.int
    HEADLINE2_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    CALL_TRACKED_FIELD_NUMBER: builtins.int
    DISABLE_CALL_CONVERSION_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_VERIFICATION_URL_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_REPORTING_STATE_FIELD_NUMBER: builtins.int
    country_code: typing.Text = ...
    phone_number: typing.Text = ...
    business_name: typing.Text = ...
    headline1: typing.Text = ...
    headline2: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    call_tracked: builtins.bool = ...
    disable_call_conversion: builtins.bool = ...
    phone_number_verification_url: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_reporting_state: google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = (
        ...
    )
    def __init__(
        self,
        *,
        country_code: typing.Text = ...,
        phone_number: typing.Text = ...,
        business_name: typing.Text = ...,
        headline1: typing.Text = ...,
        headline2: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
        call_tracked: builtins.bool = ...,
        disable_call_conversion: builtins.bool = ...,
        phone_number_verification_url: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_reporting_state: google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "conversion_reporting_state",
            b"conversion_reporting_state",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_call_tracked", b"_call_tracked"]
    ) -> typing_extensions.Literal["call_tracked"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_disable_call_conversion", b"_disable_call_conversion"
        ],
    ) -> typing_extensions.Literal["disable_call_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline1", b"_headline1"]
    ) -> typing_extensions.Literal["headline1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline2", b"_headline2"]
    ) -> typing_extensions.Literal["headline2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_phone_number", b"_phone_number"]
    ) -> typing_extensions.Literal["phone_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_number_verification_url", b"_phone_number_verification_url"
        ],
    ) -> typing_extensions.Literal["phone_number_verification_url"]: ...

global___CallOnlyAdInfo = CallOnlyAdInfo

class ExpandedDynamicSearchAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    description: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        description: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...

global___ExpandedDynamicSearchAdInfo = ExpandedDynamicSearchAdInfo

class HotelAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___HotelAdInfo = HotelAdInfo

class ShoppingSmartAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ShoppingSmartAdInfo = ShoppingSmartAdInfo

class ShoppingProductAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ShoppingProductAdInfo = ShoppingProductAdInfo

class ShoppingComparisonListingAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___ShoppingComparisonListingAdInfo = ShoppingComparisonListingAdInfo

class GmailAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEASER_FIELD_NUMBER: builtins.int
    HEADER_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_HEADLINE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_DISPLAY_CALL_TO_ACTION_FIELD_NUMBER: builtins.int
    PRODUCT_IMAGES_FIELD_NUMBER: builtins.int
    PRODUCT_VIDEOS_FIELD_NUMBER: builtins.int
    header_image: typing.Text = ...
    marketing_image: typing.Text = ...
    marketing_image_headline: typing.Text = ...
    marketing_image_description: typing.Text = ...
    @property
    def teaser(self) -> global___GmailTeaser: ...
    @property
    def marketing_image_display_call_to_action(
        self,
    ) -> global___DisplayCallToAction: ...
    @property
    def product_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductImage
    ]: ...
    @property
    def product_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductVideo
    ]: ...
    def __init__(
        self,
        *,
        teaser: typing.Optional[global___GmailTeaser] = ...,
        header_image: typing.Text = ...,
        marketing_image: typing.Text = ...,
        marketing_image_headline: typing.Text = ...,
        marketing_image_description: typing.Text = ...,
        marketing_image_display_call_to_action: typing.Optional[
            global___DisplayCallToAction
        ] = ...,
        product_images: typing.Optional[typing.Iterable[global___ProductImage]] = ...,
        product_videos: typing.Optional[typing.Iterable[global___ProductVideo]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "teaser",
            b"teaser",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "product_images",
            b"product_images",
            "product_videos",
            b"product_videos",
            "teaser",
            b"teaser",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_header_image", b"_header_image"]
    ) -> typing_extensions.Literal["header_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_marketing_image", b"_marketing_image"],
    ) -> typing_extensions.Literal["marketing_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_marketing_image_description", b"_marketing_image_description"
        ],
    ) -> typing_extensions.Literal["marketing_image_description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_marketing_image_headline", b"_marketing_image_headline"
        ],
    ) -> typing_extensions.Literal["marketing_image_headline"]: ...

global___GmailAdInfo = GmailAdInfo

class GmailTeaser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    LOGO_IMAGE_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description: typing.Text = ...
    business_name: typing.Text = ...
    logo_image: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description: typing.Text = ...,
        business_name: typing.Text = ...,
        logo_image: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions.Literal["logo_image"]: ...

global___GmailTeaser = GmailTeaser

class DisplayCallToAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    URL_COLLECTION_ID_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    text_color: typing.Text = ...
    url_collection_id: typing.Text = ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        url_collection_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text_color", b"_text_color"]
    ) -> typing_extensions.Literal["text_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions.Literal["url_collection_id"]: ...

global___DisplayCallToAction = DisplayCallToAction

class ProductImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_IMAGE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_CALL_TO_ACTION_FIELD_NUMBER: builtins.int
    product_image: typing.Text = ...
    description: typing.Text = ...
    @property
    def display_call_to_action(self) -> global___DisplayCallToAction: ...
    def __init__(
        self,
        *,
        product_image: typing.Text = ...,
        description: typing.Text = ...,
        display_call_to_action: typing.Optional[global___DisplayCallToAction] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_image", b"_product_image"],
    ) -> typing_extensions.Literal["product_image"]: ...

global___ProductImage = ProductImage

class ProductVideo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_VIDEO_FIELD_NUMBER: builtins.int
    product_video: typing.Text = ...
    def __init__(
        self,
        *,
        product_video: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_video", b"_product_video"],
    ) -> typing_extensions.Literal["product_video"]: ...

global___ProductVideo = ProductVideo

class ImageAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PIXEL_WIDTH_FIELD_NUMBER: builtins.int
    PIXEL_HEIGHT_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    PREVIEW_PIXEL_WIDTH_FIELD_NUMBER: builtins.int
    PREVIEW_PIXEL_HEIGHT_FIELD_NUMBER: builtins.int
    PREVIEW_IMAGE_URL_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEDIA_FILE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    AD_ID_TO_COPY_IMAGE_FROM_FIELD_NUMBER: builtins.int
    pixel_width: builtins.int = ...
    pixel_height: builtins.int = ...
    image_url: typing.Text = ...
    preview_pixel_width: builtins.int = ...
    preview_pixel_height: builtins.int = ...
    preview_image_url: typing.Text = ...
    mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    name: typing.Text = ...
    media_file: typing.Text = ...
    data: builtins.bytes = ...
    ad_id_to_copy_image_from: builtins.int = ...
    def __init__(
        self,
        *,
        pixel_width: builtins.int = ...,
        pixel_height: builtins.int = ...,
        image_url: typing.Text = ...,
        preview_pixel_width: builtins.int = ...,
        preview_pixel_height: builtins.int = ...,
        preview_image_url: typing.Text = ...,
        mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        name: typing.Text = ...,
        media_file: typing.Text = ...,
        data: builtins.bytes = ...,
        ad_id_to_copy_image_from: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_image_url", b"_image_url"]
    ) -> typing_extensions.Literal["image_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_pixel_height", b"_pixel_height"]
    ) -> typing_extensions.Literal["pixel_height"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_pixel_width", b"_pixel_width"]
    ) -> typing_extensions.Literal["pixel_width"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_image_url", b"_preview_image_url"
        ],
    ) -> typing_extensions.Literal["preview_image_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_pixel_height", b"_preview_pixel_height"
        ],
    ) -> typing_extensions.Literal["preview_pixel_height"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_pixel_width", b"_preview_pixel_width"
        ],
    ) -> typing_extensions.Literal["preview_pixel_width"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["image", b"image"]
    ) -> typing_extensions.Literal[
        "media_file", "data", "ad_id_to_copy_image_from"
    ]: ...

global___ImageAdInfo = ImageAdInfo

class VideoBumperInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoBumperInStreamAdInfo = VideoBumperInStreamAdInfo

class VideoNonSkippableInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoNonSkippableInStreamAdInfo = VideoNonSkippableInStreamAdInfo

class VideoTrueViewInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACTION_BUTTON_LABEL_FIELD_NUMBER: builtins.int
    ACTION_HEADLINE_FIELD_NUMBER: builtins.int
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    action_button_label: typing.Text = ...
    action_headline: typing.Text = ...
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        action_button_label: typing.Text = ...,
        action_headline: typing.Text = ...,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_action_button_label", b"_action_button_label"
        ],
    ) -> typing_extensions.Literal["action_button_label"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_action_headline", b"_action_headline"],
    ) -> typing_extensions.Literal["action_headline"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoTrueViewInStreamAdInfo = VideoTrueViewInStreamAdInfo

class VideoOutstreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___VideoOutstreamAdInfo = VideoOutstreamAdInfo

class VideoTrueViewDiscoveryAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___VideoTrueViewDiscoveryAdInfo = VideoTrueViewDiscoveryAdInfo

class VideoAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEDIA_FILE_FIELD_NUMBER: builtins.int
    IN_STREAM_FIELD_NUMBER: builtins.int
    BUMPER_FIELD_NUMBER: builtins.int
    OUT_STREAM_FIELD_NUMBER: builtins.int
    NON_SKIPPABLE_FIELD_NUMBER: builtins.int
    DISCOVERY_FIELD_NUMBER: builtins.int
    media_file: typing.Text = ...
    @property
    def in_stream(self) -> global___VideoTrueViewInStreamAdInfo: ...
    @property
    def bumper(self) -> global___VideoBumperInStreamAdInfo: ...
    @property
    def out_stream(self) -> global___VideoOutstreamAdInfo: ...
    @property
    def non_skippable(self) -> global___VideoNonSkippableInStreamAdInfo: ...
    @property
    def discovery(self) -> global___VideoTrueViewDiscoveryAdInfo: ...
    def __init__(
        self,
        *,
        media_file: typing.Text = ...,
        in_stream: typing.Optional[global___VideoTrueViewInStreamAdInfo] = ...,
        bumper: typing.Optional[global___VideoBumperInStreamAdInfo] = ...,
        out_stream: typing.Optional[global___VideoOutstreamAdInfo] = ...,
        non_skippable: typing.Optional[global___VideoNonSkippableInStreamAdInfo] = ...,
        discovery: typing.Optional[global___VideoTrueViewDiscoveryAdInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_media_file", b"_media_file"]
    ) -> typing_extensions.Literal["media_file"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["format", b"format"]
    ) -> typing_extensions.Literal[
        "in_stream", "bumper", "out_stream", "non_skippable", "discovery"
    ]: ...

global___VideoAdInfo = VideoAdInfo

class VideoResponsiveAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    LONG_HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    CALL_TO_ACTIONS_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    COMPANION_BANNERS_FIELD_NUMBER: builtins.int
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def long_headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def companion_banners(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        long_headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        call_to_actions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        companion_banners: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "call_to_actions",
            b"call_to_actions",
            "companion_banners",
            b"companion_banners",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "long_headlines",
            b"long_headlines",
            "videos",
            b"videos",
        ],
    ) -> None: ...

global___VideoResponsiveAdInfo = VideoResponsiveAdInfo

class ResponsiveSearchAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    path1: typing.Text = ...
    path2: typing.Text = ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___ResponsiveSearchAdInfo = ResponsiveSearchAdInfo

class LegacyResponsiveDisplayAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SHORT_HEADLINE_FIELD_NUMBER: builtins.int
    LONG_HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    ALLOW_FLEXIBLE_COLOR_FIELD_NUMBER: builtins.int
    ACCENT_COLOR_FIELD_NUMBER: builtins.int
    MAIN_COLOR_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TEXT_FIELD_NUMBER: builtins.int
    LOGO_IMAGE_FIELD_NUMBER: builtins.int
    SQUARE_LOGO_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    SQUARE_MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    FORMAT_SETTING_FIELD_NUMBER: builtins.int
    PRICE_PREFIX_FIELD_NUMBER: builtins.int
    PROMO_TEXT_FIELD_NUMBER: builtins.int
    short_headline: typing.Text = ...
    long_headline: typing.Text = ...
    description: typing.Text = ...
    business_name: typing.Text = ...
    allow_flexible_color: builtins.bool = ...
    accent_color: typing.Text = ...
    main_color: typing.Text = ...
    call_to_action_text: typing.Text = ...
    logo_image: typing.Text = ...
    square_logo_image: typing.Text = ...
    marketing_image: typing.Text = ...
    square_marketing_image: typing.Text = ...
    format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = (
        ...
    )
    price_prefix: typing.Text = ...
    promo_text: typing.Text = ...
    def __init__(
        self,
        *,
        short_headline: typing.Text = ...,
        long_headline: typing.Text = ...,
        description: typing.Text = ...,
        business_name: typing.Text = ...,
        allow_flexible_color: builtins.bool = ...,
        accent_color: typing.Text = ...,
        main_color: typing.Text = ...,
        call_to_action_text: typing.Text = ...,
        logo_image: typing.Text = ...,
        square_logo_image: typing.Text = ...,
        marketing_image: typing.Text = ...,
        square_marketing_image: typing.Text = ...,
        format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = ...,
        price_prefix: typing.Text = ...,
        promo_text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "format_setting",
            b"format_setting",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_accent_color", b"_accent_color"]
    ) -> typing_extensions.Literal["accent_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions.Literal["allow_flexible_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions.Literal["call_to_action_text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions.Literal["logo_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_long_headline", b"_long_headline"],
    ) -> typing_extensions.Literal["long_headline"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_main_color", b"_main_color"]
    ) -> typing_extensions.Literal["main_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_marketing_image", b"_marketing_image"],
    ) -> typing_extensions.Literal["marketing_image"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_price_prefix", b"_price_prefix"]
    ) -> typing_extensions.Literal["price_prefix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions.Literal["promo_text"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_short_headline", b"_short_headline"],
    ) -> typing_extensions.Literal["short_headline"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_square_logo_image", b"_square_logo_image"
        ],
    ) -> typing_extensions.Literal["square_logo_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_square_marketing_image", b"_square_marketing_image"
        ],
    ) -> typing_extensions.Literal["square_marketing_image"]: ...

global___LegacyResponsiveDisplayAdInfo = LegacyResponsiveDisplayAdInfo

class AppAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANDATORY_AD_TEXT_FIELD_NUMBER: builtins.int
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEOS_FIELD_NUMBER: builtins.int
    HTML5_MEDIA_BUNDLES_FIELD_NUMBER: builtins.int
    @property
    def mandatory_ad_text(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset: ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def html5_media_bundles(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
    ]: ...
    def __init__(
        self,
        *,
        mandatory_ad_text: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
        ] = ...,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        youtube_videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        html5_media_bundles: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "mandatory_ad_text", b"mandatory_ad_text"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "html5_media_bundles",
            b"html5_media_bundles",
            "images",
            b"images",
            "mandatory_ad_text",
            b"mandatory_ad_text",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...

global___AppAdInfo = AppAdInfo

class AppEngagementAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "images",
            b"images",
            "videos",
            b"videos",
        ],
    ) -> None: ...

global___AppEngagementAdInfo = AppEngagementAdInfo

class LegacyAppInstallAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ID_FIELD_NUMBER: builtins.int
    APP_STORE_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    app_id: typing.Text = ...
    app_store: google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V = (
        ...
    )
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        app_id: typing.Text = ...,
        app_store: google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V = ...,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "app_store",
            b"app_store",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___LegacyAppInstallAdInfo = LegacyAppInstallAdInfo

class ResponsiveDisplayAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    SQUARE_MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    LOGO_IMAGES_FIELD_NUMBER: builtins.int
    SQUARE_LOGO_IMAGES_FIELD_NUMBER: builtins.int
    HEADLINES_FIELD_NUMBER: builtins.int
    LONG_HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEOS_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    MAIN_COLOR_FIELD_NUMBER: builtins.int
    ACCENT_COLOR_FIELD_NUMBER: builtins.int
    ALLOW_FLEXIBLE_COLOR_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TEXT_FIELD_NUMBER: builtins.int
    PRICE_PREFIX_FIELD_NUMBER: builtins.int
    PROMO_TEXT_FIELD_NUMBER: builtins.int
    FORMAT_SETTING_FIELD_NUMBER: builtins.int
    CONTROL_SPEC_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    main_color: typing.Text = ...
    accent_color: typing.Text = ...
    allow_flexible_color: builtins.bool = ...
    call_to_action_text: typing.Text = ...
    price_prefix: typing.Text = ...
    promo_text: typing.Text = ...
    format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = (
        ...
    )
    @property
    def marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def square_marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def square_logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def long_headline(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def control_spec(self) -> global___ResponsiveDisplayAdControlSpec: ...
    def __init__(
        self,
        *,
        marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        square_marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        square_logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        long_headline: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        youtube_videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        business_name: typing.Text = ...,
        main_color: typing.Text = ...,
        accent_color: typing.Text = ...,
        allow_flexible_color: builtins.bool = ...,
        call_to_action_text: typing.Text = ...,
        price_prefix: typing.Text = ...,
        promo_text: typing.Text = ...,
        format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = ...,
        control_spec: typing.Optional[global___ResponsiveDisplayAdControlSpec] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "descriptions",
            b"descriptions",
            "format_setting",
            b"format_setting",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_images",
            b"marketing_images",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "square_logo_images",
            b"square_logo_images",
            "square_marketing_images",
            b"square_marketing_images",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_accent_color", b"_accent_color"]
    ) -> typing_extensions.Literal["accent_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions.Literal["allow_flexible_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions.Literal["call_to_action_text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_main_color", b"_main_color"]
    ) -> typing_extensions.Literal["main_color"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_price_prefix", b"_price_prefix"]
    ) -> typing_extensions.Literal["price_prefix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions.Literal["promo_text"]: ...

global___ResponsiveDisplayAdInfo = ResponsiveDisplayAdInfo

class LocalAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    CALL_TO_ACTIONS_FIELD_NUMBER: builtins.int
    MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    LOGO_IMAGES_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    path1: typing.Text = ...
    path2: typing.Text = ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        call_to_actions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "call_to_actions",
            b"call_to_actions",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "marketing_images",
            b"marketing_images",
            "path1",
            b"path1",
            "path2",
            b"path2",
            "videos",
            b"videos",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___LocalAdInfo = LocalAdInfo

class DisplayUploadAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DISPLAY_UPLOAD_PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_FIELD_NUMBER: builtins.int
    display_upload_product_type: google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2.DisplayUploadProductTypeEnum.DisplayUploadProductType.V = (
        ...
    )
    @property
    def media_bundle(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset: ...
    def __init__(
        self,
        *,
        display_upload_product_type: google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2.DisplayUploadProductTypeEnum.DisplayUploadProductType.V = ...,
        media_bundle: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "media_asset", b"media_asset", "media_bundle", b"media_bundle"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_upload_product_type",
            b"display_upload_product_type",
            "media_asset",
            b"media_asset",
            "media_bundle",
            b"media_bundle",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["media_asset", b"media_asset"]
    ) -> typing_extensions.Literal["media_bundle"]: ...

global___DisplayUploadAdInfo = DisplayUploadAdInfo

class ResponsiveDisplayAdControlSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENABLE_ASSET_ENHANCEMENTS_FIELD_NUMBER: builtins.int
    ENABLE_AUTOGEN_VIDEO_FIELD_NUMBER: builtins.int
    enable_asset_enhancements: builtins.bool = ...
    enable_autogen_video: builtins.bool = ...
    def __init__(
        self,
        *,
        enable_asset_enhancements: builtins.bool = ...,
        enable_autogen_video: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "enable_asset_enhancements",
            b"enable_asset_enhancements",
            "enable_autogen_video",
            b"enable_autogen_video",
        ],
    ) -> None: ...

global___ResponsiveDisplayAdControlSpec = ResponsiveDisplayAdControlSpec
