"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppCampaignAppStoreEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AppCampaignAppStore(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AppCampaignAppStore.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AppCampaignAppStoreEnum.AppCampaignAppStore.V(0)
        UNKNOWN = AppCampaignAppStoreEnum.AppCampaignAppStore.V(1)
        APPLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(2)
        GOOGLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(3)
    class AppCampaignAppStore(metaclass=_AppCampaignAppStore):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AppCampaignAppStoreEnum.AppCampaignAppStore.V(0)
    UNKNOWN = AppCampaignAppStoreEnum.AppCampaignAppStore.V(1)
    APPLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(2)
    GOOGLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(3)
    def __init__(
        self,
    ) -> None: ...

global___AppCampaignAppStoreEnum = AppCampaignAppStoreEnum
