"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_pb2
import grpc

from .ad_group_service_pb2 import *

class AdGroupServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroup(
        self,
        request: global___GetAdGroupRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup: ...
    def MutateAdGroups(
        self,
        request: global___MutateAdGroupsRequest,
    ) -> global___MutateAdGroupsResponse: ...

class AdGroupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroup(
        self,
        request: global___GetAdGroupRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup: ...
    @abc.abstractmethod
    def MutateAdGroups(
        self,
        request: global___MutateAdGroupsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupsResponse: ...

def add_AdGroupServiceServicer_to_server(
    servicer: AdGroupServiceServicer, server: grpc.Server
) -> None: ...
