"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2
import google.ads.google_ads.v6.proto.enums.call_type_pb2
import google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CALLER_REGION_CODE_FIELD_NUMBER: builtins.int
    CALLER_AREA_CODE_FIELD_NUMBER: builtins.int
    CALL_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    START_CALL_DATE_TIME_FIELD_NUMBER: builtins.int
    END_CALL_DATE_TIME_FIELD_NUMBER: builtins.int
    CALL_TRACKING_DISPLAY_LOCATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CALL_STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    caller_region_code: typing.Text = ...
    caller_area_code: typing.Text = ...
    call_duration_seconds: builtins.int = ...
    start_call_date_time: typing.Text = ...
    end_call_date_time: typing.Text = ...
    call_tracking_display_location: google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2.CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation.V = (
        ...
    )
    type: google.ads.google_ads.v6.proto.enums.call_type_pb2.CallTypeEnum.CallType.V = (
        ...
    )
    call_status: google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2.GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        caller_region_code: typing.Text = ...,
        caller_area_code: typing.Text = ...,
        call_duration_seconds: builtins.int = ...,
        start_call_date_time: typing.Text = ...,
        end_call_date_time: typing.Text = ...,
        call_tracking_display_location: google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2.CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation.V = ...,
        type: google.ads.google_ads.v6.proto.enums.call_type_pb2.CallTypeEnum.CallType.V = ...,
        call_status: google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2.GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "call_duration_seconds",
            b"call_duration_seconds",
            "call_status",
            b"call_status",
            "call_tracking_display_location",
            b"call_tracking_display_location",
            "caller_area_code",
            b"caller_area_code",
            "caller_region_code",
            b"caller_region_code",
            "end_call_date_time",
            b"end_call_date_time",
            "resource_name",
            b"resource_name",
            "start_call_date_time",
            b"start_call_date_time",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CallView = CallView
