"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserDataErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserDataError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserDataError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserDataErrorEnum.UserDataError.V(0)
        UNKNOWN = UserDataErrorEnum.UserDataError.V(1)
        OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = UserDataErrorEnum.UserDataError.V(2)
        TOO_MANY_USER_IDENTIFIERS = UserDataErrorEnum.UserDataError.V(3)
        USER_LIST_NOT_APPLICABLE = UserDataErrorEnum.UserDataError.V(4)
    class UserDataError(metaclass=_UserDataError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserDataErrorEnum.UserDataError.V(0)
    UNKNOWN = UserDataErrorEnum.UserDataError.V(1)
    OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = UserDataErrorEnum.UserDataError.V(2)
    TOO_MANY_USER_IDENTIFIERS = UserDataErrorEnum.UserDataError.V(3)
    USER_LIST_NOT_APPLICABLE = UserDataErrorEnum.UserDataError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___UserDataErrorEnum = UserDataErrorEnum
