"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2
import grpc

from .ad_group_ad_asset_view_service_pb2 import *

class AdGroupAdAssetViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupAdAssetView(
        self,
        request: global___GetAdGroupAdAssetViewRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView: ...

class AdGroupAdAssetViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupAdAssetView(
        self,
        request: global___GetAdGroupAdAssetViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView: ...

def add_AdGroupAdAssetViewServiceServicer_to_server(
    servicer: AdGroupAdAssetViewServiceServicer, server: grpc.Server
) -> None: ...
