"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MimeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MimeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MimeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MimeTypeEnum.MimeType.V(0)
        UNKNOWN = MimeTypeEnum.MimeType.V(1)
        IMAGE_JPEG = MimeTypeEnum.MimeType.V(2)
        IMAGE_GIF = MimeTypeEnum.MimeType.V(3)
        IMAGE_PNG = MimeTypeEnum.MimeType.V(4)
        FLASH = MimeTypeEnum.MimeType.V(5)
        TEXT_HTML = MimeTypeEnum.MimeType.V(6)
        PDF = MimeTypeEnum.MimeType.V(7)
        MSWORD = MimeTypeEnum.MimeType.V(8)
        MSEXCEL = MimeTypeEnum.MimeType.V(9)
        RTF = MimeTypeEnum.MimeType.V(10)
        AUDIO_WAV = MimeTypeEnum.MimeType.V(11)
        AUDIO_MP3 = MimeTypeEnum.MimeType.V(12)
        HTML5_AD_ZIP = MimeTypeEnum.MimeType.V(13)
    class MimeType(metaclass=_MimeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MimeTypeEnum.MimeType.V(0)
    UNKNOWN = MimeTypeEnum.MimeType.V(1)
    IMAGE_JPEG = MimeTypeEnum.MimeType.V(2)
    IMAGE_GIF = MimeTypeEnum.MimeType.V(3)
    IMAGE_PNG = MimeTypeEnum.MimeType.V(4)
    FLASH = MimeTypeEnum.MimeType.V(5)
    TEXT_HTML = MimeTypeEnum.MimeType.V(6)
    PDF = MimeTypeEnum.MimeType.V(7)
    MSWORD = MimeTypeEnum.MimeType.V(8)
    MSEXCEL = MimeTypeEnum.MimeType.V(9)
    RTF = MimeTypeEnum.MimeType.V(10)
    AUDIO_WAV = MimeTypeEnum.MimeType.V(11)
    AUDIO_MP3 = MimeTypeEnum.MimeType.V(12)
    HTML5_AD_ZIP = MimeTypeEnum.MimeType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MimeTypeEnum = MimeTypeEnum
