"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .invoice_service_pb2 import *

class InvoiceServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def ListInvoices(
        self,
        request: global___ListInvoicesRequest,
    ) -> global___ListInvoicesResponse: ...

class InvoiceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListInvoices(
        self,
        request: global___ListInvoicesRequest,
        context: grpc.ServicerContext,
    ) -> global___ListInvoicesResponse: ...

def add_InvoiceServiceServicer_to_server(
    servicer: InvoiceServiceServicer, server: grpc.Server
) -> None: ...
