"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeEventErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeEventError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChangeEventError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(0)
        UNKNOWN = ChangeEventErrorEnum.ChangeEventError.V(1)
        START_DATE_TOO_OLD = ChangeEventErrorEnum.ChangeEventError.V(2)
        CHANGE_DATE_RANGE_INFINITE = ChangeEventErrorEnum.ChangeEventError.V(3)
        CHANGE_DATE_RANGE_NEGATIVE = ChangeEventErrorEnum.ChangeEventError.V(4)
        LIMIT_NOT_SPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(5)
        INVALID_LIMIT_CLAUSE = ChangeEventErrorEnum.ChangeEventError.V(6)
    class ChangeEventError(metaclass=_ChangeEventError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(0)
    UNKNOWN = ChangeEventErrorEnum.ChangeEventError.V(1)
    START_DATE_TOO_OLD = ChangeEventErrorEnum.ChangeEventError.V(2)
    CHANGE_DATE_RANGE_INFINITE = ChangeEventErrorEnum.ChangeEventError.V(3)
    CHANGE_DATE_RANGE_NEGATIVE = ChangeEventErrorEnum.ChangeEventError.V(4)
    LIMIT_NOT_SPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(5)
    INVALID_LIMIT_CLAUSE = ChangeEventErrorEnum.ChangeEventError.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ChangeEventErrorEnum = ChangeEventErrorEnum
