"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2
import google.ads.google_ads.v6.proto.enums.access_role_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccessInvitation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    INVITATION_ID_FIELD_NUMBER: builtins.int
    ACCESS_ROLE_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    INVITATION_STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    invitation_id: builtins.int = ...
    access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = (
        ...
    )
    email_address: typing.Text = ...
    creation_date_time: typing.Text = ...
    invitation_status: google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2.AccessInvitationStatusEnum.AccessInvitationStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        invitation_id: builtins.int = ...,
        access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = ...,
        email_address: typing.Text = ...,
        creation_date_time: typing.Text = ...,
        invitation_status: google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2.AccessInvitationStatusEnum.AccessInvitationStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "access_role",
            b"access_role",
            "creation_date_time",
            b"creation_date_time",
            "email_address",
            b"email_address",
            "invitation_id",
            b"invitation_id",
            "invitation_status",
            b"invitation_status",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___CustomerUserAccessInvitation = CustomerUserAccessInvitation
