"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DayOfWeekEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DayOfWeek(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DayOfWeek.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DayOfWeekEnum.DayOfWeek.V(0)
        UNKNOWN = DayOfWeekEnum.DayOfWeek.V(1)
        MONDAY = DayOfWeekEnum.DayOfWeek.V(2)
        TUESDAY = DayOfWeekEnum.DayOfWeek.V(3)
        WEDNESDAY = DayOfWeekEnum.DayOfWeek.V(4)
        THURSDAY = DayOfWeekEnum.DayOfWeek.V(5)
        FRIDAY = DayOfWeekEnum.DayOfWeek.V(6)
        SATURDAY = DayOfWeekEnum.DayOfWeek.V(7)
        SUNDAY = DayOfWeekEnum.DayOfWeek.V(8)
    class DayOfWeek(metaclass=_DayOfWeek):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DayOfWeekEnum.DayOfWeek.V(0)
    UNKNOWN = DayOfWeekEnum.DayOfWeek.V(1)
    MONDAY = DayOfWeekEnum.DayOfWeek.V(2)
    TUESDAY = DayOfWeekEnum.DayOfWeek.V(3)
    WEDNESDAY = DayOfWeekEnum.DayOfWeek.V(4)
    THURSDAY = DayOfWeekEnum.DayOfWeek.V(5)
    FRIDAY = DayOfWeekEnum.DayOfWeek.V(6)
    SATURDAY = DayOfWeekEnum.DayOfWeek.V(7)
    SUNDAY = DayOfWeekEnum.DayOfWeek.V(8)
    def __init__(
        self,
    ) -> None: ...

global___DayOfWeekEnum = DayOfWeekEnum
