"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IncomeRangeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _IncomeRangeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[IncomeRangeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = IncomeRangeTypeEnum.IncomeRangeType.V(0)
        UNKNOWN = IncomeRangeTypeEnum.IncomeRangeType.V(1)
        INCOME_RANGE_0_50 = IncomeRangeTypeEnum.IncomeRangeType.V(510001)
        INCOME_RANGE_50_60 = IncomeRangeTypeEnum.IncomeRangeType.V(510002)
        INCOME_RANGE_60_70 = IncomeRangeTypeEnum.IncomeRangeType.V(510003)
        INCOME_RANGE_70_80 = IncomeRangeTypeEnum.IncomeRangeType.V(510004)
        INCOME_RANGE_80_90 = IncomeRangeTypeEnum.IncomeRangeType.V(510005)
        INCOME_RANGE_90_UP = IncomeRangeTypeEnum.IncomeRangeType.V(510006)
        INCOME_RANGE_UNDETERMINED = IncomeRangeTypeEnum.IncomeRangeType.V(510000)
    class IncomeRangeType(metaclass=_IncomeRangeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = IncomeRangeTypeEnum.IncomeRangeType.V(0)
    UNKNOWN = IncomeRangeTypeEnum.IncomeRangeType.V(1)
    INCOME_RANGE_0_50 = IncomeRangeTypeEnum.IncomeRangeType.V(510001)
    INCOME_RANGE_50_60 = IncomeRangeTypeEnum.IncomeRangeType.V(510002)
    INCOME_RANGE_60_70 = IncomeRangeTypeEnum.IncomeRangeType.V(510003)
    INCOME_RANGE_70_80 = IncomeRangeTypeEnum.IncomeRangeType.V(510004)
    INCOME_RANGE_80_90 = IncomeRangeTypeEnum.IncomeRangeType.V(510005)
    INCOME_RANGE_90_UP = IncomeRangeTypeEnum.IncomeRangeType.V(510006)
    INCOME_RANGE_UNDETERMINED = IncomeRangeTypeEnum.IncomeRangeType.V(510000)
    def __init__(
        self,
    ) -> None: ...

global___IncomeRangeTypeEnum = IncomeRangeTypeEnum
