"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionOrAdjustmentLagBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionOrAdjustmentLagBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionOrAdjustmentLagBucket.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(0)
        )
        UNKNOWN = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(
            1
        )
        CONVERSION_LESS_THAN_ONE_DAY = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(2)
        )
        CONVERSION_ONE_TO_TWO_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(3)
        )
        CONVERSION_TWO_TO_THREE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(4)
        )
        CONVERSION_THREE_TO_FOUR_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(5)
        )
        CONVERSION_FOUR_TO_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(6)
        )
        CONVERSION_FIVE_TO_SIX_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(7)
        )
        CONVERSION_SIX_TO_SEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(8)
        )
        CONVERSION_SEVEN_TO_EIGHT_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(9)
        )
        CONVERSION_EIGHT_TO_NINE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(10)
        )
        CONVERSION_NINE_TO_TEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(11)
        )
        CONVERSION_TEN_TO_ELEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(12)
        )
        CONVERSION_ELEVEN_TO_TWELVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(13)
        )
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(14)
        )
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(15)
        )
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(16)
        )
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(17)
        )
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(18)
        )
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(19)
        )
        CONVERSION_SIXTY_TO_NINETY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(20)
        )
        ADJUSTMENT_LESS_THAN_ONE_DAY = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(21)
        )
        ADJUSTMENT_ONE_TO_TWO_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(22)
        )
        ADJUSTMENT_TWO_TO_THREE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(23)
        )
        ADJUSTMENT_THREE_TO_FOUR_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(24)
        )
        ADJUSTMENT_FOUR_TO_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(25)
        )
        ADJUSTMENT_FIVE_TO_SIX_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(26)
        )
        ADJUSTMENT_SIX_TO_SEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(27)
        )
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(28)
        )
        ADJUSTMENT_EIGHT_TO_NINE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(29)
        )
        ADJUSTMENT_NINE_TO_TEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(30)
        )
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(31)
        )
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(32)
        )
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(33)
        )
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(34)
        )
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(35)
        )
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(36)
        )
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(37)
        )
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(38)
        )
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(39)
        )
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(40)
        )
        CONVERSION_UNKNOWN = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(41)
        )
        ADJUSTMENT_UNKNOWN = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(42)
        )
    class ConversionOrAdjustmentLagBucket(metaclass=_ConversionOrAdjustmentLagBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(
        0
    )
    UNKNOWN = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(1)
    CONVERSION_LESS_THAN_ONE_DAY = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(2)
    )
    CONVERSION_ONE_TO_TWO_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(3)
    )
    CONVERSION_TWO_TO_THREE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(4)
    )
    CONVERSION_THREE_TO_FOUR_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(5)
    )
    CONVERSION_FOUR_TO_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(6)
    )
    CONVERSION_FIVE_TO_SIX_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(7)
    )
    CONVERSION_SIX_TO_SEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(8)
    )
    CONVERSION_SEVEN_TO_EIGHT_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(9)
    )
    CONVERSION_EIGHT_TO_NINE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(10)
    )
    CONVERSION_NINE_TO_TEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(11)
    )
    CONVERSION_TEN_TO_ELEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(12)
    )
    CONVERSION_ELEVEN_TO_TWELVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(13)
    )
    CONVERSION_TWELVE_TO_THIRTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(14)
    )
    CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(15)
    )
    CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(16)
    )
    CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(17)
    )
    CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(18)
    )
    CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(19)
    )
    CONVERSION_SIXTY_TO_NINETY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(20)
    )
    ADJUSTMENT_LESS_THAN_ONE_DAY = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(21)
    )
    ADJUSTMENT_ONE_TO_TWO_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(22)
    )
    ADJUSTMENT_TWO_TO_THREE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(23)
    )
    ADJUSTMENT_THREE_TO_FOUR_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(24)
    )
    ADJUSTMENT_FOUR_TO_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(25)
    )
    ADJUSTMENT_FIVE_TO_SIX_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(26)
    )
    ADJUSTMENT_SIX_TO_SEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(27)
    )
    ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(28)
    )
    ADJUSTMENT_EIGHT_TO_NINE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(29)
    )
    ADJUSTMENT_NINE_TO_TEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(30)
    )
    ADJUSTMENT_TEN_TO_ELEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(31)
    )
    ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(32)
    )
    ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(33)
    )
    ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(34)
    )
    ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(35)
    )
    ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(36)
    )
    ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(37)
    )
    ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(38)
    )
    ADJUSTMENT_SIXTY_TO_NINETY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(39)
    )
    ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(40)
    )
    CONVERSION_UNKNOWN = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(41)
    )
    ADJUSTMENT_UNKNOWN = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(42)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionOrAdjustmentLagBucketEnum = ConversionOrAdjustmentLagBucketEnum
