"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Commission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMISSION_RATE_MICROS_FIELD_NUMBER: builtins.int
    commission_rate_micros: builtins.int = ...
    def __init__(
        self,
        *,
        commission_rate_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_commission_rate_micros", b"_commission_rate_micros"
        ],
    ) -> typing_extensions.Literal["commission_rate_micros"]: ...

global___Commission = Commission

class EnhancedCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___EnhancedCpc = EnhancedCpc

class ManualCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENHANCED_CPC_ENABLED_FIELD_NUMBER: builtins.int
    enhanced_cpc_enabled: builtins.bool = ...
    def __init__(
        self,
        *,
        enhanced_cpc_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions.Literal["enhanced_cpc_enabled"]: ...

global___ManualCpc = ManualCpc

class ManualCpm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ManualCpm = ManualCpm

class ManualCpv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ManualCpv = ManualCpv

class MaximizeConversions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___MaximizeConversions = MaximizeConversions

class MaximizeConversionValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    target_roas: builtins.float = ...
    def __init__(
        self,
        *,
        target_roas: builtins.float = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...

global___MaximizeConversionValue = MaximizeConversionValue

class TargetCpa(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_FLOOR_MICROS_FIELD_NUMBER: builtins.int
    target_cpa_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    cpc_bid_floor_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
        cpc_bid_floor_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_floor_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions.Literal["target_cpa_micros"]: ...

global___TargetCpa = TargetCpa

class TargetCpm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___TargetCpm = TargetCpm

class TargetImpressionShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOCATION_FIELD_NUMBER: builtins.int
    LOCATION_FRACTION_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    location: google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2.TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V = (
        ...
    )
    location_fraction_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    def __init__(
        self,
        *,
        location: google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2.TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V = ...,
        location_fraction_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location",
            b"location",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_location_fraction_micros", b"_location_fraction_micros"
        ],
    ) -> typing_extensions.Literal["location_fraction_micros"]: ...

global___TargetImpressionShare = TargetImpressionShare

class TargetRoas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_FLOOR_MICROS_FIELD_NUMBER: builtins.int
    target_roas: builtins.float = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    cpc_bid_floor_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_roas: builtins.float = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
        cpc_bid_floor_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_floor_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...

global___TargetRoas = TargetRoas

class TargetSpend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_SPEND_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    target_spend_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_spend_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_spend_micros", b"_target_spend_micros"
        ],
    ) -> typing_extensions.Literal["target_spend_micros"]: ...

global___TargetSpend = TargetSpend

class PercentCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    ENHANCED_CPC_ENABLED_FIELD_NUMBER: builtins.int
    cpc_bid_ceiling_micros: builtins.int = ...
    enhanced_cpc_enabled: builtins.bool = ...
    def __init__(
        self,
        *,
        cpc_bid_ceiling_micros: builtins.int = ...,
        enhanced_cpc_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions.Literal["enhanced_cpc_enabled"]: ...

global___PercentCpc = PercentCpc
