"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenderTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GenderType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GenderType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = GenderTypeEnum.GenderType.V(0)
        UNKNOWN = GenderTypeEnum.GenderType.V(1)
        MALE = GenderTypeEnum.GenderType.V(10)
        FEMALE = GenderTypeEnum.GenderType.V(11)
        UNDETERMINED = GenderTypeEnum.GenderType.V(20)
    class GenderType(metaclass=_GenderType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = GenderTypeEnum.GenderType.V(0)
    UNKNOWN = GenderTypeEnum.GenderType.V(1)
    MALE = GenderTypeEnum.GenderType.V(10)
    FEMALE = GenderTypeEnum.GenderType.V(11)
    UNDETERMINED = GenderTypeEnum.GenderType.V(20)
    def __init__(
        self,
    ) -> None: ...

global___GenderTypeEnum = GenderTypeEnum
