"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2
import grpc

from .keyword_plan_ad_group_service_pb2 import *

class KeywordPlanAdGroupServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanAdGroup(
        self,
        request: global___GetKeywordPlanAdGroupRequest,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup: ...
    def MutateKeywordPlanAdGroups(
        self,
        request: global___MutateKeywordPlanAdGroupsRequest,
    ) -> global___MutateKeywordPlanAdGroupsResponse: ...

class KeywordPlanAdGroupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanAdGroup(
        self,
        request: global___GetKeywordPlanAdGroupRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup: ...
    @abc.abstractmethod
    def MutateKeywordPlanAdGroups(
        self,
        request: global___MutateKeywordPlanAdGroupsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanAdGroupsResponse: ...

def add_KeywordPlanAdGroupServiceServicer_to_server(
    servicer: KeywordPlanAdGroupServiceServicer, server: grpc.Server
) -> None: ...
