"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionUploadError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionUploadErrorEnum.ConversionUploadError.V(0)
        UNKNOWN = ConversionUploadErrorEnum.ConversionUploadError.V(1)
        TOO_MANY_CONVERSIONS_IN_REQUEST = (
            ConversionUploadErrorEnum.ConversionUploadError.V(2)
        )
        UNPARSEABLE_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(3)
        CONVERSION_PRECEDES_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(4)
        EXPIRED_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(5)
        TOO_RECENT_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(6)
        GCLID_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(7)
        UNAUTHORIZED_CUSTOMER = ConversionUploadErrorEnum.ConversionUploadError.V(8)
        INVALID_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(9)
        TOO_RECENT_CONVERSION_ACTION = (
            ConversionUploadErrorEnum.ConversionUploadError.V(10)
        )
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = (
            ConversionUploadErrorEnum.ConversionUploadError.V(11)
        )
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(
            12
        )
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(
            13
        )
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
            ConversionUploadErrorEnum.ConversionUploadError.V(14)
        )
        ORDER_ID_ALREADY_IN_USE = ConversionUploadErrorEnum.ConversionUploadError.V(15)
        DUPLICATE_ORDER_ID = ConversionUploadErrorEnum.ConversionUploadError.V(16)
        TOO_RECENT_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(17)
        EXPIRED_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(18)
        CALL_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(19)
        CONVERSION_PRECEDES_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(20)
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = (
            ConversionUploadErrorEnum.ConversionUploadError.V(21)
        )
        UNPARSEABLE_CALLERS_PHONE_NUMBER = (
            ConversionUploadErrorEnum.ConversionUploadError.V(22)
        )
    class ConversionUploadError(metaclass=_ConversionUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionUploadErrorEnum.ConversionUploadError.V(0)
    UNKNOWN = ConversionUploadErrorEnum.ConversionUploadError.V(1)
    TOO_MANY_CONVERSIONS_IN_REQUEST = ConversionUploadErrorEnum.ConversionUploadError.V(
        2
    )
    UNPARSEABLE_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(3)
    CONVERSION_PRECEDES_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(4)
    EXPIRED_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(5)
    TOO_RECENT_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(6)
    GCLID_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(7)
    UNAUTHORIZED_CUSTOMER = ConversionUploadErrorEnum.ConversionUploadError.V(8)
    INVALID_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(9)
    TOO_RECENT_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(10)
    CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = (
        ConversionUploadErrorEnum.ConversionUploadError.V(11)
    )
    EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(12)
    )
    EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(13)
    )
    ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(14)
    )
    ORDER_ID_ALREADY_IN_USE = ConversionUploadErrorEnum.ConversionUploadError.V(15)
    DUPLICATE_ORDER_ID = ConversionUploadErrorEnum.ConversionUploadError.V(16)
    TOO_RECENT_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(17)
    EXPIRED_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(18)
    CALL_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(19)
    CONVERSION_PRECEDES_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(20)
    CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = (
        ConversionUploadErrorEnum.ConversionUploadError.V(21)
    )
    UNPARSEABLE_CALLERS_PHONE_NUMBER = (
        ConversionUploadErrorEnum.ConversionUploadError.V(22)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionUploadErrorEnum = ConversionUploadErrorEnum
