"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ServedAssetFieldTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ServedAssetFieldType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ServedAssetFieldType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(0)
        UNKNOWN = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(1)
        HEADLINE_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(2)
        HEADLINE_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(3)
        HEADLINE_3 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(4)
        DESCRIPTION_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(5)
        DESCRIPTION_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(6)
    class ServedAssetFieldType(metaclass=_ServedAssetFieldType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(0)
    UNKNOWN = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(1)
    HEADLINE_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(2)
    HEADLINE_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(3)
    HEADLINE_3 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(4)
    DESCRIPTION_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(5)
    DESCRIPTION_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ServedAssetFieldTypeEnum = ServedAssetFieldTypeEnum
