"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_item_pb2
import grpc

from .feed_item_service_pb2 import *

class FeedItemServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItem(
        self,
        request: global___GetFeedItemRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem: ...
    def MutateFeedItems(
        self,
        request: global___MutateFeedItemsRequest,
    ) -> global___MutateFeedItemsResponse: ...

class FeedItemServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItem(
        self,
        request: global___GetFeedItemRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem: ...
    @abc.abstractmethod
    def MutateFeedItems(
        self,
        request: global___MutateFeedItemsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemsResponse: ...

def add_FeedItemServiceServicer_to_server(
    servicer: FeedItemServiceServicer, server: grpc.Server
) -> None: ...
