"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaTypeEnum.MediaType.V(0)
        UNKNOWN = MediaTypeEnum.MediaType.V(1)
        IMAGE = MediaTypeEnum.MediaType.V(2)
        ICON = MediaTypeEnum.MediaType.V(3)
        MEDIA_BUNDLE = MediaTypeEnum.MediaType.V(4)
        AUDIO = MediaTypeEnum.MediaType.V(5)
        VIDEO = MediaTypeEnum.MediaType.V(6)
        DYNAMIC_IMAGE = MediaTypeEnum.MediaType.V(7)
    class MediaType(metaclass=_MediaType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaTypeEnum.MediaType.V(0)
    UNKNOWN = MediaTypeEnum.MediaType.V(1)
    IMAGE = MediaTypeEnum.MediaType.V(2)
    ICON = MediaTypeEnum.MediaType.V(3)
    MEDIA_BUNDLE = MediaTypeEnum.MediaType.V(4)
    AUDIO = MediaTypeEnum.MediaType.V(5)
    VIDEO = MediaTypeEnum.MediaType.V(6)
    DYNAMIC_IMAGE = MediaTypeEnum.MediaType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___MediaTypeEnum = MediaTypeEnum
