"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SharedSetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SharedSetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SharedSetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SharedSetErrorEnum.SharedSetError.V(0)
        UNKNOWN = SharedSetErrorEnum.SharedSetError.V(1)
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = (
            SharedSetErrorEnum.SharedSetError.V(2)
        )
        DUPLICATE_NAME = SharedSetErrorEnum.SharedSetError.V(3)
        SHARED_SET_REMOVED = SharedSetErrorEnum.SharedSetError.V(4)
        SHARED_SET_IN_USE = SharedSetErrorEnum.SharedSetError.V(5)
    class SharedSetError(metaclass=_SharedSetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SharedSetErrorEnum.SharedSetError.V(0)
    UNKNOWN = SharedSetErrorEnum.SharedSetError.V(1)
    CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = (
        SharedSetErrorEnum.SharedSetError.V(2)
    )
    DUPLICATE_NAME = SharedSetErrorEnum.SharedSetError.V(3)
    SHARED_SET_REMOVED = SharedSetErrorEnum.SharedSetError.V(4)
    SHARED_SET_IN_USE = SharedSetErrorEnum.SharedSetError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___SharedSetErrorEnum = SharedSetErrorEnum
