"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FunctionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FunctionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FunctionError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FunctionErrorEnum.FunctionError.V(0)
        UNKNOWN = FunctionErrorEnum.FunctionError.V(1)
        INVALID_FUNCTION_FORMAT = FunctionErrorEnum.FunctionError.V(2)
        DATA_TYPE_MISMATCH = FunctionErrorEnum.FunctionError.V(3)
        INVALID_CONJUNCTION_OPERANDS = FunctionErrorEnum.FunctionError.V(4)
        INVALID_NUMBER_OF_OPERANDS = FunctionErrorEnum.FunctionError.V(5)
        INVALID_OPERAND_TYPE = FunctionErrorEnum.FunctionError.V(6)
        INVALID_OPERATOR = FunctionErrorEnum.FunctionError.V(7)
        INVALID_REQUEST_CONTEXT_TYPE = FunctionErrorEnum.FunctionError.V(8)
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(9)
        INVALID_FUNCTION_FOR_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(10)
        INVALID_OPERAND = FunctionErrorEnum.FunctionError.V(11)
        MISSING_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(12)
        INVALID_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(13)
        INVALID_NESTING = FunctionErrorEnum.FunctionError.V(14)
        MULTIPLE_FEED_IDS_NOT_SUPPORTED = FunctionErrorEnum.FunctionError.V(15)
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = FunctionErrorEnum.FunctionError.V(
            16
        )
        INVALID_ATTRIBUTE_NAME = FunctionErrorEnum.FunctionError.V(17)
    class FunctionError(metaclass=_FunctionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FunctionErrorEnum.FunctionError.V(0)
    UNKNOWN = FunctionErrorEnum.FunctionError.V(1)
    INVALID_FUNCTION_FORMAT = FunctionErrorEnum.FunctionError.V(2)
    DATA_TYPE_MISMATCH = FunctionErrorEnum.FunctionError.V(3)
    INVALID_CONJUNCTION_OPERANDS = FunctionErrorEnum.FunctionError.V(4)
    INVALID_NUMBER_OF_OPERANDS = FunctionErrorEnum.FunctionError.V(5)
    INVALID_OPERAND_TYPE = FunctionErrorEnum.FunctionError.V(6)
    INVALID_OPERATOR = FunctionErrorEnum.FunctionError.V(7)
    INVALID_REQUEST_CONTEXT_TYPE = FunctionErrorEnum.FunctionError.V(8)
    INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(9)
    INVALID_FUNCTION_FOR_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(10)
    INVALID_OPERAND = FunctionErrorEnum.FunctionError.V(11)
    MISSING_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(12)
    INVALID_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(13)
    INVALID_NESTING = FunctionErrorEnum.FunctionError.V(14)
    MULTIPLE_FEED_IDS_NOT_SUPPORTED = FunctionErrorEnum.FunctionError.V(15)
    INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = FunctionErrorEnum.FunctionError.V(16)
    INVALID_ATTRIBUTE_NAME = FunctionErrorEnum.FunctionError.V(17)
    def __init__(
        self,
    ) -> None: ...

global___FunctionErrorEnum = FunctionErrorEnum
