"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AttributionModelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AttributionModel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AttributionModel.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AttributionModelEnum.AttributionModel.V(0)
        UNKNOWN = AttributionModelEnum.AttributionModel.V(1)
        EXTERNAL = AttributionModelEnum.AttributionModel.V(100)
        GOOGLE_ADS_LAST_CLICK = AttributionModelEnum.AttributionModel.V(101)
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = AttributionModelEnum.AttributionModel.V(
            102
        )
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR = AttributionModelEnum.AttributionModel.V(103)
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = AttributionModelEnum.AttributionModel.V(
            104
        )
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = (
            AttributionModelEnum.AttributionModel.V(105)
        )
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = AttributionModelEnum.AttributionModel.V(
            106
        )
    class AttributionModel(metaclass=_AttributionModel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AttributionModelEnum.AttributionModel.V(0)
    UNKNOWN = AttributionModelEnum.AttributionModel.V(1)
    EXTERNAL = AttributionModelEnum.AttributionModel.V(100)
    GOOGLE_ADS_LAST_CLICK = AttributionModelEnum.AttributionModel.V(101)
    GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = AttributionModelEnum.AttributionModel.V(102)
    GOOGLE_SEARCH_ATTRIBUTION_LINEAR = AttributionModelEnum.AttributionModel.V(103)
    GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = AttributionModelEnum.AttributionModel.V(104)
    GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = AttributionModelEnum.AttributionModel.V(
        105
    )
    GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = AttributionModelEnum.AttributionModel.V(106)
    def __init__(
        self,
    ) -> None: ...

global___AttributionModelEnum = AttributionModelEnum
