"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UrlFieldErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UrlFieldError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UrlFieldError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UrlFieldErrorEnum.UrlFieldError.V(0)
        UNKNOWN = UrlFieldErrorEnum.UrlFieldError.V(1)
        INVALID_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(2)
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(3)
        MISSING_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(4)
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(5)
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(6)
        MALFORMED_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(7)
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(8)
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(9)
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(
            10
        )
        INVALID_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(11)
        INVALID_TAG_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(12)
        REDUNDANT_NESTED_FINAL_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(13)
        MISSING_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(14)
        INVALID_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(15)
        MALFORMED_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(16)
        MISSING_HOST_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(17)
        INVALID_TLD_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(18)
        INVALID_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(19)
        INVALID_TAG_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(20)
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(21)
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(22)
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(23)
        MALFORMED_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(24)
        MISSING_HOST_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(25)
        INVALID_TLD_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(26)
        INVALID_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(27)
        INVALID_TAG_IN_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(28)
        REDUNDANT_NESTED_FINAL_APP_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(29)
        MULTIPLE_APP_URLS_FOR_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(30)
        INVALID_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(31)
        INVALID_PROTOCOL_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(32)
        INVALID_PACKAGE_ID_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(33)
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = UrlFieldErrorEnum.UrlFieldError.V(
            34
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = (
            UrlFieldErrorEnum.UrlFieldError.V(39)
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = (
            UrlFieldErrorEnum.UrlFieldError.V(40)
        )
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(
            41
        )
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = UrlFieldErrorEnum.UrlFieldError.V(
            42
        )
        MISSING_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(43)
        INVALID_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(52)
        INVALID_URL = UrlFieldErrorEnum.UrlFieldError.V(44)
        DESTINATION_URL_DEPRECATED = UrlFieldErrorEnum.UrlFieldError.V(45)
        INVALID_TAG_IN_URL = UrlFieldErrorEnum.UrlFieldError.V(46)
        MISSING_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(47)
        DUPLICATE_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(48)
        INVALID_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(49)
        FINAL_URL_SUFFIX_MALFORMED = UrlFieldErrorEnum.UrlFieldError.V(50)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = UrlFieldErrorEnum.UrlFieldError.V(51)
        INVALID_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(53)
        MALFORMED_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(54)
        MALFORMED_URL = UrlFieldErrorEnum.UrlFieldError.V(55)
        MISSING_HOST = UrlFieldErrorEnum.UrlFieldError.V(56)
        NULL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(57)
    class UrlFieldError(metaclass=_UrlFieldError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UrlFieldErrorEnum.UrlFieldError.V(0)
    UNKNOWN = UrlFieldErrorEnum.UrlFieldError.V(1)
    INVALID_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(2)
    INVALID_TAG_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(3)
    MISSING_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(4)
    MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(5)
    INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(6)
    MALFORMED_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(7)
    MISSING_HOST_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(8)
    INVALID_TLD_IN_TRACKING_URL_TEMPLATE = UrlFieldErrorEnum.UrlFieldError.V(9)
    REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = UrlFieldErrorEnum.UrlFieldError.V(10)
    INVALID_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(11)
    INVALID_TAG_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(12)
    REDUNDANT_NESTED_FINAL_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(13)
    MISSING_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(14)
    INVALID_PROTOCOL_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(15)
    MALFORMED_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(16)
    MISSING_HOST_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(17)
    INVALID_TLD_IN_FINAL_URL = UrlFieldErrorEnum.UrlFieldError.V(18)
    INVALID_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(19)
    INVALID_TAG_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(20)
    REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(21)
    MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(22)
    INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(23)
    MALFORMED_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(24)
    MISSING_HOST_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(25)
    INVALID_TLD_IN_FINAL_MOBILE_URL = UrlFieldErrorEnum.UrlFieldError.V(26)
    INVALID_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(27)
    INVALID_TAG_IN_FINAL_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(28)
    REDUNDANT_NESTED_FINAL_APP_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(29)
    MULTIPLE_APP_URLS_FOR_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(30)
    INVALID_OSTYPE = UrlFieldErrorEnum.UrlFieldError.V(31)
    INVALID_PROTOCOL_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(32)
    INVALID_PACKAGE_ID_FOR_APP_URL = UrlFieldErrorEnum.UrlFieldError.V(33)
    URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = UrlFieldErrorEnum.UrlFieldError.V(34)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = UrlFieldErrorEnum.UrlFieldError.V(
        39
    )
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = (
        UrlFieldErrorEnum.UrlFieldError.V(40)
    )
    INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(41)
    REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = UrlFieldErrorEnum.UrlFieldError.V(42)
    MISSING_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(43)
    INVALID_PROTOCOL = UrlFieldErrorEnum.UrlFieldError.V(52)
    INVALID_URL = UrlFieldErrorEnum.UrlFieldError.V(44)
    DESTINATION_URL_DEPRECATED = UrlFieldErrorEnum.UrlFieldError.V(45)
    INVALID_TAG_IN_URL = UrlFieldErrorEnum.UrlFieldError.V(46)
    MISSING_URL_TAG = UrlFieldErrorEnum.UrlFieldError.V(47)
    DUPLICATE_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(48)
    INVALID_URL_ID = UrlFieldErrorEnum.UrlFieldError.V(49)
    FINAL_URL_SUFFIX_MALFORMED = UrlFieldErrorEnum.UrlFieldError.V(50)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = UrlFieldErrorEnum.UrlFieldError.V(51)
    INVALID_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(53)
    MALFORMED_TOP_LEVEL_DOMAIN = UrlFieldErrorEnum.UrlFieldError.V(54)
    MALFORMED_URL = UrlFieldErrorEnum.UrlFieldError.V(55)
    MISSING_HOST = UrlFieldErrorEnum.UrlFieldError.V(56)
    NULL_CUSTOM_PARAMETER_VALUE = UrlFieldErrorEnum.UrlFieldError.V(57)
    def __init__(
        self,
    ) -> None: ...

global___UrlFieldErrorEnum = UrlFieldErrorEnum
