"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.geographic_view_pb2
import grpc

from .geographic_view_service_pb2 import *

class GeographicViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetGeographicView(
        self,
        request: global___GetGeographicViewRequest,
    ) -> google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView: ...

class GeographicViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGeographicView(
        self,
        request: global___GetGeographicViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView: ...

def add_GeographicViewServiceServicer_to_server(
    servicer: GeographicViewServiceServicer, server: grpc.Server
) -> None: ...
