"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.remarketing_action_pb2
import grpc

from .remarketing_action_service_pb2 import *

class RemarketingActionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetRemarketingAction(
        self,
        request: global___GetRemarketingActionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.remarketing_action_pb2.RemarketingAction: ...
    def MutateRemarketingActions(
        self,
        request: global___MutateRemarketingActionsRequest,
    ) -> global___MutateRemarketingActionsResponse: ...

class RemarketingActionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetRemarketingAction(
        self,
        request: global___GetRemarketingActionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.remarketing_action_pb2.RemarketingAction: ...
    @abc.abstractmethod
    def MutateRemarketingActions(
        self,
        request: global___MutateRemarketingActionsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateRemarketingActionsResponse: ...

def add_RemarketingActionServiceServicer_to_server(
    servicer: RemarketingActionServiceServicer, server: grpc.Server
) -> None: ...
