"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.access_role_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    ACCESS_ROLE_FIELD_NUMBER: builtins.int
    ACCESS_CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    INVITER_USER_EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    user_id: builtins.int = ...
    email_address: typing.Text = ...
    access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = (
        ...
    )
    access_creation_date_time: typing.Text = ...
    inviter_user_email_address: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        user_id: builtins.int = ...,
        email_address: typing.Text = ...,
        access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = ...,
        access_creation_date_time: typing.Text = ...,
        inviter_user_email_address: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "access_role",
            b"access_role",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
            "resource_name",
            b"resource_name",
            "user_id",
            b"user_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_access_creation_date_time", b"_access_creation_date_time"
        ],
    ) -> typing_extensions.Literal["access_creation_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_email_address", b"_email_address"],
    ) -> typing_extensions.Literal["email_address"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_inviter_user_email_address", b"_inviter_user_email_address"
        ],
    ) -> typing_extensions.Literal["inviter_user_email_address"]: ...

global___CustomerUserAccess = CustomerUserAccess
