"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TrackingCodeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TrackingCodeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TrackingCodeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TrackingCodeTypeEnum.TrackingCodeType.V(0)
        UNKNOWN = TrackingCodeTypeEnum.TrackingCodeType.V(1)
        WEBPAGE = TrackingCodeTypeEnum.TrackingCodeType.V(2)
        WEBPAGE_ONCLICK = TrackingCodeTypeEnum.TrackingCodeType.V(3)
        CLICK_TO_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(4)
        WEBSITE_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(5)
    class TrackingCodeType(metaclass=_TrackingCodeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TrackingCodeTypeEnum.TrackingCodeType.V(0)
    UNKNOWN = TrackingCodeTypeEnum.TrackingCodeType.V(1)
    WEBPAGE = TrackingCodeTypeEnum.TrackingCodeType.V(2)
    WEBPAGE_ONCLICK = TrackingCodeTypeEnum.TrackingCodeType.V(3)
    CLICK_TO_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(4)
    WEBSITE_CALL = TrackingCodeTypeEnum.TrackingCodeType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___TrackingCodeTypeEnum = TrackingCodeTypeEnum
