"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccessErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerUserAccessError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerUserAccessError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(0)
        UNKNOWN = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(1)
        INVALID_USER_ID = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(2)
        REMOVAL_DISALLOWED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(3)
        DISALLOWED_ACCESS_ROLE = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(
            4
        )
        LAST_ADMIN_USER_OF_SERVING_CUSTOMER = (
            CustomerUserAccessErrorEnum.CustomerUserAccessError.V(5)
        )
        LAST_ADMIN_USER_OF_MANAGER = (
            CustomerUserAccessErrorEnum.CustomerUserAccessError.V(6)
        )
    class CustomerUserAccessError(metaclass=_CustomerUserAccessError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(0)
    UNKNOWN = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(1)
    INVALID_USER_ID = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(2)
    REMOVAL_DISALLOWED = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(3)
    DISALLOWED_ACCESS_ROLE = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(4)
    LAST_ADMIN_USER_OF_SERVING_CUSTOMER = (
        CustomerUserAccessErrorEnum.CustomerUserAccessError.V(5)
    )
    LAST_ADMIN_USER_OF_MANAGER = CustomerUserAccessErrorEnum.CustomerUserAccessError.V(
        6
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerUserAccessErrorEnum = CustomerUserAccessErrorEnum
