"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.offline_user_data_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2
import google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    CUSTOMER_MATCH_USER_LIST_METADATA_FIELD_NUMBER: builtins.int
    STORE_SALES_METADATA_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2.OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V = (
        ...
    )
    status: google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2.OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V = (
        ...
    )
    failure_reason: google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2.OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def external_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google.ads.google_ads.v5.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata: ...
    @property
    def store_sales_metadata(
        self,
    ) -> google.ads.google_ads.v5.proto.common.offline_user_data_pb2.StoreSalesMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        external_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        type: google.ads.google_ads.v5.proto.enums.offline_user_data_job_type_pb2.OfflineUserDataJobTypeEnum.OfflineUserDataJobType.V = ...,
        status: google.ads.google_ads.v5.proto.enums.offline_user_data_job_status_pb2.OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V = ...,
        failure_reason: google.ads.google_ads.v5.proto.enums.offline_user_data_job_failure_reason_pb2.OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V = ...,
        customer_match_user_list_metadata: typing.Optional[
            google.ads.google_ads.v5.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata
        ] = ...,
        store_sales_metadata: typing.Optional[
            google.ads.google_ads.v5.proto.common.offline_user_data_pb2.StoreSalesMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "store_sales_metadata",
            b"store_sales_metadata",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "failure_reason",
            b"failure_reason",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "store_sales_metadata",
            b"store_sales_metadata",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]
    ) -> typing_extensions.Literal[
        "customer_match_user_list_metadata", "store_sales_metadata"
    ]: ...

global___OfflineUserDataJob = OfflineUserDataJob
