"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PaymentsAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    SECONDARY_PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    PAYING_MANAGER_CUSTOMER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    payments_account_id: typing.Text = ...
    name: typing.Text = ...
    currency_code: typing.Text = ...
    payments_profile_id: typing.Text = ...
    secondary_payments_profile_id: typing.Text = ...
    paying_manager_customer: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        payments_account_id: typing.Text = ...,
        name: typing.Text = ...,
        currency_code: typing.Text = ...,
        payments_profile_id: typing.Text = ...,
        secondary_payments_profile_id: typing.Text = ...,
        paying_manager_customer: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "resource_name",
            b"resource_name",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_paying_manager_customer", b"_paying_manager_customer"
        ],
    ) -> typing_extensions.Literal["paying_manager_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions.Literal["payments_account_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions.Literal["payments_profile_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_secondary_payments_profile_id", b"_secondary_payments_profile_id"
        ],
    ) -> typing_extensions.Literal["secondary_payments_profile_id"]: ...

global___PaymentsAccount = PaymentsAccount
