"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionAdjustmentUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionAdjustmentUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionAdjustmentUploadError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(0)
        )
        UNKNOWN = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(
            1
        )
        TOO_RECENT_CONVERSION_ACTION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(2)
        )
        INVALID_CONVERSION_ACTION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(3)
        )
        CONVERSION_ALREADY_RETRACTED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(4)
        )
        CONVERSION_NOT_FOUND = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(5)
        )
        CONVERSION_EXPIRED = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(6)
        )
        ADJUSTMENT_PRECEDES_CONVERSION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(7)
        )
        MORE_RECENT_RESTATEMENT_FOUND = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(8)
        )
        TOO_RECENT_CONVERSION = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(9)
        )
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(10)
        )
        TOO_MANY_ADJUSTMENTS_IN_REQUEST = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(11)
        )
        TOO_MANY_ADJUSTMENTS = (
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(12)
        )
    class ConversionAdjustmentUploadError(metaclass=_ConversionAdjustmentUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(
        0
    )
    UNKNOWN = ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(1)
    TOO_RECENT_CONVERSION_ACTION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(2)
    )
    INVALID_CONVERSION_ACTION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(3)
    )
    CONVERSION_ALREADY_RETRACTED = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(4)
    )
    CONVERSION_NOT_FOUND = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(5)
    )
    CONVERSION_EXPIRED = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(6)
    )
    ADJUSTMENT_PRECEDES_CONVERSION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(7)
    )
    MORE_RECENT_RESTATEMENT_FOUND = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(8)
    )
    TOO_RECENT_CONVERSION = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(9)
    )
    CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(10)
    )
    TOO_MANY_ADJUSTMENTS_IN_REQUEST = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(11)
    )
    TOO_MANY_ADJUSTMENTS = (
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionAdjustmentUploadErrorEnum = ConversionAdjustmentUploadErrorEnum
