"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserInterestTaxonomyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserInterestTaxonomyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserInterestTaxonomyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(0)
        UNKNOWN = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(1)
        AFFINITY = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(2)
        IN_MARKET = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(3)
        MOBILE_APP_INSTALL_USER = (
            UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(4)
        )
        VERTICAL_GEO = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(5)
        NEW_SMART_PHONE_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(
            6
        )
    class UserInterestTaxonomyType(metaclass=_UserInterestTaxonomyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(0)
    UNKNOWN = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(1)
    AFFINITY = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(2)
    IN_MARKET = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(3)
    MOBILE_APP_INSTALL_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(4)
    VERTICAL_GEO = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(5)
    NEW_SMART_PHONE_USER = UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___UserInterestTaxonomyTypeEnum = UserInterestTaxonomyTypeEnum
