"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.recommendation_pb2
import grpc

from .recommendation_service_pb2 import *

class RecommendationServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetRecommendation(
        self,
        request: global___GetRecommendationRequest,
    ) -> google.ads.google_ads.v5.proto.resources.recommendation_pb2.Recommendation: ...
    def ApplyRecommendation(
        self,
        request: global___ApplyRecommendationRequest,
    ) -> global___ApplyRecommendationResponse: ...
    def DismissRecommendation(
        self,
        request: global___DismissRecommendationRequest,
    ) -> global___DismissRecommendationResponse: ...

class RecommendationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetRecommendation(
        self,
        request: global___GetRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.recommendation_pb2.Recommendation: ...
    @abc.abstractmethod
    def ApplyRecommendation(
        self,
        request: global___ApplyRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> global___ApplyRecommendationResponse: ...
    @abc.abstractmethod
    def DismissRecommendation(
        self,
        request: global___DismissRecommendationRequest,
        context: grpc.ServicerContext,
    ) -> global___DismissRecommendationResponse: ...

def add_RecommendationServiceServicer_to_server(
    servicer: RecommendationServiceServicer, server: grpc.Server
) -> None: ...
