"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .keyword_plan_idea_service_pb2 import *

class KeywordPlanIdeaServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GenerateKeywordIdeas(
        self,
        request: global___GenerateKeywordIdeasRequest,
    ) -> global___GenerateKeywordIdeaResponse: ...

class KeywordPlanIdeaServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GenerateKeywordIdeas(
        self,
        request: global___GenerateKeywordIdeasRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateKeywordIdeaResponse: ...

def add_KeywordPlanIdeaServiceServicer_to_server(
    servicer: KeywordPlanIdeaServiceServicer, server: grpc.Server
) -> None: ...
