"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeoTargetConstantSuggestionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GeoTargetConstantSuggestionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GeoTargetConstantSuggestionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(0)
        )
        UNKNOWN = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(1)
        )
        LOCATION_NAME_SIZE_LIMIT = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(2)
        )
        LOCATION_NAME_LIMIT = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(3)
        )
        INVALID_COUNTRY_CODE = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(4)
        )
        REQUEST_PARAMETERS_UNSET = (
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(5)
        )
    class GeoTargetConstantSuggestionError(metaclass=_GeoTargetConstantSuggestionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(0)
    )
    UNKNOWN = GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(1)
    LOCATION_NAME_SIZE_LIMIT = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(2)
    )
    LOCATION_NAME_LIMIT = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(3)
    )
    INVALID_COUNTRY_CODE = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(4)
    )
    REQUEST_PARAMETERS_UNSET = (
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___GeoTargetConstantSuggestionErrorEnum = GeoTargetConstantSuggestionErrorEnum
