"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaUploadError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
        UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
        FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
        UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
        ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
        FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
        EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
        INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
        ANIMATED_VISUAL_EFFECT = MediaUploadErrorEnum.MediaUploadError.V(9)
        ANIMATION_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(10)
        ASPECT_RATIO_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(11)
        AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(12)
        CMYK_JPEG_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(13)
        FLASH_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(14)
        FRAME_RATE_TOO_HIGH = MediaUploadErrorEnum.MediaUploadError.V(15)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
            MediaUploadErrorEnum.MediaUploadError.V(16)
        )
        IMAGE_CONSTRAINTS_VIOLATED = MediaUploadErrorEnum.MediaUploadError.V(17)
        INVALID_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(18)
        INVALID_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(19)
        INVALID_MIME_TYPE = MediaUploadErrorEnum.MediaUploadError.V(20)
        INVALID_PATH = MediaUploadErrorEnum.MediaUploadError.V(21)
        LAYOUT_PROBLEM = MediaUploadErrorEnum.MediaUploadError.V(22)
        MALFORMED_URL = MediaUploadErrorEnum.MediaUploadError.V(23)
        MEDIA_BUNDLE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(24)
        MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = (
            MediaUploadErrorEnum.MediaUploadError.V(25)
        )
        MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = (
            MediaUploadErrorEnum.MediaUploadError.V(26)
        )
        TOO_MANY_FILES_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(27)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
            MediaUploadErrorEnum.MediaUploadError.V(28)
        )
        UNSUPPORTED_HTML5_FEATURE = MediaUploadErrorEnum.MediaUploadError.V(29)
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaUploadErrorEnum.MediaUploadError.V(
            30
        )
        VIDEO_FILE_NAME_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(31)
        VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = MediaUploadErrorEnum.MediaUploadError.V(
            32
        )
        VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(33)
        CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = MediaUploadErrorEnum.MediaUploadError.V(
            34
        )
    class MediaUploadError(metaclass=_MediaUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
    UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
    FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
    UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
    ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
    FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
    EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
    INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    ANIMATED_VISUAL_EFFECT = MediaUploadErrorEnum.MediaUploadError.V(9)
    ANIMATION_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(10)
    ASPECT_RATIO_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(11)
    AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(12)
    CMYK_JPEG_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(13)
    FLASH_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(14)
    FRAME_RATE_TOO_HIGH = MediaUploadErrorEnum.MediaUploadError.V(15)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
        MediaUploadErrorEnum.MediaUploadError.V(16)
    )
    IMAGE_CONSTRAINTS_VIOLATED = MediaUploadErrorEnum.MediaUploadError.V(17)
    INVALID_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(18)
    INVALID_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(19)
    INVALID_MIME_TYPE = MediaUploadErrorEnum.MediaUploadError.V(20)
    INVALID_PATH = MediaUploadErrorEnum.MediaUploadError.V(21)
    LAYOUT_PROBLEM = MediaUploadErrorEnum.MediaUploadError.V(22)
    MALFORMED_URL = MediaUploadErrorEnum.MediaUploadError.V(23)
    MEDIA_BUNDLE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(24)
    MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = (
        MediaUploadErrorEnum.MediaUploadError.V(25)
    )
    MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = (
        MediaUploadErrorEnum.MediaUploadError.V(26)
    )
    TOO_MANY_FILES_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(27)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
        MediaUploadErrorEnum.MediaUploadError.V(28)
    )
    UNSUPPORTED_HTML5_FEATURE = MediaUploadErrorEnum.MediaUploadError.V(29)
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaUploadErrorEnum.MediaUploadError.V(30)
    VIDEO_FILE_NAME_TOO_LONG = MediaUploadErrorEnum.MediaUploadError.V(31)
    VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = MediaUploadErrorEnum.MediaUploadError.V(32)
    VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = MediaUploadErrorEnum.MediaUploadError.V(33)
    CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = MediaUploadErrorEnum.MediaUploadError.V(34)
    def __init__(
        self,
    ) -> None: ...

global___MediaUploadErrorEnum = MediaUploadErrorEnum
