"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class EducationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _EducationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            EducationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(0)
        UNKNOWN = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(1)
        PROGRAM_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(2)
        LOCATION_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(3)
        PROGRAM_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(4)
        AREA_OF_STUDY = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(5)
        PROGRAM_DESCRIPTION = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            6
        )
        SCHOOL_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(7)
        ADDRESS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(8)
        THUMBNAIL_IMAGE_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            9
        )
        ALTERNATIVE_THUMBNAIL_IMAGE_URL = (
            EducationPlaceholderFieldEnum.EducationPlaceholderField.V(10)
        )
        FINAL_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(11)
        FINAL_MOBILE_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            12
        )
        TRACKING_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(13)
        CONTEXTUAL_KEYWORDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            14
        )
        ANDROID_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(15)
        SIMILAR_PROGRAM_IDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(
            16
        )
        IOS_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(17)
        IOS_APP_STORE_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(18)
    class EducationPlaceholderField(metaclass=_EducationPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(0)
    UNKNOWN = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(1)
    PROGRAM_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(2)
    LOCATION_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(3)
    PROGRAM_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(4)
    AREA_OF_STUDY = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(5)
    PROGRAM_DESCRIPTION = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(6)
    SCHOOL_NAME = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(7)
    ADDRESS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(8)
    THUMBNAIL_IMAGE_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(9)
    ALTERNATIVE_THUMBNAIL_IMAGE_URL = (
        EducationPlaceholderFieldEnum.EducationPlaceholderField.V(10)
    )
    FINAL_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(11)
    FINAL_MOBILE_URLS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(12)
    TRACKING_URL = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(13)
    CONTEXTUAL_KEYWORDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(14)
    ANDROID_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(15)
    SIMILAR_PROGRAM_IDS = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(16)
    IOS_APP_LINK = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(17)
    IOS_APP_STORE_ID = EducationPlaceholderFieldEnum.EducationPlaceholderField.V(18)
    def __init__(
        self,
    ) -> None: ...

global___EducationPlaceholderFieldEnum = EducationPlaceholderFieldEnum
