"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(
    google.protobuf.message.Message
):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            0
        )
        UNKNOWN = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            1
        )
        HOSTNAME_NOT_FOUND = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            2
        )
        GOOGLE_CRAWLER_DNS_ISSUE = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
            3
        )
    class PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        metaclass=_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        0
    )
    UNKNOWN = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        1
    )
    HOSTNAME_NOT_FOUND = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        2
    )
    GOOGLE_CRAWLER_DNS_ISSUE = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType.V(
        3
    )
    def __init__(
        self,
    ) -> None: ...

global___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum = (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
)
