"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DateErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DateError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DateError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DateErrorEnum.DateError.V(0)
        UNKNOWN = DateErrorEnum.DateError.V(1)
        INVALID_FIELD_VALUES_IN_DATE = DateErrorEnum.DateError.V(2)
        INVALID_FIELD_VALUES_IN_DATE_TIME = DateErrorEnum.DateError.V(3)
        INVALID_STRING_DATE = DateErrorEnum.DateError.V(4)
        INVALID_STRING_DATE_TIME_MICROS = DateErrorEnum.DateError.V(6)
        INVALID_STRING_DATE_TIME_SECONDS = DateErrorEnum.DateError.V(11)
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = DateErrorEnum.DateError.V(12)
        EARLIER_THAN_MINIMUM_DATE = DateErrorEnum.DateError.V(7)
        LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(8)
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(9)
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = DateErrorEnum.DateError.V(10)
    class DateError(metaclass=_DateError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DateErrorEnum.DateError.V(0)
    UNKNOWN = DateErrorEnum.DateError.V(1)
    INVALID_FIELD_VALUES_IN_DATE = DateErrorEnum.DateError.V(2)
    INVALID_FIELD_VALUES_IN_DATE_TIME = DateErrorEnum.DateError.V(3)
    INVALID_STRING_DATE = DateErrorEnum.DateError.V(4)
    INVALID_STRING_DATE_TIME_MICROS = DateErrorEnum.DateError.V(6)
    INVALID_STRING_DATE_TIME_SECONDS = DateErrorEnum.DateError.V(11)
    INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = DateErrorEnum.DateError.V(12)
    EARLIER_THAN_MINIMUM_DATE = DateErrorEnum.DateError.V(7)
    LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(8)
    DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = DateErrorEnum.DateError.V(9)
    DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = DateErrorEnum.DateError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___DateErrorEnum = DateErrorEnum
