"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2
import google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenerateKeywordIdeasRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
    INCLUDE_ADULT_KEYWORDS_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_NETWORK_FIELD_NUMBER: builtins.int
    KEYWORD_AND_URL_SEED_FIELD_NUMBER: builtins.int
    KEYWORD_SEED_FIELD_NUMBER: builtins.int
    URL_SEED_FIELD_NUMBER: builtins.int
    SITE_SEED_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    include_adult_keywords: builtins.bool = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = (
        ...
    )
    @property
    def language(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def geo_target_constants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def keyword_and_url_seed(self) -> global___KeywordAndUrlSeed: ...
    @property
    def keyword_seed(self) -> global___KeywordSeed: ...
    @property
    def url_seed(self) -> global___UrlSeed: ...
    @property
    def site_seed(self) -> global___SiteSeed: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        language: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        geo_target_constants: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        include_adult_keywords: builtins.bool = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
        keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = ...,
        keyword_and_url_seed: typing.Optional[global___KeywordAndUrlSeed] = ...,
        keyword_seed: typing.Optional[global___KeywordSeed] = ...,
        url_seed: typing.Optional[global___UrlSeed] = ...,
        site_seed: typing.Optional[global___SiteSeed] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "geo_target_constants",
            b"geo_target_constants",
            "include_adult_keywords",
            b"include_adult_keywords",
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_plan_network",
            b"keyword_plan_network",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["seed", b"seed"]
    ) -> typing_extensions.Literal[
        "keyword_and_url_seed", "keyword_seed", "url_seed", "site_seed"
    ]: ...

global___GenerateKeywordIdeasRequest = GenerateKeywordIdeasRequest

class KeywordAndUrlSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def keywords(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        keywords: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["keywords", b"keywords", "url", b"url"],
    ) -> None: ...

global___KeywordAndUrlSeed = KeywordAndUrlSeed

class KeywordSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEYWORDS_FIELD_NUMBER: builtins.int
    @property
    def keywords(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    def __init__(
        self,
        *,
        keywords: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["keywords", b"keywords"]
    ) -> None: ...

global___KeywordSeed = KeywordSeed

class SiteSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SITE_FIELD_NUMBER: builtins.int
    @property
    def site(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        site: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["site", b"site"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["site", b"site"]
    ) -> None: ...

global___SiteSeed = SiteSeed

class UrlSeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["url", b"url"]
    ) -> None: ...

global___UrlSeed = UrlSeed

class GenerateKeywordIdeaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    total_size: builtins.int = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GenerateKeywordIdeaResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[global___GenerateKeywordIdeaResult]
        ] = ...,
        next_page_token: typing.Text = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_size",
            b"total_size",
        ],
    ) -> None: ...

global___GenerateKeywordIdeaResponse = GenerateKeywordIdeaResponse

class GenerateKeywordIdeaResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    KEYWORD_IDEA_METRICS_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def keyword_idea_metrics(
        self,
    ) -> google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        keyword_idea_metrics: typing.Optional[
            google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2.KeywordPlanHistoricalMetrics
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> None: ...

global___GenerateKeywordIdeaResult = GenerateKeywordIdeaResult
