"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdTypeEnum.AdType.V(0)
        UNKNOWN = AdTypeEnum.AdType.V(1)
        TEXT_AD = AdTypeEnum.AdType.V(2)
        EXPANDED_TEXT_AD = AdTypeEnum.AdType.V(3)
        CALL_ONLY_AD = AdTypeEnum.AdType.V(6)
        EXPANDED_DYNAMIC_SEARCH_AD = AdTypeEnum.AdType.V(7)
        HOTEL_AD = AdTypeEnum.AdType.V(8)
        SHOPPING_SMART_AD = AdTypeEnum.AdType.V(9)
        SHOPPING_PRODUCT_AD = AdTypeEnum.AdType.V(10)
        VIDEO_AD = AdTypeEnum.AdType.V(12)
        GMAIL_AD = AdTypeEnum.AdType.V(13)
        IMAGE_AD = AdTypeEnum.AdType.V(14)
        RESPONSIVE_SEARCH_AD = AdTypeEnum.AdType.V(15)
        LEGACY_RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(16)
        APP_AD = AdTypeEnum.AdType.V(17)
        LEGACY_APP_INSTALL_AD = AdTypeEnum.AdType.V(18)
        RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(19)
        LOCAL_AD = AdTypeEnum.AdType.V(20)
        HTML5_UPLOAD_AD = AdTypeEnum.AdType.V(21)
        DYNAMIC_HTML5_AD = AdTypeEnum.AdType.V(22)
        APP_ENGAGEMENT_AD = AdTypeEnum.AdType.V(23)
        SHOPPING_COMPARISON_LISTING_AD = AdTypeEnum.AdType.V(24)
        VIDEO_BUMPER_AD = AdTypeEnum.AdType.V(25)
        VIDEO_NON_SKIPPABLE_IN_STREAM_AD = AdTypeEnum.AdType.V(26)
        VIDEO_OUTSTREAM_AD = AdTypeEnum.AdType.V(27)
        VIDEO_TRUEVIEW_DISCOVERY_AD = AdTypeEnum.AdType.V(28)
        VIDEO_TRUEVIEW_IN_STREAM_AD = AdTypeEnum.AdType.V(29)
        VIDEO_RESPONSIVE_AD = AdTypeEnum.AdType.V(30)
    class AdType(metaclass=_AdType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdTypeEnum.AdType.V(0)
    UNKNOWN = AdTypeEnum.AdType.V(1)
    TEXT_AD = AdTypeEnum.AdType.V(2)
    EXPANDED_TEXT_AD = AdTypeEnum.AdType.V(3)
    CALL_ONLY_AD = AdTypeEnum.AdType.V(6)
    EXPANDED_DYNAMIC_SEARCH_AD = AdTypeEnum.AdType.V(7)
    HOTEL_AD = AdTypeEnum.AdType.V(8)
    SHOPPING_SMART_AD = AdTypeEnum.AdType.V(9)
    SHOPPING_PRODUCT_AD = AdTypeEnum.AdType.V(10)
    VIDEO_AD = AdTypeEnum.AdType.V(12)
    GMAIL_AD = AdTypeEnum.AdType.V(13)
    IMAGE_AD = AdTypeEnum.AdType.V(14)
    RESPONSIVE_SEARCH_AD = AdTypeEnum.AdType.V(15)
    LEGACY_RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(16)
    APP_AD = AdTypeEnum.AdType.V(17)
    LEGACY_APP_INSTALL_AD = AdTypeEnum.AdType.V(18)
    RESPONSIVE_DISPLAY_AD = AdTypeEnum.AdType.V(19)
    LOCAL_AD = AdTypeEnum.AdType.V(20)
    HTML5_UPLOAD_AD = AdTypeEnum.AdType.V(21)
    DYNAMIC_HTML5_AD = AdTypeEnum.AdType.V(22)
    APP_ENGAGEMENT_AD = AdTypeEnum.AdType.V(23)
    SHOPPING_COMPARISON_LISTING_AD = AdTypeEnum.AdType.V(24)
    VIDEO_BUMPER_AD = AdTypeEnum.AdType.V(25)
    VIDEO_NON_SKIPPABLE_IN_STREAM_AD = AdTypeEnum.AdType.V(26)
    VIDEO_OUTSTREAM_AD = AdTypeEnum.AdType.V(27)
    VIDEO_TRUEVIEW_DISCOVERY_AD = AdTypeEnum.AdType.V(28)
    VIDEO_TRUEVIEW_IN_STREAM_AD = AdTypeEnum.AdType.V(29)
    VIDEO_RESPONSIVE_AD = AdTypeEnum.AdType.V(30)
    def __init__(
        self,
    ) -> None: ...

global___AdTypeEnum = AdTypeEnum
