"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ParentalStatusTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ParentalStatusType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ParentalStatusType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ParentalStatusTypeEnum.ParentalStatusType.V(0)
        UNKNOWN = ParentalStatusTypeEnum.ParentalStatusType.V(1)
        PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(300)
        NOT_A_PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(301)
        UNDETERMINED = ParentalStatusTypeEnum.ParentalStatusType.V(302)
    class ParentalStatusType(metaclass=_ParentalStatusType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ParentalStatusTypeEnum.ParentalStatusType.V(0)
    UNKNOWN = ParentalStatusTypeEnum.ParentalStatusType.V(1)
    PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(300)
    NOT_A_PARENT = ParentalStatusTypeEnum.ParentalStatusType.V(301)
    UNDETERMINED = ParentalStatusTypeEnum.ParentalStatusType.V(302)
    def __init__(
        self,
    ) -> None: ...

global___ParentalStatusTypeEnum = ParentalStatusTypeEnum
