"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.bidding_pb2
import google.ads.google_ads.v4.proto.common.custom_parameter_pb2
import google.ads.google_ads.v4.proto.common.frequency_cap_pb2
import google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2
import google.ads.google_ads.v4.proto.common.targeting_setting_pb2
import google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2
import google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2
import google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2
import google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2
import google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2
import google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2
import google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2
import google.ads.google_ads.v4.proto.enums.campaign_status_pb2
import google.ads.google_ads.v4.proto.enums.location_source_type_pb2
import google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2
import google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2
import google.ads.google_ads.v4.proto.enums.payment_mode_pb2
import google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2
import google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2
import google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Campaign(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class NetworkSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TARGET_GOOGLE_SEARCH_FIELD_NUMBER: builtins.int
        TARGET_SEARCH_NETWORK_FIELD_NUMBER: builtins.int
        TARGET_CONTENT_NETWORK_FIELD_NUMBER: builtins.int
        TARGET_PARTNER_SEARCH_NETWORK_FIELD_NUMBER: builtins.int
        @property
        def target_google_search(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_search_network(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_content_network(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def target_partner_search_network(
            self,
        ) -> google.protobuf.wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            target_google_search: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_search_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_content_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            target_partner_search_network: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> None: ...
    class HotelSettingInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        HOTEL_CENTER_ID_FIELD_NUMBER: builtins.int
        @property
        def hotel_center_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            hotel_center_id: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> None: ...
    class DynamicSearchAdsSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DOMAIN_NAME_FIELD_NUMBER: builtins.int
        LANGUAGE_CODE_FIELD_NUMBER: builtins.int
        USE_SUPPLIED_URLS_ONLY_FIELD_NUMBER: builtins.int
        FEEDS_FIELD_NUMBER: builtins.int
        @property
        def domain_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def use_supplied_urls_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def feeds(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            domain_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            language_code: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            use_supplied_urls_only: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            feeds: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "domain_name",
                b"domain_name",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "domain_name",
                b"domain_name",
                "feeds",
                b"feeds",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> None: ...
    class SelectiveOptimization(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONVERSION_ACTIONS_FIELD_NUMBER: builtins.int
        @property
        def conversion_actions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            conversion_actions: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "conversion_actions", b"conversion_actions"
            ],
        ) -> None: ...
    class ShoppingSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MERCHANT_ID_FIELD_NUMBER: builtins.int
        SALES_COUNTRY_FIELD_NUMBER: builtins.int
        CAMPAIGN_PRIORITY_FIELD_NUMBER: builtins.int
        ENABLE_LOCAL_FIELD_NUMBER: builtins.int
        @property
        def merchant_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def sales_country(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def campaign_priority(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
        @property
        def enable_local(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            merchant_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
            sales_country: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            campaign_priority: typing.Optional[
                google.protobuf.wrappers_pb2.Int32Value
            ] = ...,
            enable_local: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> None: ...
    class LocalCampaignSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LOCATION_SOURCE_TYPE_FIELD_NUMBER: builtins.int
        location_source_type: google.ads.google_ads.v4.proto.enums.location_source_type_pb2.LocationSourceTypeEnum.LocationSourceType.V = (
            ...
        )
        def __init__(
            self,
            *,
            location_source_type: google.ads.google_ads.v4.proto.enums.location_source_type_pb2.LocationSourceTypeEnum.LocationSourceType.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "location_source_type", b"location_source_type"
            ],
        ) -> None: ...
    class TrackingSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TRACKING_URL_FIELD_NUMBER: builtins.int
        @property
        def tracking_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            tracking_url: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["tracking_url", b"tracking_url"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["tracking_url", b"tracking_url"]
        ) -> None: ...
    class GeoTargetTypeSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        POSITIVE_GEO_TARGET_TYPE_FIELD_NUMBER: builtins.int
        NEGATIVE_GEO_TARGET_TYPE_FIELD_NUMBER: builtins.int
        positive_geo_target_type: google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2.PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V = (
            ...
        )
        negative_geo_target_type: google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2.NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V = (
            ...
        )
        def __init__(
            self,
            *,
            positive_geo_target_type: google.ads.google_ads.v4.proto.enums.positive_geo_target_type_pb2.PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V = ...,
            negative_geo_target_type: google.ads.google_ads.v4.proto.enums.negative_geo_target_type_pb2.NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "negative_geo_target_type",
                b"negative_geo_target_type",
                "positive_geo_target_type",
                b"positive_geo_target_type",
            ],
        ) -> None: ...
    class AppCampaignSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BIDDING_STRATEGY_GOAL_TYPE_FIELD_NUMBER: builtins.int
        APP_ID_FIELD_NUMBER: builtins.int
        APP_STORE_FIELD_NUMBER: builtins.int
        bidding_strategy_goal_type: google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V = (
            ...
        )
        app_store: google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2.AppCampaignAppStoreEnum.AppCampaignAppStore.V = (
            ...
        )
        @property
        def app_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            bidding_strategy_goal_type: google.ads.google_ads.v4.proto.enums.app_campaign_bidding_strategy_goal_type_pb2.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V = ...,
            app_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
            app_store: google.ads.google_ads.v4.proto.enums.app_campaign_app_store_pb2.AppCampaignAppStoreEnum.AppCampaignAppStore.V = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["app_id", b"app_id"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "app_id",
                b"app_id",
                "app_store",
                b"app_store",
                "bidding_strategy_goal_type",
                b"bidding_strategy_goal_type",
            ],
        ) -> None: ...
    class OptimizationGoalSetting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        OPTIMIZATION_GOAL_TYPES_FIELD_NUMBER: builtins.int
        optimization_goal_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2.OptimizationGoalTypeEnum.OptimizationGoalType.V
        ] = ...
        def __init__(
            self,
            *,
            optimization_goal_types: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v4.proto.enums.optimization_goal_type_pb2.OptimizationGoalTypeEnum.OptimizationGoalType.V
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "optimization_goal_types", b"optimization_goal_types"
            ],
        ) -> None: ...
    class VanityPharma(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VANITY_PHARMA_DISPLAY_URL_MODE_FIELD_NUMBER: builtins.int
        VANITY_PHARMA_TEXT_FIELD_NUMBER: builtins.int
        vanity_pharma_display_url_mode: google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode.V = (
            ...
        )
        vanity_pharma_text: google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2.VanityPharmaTextEnum.VanityPharmaText.V = (
            ...
        )
        def __init__(
            self,
            *,
            vanity_pharma_display_url_mode: google.ads.google_ads.v4.proto.enums.vanity_pharma_display_url_mode_pb2.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode.V = ...,
            vanity_pharma_text: google.ads.google_ads.v4.proto.enums.vanity_pharma_text_pb2.VanityPharmaTextEnum.VanityPharmaText.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "vanity_pharma_display_url_mode",
                b"vanity_pharma_display_url_mode",
                "vanity_pharma_text",
                b"vanity_pharma_text",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SERVING_STATUS_FIELD_NUMBER: builtins.int
    AD_SERVING_OPTIMIZATION_STATUS_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    REAL_TIME_BIDDING_SETTING_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    HOTEL_SETTING_FIELD_NUMBER: builtins.int
    DYNAMIC_SEARCH_ADS_SETTING_FIELD_NUMBER: builtins.int
    SHOPPING_SETTING_FIELD_NUMBER: builtins.int
    TARGETING_SETTING_FIELD_NUMBER: builtins.int
    GEO_TARGET_TYPE_SETTING_FIELD_NUMBER: builtins.int
    LOCAL_CAMPAIGN_SETTING_FIELD_NUMBER: builtins.int
    APP_CAMPAIGN_SETTING_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    EXPERIMENT_TYPE_FIELD_NUMBER: builtins.int
    BASE_CAMPAIGN_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_TYPE_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    FREQUENCY_CAPS_FIELD_NUMBER: builtins.int
    VIDEO_BRAND_SAFETY_SUITABILITY_FIELD_NUMBER: builtins.int
    VANITY_PHARMA_FIELD_NUMBER: builtins.int
    SELECTIVE_OPTIMIZATION_FIELD_NUMBER: builtins.int
    OPTIMIZATION_GOAL_SETTING_FIELD_NUMBER: builtins.int
    TRACKING_SETTING_FIELD_NUMBER: builtins.int
    PAYMENT_MODE_FIELD_NUMBER: builtins.int
    OPTIMIZATION_SCORE_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_FIELD_NUMBER: builtins.int
    COMMISSION_FIELD_NUMBER: builtins.int
    MANUAL_CPC_FIELD_NUMBER: builtins.int
    MANUAL_CPM_FIELD_NUMBER: builtins.int
    MANUAL_CPV_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSIONS_FIELD_NUMBER: builtins.int
    MAXIMIZE_CONVERSION_VALUE_FIELD_NUMBER: builtins.int
    TARGET_CPA_FIELD_NUMBER: builtins.int
    TARGET_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    TARGET_SPEND_FIELD_NUMBER: builtins.int
    PERCENT_CPC_FIELD_NUMBER: builtins.int
    TARGET_CPM_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.campaign_status_pb2.CampaignStatusEnum.CampaignStatus.V = (
        ...
    )
    serving_status: google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2.CampaignServingStatusEnum.CampaignServingStatus.V = (
        ...
    )
    ad_serving_optimization_status: google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2.AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V = (
        ...
    )
    advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = (
        ...
    )
    advertising_channel_sub_type: google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V = (
        ...
    )
    experiment_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2.CampaignExperimentTypeEnum.CampaignExperimentType.V = (
        ...
    )
    bidding_strategy_type: google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = (
        ...
    )
    video_brand_safety_suitability: google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2.BrandSafetySuitabilityEnum.BrandSafetySuitability.V = (
        ...
    )
    payment_mode: google.ads.google_ads.v4.proto.enums.payment_mode_pb2.PaymentModeEnum.PaymentMode.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def real_time_bidding_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2.RealTimeBiddingSetting: ...
    @property
    def network_settings(self) -> global___Campaign.NetworkSettings: ...
    @property
    def hotel_setting(self) -> global___Campaign.HotelSettingInfo: ...
    @property
    def dynamic_search_ads_setting(
        self,
    ) -> global___Campaign.DynamicSearchAdsSetting: ...
    @property
    def shopping_setting(self) -> global___Campaign.ShoppingSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.common.targeting_setting_pb2.TargetingSetting: ...
    @property
    def geo_target_type_setting(self) -> global___Campaign.GeoTargetTypeSetting: ...
    @property
    def local_campaign_setting(self) -> global___Campaign.LocalCampaignSetting: ...
    @property
    def app_campaign_setting(self) -> global___Campaign.AppCampaignSetting: ...
    @property
    def labels(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def base_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_budget(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def frequency_caps(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.frequency_cap_pb2.FrequencyCapEntry
    ]: ...
    @property
    def vanity_pharma(self) -> global___Campaign.VanityPharma: ...
    @property
    def selective_optimization(self) -> global___Campaign.SelectiveOptimization: ...
    @property
    def optimization_goal_setting(
        self,
    ) -> global___Campaign.OptimizationGoalSetting: ...
    @property
    def tracking_setting(self) -> global___Campaign.TrackingSetting: ...
    @property
    def optimization_score(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bidding_strategy(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def commission(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.Commission: ...
    @property
    def manual_cpc(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpc: ...
    @property
    def manual_cpm(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpm: ...
    @property
    def manual_cpv(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpv: ...
    @property
    def maximize_conversions(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversions: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversionValue: ...
    @property
    def target_cpa(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetSpend: ...
    @property
    def percent_cpc(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.PercentCpc: ...
    @property
    def target_cpm(
        self,
    ) -> google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpm: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        status: google.ads.google_ads.v4.proto.enums.campaign_status_pb2.CampaignStatusEnum.CampaignStatus.V = ...,
        serving_status: google.ads.google_ads.v4.proto.enums.campaign_serving_status_pb2.CampaignServingStatusEnum.CampaignServingStatus.V = ...,
        ad_serving_optimization_status: google.ads.google_ads.v4.proto.enums.ad_serving_optimization_status_pb2.AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V = ...,
        advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = ...,
        advertising_channel_sub_type: google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        real_time_bidding_setting: typing.Optional[
            google.ads.google_ads.v4.proto.common.real_time_bidding_setting_pb2.RealTimeBiddingSetting
        ] = ...,
        network_settings: typing.Optional[global___Campaign.NetworkSettings] = ...,
        hotel_setting: typing.Optional[global___Campaign.HotelSettingInfo] = ...,
        dynamic_search_ads_setting: typing.Optional[
            global___Campaign.DynamicSearchAdsSetting
        ] = ...,
        shopping_setting: typing.Optional[global___Campaign.ShoppingSetting] = ...,
        targeting_setting: typing.Optional[
            google.ads.google_ads.v4.proto.common.targeting_setting_pb2.TargetingSetting
        ] = ...,
        geo_target_type_setting: typing.Optional[
            global___Campaign.GeoTargetTypeSetting
        ] = ...,
        local_campaign_setting: typing.Optional[
            global___Campaign.LocalCampaignSetting
        ] = ...,
        app_campaign_setting: typing.Optional[
            global___Campaign.AppCampaignSetting
        ] = ...,
        labels: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        experiment_type: google.ads.google_ads.v4.proto.enums.campaign_experiment_type_pb2.CampaignExperimentTypeEnum.CampaignExperimentType.V = ...,
        base_campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        campaign_budget: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        bidding_strategy_type: google.ads.google_ads.v4.proto.enums.bidding_strategy_type_pb2.BiddingStrategyTypeEnum.BiddingStrategyType.V = ...,
        start_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        frequency_caps: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.frequency_cap_pb2.FrequencyCapEntry
            ]
        ] = ...,
        video_brand_safety_suitability: google.ads.google_ads.v4.proto.enums.brand_safety_suitability_pb2.BrandSafetySuitabilityEnum.BrandSafetySuitability.V = ...,
        vanity_pharma: typing.Optional[global___Campaign.VanityPharma] = ...,
        selective_optimization: typing.Optional[
            global___Campaign.SelectiveOptimization
        ] = ...,
        optimization_goal_setting: typing.Optional[
            global___Campaign.OptimizationGoalSetting
        ] = ...,
        tracking_setting: typing.Optional[global___Campaign.TrackingSetting] = ...,
        payment_mode: google.ads.google_ads.v4.proto.enums.payment_mode_pb2.PaymentModeEnum.PaymentMode.V = ...,
        optimization_score: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        bidding_strategy: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        commission: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.Commission
        ] = ...,
        manual_cpc: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpc
        ] = ...,
        manual_cpm: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpm
        ] = ...,
        manual_cpv: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.ManualCpv
        ] = ...,
        maximize_conversions: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversions
        ] = ...,
        maximize_conversion_value: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.MaximizeConversionValue
        ] = ...,
        target_cpa: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpa
        ] = ...,
        target_impression_share: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetImpressionShare
        ] = ...,
        target_roas: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetRoas
        ] = ...,
        target_spend: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetSpend
        ] = ...,
        percent_cpc: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.PercentCpc
        ] = ...,
        target_cpm: typing.Optional[
            google.ads.google_ads.v4.proto.common.bidding_pb2.TargetCpm
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "final_url_suffix",
            b"final_url_suffix",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "local_campaign_setting",
            b"local_campaign_setting",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_goal_setting",
            b"optimization_goal_setting",
            "optimization_score",
            b"optimization_score",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "selective_optimization",
            b"selective_optimization",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "vanity_pharma",
            b"vanity_pharma",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_serving_optimization_status",
            b"ad_serving_optimization_status",
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "bidding_strategy_type",
            b"bidding_strategy_type",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "experiment_type",
            b"experiment_type",
            "final_url_suffix",
            b"final_url_suffix",
            "frequency_caps",
            b"frequency_caps",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "labels",
            b"labels",
            "local_campaign_setting",
            b"local_campaign_setting",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_goal_setting",
            b"optimization_goal_setting",
            "optimization_score",
            b"optimization_score",
            "payment_mode",
            b"payment_mode",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "resource_name",
            b"resource_name",
            "selective_optimization",
            b"selective_optimization",
            "serving_status",
            b"serving_status",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
            "vanity_pharma",
            b"vanity_pharma",
            "video_brand_safety_suitability",
            b"video_brand_safety_suitability",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "campaign_bidding_strategy", b"campaign_bidding_strategy"
        ],
    ) -> typing_extensions.Literal[
        "bidding_strategy",
        "commission",
        "manual_cpc",
        "manual_cpm",
        "manual_cpv",
        "maximize_conversions",
        "maximize_conversion_value",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
        "percent_cpc",
        "target_cpm",
    ]: ...

global___Campaign = Campaign
