"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Value(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    INT64_VALUE_FIELD_NUMBER: builtins.int
    FLOAT_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    boolean_value: builtins.bool = ...
    int64_value: builtins.int = ...
    float_value: builtins.float = ...
    double_value: builtins.float = ...
    string_value: typing.Text = ...
    def __init__(
        self,
        *,
        boolean_value: builtins.bool = ...,
        int64_value: builtins.int = ...,
        float_value: builtins.float = ...,
        double_value: builtins.float = ...,
        string_value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "float_value",
            b"float_value",
            "int64_value",
            b"int64_value",
            "string_value",
            b"string_value",
            "value",
            b"value",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["value", b"value"]
    ) -> typing_extensions.Literal[
        "boolean_value", "int64_value", "float_value", "double_value", "string_value"
    ]: ...

global___Value = Value
