"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(0)
        UNKNOWN = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(1)
        INVALID_USER_LIST_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(3)
        INVALID_USER_LIST_TYPE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            4
        )
        NOT_ON_ALLOWLIST_FOR_USER_ID = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(33)
        )
        INCOMPATIBLE_UPLOAD_KEY_TYPE = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(6)
        )
        MISSING_USER_IDENTIFIER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            7
        )
        INVALID_MOBILE_ID_FORMAT = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(8)
        )
        TOO_MANY_USER_IDENTIFIERS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(9)
        )
        NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(31)
        )
        NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(32)
        )
        INVALID_PARTNER_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(11)
        INVALID_ENCODING = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(12)
        INVALID_COUNTRY_CODE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(13)
        INCOMPATIBLE_USER_IDENTIFIER = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(14)
        )
        FUTURE_TRANSACTION_TIME = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            15
        )
        INVALID_CONVERSION_ACTION = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(16)
        )
        MOBILE_ID_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            17
        )
        INVALID_OPERATION_ORDER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            18
        )
        CONFLICTING_OPERATION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            19
        )
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(21)
        )
        JOB_ALREADY_STARTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(22)
        REMOVE_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(23)
        REMOVE_ALL_NOT_SUPPORTED = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(24)
        )
        INVALID_SHA256_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
            25
        )
        CUSTOM_KEY_DISABLED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(26)
        CUSTOM_KEY_NOT_PREDEFINED = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(27)
        )
        CUSTOM_KEY_NOT_SET = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(29)
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(30)
        )
        ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(34)
        )
        LIFETIME_VALUE_BUCKET_NOT_IN_RANGE = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(35)
        )
        INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES = (
            OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(36)
        )
    class OfflineUserDataJobError(metaclass=_OfflineUserDataJobError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(0)
    UNKNOWN = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(1)
    INVALID_USER_LIST_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(3)
    INVALID_USER_LIST_TYPE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(4)
    NOT_ON_ALLOWLIST_FOR_USER_ID = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(33)
    )
    INCOMPATIBLE_UPLOAD_KEY_TYPE = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(6)
    )
    MISSING_USER_IDENTIFIER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(7)
    INVALID_MOBILE_ID_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(8)
    TOO_MANY_USER_IDENTIFIERS = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(9)
    NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(31)
    )
    NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(32)
    )
    INVALID_PARTNER_ID = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(11)
    INVALID_ENCODING = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(12)
    INVALID_COUNTRY_CODE = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(13)
    INCOMPATIBLE_USER_IDENTIFIER = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(14)
    )
    FUTURE_TRANSACTION_TIME = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(15)
    INVALID_CONVERSION_ACTION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
        16
    )
    MOBILE_ID_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(17)
    INVALID_OPERATION_ORDER = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(18)
    CONFLICTING_OPERATION = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(19)
    EXTERNAL_UPDATE_ID_ALREADY_EXISTS = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(21)
    )
    JOB_ALREADY_STARTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(22)
    REMOVE_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(23)
    REMOVE_ALL_NOT_SUPPORTED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(24)
    INVALID_SHA256_FORMAT = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(25)
    CUSTOM_KEY_DISABLED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(26)
    CUSTOM_KEY_NOT_PREDEFINED = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(
        27
    )
    CUSTOM_KEY_NOT_SET = OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(29)
    CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(30)
    )
    ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(34)
    )
    LIFETIME_VALUE_BUCKET_NOT_IN_RANGE = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(35)
    )
    INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES = (
        OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V(36)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobErrorEnum = OfflineUserDataJobErrorEnum
