"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_budget_pb2
import grpc

from .campaign_budget_service_pb2 import *

class CampaignBudgetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignBudget(
        self,
        request: global___GetCampaignBudgetRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_budget_pb2.CampaignBudget: ...
    def MutateCampaignBudgets(
        self,
        request: global___MutateCampaignBudgetsRequest,
    ) -> global___MutateCampaignBudgetsResponse: ...

class CampaignBudgetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignBudget(
        self,
        request: global___GetCampaignBudgetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_budget_pb2.CampaignBudget: ...
    @abc.abstractmethod
    def MutateCampaignBudgets(
        self,
        request: global___MutateCampaignBudgetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignBudgetsResponse: ...

def add_CampaignBudgetServiceServicer_to_server(
    servicer: CampaignBudgetServiceServicer, server: grpc.Server
) -> None: ...
