"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2
import grpc

from .campaign_bid_modifier_service_pb2 import *

class CampaignBidModifierServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignBidModifier(
        self,
        request: global___GetCampaignBidModifierRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier: ...
    def MutateCampaignBidModifiers(
        self,
        request: global___MutateCampaignBidModifiersRequest,
    ) -> global___MutateCampaignBidModifiersResponse: ...

class CampaignBidModifierServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignBidModifier(
        self,
        request: global___GetCampaignBidModifierRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier: ...
    @abc.abstractmethod
    def MutateCampaignBidModifiers(
        self,
        request: global___MutateCampaignBidModifiersRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignBidModifiersResponse: ...

def add_CampaignBidModifierServiceServicer_to_server(
    servicer: CampaignBidModifierServiceServicer, server: grpc.Server
) -> None: ...
