"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ThirdPartyAppAnalyticsLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ThirdPartyAppAnalyticsLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ThirdPartyAppAnalyticsLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(0)
        )
        UNKNOWN = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(
            1
        )
        INVALID_ANALYTICS_PROVIDER_ID = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(2)
        )
        INVALID_MOBILE_APP_ID = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(3)
        )
        MOBILE_APP_IS_NOT_ENABLED = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(4)
        )
        CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = (
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(5)
        )
    class ThirdPartyAppAnalyticsLinkError(metaclass=_ThirdPartyAppAnalyticsLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(
        0
    )
    UNKNOWN = ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(1)
    INVALID_ANALYTICS_PROVIDER_ID = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(2)
    )
    INVALID_MOBILE_APP_ID = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(3)
    )
    MOBILE_APP_IS_NOT_ENABLED = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(4)
    )
    CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = (
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___ThirdPartyAppAnalyticsLinkErrorEnum = ThirdPartyAppAnalyticsLinkErrorEnum
