"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .reach_plan_service_pb2 import *

class ReachPlanServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def ListPlannableLocations(
        self,
        request: global___ListPlannableLocationsRequest,
    ) -> global___ListPlannableLocationsResponse: ...
    def ListPlannableProducts(
        self,
        request: global___ListPlannableProductsRequest,
    ) -> global___ListPlannableProductsResponse: ...
    def GenerateProductMixIdeas(
        self,
        request: global___GenerateProductMixIdeasRequest,
    ) -> global___GenerateProductMixIdeasResponse: ...
    def GenerateReachForecast(
        self,
        request: global___GenerateReachForecastRequest,
    ) -> global___GenerateReachForecastResponse: ...

class ReachPlanServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListPlannableLocations(
        self,
        request: global___ListPlannableLocationsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListPlannableLocationsResponse: ...
    @abc.abstractmethod
    def ListPlannableProducts(
        self,
        request: global___ListPlannableProductsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListPlannableProductsResponse: ...
    @abc.abstractmethod
    def GenerateProductMixIdeas(
        self,
        request: global___GenerateProductMixIdeasRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateProductMixIdeasResponse: ...
    @abc.abstractmethod
    def GenerateReachForecast(
        self,
        request: global___GenerateReachForecastRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateReachForecastResponse: ...

def add_ReachPlanServiceServicer_to_server(
    servicer: ReachPlanServiceServicer, server: grpc.Server
) -> None: ...
