"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CallType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CallType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CallTypeEnum.CallType.V(0)
        UNKNOWN = CallTypeEnum.CallType.V(1)
        MANUALLY_DIALED = CallTypeEnum.CallType.V(2)
        HIGH_END_MOBILE_SEARCH = CallTypeEnum.CallType.V(3)
    class CallType(metaclass=_CallType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CallTypeEnum.CallType.V(0)
    UNKNOWN = CallTypeEnum.CallType.V(1)
    MANUALLY_DIALED = CallTypeEnum.CallType.V(2)
    HIGH_END_MOBILE_SEARCH = CallTypeEnum.CallType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___CallTypeEnum = CallTypeEnum
