"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudgetProposalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccountBudgetProposalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccountBudgetProposalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(0)
        UNKNOWN = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(1)
        PENDING = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(2)
        APPROVED_HELD = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(3)
        APPROVED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(4)
        CANCELLED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(5)
        REJECTED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(6)
    class AccountBudgetProposalStatus(metaclass=_AccountBudgetProposalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(0)
    UNKNOWN = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(1)
    PENDING = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(2)
    APPROVED_HELD = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(3)
    APPROVED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(4)
    CANCELLED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(5)
    REJECTED = AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AccountBudgetProposalStatusEnum = AccountBudgetProposalStatusEnum
