"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.media_type_pb2
import google.ads.google_ads.v4.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v4.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = (
        ...
    )
    mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def source_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def file_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def image(self) -> global___MediaImage: ...
    @property
    def media_bundle(self) -> global___MediaBundle: ...
    @property
    def audio(self) -> global___MediaAudio: ...
    @property
    def video(self) -> global___MediaVideo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        type: google.ads.google_ads.v4.proto.enums.media_type_pb2.MediaTypeEnum.MediaType.V = ...,
        mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        source_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        file_size: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        image: typing.Optional[global___MediaImage] = ...,
        media_bundle: typing.Optional[global___MediaBundle] = ...,
        audio: typing.Optional[global___MediaAudio] = ...,
        video: typing.Optional[global___MediaVideo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "name",
            b"name",
            "source_url",
            b"source_url",
            "video",
            b"video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "audio",
            b"audio",
            "file_size",
            b"file_size",
            "id",
            b"id",
            "image",
            b"image",
            "media_bundle",
            b"media_bundle",
            "mediatype",
            b"mediatype",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "source_url",
            b"source_url",
            "type",
            b"type",
            "video",
            b"video",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["mediatype", b"mediatype"]
    ) -> typing_extensions.Literal["image", "media_bundle", "audio", "video"]: ...

global___MediaFile = MediaFile

class MediaImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaImage = MediaImage

class MediaBundle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaBundle = MediaBundle

class MediaAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    @property
    def ad_duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis", b"ad_duration_millis"
        ],
    ) -> None: ...

global___MediaAudio = MediaAudio

class MediaVideo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DURATION_MILLIS_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    ADVERTISING_ID_CODE_FIELD_NUMBER: builtins.int
    ISCI_CODE_FIELD_NUMBER: builtins.int
    @property
    def ad_duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def youtube_video_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def advertising_id_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def isci_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        ad_duration_millis: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        youtube_video_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        advertising_id_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        isci_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_duration_millis",
            b"ad_duration_millis",
            "advertising_id_code",
            b"advertising_id_code",
            "isci_code",
            b"isci_code",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...

global___MediaVideo = MediaVideo
