"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryChannelAvailabilityModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionCategoryChannelAvailabilityMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CriterionCategoryChannelAvailabilityMode.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            0
        )
        UNKNOWN = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            1
        )
        ALL_CHANNELS = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            2
        )
        CHANNEL_TYPE_AND_ALL_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            3
        )
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
            4
        )
    class CriterionCategoryChannelAvailabilityMode(
        metaclass=_CriterionCategoryChannelAvailabilityMode
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        0
    )
    UNKNOWN = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        1
    )
    ALL_CHANNELS = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        2
    )
    CHANNEL_TYPE_AND_ALL_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        3
    )
    CHANNEL_TYPE_AND_SUBSET_SUBTYPES = CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V(
        4
    )
    def __init__(
        self,
    ) -> None: ...

global___CriterionCategoryChannelAvailabilityModeEnum = (
    CriterionCategoryChannelAvailabilityModeEnum
)
