"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_label_pb2
import grpc

from .customer_label_service_pb2 import *

class CustomerLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerLabel(
        self,
        request: global___GetCustomerLabelRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel: ...
    def MutateCustomerLabels(
        self,
        request: global___MutateCustomerLabelsRequest,
    ) -> global___MutateCustomerLabelsResponse: ...

class CustomerLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerLabel(
        self,
        request: global___GetCustomerLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel: ...
    @abc.abstractmethod
    def MutateCustomerLabels(
        self,
        request: global___MutateCustomerLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerLabelsResponse: ...

def add_CustomerLabelServiceServicer_to_server(
    servicer: CustomerLabelServiceServicer, server: grpc.Server
) -> None: ...
