"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LocationExtensionTargetingCriterionFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LocationExtensionTargetingCriterionField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LocationExtensionTargetingCriterionField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            0
        )
        UNKNOWN = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            1
        )
        ADDRESS_LINE_1 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            2
        )
        ADDRESS_LINE_2 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            3
        )
        CITY = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            4
        )
        PROVINCE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            5
        )
        POSTAL_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            6
        )
        COUNTRY_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
            7
        )
    class LocationExtensionTargetingCriterionField(
        metaclass=_LocationExtensionTargetingCriterionField
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        0
    )
    UNKNOWN = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        1
    )
    ADDRESS_LINE_1 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        2
    )
    ADDRESS_LINE_2 = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        3
    )
    CITY = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        4
    )
    PROVINCE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        5
    )
    POSTAL_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        6
    )
    COUNTRY_CODE = LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField.V(
        7
    )
    def __init__(
        self,
    ) -> None: ...

global___LocationExtensionTargetingCriterionFieldEnum = (
    LocationExtensionTargetingCriterionFieldEnum
)
