"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2
import grpc

from .account_budget_proposal_service_pb2 import *

class AccountBudgetProposalServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAccountBudgetProposal(
        self,
        request: global___GetAccountBudgetProposalRequest,
    ) -> google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal: ...
    def MutateAccountBudgetProposal(
        self,
        request: global___MutateAccountBudgetProposalRequest,
    ) -> global___MutateAccountBudgetProposalResponse: ...

class AccountBudgetProposalServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountBudgetProposal(
        self,
        request: global___GetAccountBudgetProposalRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal: ...
    @abc.abstractmethod
    def MutateAccountBudgetProposal(
        self,
        request: global___MutateAccountBudgetProposalRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAccountBudgetProposalResponse: ...

def add_AccountBudgetProposalServiceServicer_to_server(
    servicer: AccountBudgetProposalServiceServicer, server: grpc.Server
) -> None: ...
