"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DisplayUploadProductTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DisplayUploadProductType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DisplayUploadProductType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(0)
        UNKNOWN = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(1)
        HTML5_UPLOAD_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(2)
        DYNAMIC_HTML5_EDUCATION_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(3)
        )
        DYNAMIC_HTML5_FLIGHT_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(4)
        )
        DYNAMIC_HTML5_HOTEL_RENTAL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(5)
        )
        DYNAMIC_HTML5_JOB_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(
            6
        )
        DYNAMIC_HTML5_LOCAL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(7)
        )
        DYNAMIC_HTML5_REAL_ESTATE_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(8)
        )
        DYNAMIC_HTML5_CUSTOM_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(9)
        )
        DYNAMIC_HTML5_TRAVEL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(10)
        )
        DYNAMIC_HTML5_HOTEL_AD = (
            DisplayUploadProductTypeEnum.DisplayUploadProductType.V(11)
        )
    class DisplayUploadProductType(metaclass=_DisplayUploadProductType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(0)
    UNKNOWN = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(1)
    HTML5_UPLOAD_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(2)
    DYNAMIC_HTML5_EDUCATION_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(3)
    )
    DYNAMIC_HTML5_FLIGHT_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(4)
    DYNAMIC_HTML5_HOTEL_RENTAL_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(5)
    )
    DYNAMIC_HTML5_JOB_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(6)
    DYNAMIC_HTML5_LOCAL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(7)
    DYNAMIC_HTML5_REAL_ESTATE_AD = (
        DisplayUploadProductTypeEnum.DisplayUploadProductType.V(8)
    )
    DYNAMIC_HTML5_CUSTOM_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(9)
    DYNAMIC_HTML5_TRAVEL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(
        10
    )
    DYNAMIC_HTML5_HOTEL_AD = DisplayUploadProductTypeEnum.DisplayUploadProductType.V(11)
    def __init__(
        self,
    ) -> None: ...

global___DisplayUploadProductTypeEnum = DisplayUploadProductTypeEnum
