"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2
import grpc

from .customer_user_access_invitation_service_pb2 import *

class CustomerUserAccessInvitationServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerUserAccessInvitation(
        self,
        request: global___GetCustomerUserAccessInvitationRequest,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    def MutateCustomerUserAccessInvitation(
        self,
        request: global___MutateCustomerUserAccessInvitationRequest,
    ) -> global___MutateCustomerUserAccessInvitationResponse: ...

class CustomerUserAccessInvitationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerUserAccessInvitation(
        self,
        request: global___GetCustomerUserAccessInvitationRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    @abc.abstractmethod
    def MutateCustomerUserAccessInvitation(
        self,
        request: global___MutateCustomerUserAccessInvitationRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerUserAccessInvitationResponse: ...

def add_CustomerUserAccessInvitationServiceServicer_to_server(
    servicer: CustomerUserAccessInvitationServiceServicer, server: grpc.Server
) -> None: ...
