"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FrequencyCapTimeUnitEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FrequencyCapTimeUnit(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FrequencyCapTimeUnit.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(0)
        UNKNOWN = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(1)
        DAY = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(2)
        WEEK = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(3)
        MONTH = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(4)
    class FrequencyCapTimeUnit(metaclass=_FrequencyCapTimeUnit):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(0)
    UNKNOWN = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(1)
    DAY = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(2)
    WEEK = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(3)
    MONTH = FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V(4)
    def __init__(
        self,
    ) -> None: ...

global___FrequencyCapTimeUnitEnum = FrequencyCapTimeUnitEnum
