"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FlightPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FlightPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FlightPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(0)
        UNKNOWN = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(1)
        DESTINATION_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(2)
        ORIGIN_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(3)
        FLIGHT_DESCRIPTION = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(4)
        ORIGIN_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(5)
        DESTINATION_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(6)
        FLIGHT_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(7)
        FORMATTED_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(8)
        FLIGHT_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(10)
        IMAGE_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(11)
        FINAL_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(12)
        FINAL_MOBILE_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(13)
        TRACKING_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(14)
        ANDROID_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(15)
        SIMILAR_DESTINATION_IDS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(
            16
        )
        IOS_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(17)
        IOS_APP_STORE_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(18)
    class FlightPlaceholderField(metaclass=_FlightPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(0)
    UNKNOWN = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(1)
    DESTINATION_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(2)
    ORIGIN_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(3)
    FLIGHT_DESCRIPTION = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(4)
    ORIGIN_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(5)
    DESTINATION_NAME = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(6)
    FLIGHT_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(7)
    FORMATTED_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(8)
    FLIGHT_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(10)
    IMAGE_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(11)
    FINAL_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(12)
    FINAL_MOBILE_URLS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(13)
    TRACKING_URL = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(14)
    ANDROID_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(15)
    SIMILAR_DESTINATION_IDS = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(16)
    IOS_APP_LINK = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(17)
    IOS_APP_STORE_ID = FlightPlaceholderFieldEnum.FlightPlaceholderField.V(18)
    def __init__(
        self,
    ) -> None: ...

global___FlightPlaceholderFieldEnum = FlightPlaceholderFieldEnum
