"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.age_range_type_pb2
import google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2
import google.ads.google_ads.v5.proto.enums.content_label_type_pb2
import google.ads.google_ads.v5.proto.enums.day_of_week_pb2
import google.ads.google_ads.v5.proto.enums.device_pb2
import google.ads.google_ads.v5.proto.enums.gender_type_pb2
import google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2
import google.ads.google_ads.v5.proto.enums.income_range_type_pb2
import google.ads.google_ads.v5.proto.enums.interaction_type_pb2
import google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2
import google.ads.google_ads.v5.proto.enums.listing_group_type_pb2
import google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2
import google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2
import google.ads.google_ads.v5.proto.enums.parental_status_type_pb2
import google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2
import google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2
import google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2
import google.ads.google_ads.v5.proto.enums.product_channel_pb2
import google.ads.google_ads.v5.proto.enums.product_condition_pb2
import google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2
import google.ads.google_ads.v5.proto.enums.product_type_level_pb2
import google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2
import google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2
import google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    MATCH_TYPE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
        ...
    )
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text", b"_text", "match_type", b"match_type", "text", b"text"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___KeywordInfo = KeywordInfo

class PlacementInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    url: typing.Text = ...
    def __init__(
        self,
        *,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...

global___PlacementInfo = PlacementInfo

class MobileAppCategoryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MOBILE_APP_CATEGORY_CONSTANT_FIELD_NUMBER: builtins.int
    mobile_app_category_constant: typing.Text = ...
    def __init__(
        self,
        *,
        mobile_app_category_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_app_category_constant",
            b"_mobile_app_category_constant",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_app_category_constant",
            b"_mobile_app_category_constant",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_app_category_constant", b"_mobile_app_category_constant"
        ],
    ) -> typing_extensions.Literal["mobile_app_category_constant"]: ...

global___MobileAppCategoryInfo = MobileAppCategoryInfo

class MobileApplicationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    app_id: typing.Text = ...
    name: typing.Text = ...
    def __init__(
        self,
        *,
        app_id: typing.Text = ...,
        name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_name",
            b"_name",
            "app_id",
            b"app_id",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_name",
            b"_name",
            "app_id",
            b"app_id",
            "name",
            b"name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___MobileApplicationInfo = MobileApplicationInfo

class LocationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    geo_target_constant: typing.Text = ...
    def __init__(
        self,
        *,
        geo_target_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_geo_target_constant",
            b"_geo_target_constant",
            "geo_target_constant",
            b"geo_target_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_geo_target_constant",
            b"_geo_target_constant",
            "geo_target_constant",
            b"geo_target_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_constant", b"_geo_target_constant"
        ],
    ) -> typing_extensions.Literal["geo_target_constant"]: ...

global___LocationInfo = LocationInfo

class DeviceInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.device_pb2.DeviceEnum.Device.V = ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.device_pb2.DeviceEnum.Device.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___DeviceInfo = DeviceInfo

class PreferredContentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2.PreferredContentTypeEnum.PreferredContentType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2.PreferredContentTypeEnum.PreferredContentType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___PreferredContentInfo = PreferredContentInfo

class ListingGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    CASE_VALUE_FIELD_NUMBER: builtins.int
    PARENT_AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.listing_group_type_pb2.ListingGroupTypeEnum.ListingGroupType.V = (
        ...
    )
    parent_ad_group_criterion: typing.Text = ...
    @property
    def case_value(self) -> global___ListingDimensionInfo: ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.listing_group_type_pb2.ListingGroupTypeEnum.ListingGroupType.V = ...,
        case_value: typing.Optional[global___ListingDimensionInfo] = ...,
        parent_ad_group_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_parent_ad_group_criterion",
            b"_parent_ad_group_criterion",
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_parent_ad_group_criterion",
            b"_parent_ad_group_criterion",
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_ad_group_criterion", b"_parent_ad_group_criterion"
        ],
    ) -> typing_extensions.Literal["parent_ad_group_criterion"]: ...

global___ListingGroupInfo = ListingGroupInfo

class ListingScopeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DIMENSIONS_FIELD_NUMBER: builtins.int
    @property
    def dimensions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ListingDimensionInfo
    ]: ...
    def __init__(
        self,
        *,
        dimensions: typing.Optional[
            typing.Iterable[global___ListingDimensionInfo]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["dimensions", b"dimensions"]
    ) -> None: ...

global___ListingScopeInfo = ListingScopeInfo

class ListingDimensionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HOTEL_ID_FIELD_NUMBER: builtins.int
    HOTEL_CLASS_FIELD_NUMBER: builtins.int
    HOTEL_COUNTRY_REGION_FIELD_NUMBER: builtins.int
    HOTEL_STATE_FIELD_NUMBER: builtins.int
    HOTEL_CITY_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_FIELD_NUMBER: builtins.int
    PRODUCT_BRAND_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    PRODUCT_CONDITION_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE_FIELD_NUMBER: builtins.int
    PRODUCT_ITEM_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    UNKNOWN_LISTING_DIMENSION_FIELD_NUMBER: builtins.int
    @property
    def hotel_id(self) -> global___HotelIdInfo: ...
    @property
    def hotel_class(self) -> global___HotelClassInfo: ...
    @property
    def hotel_country_region(self) -> global___HotelCountryRegionInfo: ...
    @property
    def hotel_state(self) -> global___HotelStateInfo: ...
    @property
    def hotel_city(self) -> global___HotelCityInfo: ...
    @property
    def product_bidding_category(self) -> global___ProductBiddingCategoryInfo: ...
    @property
    def product_brand(self) -> global___ProductBrandInfo: ...
    @property
    def product_channel(self) -> global___ProductChannelInfo: ...
    @property
    def product_channel_exclusivity(self) -> global___ProductChannelExclusivityInfo: ...
    @property
    def product_condition(self) -> global___ProductConditionInfo: ...
    @property
    def product_custom_attribute(self) -> global___ProductCustomAttributeInfo: ...
    @property
    def product_item_id(self) -> global___ProductItemIdInfo: ...
    @property
    def product_type(self) -> global___ProductTypeInfo: ...
    @property
    def unknown_listing_dimension(self) -> global___UnknownListingDimensionInfo: ...
    def __init__(
        self,
        *,
        hotel_id: typing.Optional[global___HotelIdInfo] = ...,
        hotel_class: typing.Optional[global___HotelClassInfo] = ...,
        hotel_country_region: typing.Optional[global___HotelCountryRegionInfo] = ...,
        hotel_state: typing.Optional[global___HotelStateInfo] = ...,
        hotel_city: typing.Optional[global___HotelCityInfo] = ...,
        product_bidding_category: typing.Optional[
            global___ProductBiddingCategoryInfo
        ] = ...,
        product_brand: typing.Optional[global___ProductBrandInfo] = ...,
        product_channel: typing.Optional[global___ProductChannelInfo] = ...,
        product_channel_exclusivity: typing.Optional[
            global___ProductChannelExclusivityInfo
        ] = ...,
        product_condition: typing.Optional[global___ProductConditionInfo] = ...,
        product_custom_attribute: typing.Optional[
            global___ProductCustomAttributeInfo
        ] = ...,
        product_item_id: typing.Optional[global___ProductItemIdInfo] = ...,
        product_type: typing.Optional[global___ProductTypeInfo] = ...,
        unknown_listing_dimension: typing.Optional[
            global___UnknownListingDimensionInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["dimension", b"dimension"]
    ) -> typing_extensions.Literal[
        "hotel_id",
        "hotel_class",
        "hotel_country_region",
        "hotel_state",
        "hotel_city",
        "product_bidding_category",
        "product_brand",
        "product_channel",
        "product_channel_exclusivity",
        "product_condition",
        "product_custom_attribute",
        "product_item_id",
        "product_type",
        "unknown_listing_dimension",
    ]: ...

global___ListingDimensionInfo = ListingDimensionInfo

class HotelIdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___HotelIdInfo = HotelIdInfo

class HotelClassInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int = ...
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___HotelClassInfo = HotelClassInfo

class HotelCountryRegionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNTRY_REGION_CRITERION_FIELD_NUMBER: builtins.int
    country_region_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        country_region_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_region_criterion",
            b"_country_region_criterion",
            "country_region_criterion",
            b"country_region_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_region_criterion",
            b"_country_region_criterion",
            "country_region_criterion",
            b"country_region_criterion",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_country_region_criterion", b"_country_region_criterion"
        ],
    ) -> typing_extensions.Literal["country_region_criterion"]: ...

global___HotelCountryRegionInfo = HotelCountryRegionInfo

class HotelStateInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATE_CRITERION_FIELD_NUMBER: builtins.int
    state_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        state_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_state_criterion",
            b"_state_criterion",
            "state_criterion",
            b"state_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_state_criterion",
            b"_state_criterion",
            "state_criterion",
            b"state_criterion",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_state_criterion", b"_state_criterion"],
    ) -> typing_extensions.Literal["state_criterion"]: ...

global___HotelStateInfo = HotelStateInfo

class HotelCityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CITY_CRITERION_FIELD_NUMBER: builtins.int
    city_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        city_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city_criterion", b"_city_criterion", "city_criterion", b"city_criterion"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city_criterion", b"_city_criterion", "city_criterion", b"city_criterion"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_city_criterion", b"_city_criterion"],
    ) -> typing_extensions.Literal["city_criterion"]: ...

global___HotelCityInfo = HotelCityInfo

class ProductBiddingCategoryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    id: builtins.int = ...
    country_code: typing.Text = ...
    level: google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = (
        ...
    )
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        country_code: typing.Text = ...,
        level: google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "country_code",
            b"country_code",
            "id",
            b"id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "level",
            b"level",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...

global___ProductBiddingCategoryInfo = ProductBiddingCategoryInfo

class ProductBrandInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductBrandInfo = ProductBrandInfo

class ProductChannelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_FIELD_NUMBER: builtins.int
    channel: google.ads.google_ads.v5.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = (
        ...
    )
    def __init__(
        self,
        *,
        channel: google.ads.google_ads.v5.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["channel", b"channel"]
    ) -> None: ...

global___ProductChannelInfo = ProductChannelInfo

class ProductChannelExclusivityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    channel_exclusivity: google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = (
        ...
    )
    def __init__(
        self,
        *,
        channel_exclusivity: google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel_exclusivity", b"channel_exclusivity"
        ],
    ) -> None: ...

global___ProductChannelExclusivityInfo = ProductChannelExclusivityInfo

class ProductConditionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONDITION_FIELD_NUMBER: builtins.int
    condition: google.ads.google_ads.v5.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = (
        ...
    )
    def __init__(
        self,
        *,
        condition: google.ads.google_ads.v5.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["condition", b"condition"]
    ) -> None: ...

global___ProductConditionInfo = ProductConditionInfo

class ProductCustomAttributeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    index: google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V = (
        ...
    )
    def __init__(
        self,
        *,
        value: typing.Text = ...,
        index: google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_value", b"_value", "index", b"index", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductCustomAttributeInfo = ProductCustomAttributeInfo

class ProductItemIdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductItemIdInfo = ProductItemIdInfo

class ProductTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    level: google.ads.google_ads.v5.proto.enums.product_type_level_pb2.ProductTypeLevelEnum.ProductTypeLevel.V = (
        ...
    )
    def __init__(
        self,
        *,
        value: typing.Text = ...,
        level: google.ads.google_ads.v5.proto.enums.product_type_level_pb2.ProductTypeLevelEnum.ProductTypeLevel.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_value", b"_value", "level", b"level", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductTypeInfo = ProductTypeInfo

class UnknownListingDimensionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___UnknownListingDimensionInfo = UnknownListingDimensionInfo

class HotelDateSelectionTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___HotelDateSelectionTypeInfo = HotelDateSelectionTypeInfo

class HotelAdvanceBookingWindowInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MIN_DAYS_FIELD_NUMBER: builtins.int
    MAX_DAYS_FIELD_NUMBER: builtins.int
    min_days: builtins.int = ...
    max_days: builtins.int = ...
    def __init__(
        self,
        *,
        min_days: builtins.int = ...,
        max_days: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_max_days",
            b"_max_days",
            "_min_days",
            b"_min_days",
            "max_days",
            b"max_days",
            "min_days",
            b"min_days",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_max_days",
            b"_max_days",
            "_min_days",
            b"_min_days",
            "max_days",
            b"max_days",
            "min_days",
            b"min_days",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_max_days", b"_max_days"]
    ) -> typing_extensions.Literal["max_days"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_min_days", b"_min_days"]
    ) -> typing_extensions.Literal["min_days"]: ...

global___HotelAdvanceBookingWindowInfo = HotelAdvanceBookingWindowInfo

class HotelLengthOfStayInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MIN_NIGHTS_FIELD_NUMBER: builtins.int
    MAX_NIGHTS_FIELD_NUMBER: builtins.int
    min_nights: builtins.int = ...
    max_nights: builtins.int = ...
    def __init__(
        self,
        *,
        min_nights: builtins.int = ...,
        max_nights: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_max_nights",
            b"_max_nights",
            "_min_nights",
            b"_min_nights",
            "max_nights",
            b"max_nights",
            "min_nights",
            b"min_nights",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_max_nights",
            b"_max_nights",
            "_min_nights",
            b"_min_nights",
            "max_nights",
            b"max_nights",
            "min_nights",
            b"min_nights",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_max_nights", b"_max_nights"]
    ) -> typing_extensions.Literal["max_nights"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_min_nights", b"_min_nights"]
    ) -> typing_extensions.Literal["min_nights"]: ...

global___HotelLengthOfStayInfo = HotelLengthOfStayInfo

class HotelCheckInDayInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    def __init__(
        self,
        *,
        day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week"]
    ) -> None: ...

global___HotelCheckInDayInfo = HotelCheckInDayInfo

class InteractionTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.interaction_type_pb2.InteractionTypeEnum.InteractionType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.interaction_type_pb2.InteractionTypeEnum.InteractionType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___InteractionTypeInfo = InteractionTypeInfo

class AdScheduleInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_MINUTE_FIELD_NUMBER: builtins.int
    END_MINUTE_FIELD_NUMBER: builtins.int
    START_HOUR_FIELD_NUMBER: builtins.int
    END_HOUR_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    start_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = (
        ...
    )
    end_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = (
        ...
    )
    start_hour: builtins.int = ...
    end_hour: builtins.int = ...
    day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    def __init__(
        self,
        *,
        start_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = ...,
        end_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = ...,
        start_hour: builtins.int = ...,
        end_hour: builtins.int = ...,
        day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_end_hour",
            b"_end_hour",
            "_start_hour",
            b"_start_hour",
            "end_hour",
            b"end_hour",
            "start_hour",
            b"start_hour",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_end_hour",
            b"_end_hour",
            "_start_hour",
            b"_start_hour",
            "day_of_week",
            b"day_of_week",
            "end_hour",
            b"end_hour",
            "end_minute",
            b"end_minute",
            "start_hour",
            b"start_hour",
            "start_minute",
            b"start_minute",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_end_hour", b"_end_hour"]
    ) -> typing_extensions.Literal["end_hour"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_hour", b"_start_hour"]
    ) -> typing_extensions.Literal["start_hour"]: ...

global___AdScheduleInfo = AdScheduleInfo

class AgeRangeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.age_range_type_pb2.AgeRangeTypeEnum.AgeRangeType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.age_range_type_pb2.AgeRangeTypeEnum.AgeRangeType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___AgeRangeInfo = AgeRangeInfo

class GenderInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.gender_type_pb2.GenderTypeEnum.GenderType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.gender_type_pb2.GenderTypeEnum.GenderType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___GenderInfo = GenderInfo

class IncomeRangeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.income_range_type_pb2.IncomeRangeTypeEnum.IncomeRangeType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.income_range_type_pb2.IncomeRangeTypeEnum.IncomeRangeType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___IncomeRangeInfo = IncomeRangeInfo

class ParentalStatusInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.parental_status_type_pb2.ParentalStatusTypeEnum.ParentalStatusType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.parental_status_type_pb2.ParentalStatusTypeEnum.ParentalStatusType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___ParentalStatusInfo = ParentalStatusInfo

class YouTubeVideoInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: typing.Text = ...
    def __init__(
        self,
        *,
        video_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_video_id", b"_video_id", "video_id", b"video_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_video_id", b"_video_id", "video_id", b"video_id"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_video_id", b"_video_id"]
    ) -> typing_extensions.Literal["video_id"]: ...

global___YouTubeVideoInfo = YouTubeVideoInfo

class YouTubeChannelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: typing.Text = ...
    def __init__(
        self,
        *,
        channel_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id", b"_channel_id", "channel_id", b"channel_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id", b"_channel_id", "channel_id", b"channel_id"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_channel_id", b"_channel_id"]
    ) -> typing_extensions.Literal["channel_id"]: ...

global___YouTubeChannelInfo = YouTubeChannelInfo

class UserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_LIST_FIELD_NUMBER: builtins.int
    user_list: typing.Text = ...
    def __init__(
        self,
        *,
        user_list: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_user_list", b"_user_list"]
    ) -> typing_extensions.Literal["user_list"]: ...

global___UserListInfo = UserListInfo

class ProximityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_POINT_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    RADIUS_UNITS_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    radius: builtins.float = ...
    radius_units: google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2.ProximityRadiusUnitsEnum.ProximityRadiusUnits.V = (
        ...
    )
    @property
    def geo_point(self) -> global___GeoPointInfo: ...
    @property
    def address(self) -> global___AddressInfo: ...
    def __init__(
        self,
        *,
        geo_point: typing.Optional[global___GeoPointInfo] = ...,
        radius: builtins.float = ...,
        radius_units: google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2.ProximityRadiusUnitsEnum.ProximityRadiusUnits.V = ...,
        address: typing.Optional[global___AddressInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_radius",
            b"_radius",
            "address",
            b"address",
            "geo_point",
            b"geo_point",
            "radius",
            b"radius",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_radius",
            b"_radius",
            "address",
            b"address",
            "geo_point",
            b"geo_point",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_radius", b"_radius"]
    ) -> typing_extensions.Literal["radius"]: ...

global___ProximityInfo = ProximityInfo

class GeoPointInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LONGITUDE_IN_MICRO_DEGREES_FIELD_NUMBER: builtins.int
    LATITUDE_IN_MICRO_DEGREES_FIELD_NUMBER: builtins.int
    longitude_in_micro_degrees: builtins.int = ...
    latitude_in_micro_degrees: builtins.int = ...
    def __init__(
        self,
        *,
        longitude_in_micro_degrees: builtins.int = ...,
        latitude_in_micro_degrees: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_latitude_in_micro_degrees",
            b"_latitude_in_micro_degrees",
            "_longitude_in_micro_degrees",
            b"_longitude_in_micro_degrees",
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_latitude_in_micro_degrees",
            b"_latitude_in_micro_degrees",
            "_longitude_in_micro_degrees",
            b"_longitude_in_micro_degrees",
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_latitude_in_micro_degrees", b"_latitude_in_micro_degrees"
        ],
    ) -> typing_extensions.Literal["latitude_in_micro_degrees"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_longitude_in_micro_degrees", b"_longitude_in_micro_degrees"
        ],
    ) -> typing_extensions.Literal["longitude_in_micro_degrees"]: ...

global___GeoPointInfo = GeoPointInfo

class AddressInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_NAME_FIELD_NUMBER: builtins.int
    STREET_ADDRESS_FIELD_NUMBER: builtins.int
    STREET_ADDRESS2_FIELD_NUMBER: builtins.int
    CITY_NAME_FIELD_NUMBER: builtins.int
    postal_code: typing.Text = ...
    province_code: typing.Text = ...
    country_code: typing.Text = ...
    province_name: typing.Text = ...
    street_address: typing.Text = ...
    street_address2: typing.Text = ...
    city_name: typing.Text = ...
    def __init__(
        self,
        *,
        postal_code: typing.Text = ...,
        province_code: typing.Text = ...,
        country_code: typing.Text = ...,
        province_name: typing.Text = ...,
        street_address: typing.Text = ...,
        street_address2: typing.Text = ...,
        city_name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city_name",
            b"_city_name",
            "_country_code",
            b"_country_code",
            "_postal_code",
            b"_postal_code",
            "_province_code",
            b"_province_code",
            "_province_name",
            b"_province_name",
            "_street_address",
            b"_street_address",
            "_street_address2",
            b"_street_address2",
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city_name",
            b"_city_name",
            "_country_code",
            b"_country_code",
            "_postal_code",
            b"_postal_code",
            "_province_code",
            b"_province_code",
            "_province_name",
            b"_province_name",
            "_street_address",
            b"_street_address",
            "_street_address2",
            b"_street_address2",
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_city_name", b"_city_name"]
    ) -> typing_extensions.Literal["city_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_postal_code", b"_postal_code"]
    ) -> typing_extensions.Literal["postal_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_province_code", b"_province_code"],
    ) -> typing_extensions.Literal["province_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_province_name", b"_province_name"],
    ) -> typing_extensions.Literal["province_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_street_address", b"_street_address"],
    ) -> typing_extensions.Literal["street_address"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_street_address2", b"_street_address2"],
    ) -> typing_extensions.Literal["street_address2"]: ...

global___AddressInfo = AddressInfo

class TopicInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOPIC_CONSTANT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    topic_constant: typing.Text = ...
    path: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        topic_constant: typing.Text = ...,
        path: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_topic_constant", b"_topic_constant", "topic_constant", b"topic_constant"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_topic_constant",
            b"_topic_constant",
            "path",
            b"path",
            "topic_constant",
            b"topic_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_topic_constant", b"_topic_constant"],
    ) -> typing_extensions.Literal["topic_constant"]: ...

global___TopicInfo = TopicInfo

class LanguageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LANGUAGE_CONSTANT_FIELD_NUMBER: builtins.int
    language_constant: typing.Text = ...
    def __init__(
        self,
        *,
        language_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_language_constant",
            b"_language_constant",
            "language_constant",
            b"language_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_language_constant",
            b"_language_constant",
            "language_constant",
            b"language_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_language_constant", b"_language_constant"
        ],
    ) -> typing_extensions.Literal["language_constant"]: ...

global___LanguageInfo = LanguageInfo

class IpBlockInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    ip_address: typing.Text = ...
    def __init__(
        self,
        *,
        ip_address: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ip_address", b"_ip_address", "ip_address", b"ip_address"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ip_address", b"_ip_address", "ip_address", b"ip_address"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ip_address", b"_ip_address"]
    ) -> typing_extensions.Literal["ip_address"]: ...

global___IpBlockInfo = IpBlockInfo

class ContentLabelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.content_label_type_pb2.ContentLabelTypeEnum.ContentLabelType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.content_label_type_pb2.ContentLabelTypeEnum.ContentLabelType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___ContentLabelInfo = ContentLabelInfo

class CarrierInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CARRIER_CONSTANT_FIELD_NUMBER: builtins.int
    carrier_constant: typing.Text = ...
    def __init__(
        self,
        *,
        carrier_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_carrier_constant",
            b"_carrier_constant",
            "carrier_constant",
            b"carrier_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_carrier_constant",
            b"_carrier_constant",
            "carrier_constant",
            b"carrier_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_carrier_constant", b"_carrier_constant"
        ],
    ) -> typing_extensions.Literal["carrier_constant"]: ...

global___CarrierInfo = CarrierInfo

class UserInterestInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_INTEREST_CATEGORY_FIELD_NUMBER: builtins.int
    user_interest_category: typing.Text = ...
    def __init__(
        self,
        *,
        user_interest_category: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_user_interest_category",
            b"_user_interest_category",
            "user_interest_category",
            b"user_interest_category",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_user_interest_category",
            b"_user_interest_category",
            "user_interest_category",
            b"user_interest_category",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_user_interest_category", b"_user_interest_category"
        ],
    ) -> typing_extensions.Literal["user_interest_category"]: ...

global___UserInterestInfo = UserInterestInfo

class WebpageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CRITERION_NAME_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    criterion_name: typing.Text = ...
    @property
    def conditions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___WebpageConditionInfo
    ]: ...
    def __init__(
        self,
        *,
        criterion_name: typing.Text = ...,
        conditions: typing.Optional[
            typing.Iterable[global___WebpageConditionInfo]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_name", b"_criterion_name", "criterion_name", b"criterion_name"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_name",
            b"_criterion_name",
            "conditions",
            b"conditions",
            "criterion_name",
            b"criterion_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_criterion_name", b"_criterion_name"],
    ) -> typing_extensions.Literal["criterion_name"]: ...

global___WebpageInfo = WebpageInfo

class WebpageConditionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERAND_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    ARGUMENT_FIELD_NUMBER: builtins.int
    operand: google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2.WebpageConditionOperandEnum.WebpageConditionOperand.V = (
        ...
    )
    operator: google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2.WebpageConditionOperatorEnum.WebpageConditionOperator.V = (
        ...
    )
    argument: typing.Text = ...
    def __init__(
        self,
        *,
        operand: google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2.WebpageConditionOperandEnum.WebpageConditionOperand.V = ...,
        operator: google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2.WebpageConditionOperatorEnum.WebpageConditionOperator.V = ...,
        argument: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_argument", b"_argument", "argument", b"argument"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_argument",
            b"_argument",
            "argument",
            b"argument",
            "operand",
            b"operand",
            "operator",
            b"operator",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_argument", b"_argument"]
    ) -> typing_extensions.Literal["argument"]: ...

global___WebpageConditionInfo = WebpageConditionInfo

class OperatingSystemVersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATING_SYSTEM_VERSION_CONSTANT_FIELD_NUMBER: builtins.int
    operating_system_version_constant: typing.Text = ...
    def __init__(
        self,
        *,
        operating_system_version_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_operating_system_version_constant",
            b"_operating_system_version_constant",
            "operating_system_version_constant",
            b"operating_system_version_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_operating_system_version_constant",
            b"_operating_system_version_constant",
            "operating_system_version_constant",
            b"operating_system_version_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_operating_system_version_constant", b"_operating_system_version_constant"
        ],
    ) -> typing_extensions.Literal["operating_system_version_constant"]: ...

global___OperatingSystemVersionInfo = OperatingSystemVersionInfo

class AppPaymentModelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2.AppPaymentModelTypeEnum.AppPaymentModelType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2.AppPaymentModelTypeEnum.AppPaymentModelType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___AppPaymentModelInfo = AppPaymentModelInfo

class MobileDeviceInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MOBILE_DEVICE_CONSTANT_FIELD_NUMBER: builtins.int
    mobile_device_constant: typing.Text = ...
    def __init__(
        self,
        *,
        mobile_device_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_device_constant",
            b"_mobile_device_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_device_constant",
            b"_mobile_device_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_device_constant", b"_mobile_device_constant"
        ],
    ) -> typing_extensions.Literal["mobile_device_constant"]: ...

global___MobileDeviceInfo = MobileDeviceInfo

class CustomAffinityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOM_AFFINITY_FIELD_NUMBER: builtins.int
    custom_affinity: typing.Text = ...
    def __init__(
        self,
        *,
        custom_affinity: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_affinity",
            b"_custom_affinity",
            "custom_affinity",
            b"custom_affinity",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_affinity",
            b"_custom_affinity",
            "custom_affinity",
            b"custom_affinity",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_custom_affinity", b"_custom_affinity"],
    ) -> typing_extensions.Literal["custom_affinity"]: ...

global___CustomAffinityInfo = CustomAffinityInfo

class CustomIntentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOM_INTENT_FIELD_NUMBER: builtins.int
    custom_intent: typing.Text = ...
    def __init__(
        self,
        *,
        custom_intent: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_intent", b"_custom_intent", "custom_intent", b"custom_intent"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_intent", b"_custom_intent", "custom_intent", b"custom_intent"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_custom_intent", b"_custom_intent"],
    ) -> typing_extensions.Literal["custom_intent"]: ...

global___CustomIntentInfo = CustomIntentInfo

class LocationGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FEED_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    RADIUS_UNITS_FIELD_NUMBER: builtins.int
    feed: typing.Text = ...
    geo_target_constants: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    radius: builtins.int = ...
    radius_units: google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits.V = (
        ...
    )
    def __init__(
        self,
        *,
        feed: typing.Text = ...,
        geo_target_constants: typing.Optional[typing.Iterable[typing.Text]] = ...,
        radius: builtins.int = ...,
        radius_units: google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_feed",
            b"_feed",
            "_radius",
            b"_radius",
            "feed",
            b"feed",
            "radius",
            b"radius",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_feed",
            b"_feed",
            "_radius",
            b"_radius",
            "feed",
            b"feed",
            "geo_target_constants",
            b"geo_target_constants",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_feed", b"_feed"]
    ) -> typing_extensions.Literal["feed"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_radius", b"_radius"]
    ) -> typing_extensions.Literal["radius"]: ...

global___LocationGroupInfo = LocationGroupInfo
