"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.criteria_pb2
import google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2
import google.ads.google_ads.v6.proto.enums.ad_network_type_pb2
import google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2
import google.ads.google_ads.v6.proto.enums.click_type_pb2
import google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2
import google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2
import google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2
import google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2
import google.ads.google_ads.v6.proto.enums.day_of_week_pb2
import google.ads.google_ads.v6.proto.enums.device_pb2
import google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2
import google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2
import google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2
import google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2
import google.ads.google_ads.v6.proto.enums.month_of_year_pb2
import google.ads.google_ads.v6.proto.enums.placeholder_type_pb2
import google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2
import google.ads.google_ads.v6.proto.enums.product_channel_pb2
import google.ads.google_ads.v6.proto.enums.product_condition_pb2
import google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2
import google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2
import google.ads.google_ads.v6.proto.enums.slot_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Segments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DESTINATION_TYPE_FIELD_NUMBER: builtins.int
    AD_NETWORK_TYPE_FIELD_NUMBER: builtins.int
    BUDGET_CAMPAIGN_ASSOCIATION_STATUS_FIELD_NUMBER: builtins.int
    CLICK_TYPE_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_CATEGORY_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_NAME_FIELD_NUMBER: builtins.int
    CONVERSION_ADJUSTMENT_FIELD_NUMBER: builtins.int
    CONVERSION_ATTRIBUTION_EVENT_TYPE_FIELD_NUMBER: builtins.int
    CONVERSION_LAG_BUCKET_FIELD_NUMBER: builtins.int
    CONVERSION_OR_ADJUSTMENT_LAG_BUCKET_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    EXTERNAL_CONVERSION_SOURCE_FIELD_NUMBER: builtins.int
    GEO_TARGET_AIRPORT_FIELD_NUMBER: builtins.int
    GEO_TARGET_CANTON_FIELD_NUMBER: builtins.int
    GEO_TARGET_CITY_FIELD_NUMBER: builtins.int
    GEO_TARGET_COUNTRY_FIELD_NUMBER: builtins.int
    GEO_TARGET_COUNTY_FIELD_NUMBER: builtins.int
    GEO_TARGET_DISTRICT_FIELD_NUMBER: builtins.int
    GEO_TARGET_METRO_FIELD_NUMBER: builtins.int
    GEO_TARGET_MOST_SPECIFIC_LOCATION_FIELD_NUMBER: builtins.int
    GEO_TARGET_POSTAL_CODE_FIELD_NUMBER: builtins.int
    GEO_TARGET_PROVINCE_FIELD_NUMBER: builtins.int
    GEO_TARGET_REGION_FIELD_NUMBER: builtins.int
    GEO_TARGET_STATE_FIELD_NUMBER: builtins.int
    HOTEL_BOOKING_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    HOTEL_CENTER_ID_FIELD_NUMBER: builtins.int
    HOTEL_CHECK_IN_DATE_FIELD_NUMBER: builtins.int
    HOTEL_CHECK_IN_DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    HOTEL_CITY_FIELD_NUMBER: builtins.int
    HOTEL_CLASS_FIELD_NUMBER: builtins.int
    HOTEL_COUNTRY_FIELD_NUMBER: builtins.int
    HOTEL_DATE_SELECTION_TYPE_FIELD_NUMBER: builtins.int
    HOTEL_LENGTH_OF_STAY_FIELD_NUMBER: builtins.int
    HOTEL_RATE_RULE_ID_FIELD_NUMBER: builtins.int
    HOTEL_RATE_TYPE_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_BUCKET_FIELD_NUMBER: builtins.int
    HOTEL_STATE_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    INTERACTION_ON_THIS_EXTENSION_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    MONTH_OF_YEAR_FIELD_NUMBER: builtins.int
    PARTNER_HOTEL_ID_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPE_FIELD_NUMBER: builtins.int
    PRODUCT_AGGREGATOR_ID_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL1_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL2_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL3_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL4_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL5_FIELD_NUMBER: builtins.int
    PRODUCT_BRAND_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    PRODUCT_CONDITION_FIELD_NUMBER: builtins.int
    PRODUCT_COUNTRY_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE0_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE1_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE2_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE3_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE4_FIELD_NUMBER: builtins.int
    PRODUCT_ITEM_ID_FIELD_NUMBER: builtins.int
    PRODUCT_LANGUAGE_FIELD_NUMBER: builtins.int
    PRODUCT_MERCHANT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_STORE_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TITLE_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L1_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L2_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L3_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L4_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L5_FIELD_NUMBER: builtins.int
    QUARTER_FIELD_NUMBER: builtins.int
    SEARCH_ENGINE_RESULTS_PAGE_TYPE_FIELD_NUMBER: builtins.int
    SEARCH_TERM_MATCH_TYPE_FIELD_NUMBER: builtins.int
    SLOT_FIELD_NUMBER: builtins.int
    WEBPAGE_FIELD_NUMBER: builtins.int
    WEEK_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    ad_destination_type: google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2.AdDestinationTypeEnum.AdDestinationType.V = (
        ...
    )
    ad_network_type: google.ads.google_ads.v6.proto.enums.ad_network_type_pb2.AdNetworkTypeEnum.AdNetworkType.V = (
        ...
    )
    click_type: google.ads.google_ads.v6.proto.enums.click_type_pb2.ClickTypeEnum.ClickType.V = (
        ...
    )
    conversion_action: typing.Text = ...
    conversion_action_category: google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = (
        ...
    )
    conversion_action_name: typing.Text = ...
    conversion_adjustment: builtins.bool = ...
    conversion_attribution_event_type: google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2.ConversionAttributionEventTypeEnum.ConversionAttributionEventType.V = (
        ...
    )
    conversion_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2.ConversionLagBucketEnum.ConversionLagBucket.V = (
        ...
    )
    conversion_or_adjustment_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V = (
        ...
    )
    date: typing.Text = ...
    day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    device: google.ads.google_ads.v6.proto.enums.device_pb2.DeviceEnum.Device.V = ...
    external_conversion_source: google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2.ExternalConversionSourceEnum.ExternalConversionSource.V = (
        ...
    )
    geo_target_airport: typing.Text = ...
    geo_target_canton: typing.Text = ...
    geo_target_city: typing.Text = ...
    geo_target_country: typing.Text = ...
    geo_target_county: typing.Text = ...
    geo_target_district: typing.Text = ...
    geo_target_metro: typing.Text = ...
    geo_target_most_specific_location: typing.Text = ...
    geo_target_postal_code: typing.Text = ...
    geo_target_province: typing.Text = ...
    geo_target_region: typing.Text = ...
    geo_target_state: typing.Text = ...
    hotel_booking_window_days: builtins.int = ...
    hotel_center_id: builtins.int = ...
    hotel_check_in_date: typing.Text = ...
    hotel_check_in_day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    hotel_city: typing.Text = ...
    hotel_class: builtins.int = ...
    hotel_country: typing.Text = ...
    hotel_date_selection_type: google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = (
        ...
    )
    hotel_length_of_stay: builtins.int = ...
    hotel_rate_rule_id: typing.Text = ...
    hotel_rate_type: google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2.HotelRateTypeEnum.HotelRateType.V = (
        ...
    )
    hotel_price_bucket: google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2.HotelPriceBucketEnum.HotelPriceBucket.V = (
        ...
    )
    hotel_state: typing.Text = ...
    hour: builtins.int = ...
    interaction_on_this_extension: builtins.bool = ...
    month: typing.Text = ...
    month_of_year: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    partner_hotel_id: typing.Text = ...
    placeholder_type: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    product_aggregator_id: builtins.int = ...
    product_bidding_category_level1: typing.Text = ...
    product_bidding_category_level2: typing.Text = ...
    product_bidding_category_level3: typing.Text = ...
    product_bidding_category_level4: typing.Text = ...
    product_bidding_category_level5: typing.Text = ...
    product_brand: typing.Text = ...
    product_channel: google.ads.google_ads.v6.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = (
        ...
    )
    product_channel_exclusivity: google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = (
        ...
    )
    product_condition: google.ads.google_ads.v6.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = (
        ...
    )
    product_country: typing.Text = ...
    product_custom_attribute0: typing.Text = ...
    product_custom_attribute1: typing.Text = ...
    product_custom_attribute2: typing.Text = ...
    product_custom_attribute3: typing.Text = ...
    product_custom_attribute4: typing.Text = ...
    product_item_id: typing.Text = ...
    product_language: typing.Text = ...
    product_merchant_id: builtins.int = ...
    product_store_id: typing.Text = ...
    product_title: typing.Text = ...
    product_type_l1: typing.Text = ...
    product_type_l2: typing.Text = ...
    product_type_l3: typing.Text = ...
    product_type_l4: typing.Text = ...
    product_type_l5: typing.Text = ...
    quarter: typing.Text = ...
    search_engine_results_page_type: google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType.V = (
        ...
    )
    search_term_match_type: google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2.SearchTermMatchTypeEnum.SearchTermMatchType.V = (
        ...
    )
    slot: google.ads.google_ads.v6.proto.enums.slot_pb2.SlotEnum.Slot.V = ...
    webpage: typing.Text = ...
    week: typing.Text = ...
    year: builtins.int = ...
    @property
    def budget_campaign_association_status(
        self,
    ) -> global___BudgetCampaignAssociationStatus: ...
    @property
    def keyword(self) -> global___Keyword: ...
    def __init__(
        self,
        *,
        ad_destination_type: google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2.AdDestinationTypeEnum.AdDestinationType.V = ...,
        ad_network_type: google.ads.google_ads.v6.proto.enums.ad_network_type_pb2.AdNetworkTypeEnum.AdNetworkType.V = ...,
        budget_campaign_association_status: typing.Optional[
            global___BudgetCampaignAssociationStatus
        ] = ...,
        click_type: google.ads.google_ads.v6.proto.enums.click_type_pb2.ClickTypeEnum.ClickType.V = ...,
        conversion_action: typing.Text = ...,
        conversion_action_category: google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = ...,
        conversion_action_name: typing.Text = ...,
        conversion_adjustment: builtins.bool = ...,
        conversion_attribution_event_type: google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2.ConversionAttributionEventTypeEnum.ConversionAttributionEventType.V = ...,
        conversion_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2.ConversionLagBucketEnum.ConversionLagBucket.V = ...,
        conversion_or_adjustment_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V = ...,
        date: typing.Text = ...,
        day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
        device: google.ads.google_ads.v6.proto.enums.device_pb2.DeviceEnum.Device.V = ...,
        external_conversion_source: google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2.ExternalConversionSourceEnum.ExternalConversionSource.V = ...,
        geo_target_airport: typing.Text = ...,
        geo_target_canton: typing.Text = ...,
        geo_target_city: typing.Text = ...,
        geo_target_country: typing.Text = ...,
        geo_target_county: typing.Text = ...,
        geo_target_district: typing.Text = ...,
        geo_target_metro: typing.Text = ...,
        geo_target_most_specific_location: typing.Text = ...,
        geo_target_postal_code: typing.Text = ...,
        geo_target_province: typing.Text = ...,
        geo_target_region: typing.Text = ...,
        geo_target_state: typing.Text = ...,
        hotel_booking_window_days: builtins.int = ...,
        hotel_center_id: builtins.int = ...,
        hotel_check_in_date: typing.Text = ...,
        hotel_check_in_day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
        hotel_city: typing.Text = ...,
        hotel_class: builtins.int = ...,
        hotel_country: typing.Text = ...,
        hotel_date_selection_type: google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = ...,
        hotel_length_of_stay: builtins.int = ...,
        hotel_rate_rule_id: typing.Text = ...,
        hotel_rate_type: google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2.HotelRateTypeEnum.HotelRateType.V = ...,
        hotel_price_bucket: google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2.HotelPriceBucketEnum.HotelPriceBucket.V = ...,
        hotel_state: typing.Text = ...,
        hour: builtins.int = ...,
        interaction_on_this_extension: builtins.bool = ...,
        keyword: typing.Optional[global___Keyword] = ...,
        month: typing.Text = ...,
        month_of_year: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
        partner_hotel_id: typing.Text = ...,
        placeholder_type: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
        product_aggregator_id: builtins.int = ...,
        product_bidding_category_level1: typing.Text = ...,
        product_bidding_category_level2: typing.Text = ...,
        product_bidding_category_level3: typing.Text = ...,
        product_bidding_category_level4: typing.Text = ...,
        product_bidding_category_level5: typing.Text = ...,
        product_brand: typing.Text = ...,
        product_channel: google.ads.google_ads.v6.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = ...,
        product_channel_exclusivity: google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = ...,
        product_condition: google.ads.google_ads.v6.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = ...,
        product_country: typing.Text = ...,
        product_custom_attribute0: typing.Text = ...,
        product_custom_attribute1: typing.Text = ...,
        product_custom_attribute2: typing.Text = ...,
        product_custom_attribute3: typing.Text = ...,
        product_custom_attribute4: typing.Text = ...,
        product_item_id: typing.Text = ...,
        product_language: typing.Text = ...,
        product_merchant_id: builtins.int = ...,
        product_store_id: typing.Text = ...,
        product_title: typing.Text = ...,
        product_type_l1: typing.Text = ...,
        product_type_l2: typing.Text = ...,
        product_type_l3: typing.Text = ...,
        product_type_l4: typing.Text = ...,
        product_type_l5: typing.Text = ...,
        quarter: typing.Text = ...,
        search_engine_results_page_type: google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType.V = ...,
        search_term_match_type: google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2.SearchTermMatchTypeEnum.SearchTermMatchType.V = ...,
        slot: google.ads.google_ads.v6.proto.enums.slot_pb2.SlotEnum.Slot.V = ...,
        webpage: typing.Text = ...,
        week: typing.Text = ...,
        year: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "conversion_action",
            b"conversion_action",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "date",
            b"date",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "partner_hotel_id",
            b"partner_hotel_id",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "ad_destination_type",
            b"ad_destination_type",
            "ad_network_type",
            b"ad_network_type",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "click_type",
            b"click_type",
            "conversion_action",
            b"conversion_action",
            "conversion_action_category",
            b"conversion_action_category",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "conversion_attribution_event_type",
            b"conversion_attribution_event_type",
            "conversion_lag_bucket",
            b"conversion_lag_bucket",
            "conversion_or_adjustment_lag_bucket",
            b"conversion_or_adjustment_lag_bucket",
            "date",
            b"date",
            "day_of_week",
            b"day_of_week",
            "device",
            b"device",
            "external_conversion_source",
            b"external_conversion_source",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_check_in_day_of_week",
            b"hotel_check_in_day_of_week",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_price_bucket",
            b"hotel_price_bucket",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_rate_type",
            b"hotel_rate_type",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "month_of_year",
            b"month_of_year",
            "partner_hotel_id",
            b"partner_hotel_id",
            "placeholder_type",
            b"placeholder_type",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "search_engine_results_page_type",
            b"search_engine_results_page_type",
            "search_term_match_type",
            b"search_term_match_type",
            "slot",
            b"slot",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action_name", b"_conversion_action_name"
        ],
    ) -> typing_extensions.Literal["conversion_action_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_adjustment", b"_conversion_adjustment"
        ],
    ) -> typing_extensions.Literal["conversion_adjustment"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_date", b"_date"]
    ) -> typing_extensions.Literal["date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_airport", b"_geo_target_airport"
        ],
    ) -> typing_extensions.Literal["geo_target_airport"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_canton", b"_geo_target_canton"
        ],
    ) -> typing_extensions.Literal["geo_target_canton"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_geo_target_city", b"_geo_target_city"],
    ) -> typing_extensions.Literal["geo_target_city"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_country", b"_geo_target_country"
        ],
    ) -> typing_extensions.Literal["geo_target_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_county", b"_geo_target_county"
        ],
    ) -> typing_extensions.Literal["geo_target_county"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_district", b"_geo_target_district"
        ],
    ) -> typing_extensions.Literal["geo_target_district"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_metro", b"_geo_target_metro"
        ],
    ) -> typing_extensions.Literal["geo_target_metro"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_most_specific_location", b"_geo_target_most_specific_location"
        ],
    ) -> typing_extensions.Literal["geo_target_most_specific_location"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_postal_code", b"_geo_target_postal_code"
        ],
    ) -> typing_extensions.Literal["geo_target_postal_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_province", b"_geo_target_province"
        ],
    ) -> typing_extensions.Literal["geo_target_province"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_region", b"_geo_target_region"
        ],
    ) -> typing_extensions.Literal["geo_target_region"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_state", b"_geo_target_state"
        ],
    ) -> typing_extensions.Literal["geo_target_state"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_booking_window_days", b"_hotel_booking_window_days"
        ],
    ) -> typing_extensions.Literal["hotel_booking_window_days"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_hotel_center_id", b"_hotel_center_id"],
    ) -> typing_extensions.Literal["hotel_center_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_check_in_date", b"_hotel_check_in_date"
        ],
    ) -> typing_extensions.Literal["hotel_check_in_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_city", b"_hotel_city"]
    ) -> typing_extensions.Literal["hotel_city"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_class", b"_hotel_class"]
    ) -> typing_extensions.Literal["hotel_class"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_hotel_country", b"_hotel_country"],
    ) -> typing_extensions.Literal["hotel_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_length_of_stay", b"_hotel_length_of_stay"
        ],
    ) -> typing_extensions.Literal["hotel_length_of_stay"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_rate_rule_id", b"_hotel_rate_rule_id"
        ],
    ) -> typing_extensions.Literal["hotel_rate_rule_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_state", b"_hotel_state"]
    ) -> typing_extensions.Literal["hotel_state"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hour", b"_hour"]
    ) -> typing_extensions.Literal["hour"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_interaction_on_this_extension", b"_interaction_on_this_extension"
        ],
    ) -> typing_extensions.Literal["interaction_on_this_extension"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_month", b"_month"]
    ) -> typing_extensions.Literal["month"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_partner_hotel_id", b"_partner_hotel_id"
        ],
    ) -> typing_extensions.Literal["partner_hotel_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_aggregator_id", b"_product_aggregator_id"
        ],
    ) -> typing_extensions.Literal["product_aggregator_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level1", b"_product_bidding_category_level1"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level2", b"_product_bidding_category_level2"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level3", b"_product_bidding_category_level3"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level4", b"_product_bidding_category_level4"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level5", b"_product_bidding_category_level5"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level5"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_brand", b"_product_brand"],
    ) -> typing_extensions.Literal["product_brand"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_country", b"_product_country"],
    ) -> typing_extensions.Literal["product_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute0", b"_product_custom_attribute0"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute0"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute1", b"_product_custom_attribute1"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute2", b"_product_custom_attribute2"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute3", b"_product_custom_attribute3"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute4", b"_product_custom_attribute4"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_item_id", b"_product_item_id"],
    ) -> typing_extensions.Literal["product_item_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_language", b"_product_language"
        ],
    ) -> typing_extensions.Literal["product_language"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_merchant_id", b"_product_merchant_id"
        ],
    ) -> typing_extensions.Literal["product_merchant_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_store_id", b"_product_store_id"
        ],
    ) -> typing_extensions.Literal["product_store_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_title", b"_product_title"],
    ) -> typing_extensions.Literal["product_title"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l1", b"_product_type_l1"],
    ) -> typing_extensions.Literal["product_type_l1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l2", b"_product_type_l2"],
    ) -> typing_extensions.Literal["product_type_l2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l3", b"_product_type_l3"],
    ) -> typing_extensions.Literal["product_type_l3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l4", b"_product_type_l4"],
    ) -> typing_extensions.Literal["product_type_l4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l5", b"_product_type_l5"],
    ) -> typing_extensions.Literal["product_type_l5"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_quarter", b"_quarter"]
    ) -> typing_extensions.Literal["quarter"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_webpage", b"_webpage"]
    ) -> typing_extensions.Literal["webpage"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_week", b"_week"]
    ) -> typing_extensions.Literal["week"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_year", b"_year"]
    ) -> typing_extensions.Literal["year"]: ...

global___Segments = Segments

class Keyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    ad_group_criterion: typing.Text = ...
    @property
    def info(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo: ...
    def __init__(
        self,
        *,
        ad_group_criterion: typing.Text = ...,
        info: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_ad_group_criterion", b"_ad_group_criterion"
        ],
    ) -> typing_extensions.Literal["ad_group_criterion"]: ...

global___Keyword = Keyword

class BudgetCampaignAssociationStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    campaign: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2.BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        campaign: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2.BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign", b"_campaign", "campaign", b"campaign"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign", b"_campaign", "campaign", b"campaign", "status", b"status"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...

global___BudgetCampaignAssociationStatus = BudgetCampaignAssociationStatus
