"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdNetworkTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdNetworkType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdNetworkType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdNetworkTypeEnum.AdNetworkType.V(0)
        UNKNOWN = AdNetworkTypeEnum.AdNetworkType.V(1)
        SEARCH = AdNetworkTypeEnum.AdNetworkType.V(2)
        SEARCH_PARTNERS = AdNetworkTypeEnum.AdNetworkType.V(3)
        CONTENT = AdNetworkTypeEnum.AdNetworkType.V(4)
        YOUTUBE_SEARCH = AdNetworkTypeEnum.AdNetworkType.V(5)
        YOUTUBE_WATCH = AdNetworkTypeEnum.AdNetworkType.V(6)
        MIXED = AdNetworkTypeEnum.AdNetworkType.V(7)
    class AdNetworkType(metaclass=_AdNetworkType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdNetworkTypeEnum.AdNetworkType.V(0)
    UNKNOWN = AdNetworkTypeEnum.AdNetworkType.V(1)
    SEARCH = AdNetworkTypeEnum.AdNetworkType.V(2)
    SEARCH_PARTNERS = AdNetworkTypeEnum.AdNetworkType.V(3)
    CONTENT = AdNetworkTypeEnum.AdNetworkType.V(4)
    YOUTUBE_SEARCH = AdNetworkTypeEnum.AdNetworkType.V(5)
    YOUTUBE_WATCH = AdNetworkTypeEnum.AdNetworkType.V(6)
    MIXED = AdNetworkTypeEnum.AdNetworkType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AdNetworkTypeEnum = AdNetworkTypeEnum
