"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SlotEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Slot(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Slot.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SlotEnum.Slot.V(0)
        UNKNOWN = SlotEnum.Slot.V(1)
        SEARCH_SIDE = SlotEnum.Slot.V(2)
        SEARCH_TOP = SlotEnum.Slot.V(3)
        SEARCH_OTHER = SlotEnum.Slot.V(4)
        CONTENT = SlotEnum.Slot.V(5)
        SEARCH_PARTNER_TOP = SlotEnum.Slot.V(6)
        SEARCH_PARTNER_OTHER = SlotEnum.Slot.V(7)
        MIXED = SlotEnum.Slot.V(8)
    class Slot(metaclass=_Slot):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SlotEnum.Slot.V(0)
    UNKNOWN = SlotEnum.Slot.V(1)
    SEARCH_SIDE = SlotEnum.Slot.V(2)
    SEARCH_TOP = SlotEnum.Slot.V(3)
    SEARCH_OTHER = SlotEnum.Slot.V(4)
    CONTENT = SlotEnum.Slot.V(5)
    SEARCH_PARTNER_TOP = SlotEnum.Slot.V(6)
    SEARCH_PARTNER_OTHER = SlotEnum.Slot.V(7)
    MIXED = SlotEnum.Slot.V(8)
    def __init__(
        self,
    ) -> None: ...

global___SlotEnum = SlotEnum
