"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedErrorEnum.FeedError.V(0)
        UNKNOWN = FeedErrorEnum.FeedError.V(1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = FeedErrorEnum.FeedError.V(2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = FeedErrorEnum.FeedError.V(3)
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(4)
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = FeedErrorEnum.FeedError.V(5)
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(6)
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = FeedErrorEnum.FeedError.V(7)
        FEED_REMOVED = FeedErrorEnum.FeedError.V(8)
        INVALID_ORIGIN_VALUE = FeedErrorEnum.FeedError.V(9)
        FEED_ORIGIN_IS_NOT_USER = FeedErrorEnum.FeedError.V(10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = FeedErrorEnum.FeedError.V(11)
        INVALID_EMAIL = FeedErrorEnum.FeedError.V(12)
        DUPLICATE_FEED_NAME = FeedErrorEnum.FeedError.V(13)
        INVALID_FEED_NAME = FeedErrorEnum.FeedError.V(14)
        MISSING_OAUTH_INFO = FeedErrorEnum.FeedError.V(15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = FeedErrorEnum.FeedError.V(16)
        TOO_MANY_ATTRIBUTES = FeedErrorEnum.FeedError.V(17)
        INVALID_BUSINESS_ACCOUNT = FeedErrorEnum.FeedError.V(18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = FeedErrorEnum.FeedError.V(19)
        INVALID_AFFILIATE_CHAIN_ID = FeedErrorEnum.FeedError.V(20)
        DUPLICATE_SYSTEM_FEED = FeedErrorEnum.FeedError.V(21)
        GMB_ACCESS_ERROR = FeedErrorEnum.FeedError.V(22)
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = FeedErrorEnum.FeedError.V(
            23
        )
    class FeedError(metaclass=_FeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedErrorEnum.FeedError.V(0)
    UNKNOWN = FeedErrorEnum.FeedError.V(1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = FeedErrorEnum.FeedError.V(2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = FeedErrorEnum.FeedError.V(3)
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(4)
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = FeedErrorEnum.FeedError.V(5)
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = FeedErrorEnum.FeedError.V(6)
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = FeedErrorEnum.FeedError.V(7)
    FEED_REMOVED = FeedErrorEnum.FeedError.V(8)
    INVALID_ORIGIN_VALUE = FeedErrorEnum.FeedError.V(9)
    FEED_ORIGIN_IS_NOT_USER = FeedErrorEnum.FeedError.V(10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = FeedErrorEnum.FeedError.V(11)
    INVALID_EMAIL = FeedErrorEnum.FeedError.V(12)
    DUPLICATE_FEED_NAME = FeedErrorEnum.FeedError.V(13)
    INVALID_FEED_NAME = FeedErrorEnum.FeedError.V(14)
    MISSING_OAUTH_INFO = FeedErrorEnum.FeedError.V(15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = FeedErrorEnum.FeedError.V(16)
    TOO_MANY_ATTRIBUTES = FeedErrorEnum.FeedError.V(17)
    INVALID_BUSINESS_ACCOUNT = FeedErrorEnum.FeedError.V(18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = FeedErrorEnum.FeedError.V(19)
    INVALID_AFFILIATE_CHAIN_ID = FeedErrorEnum.FeedError.V(20)
    DUPLICATE_SYSTEM_FEED = FeedErrorEnum.FeedError.V(21)
    GMB_ACCESS_ERROR = FeedErrorEnum.FeedError.V(22)
    CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = FeedErrorEnum.FeedError.V(23)
    def __init__(
        self,
    ) -> None: ...

global___FeedErrorEnum = FeedErrorEnum
