"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MultiplierErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MultiplierError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiplierError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MultiplierErrorEnum.MultiplierError.V(0)
        UNKNOWN = MultiplierErrorEnum.MultiplierError.V(1)
        MULTIPLIER_TOO_HIGH = MultiplierErrorEnum.MultiplierError.V(2)
        MULTIPLIER_TOO_LOW = MultiplierErrorEnum.MultiplierError.V(3)
        TOO_MANY_FRACTIONAL_DIGITS = MultiplierErrorEnum.MultiplierError.V(4)
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = (
            MultiplierErrorEnum.MultiplierError.V(5)
        )
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = (
            MultiplierErrorEnum.MultiplierError.V(6)
        )
        NO_MULTIPLIER_SPECIFIED = MultiplierErrorEnum.MultiplierError.V(7)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(8)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(9)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = (
            MultiplierErrorEnum.MultiplierError.V(10)
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = (
            MultiplierErrorEnum.MultiplierError.V(11)
        )
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = (
            MultiplierErrorEnum.MultiplierError.V(12)
        )
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = (
            MultiplierErrorEnum.MultiplierError.V(13)
        )
    class MultiplierError(metaclass=_MultiplierError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MultiplierErrorEnum.MultiplierError.V(0)
    UNKNOWN = MultiplierErrorEnum.MultiplierError.V(1)
    MULTIPLIER_TOO_HIGH = MultiplierErrorEnum.MultiplierError.V(2)
    MULTIPLIER_TOO_LOW = MultiplierErrorEnum.MultiplierError.V(3)
    TOO_MANY_FRACTIONAL_DIGITS = MultiplierErrorEnum.MultiplierError.V(4)
    MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = MultiplierErrorEnum.MultiplierError.V(
        5
    )
    MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = (
        MultiplierErrorEnum.MultiplierError.V(6)
    )
    NO_MULTIPLIER_SPECIFIED = MultiplierErrorEnum.MultiplierError.V(7)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(8)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(9)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = (
        MultiplierErrorEnum.MultiplierError.V(10)
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = (
        MultiplierErrorEnum.MultiplierError.V(11)
    )
    BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = (
        MultiplierErrorEnum.MultiplierError.V(12)
    )
    MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = (
        MultiplierErrorEnum.MultiplierError.V(13)
    )
    def __init__(
        self,
    ) -> None: ...

global___MultiplierErrorEnum = MultiplierErrorEnum
