"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeClientTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeClientType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChangeClientType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeClientTypeEnum.ChangeClientType.V(0)
        UNKNOWN = ChangeClientTypeEnum.ChangeClientType.V(1)
        GOOGLE_ADS_WEB_CLIENT = ChangeClientTypeEnum.ChangeClientType.V(2)
        GOOGLE_ADS_AUTOMATED_RULE = ChangeClientTypeEnum.ChangeClientType.V(3)
        GOOGLE_ADS_SCRIPTS = ChangeClientTypeEnum.ChangeClientType.V(4)
        GOOGLE_ADS_BULK_UPLOAD = ChangeClientTypeEnum.ChangeClientType.V(5)
        GOOGLE_ADS_API = ChangeClientTypeEnum.ChangeClientType.V(6)
        GOOGLE_ADS_EDITOR = ChangeClientTypeEnum.ChangeClientType.V(7)
        GOOGLE_ADS_MOBILE_APP = ChangeClientTypeEnum.ChangeClientType.V(8)
        GOOGLE_ADS_RECOMMENDATIONS = ChangeClientTypeEnum.ChangeClientType.V(9)
        SEARCH_ADS_360_SYNC = ChangeClientTypeEnum.ChangeClientType.V(10)
        SEARCH_ADS_360_POST = ChangeClientTypeEnum.ChangeClientType.V(11)
        INTERNAL_TOOL = ChangeClientTypeEnum.ChangeClientType.V(12)
        OTHER = ChangeClientTypeEnum.ChangeClientType.V(13)
    class ChangeClientType(metaclass=_ChangeClientType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeClientTypeEnum.ChangeClientType.V(0)
    UNKNOWN = ChangeClientTypeEnum.ChangeClientType.V(1)
    GOOGLE_ADS_WEB_CLIENT = ChangeClientTypeEnum.ChangeClientType.V(2)
    GOOGLE_ADS_AUTOMATED_RULE = ChangeClientTypeEnum.ChangeClientType.V(3)
    GOOGLE_ADS_SCRIPTS = ChangeClientTypeEnum.ChangeClientType.V(4)
    GOOGLE_ADS_BULK_UPLOAD = ChangeClientTypeEnum.ChangeClientType.V(5)
    GOOGLE_ADS_API = ChangeClientTypeEnum.ChangeClientType.V(6)
    GOOGLE_ADS_EDITOR = ChangeClientTypeEnum.ChangeClientType.V(7)
    GOOGLE_ADS_MOBILE_APP = ChangeClientTypeEnum.ChangeClientType.V(8)
    GOOGLE_ADS_RECOMMENDATIONS = ChangeClientTypeEnum.ChangeClientType.V(9)
    SEARCH_ADS_360_SYNC = ChangeClientTypeEnum.ChangeClientType.V(10)
    SEARCH_ADS_360_POST = ChangeClientTypeEnum.ChangeClientType.V(11)
    INTERNAL_TOOL = ChangeClientTypeEnum.ChangeClientType.V(12)
    OTHER = ChangeClientTypeEnum.ChangeClientType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeClientTypeEnum = ChangeClientTypeEnum
