"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.feed_mapping_pb2
import grpc

from .feed_mapping_service_pb2 import *

class FeedMappingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedMapping(
        self,
        request: global___GetFeedMappingRequest,
    ) -> google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping: ...
    def MutateFeedMappings(
        self,
        request: global___MutateFeedMappingsRequest,
    ) -> global___MutateFeedMappingsResponse: ...

class FeedMappingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedMapping(
        self,
        request: global___GetFeedMappingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping: ...
    @abc.abstractmethod
    def MutateFeedMappings(
        self,
        request: global___MutateFeedMappingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedMappingsResponse: ...

def add_FeedMappingServiceServicer_to_server(
    servicer: FeedMappingServiceServicer, server: grpc.Server
) -> None: ...
