"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2
import grpc

from .geo_target_constant_service_pb2 import *

class GeoTargetConstantServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetGeoTargetConstant(
        self,
        request: global___GetGeoTargetConstantRequest,
    ) -> google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    def SuggestGeoTargetConstants(
        self,
        request: global___SuggestGeoTargetConstantsRequest,
    ) -> global___SuggestGeoTargetConstantsResponse: ...

class GeoTargetConstantServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGeoTargetConstant(
        self,
        request: global___GetGeoTargetConstantRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    @abc.abstractmethod
    def SuggestGeoTargetConstants(
        self,
        request: global___SuggestGeoTargetConstantsRequest,
        context: grpc.ServicerContext,
    ) -> global___SuggestGeoTargetConstantsResponse: ...

def add_GeoTargetConstantServiceServicer_to_server(
    servicer: GeoTargetConstantServiceServicer, server: grpc.Server
) -> None: ...
