"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserListType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListTypeEnum.UserListType.V(0)
        UNKNOWN = UserListTypeEnum.UserListType.V(1)
        REMARKETING = UserListTypeEnum.UserListType.V(2)
        LOGICAL = UserListTypeEnum.UserListType.V(3)
        EXTERNAL_REMARKETING = UserListTypeEnum.UserListType.V(4)
        RULE_BASED = UserListTypeEnum.UserListType.V(5)
        SIMILAR = UserListTypeEnum.UserListType.V(6)
        CRM_BASED = UserListTypeEnum.UserListType.V(7)
    class UserListType(metaclass=_UserListType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListTypeEnum.UserListType.V(0)
    UNKNOWN = UserListTypeEnum.UserListType.V(1)
    REMARKETING = UserListTypeEnum.UserListType.V(2)
    LOGICAL = UserListTypeEnum.UserListType.V(3)
    EXTERNAL_REMARKETING = UserListTypeEnum.UserListType.V(4)
    RULE_BASED = UserListTypeEnum.UserListType.V(5)
    SIMILAR = UserListTypeEnum.UserListType.V(6)
    CRM_BASED = UserListTypeEnum.UserListType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___UserListTypeEnum = UserListTypeEnum
