"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2
import grpc

from .customer_extension_setting_service_pb2 import *

class CustomerExtensionSettingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerExtensionSetting(
        self,
        request: global___GetCustomerExtensionSettingRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting: ...
    def MutateCustomerExtensionSettings(
        self,
        request: global___MutateCustomerExtensionSettingsRequest,
    ) -> global___MutateCustomerExtensionSettingsResponse: ...

class CustomerExtensionSettingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerExtensionSetting(
        self,
        request: global___GetCustomerExtensionSettingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting: ...
    @abc.abstractmethod
    def MutateCustomerExtensionSettings(
        self,
        request: global___MutateCustomerExtensionSettingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerExtensionSettingsResponse: ...

def add_CustomerExtensionSettingServiceServicer_to_server(
    servicer: CustomerExtensionSettingServiceServicer, server: grpc.Server
) -> None: ...
