"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ReachPlanAgeRangeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ReachPlanAgeRange(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ReachPlanAgeRange.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(0)
        UNKNOWN = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(1)
        AGE_RANGE_18_24 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503001)
        AGE_RANGE_18_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(2)
        AGE_RANGE_18_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(3)
        AGE_RANGE_18_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(4)
        AGE_RANGE_18_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(5)
        AGE_RANGE_18_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(6)
        AGE_RANGE_18_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(7)
        AGE_RANGE_21_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(8)
        AGE_RANGE_25_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503002)
        AGE_RANGE_25_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(9)
        AGE_RANGE_25_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(10)
        AGE_RANGE_25_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(11)
        AGE_RANGE_25_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(12)
        AGE_RANGE_25_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(13)
        AGE_RANGE_35_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503003)
        AGE_RANGE_35_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(14)
        AGE_RANGE_35_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(15)
        AGE_RANGE_35_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(16)
        AGE_RANGE_35_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(17)
        AGE_RANGE_45_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503004)
        AGE_RANGE_45_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(18)
        AGE_RANGE_45_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(19)
        AGE_RANGE_50_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(20)
        AGE_RANGE_55_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503005)
        AGE_RANGE_55_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(21)
        AGE_RANGE_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503006)
    class ReachPlanAgeRange(metaclass=_ReachPlanAgeRange):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(0)
    UNKNOWN = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(1)
    AGE_RANGE_18_24 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503001)
    AGE_RANGE_18_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(2)
    AGE_RANGE_18_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(3)
    AGE_RANGE_18_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(4)
    AGE_RANGE_18_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(5)
    AGE_RANGE_18_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(6)
    AGE_RANGE_18_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(7)
    AGE_RANGE_21_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(8)
    AGE_RANGE_25_34 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503002)
    AGE_RANGE_25_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(9)
    AGE_RANGE_25_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(10)
    AGE_RANGE_25_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(11)
    AGE_RANGE_25_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(12)
    AGE_RANGE_25_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(13)
    AGE_RANGE_35_44 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503003)
    AGE_RANGE_35_49 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(14)
    AGE_RANGE_35_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(15)
    AGE_RANGE_35_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(16)
    AGE_RANGE_35_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(17)
    AGE_RANGE_45_54 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503004)
    AGE_RANGE_45_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(18)
    AGE_RANGE_45_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(19)
    AGE_RANGE_50_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(20)
    AGE_RANGE_55_64 = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503005)
    AGE_RANGE_55_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(21)
    AGE_RANGE_65_UP = ReachPlanAgeRangeEnum.ReachPlanAgeRange.V(503006)
    def __init__(
        self,
    ) -> None: ...

global___ReachPlanAgeRangeEnum = ReachPlanAgeRangeEnum
