"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerPayPerConversionEligibilityFailureReasonEnum(
    google.protobuf.message.Message
):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerPayPerConversionEligibilityFailureReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerPayPerConversionEligibilityFailureReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            0
        )
        UNKNOWN = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            1
        )
        NOT_ENOUGH_CONVERSIONS = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            2
        )
        CONVERSION_LAG_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            3
        )
        HAS_CAMPAIGN_WITH_SHARED_BUDGET = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            4
        )
        HAS_UPLOAD_CLICKS_CONVERSION = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            5
        )
        AVERAGE_DAILY_SPEND_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            6
        )
        ANALYSIS_NOT_COMPLETE = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            7
        )
        OTHER = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
            8
        )
    class CustomerPayPerConversionEligibilityFailureReason(
        metaclass=_CustomerPayPerConversionEligibilityFailureReason
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        0
    )
    UNKNOWN = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        1
    )
    NOT_ENOUGH_CONVERSIONS = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        2
    )
    CONVERSION_LAG_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        3
    )
    HAS_CAMPAIGN_WITH_SHARED_BUDGET = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        4
    )
    HAS_UPLOAD_CLICKS_CONVERSION = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        5
    )
    AVERAGE_DAILY_SPEND_TOO_HIGH = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        6
    )
    ANALYSIS_NOT_COMPLETE = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        7
    )
    OTHER = CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V(
        8
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerPayPerConversionEligibilityFailureReasonEnum = (
    CustomerPayPerConversionEligibilityFailureReasonEnum
)
