"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.shared_set_status_pb2
import google.ads.google_ads.v6.proto.enums.shared_set_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SharedSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MEMBER_COUNT_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    type: google.ads.google_ads.v6.proto.enums.shared_set_type_pb2.SharedSetTypeEnum.SharedSetType.V = (
        ...
    )
    name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.shared_set_status_pb2.SharedSetStatusEnum.SharedSetStatus.V = (
        ...
    )
    member_count: builtins.int = ...
    reference_count: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        type: google.ads.google_ads.v6.proto.enums.shared_set_type_pb2.SharedSetTypeEnum.SharedSetType.V = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.shared_set_status_pb2.SharedSetStatusEnum.SharedSetStatus.V = ...,
        member_count: builtins.int = ...,
        reference_count: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_member_count",
            b"_member_count",
            "_name",
            b"_name",
            "_reference_count",
            b"_reference_count",
            "id",
            b"id",
            "member_count",
            b"member_count",
            "name",
            b"name",
            "reference_count",
            b"reference_count",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_member_count",
            b"_member_count",
            "_name",
            b"_name",
            "_reference_count",
            b"_reference_count",
            "id",
            b"id",
            "member_count",
            b"member_count",
            "name",
            b"name",
            "reference_count",
            b"reference_count",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_member_count", b"_member_count"]
    ) -> typing_extensions.Literal["member_count"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_reference_count", b"_reference_count"],
    ) -> typing_extensions.Literal["reference_count"]: ...

global___SharedSet = SharedSet
