"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    DURATION_MILLIS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def channel_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def duration_millis(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        channel_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        duration_millis: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        title: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "title",
            b"title",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "resource_name",
            b"resource_name",
            "title",
            b"title",
        ],
    ) -> None: ...

global___Video = Video
