"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DeviceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _Device(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Device.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DeviceEnum.Device.V(0)
        UNKNOWN = DeviceEnum.Device.V(1)
        MOBILE = DeviceEnum.Device.V(2)
        TABLET = DeviceEnum.Device.V(3)
        DESKTOP = DeviceEnum.Device.V(4)
        CONNECTED_TV = DeviceEnum.Device.V(6)
        OTHER = DeviceEnum.Device.V(5)
    class Device(metaclass=_Device):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DeviceEnum.Device.V(0)
    UNKNOWN = DeviceEnum.Device.V(1)
    MOBILE = DeviceEnum.Device.V(2)
    TABLET = DeviceEnum.Device.V(3)
    DESKTOP = DeviceEnum.Device.V(4)
    CONNECTED_TV = DeviceEnum.Device.V(6)
    OTHER = DeviceEnum.Device.V(5)
    def __init__(
        self,
    ) -> None: ...

global___DeviceEnum = DeviceEnum
