"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PlaceholderTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PlaceholderType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PlaceholderType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PlaceholderTypeEnum.PlaceholderType.V(0)
        UNKNOWN = PlaceholderTypeEnum.PlaceholderType.V(1)
        SITELINK = PlaceholderTypeEnum.PlaceholderType.V(2)
        CALL = PlaceholderTypeEnum.PlaceholderType.V(3)
        APP = PlaceholderTypeEnum.PlaceholderType.V(4)
        LOCATION = PlaceholderTypeEnum.PlaceholderType.V(5)
        AFFILIATE_LOCATION = PlaceholderTypeEnum.PlaceholderType.V(6)
        CALLOUT = PlaceholderTypeEnum.PlaceholderType.V(7)
        STRUCTURED_SNIPPET = PlaceholderTypeEnum.PlaceholderType.V(8)
        MESSAGE = PlaceholderTypeEnum.PlaceholderType.V(9)
        PRICE = PlaceholderTypeEnum.PlaceholderType.V(10)
        PROMOTION = PlaceholderTypeEnum.PlaceholderType.V(11)
        AD_CUSTOMIZER = PlaceholderTypeEnum.PlaceholderType.V(12)
        DYNAMIC_EDUCATION = PlaceholderTypeEnum.PlaceholderType.V(13)
        DYNAMIC_FLIGHT = PlaceholderTypeEnum.PlaceholderType.V(14)
        DYNAMIC_CUSTOM = PlaceholderTypeEnum.PlaceholderType.V(15)
        DYNAMIC_HOTEL = PlaceholderTypeEnum.PlaceholderType.V(16)
        DYNAMIC_REAL_ESTATE = PlaceholderTypeEnum.PlaceholderType.V(17)
        DYNAMIC_TRAVEL = PlaceholderTypeEnum.PlaceholderType.V(18)
        DYNAMIC_LOCAL = PlaceholderTypeEnum.PlaceholderType.V(19)
        DYNAMIC_JOB = PlaceholderTypeEnum.PlaceholderType.V(20)
    class PlaceholderType(metaclass=_PlaceholderType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PlaceholderTypeEnum.PlaceholderType.V(0)
    UNKNOWN = PlaceholderTypeEnum.PlaceholderType.V(1)
    SITELINK = PlaceholderTypeEnum.PlaceholderType.V(2)
    CALL = PlaceholderTypeEnum.PlaceholderType.V(3)
    APP = PlaceholderTypeEnum.PlaceholderType.V(4)
    LOCATION = PlaceholderTypeEnum.PlaceholderType.V(5)
    AFFILIATE_LOCATION = PlaceholderTypeEnum.PlaceholderType.V(6)
    CALLOUT = PlaceholderTypeEnum.PlaceholderType.V(7)
    STRUCTURED_SNIPPET = PlaceholderTypeEnum.PlaceholderType.V(8)
    MESSAGE = PlaceholderTypeEnum.PlaceholderType.V(9)
    PRICE = PlaceholderTypeEnum.PlaceholderType.V(10)
    PROMOTION = PlaceholderTypeEnum.PlaceholderType.V(11)
    AD_CUSTOMIZER = PlaceholderTypeEnum.PlaceholderType.V(12)
    DYNAMIC_EDUCATION = PlaceholderTypeEnum.PlaceholderType.V(13)
    DYNAMIC_FLIGHT = PlaceholderTypeEnum.PlaceholderType.V(14)
    DYNAMIC_CUSTOM = PlaceholderTypeEnum.PlaceholderType.V(15)
    DYNAMIC_HOTEL = PlaceholderTypeEnum.PlaceholderType.V(16)
    DYNAMIC_REAL_ESTATE = PlaceholderTypeEnum.PlaceholderType.V(17)
    DYNAMIC_TRAVEL = PlaceholderTypeEnum.PlaceholderType.V(18)
    DYNAMIC_LOCAL = PlaceholderTypeEnum.PlaceholderType.V(19)
    DYNAMIC_JOB = PlaceholderTypeEnum.PlaceholderType.V(20)
    def __init__(
        self,
    ) -> None: ...

global___PlaceholderTypeEnum = PlaceholderTypeEnum
