"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealEstatePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RealEstatePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RealEstatePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(0)
        UNKNOWN = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(1)
        LISTING_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(2)
        LISTING_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(3)
        CITY_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(4)
        DESCRIPTION = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(5)
        ADDRESS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(6)
        PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(7)
        FORMATTED_PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(8)
        IMAGE_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(9)
        PROPERTY_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(10)
        LISTING_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(11)
        CONTEXTUAL_KEYWORDS = (
            RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(12)
        )
        FINAL_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(13)
        FINAL_MOBILE_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            14
        )
        TRACKING_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(15)
        ANDROID_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            16
        )
        SIMILAR_LISTING_IDS = (
            RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(17)
        )
        IOS_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(18)
        IOS_APP_STORE_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
            19
        )
    class RealEstatePlaceholderField(metaclass=_RealEstatePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(0)
    UNKNOWN = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(1)
    LISTING_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(2)
    LISTING_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(3)
    CITY_NAME = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(4)
    DESCRIPTION = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(5)
    ADDRESS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(6)
    PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(7)
    FORMATTED_PRICE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(8)
    IMAGE_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(9)
    PROPERTY_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(10)
    LISTING_TYPE = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(11)
    CONTEXTUAL_KEYWORDS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
        12
    )
    FINAL_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(13)
    FINAL_MOBILE_URLS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(14)
    TRACKING_URL = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(15)
    ANDROID_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(16)
    SIMILAR_LISTING_IDS = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(
        17
    )
    IOS_APP_LINK = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(18)
    IOS_APP_STORE_ID = RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField.V(19)
    def __init__(
        self,
    ) -> None: ...

global___RealEstatePlaceholderFieldEnum = RealEstatePlaceholderFieldEnum
