"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ImageErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ImageError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ImageErrorEnum.ImageError.V(0)
        UNKNOWN = ImageErrorEnum.ImageError.V(1)
        INVALID_IMAGE = ImageErrorEnum.ImageError.V(2)
        STORAGE_ERROR = ImageErrorEnum.ImageError.V(3)
        BAD_REQUEST = ImageErrorEnum.ImageError.V(4)
        UNEXPECTED_SIZE = ImageErrorEnum.ImageError.V(5)
        ANIMATED_NOT_ALLOWED = ImageErrorEnum.ImageError.V(6)
        ANIMATION_TOO_LONG = ImageErrorEnum.ImageError.V(7)
        SERVER_ERROR = ImageErrorEnum.ImageError.V(8)
        CMYK_JPEG_NOT_ALLOWED = ImageErrorEnum.ImageError.V(9)
        FLASH_NOT_ALLOWED = ImageErrorEnum.ImageError.V(10)
        FLASH_WITHOUT_CLICKTAG = ImageErrorEnum.ImageError.V(11)
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG = ImageErrorEnum.ImageError.V(12)
        ANIMATED_VISUAL_EFFECT = ImageErrorEnum.ImageError.V(13)
        FLASH_ERROR = ImageErrorEnum.ImageError.V(14)
        LAYOUT_PROBLEM = ImageErrorEnum.ImageError.V(15)
        PROBLEM_READING_IMAGE_FILE = ImageErrorEnum.ImageError.V(16)
        ERROR_STORING_IMAGE = ImageErrorEnum.ImageError.V(17)
        ASPECT_RATIO_NOT_ALLOWED = ImageErrorEnum.ImageError.V(18)
        FLASH_HAS_NETWORK_OBJECTS = ImageErrorEnum.ImageError.V(19)
        FLASH_HAS_NETWORK_METHODS = ImageErrorEnum.ImageError.V(20)
        FLASH_HAS_URL = ImageErrorEnum.ImageError.V(21)
        FLASH_HAS_MOUSE_TRACKING = ImageErrorEnum.ImageError.V(22)
        FLASH_HAS_RANDOM_NUM = ImageErrorEnum.ImageError.V(23)
        FLASH_SELF_TARGETS = ImageErrorEnum.ImageError.V(24)
        FLASH_BAD_GETURL_TARGET = ImageErrorEnum.ImageError.V(25)
        FLASH_VERSION_NOT_SUPPORTED = ImageErrorEnum.ImageError.V(26)
        FLASH_WITHOUT_HARD_CODED_CLICK_URL = ImageErrorEnum.ImageError.V(27)
        INVALID_FLASH_FILE = ImageErrorEnum.ImageError.V(28)
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH = ImageErrorEnum.ImageError.V(29)
        FLASH_ACCESSES_NETWORK_RESOURCES = ImageErrorEnum.ImageError.V(30)
        FLASH_EXTERNAL_JS_CALL = ImageErrorEnum.ImageError.V(31)
        FLASH_EXTERNAL_FS_CALL = ImageErrorEnum.ImageError.V(32)
        FILE_TOO_LARGE = ImageErrorEnum.ImageError.V(33)
        IMAGE_DATA_TOO_LARGE = ImageErrorEnum.ImageError.V(34)
        IMAGE_PROCESSING_ERROR = ImageErrorEnum.ImageError.V(35)
        IMAGE_TOO_SMALL = ImageErrorEnum.ImageError.V(36)
        INVALID_INPUT = ImageErrorEnum.ImageError.V(37)
        PROBLEM_READING_FILE = ImageErrorEnum.ImageError.V(38)
        IMAGE_CONSTRAINTS_VIOLATED = ImageErrorEnum.ImageError.V(39)
    class ImageError(metaclass=_ImageError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ImageErrorEnum.ImageError.V(0)
    UNKNOWN = ImageErrorEnum.ImageError.V(1)
    INVALID_IMAGE = ImageErrorEnum.ImageError.V(2)
    STORAGE_ERROR = ImageErrorEnum.ImageError.V(3)
    BAD_REQUEST = ImageErrorEnum.ImageError.V(4)
    UNEXPECTED_SIZE = ImageErrorEnum.ImageError.V(5)
    ANIMATED_NOT_ALLOWED = ImageErrorEnum.ImageError.V(6)
    ANIMATION_TOO_LONG = ImageErrorEnum.ImageError.V(7)
    SERVER_ERROR = ImageErrorEnum.ImageError.V(8)
    CMYK_JPEG_NOT_ALLOWED = ImageErrorEnum.ImageError.V(9)
    FLASH_NOT_ALLOWED = ImageErrorEnum.ImageError.V(10)
    FLASH_WITHOUT_CLICKTAG = ImageErrorEnum.ImageError.V(11)
    FLASH_ERROR_AFTER_FIXING_CLICK_TAG = ImageErrorEnum.ImageError.V(12)
    ANIMATED_VISUAL_EFFECT = ImageErrorEnum.ImageError.V(13)
    FLASH_ERROR = ImageErrorEnum.ImageError.V(14)
    LAYOUT_PROBLEM = ImageErrorEnum.ImageError.V(15)
    PROBLEM_READING_IMAGE_FILE = ImageErrorEnum.ImageError.V(16)
    ERROR_STORING_IMAGE = ImageErrorEnum.ImageError.V(17)
    ASPECT_RATIO_NOT_ALLOWED = ImageErrorEnum.ImageError.V(18)
    FLASH_HAS_NETWORK_OBJECTS = ImageErrorEnum.ImageError.V(19)
    FLASH_HAS_NETWORK_METHODS = ImageErrorEnum.ImageError.V(20)
    FLASH_HAS_URL = ImageErrorEnum.ImageError.V(21)
    FLASH_HAS_MOUSE_TRACKING = ImageErrorEnum.ImageError.V(22)
    FLASH_HAS_RANDOM_NUM = ImageErrorEnum.ImageError.V(23)
    FLASH_SELF_TARGETS = ImageErrorEnum.ImageError.V(24)
    FLASH_BAD_GETURL_TARGET = ImageErrorEnum.ImageError.V(25)
    FLASH_VERSION_NOT_SUPPORTED = ImageErrorEnum.ImageError.V(26)
    FLASH_WITHOUT_HARD_CODED_CLICK_URL = ImageErrorEnum.ImageError.V(27)
    INVALID_FLASH_FILE = ImageErrorEnum.ImageError.V(28)
    FAILED_TO_FIX_CLICK_TAG_IN_FLASH = ImageErrorEnum.ImageError.V(29)
    FLASH_ACCESSES_NETWORK_RESOURCES = ImageErrorEnum.ImageError.V(30)
    FLASH_EXTERNAL_JS_CALL = ImageErrorEnum.ImageError.V(31)
    FLASH_EXTERNAL_FS_CALL = ImageErrorEnum.ImageError.V(32)
    FILE_TOO_LARGE = ImageErrorEnum.ImageError.V(33)
    IMAGE_DATA_TOO_LARGE = ImageErrorEnum.ImageError.V(34)
    IMAGE_PROCESSING_ERROR = ImageErrorEnum.ImageError.V(35)
    IMAGE_TOO_SMALL = ImageErrorEnum.ImageError.V(36)
    INVALID_INPUT = ImageErrorEnum.ImageError.V(37)
    PROBLEM_READING_FILE = ImageErrorEnum.ImageError.V(38)
    IMAGE_CONSTRAINTS_VIOLATED = ImageErrorEnum.ImageError.V(39)
    def __init__(
        self,
    ) -> None: ...

global___ImageErrorEnum = ImageErrorEnum
