"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchTermTargetingStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SearchTermTargetingStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            SearchTermTargetingStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(0)
        UNKNOWN = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(1)
        ADDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(2)
        EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(3)
        ADDED_EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(4)
        NONE = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(5)
    class SearchTermTargetingStatus(metaclass=_SearchTermTargetingStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(0)
    UNKNOWN = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(1)
    ADDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(2)
    EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(3)
    ADDED_EXCLUDED = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(4)
    NONE = SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___SearchTermTargetingStatusEnum = SearchTermTargetingStatusEnum
