"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LeadFormFieldUserInputTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LeadFormFieldUserInputType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LeadFormFieldUserInputType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(0)
        UNKNOWN = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1)
        FULL_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(2)
        GIVEN_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(6)
        FAMILY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(7)
        EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(3)
        PHONE_NUMBER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(4)
        POSTAL_CODE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(5)
        CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(9)
        REGION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(10)
        COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(11)
        WORK_EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(12)
        COMPANY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(13)
        WORK_PHONE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(14)
        JOB_TITLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(15)
        VEHICLE_MODEL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1001
        )
        VEHICLE_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1002)
        PREFERRED_DEALERSHIP = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1003)
        )
        VEHICLE_PURCHASE_TIMELINE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1004)
        )
        VEHICLE_OWNERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1005
        )
        VEHICLE_PAYMENT_TYPE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1009)
        )
        VEHICLE_CONDITION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1010
        )
        COMPANY_SIZE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1006)
        ANNUAL_SALES = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1007)
        YEARS_IN_BUSINESS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1008
        )
        JOB_DEPARTMENT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1011
        )
        JOB_ROLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1012)
        EDUCATION_PROGRAM = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1013
        )
        EDUCATION_COURSE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1014
        )
        PRODUCT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1016)
        SERVICE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1017)
        OFFER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1018)
        CATEGORY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1019)
        PREFERRED_CONTACT_METHOD = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1020)
        )
        PREFERRED_LOCATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1021)
        )
        PREFERRED_CONTACT_TIME = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1022)
        )
        PURCHASE_TIMELINE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1023
        )
        YEARS_OF_EXPERIENCE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1048)
        )
        JOB_INDUSTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1049)
        LEVEL_OF_EDUCATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1050)
        )
        PROPERTY_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1024
        )
        REALTOR_HELP_GOAL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1025
        )
        PROPERTY_COMMUNITY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1026)
        )
        PRICE_RANGE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1027)
        NUMBER_OF_BEDROOMS = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1028)
        )
        FURNISHED_PROPERTY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1029)
        )
        PETS_ALLOWED_PROPERTY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1030)
        )
        NEXT_PLANNED_PURCHASE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1031)
        )
        EVENT_SIGNUP_INTEREST = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1033)
        )
        PREFERRED_SHOPPING_PLACES = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1034)
        )
        FAVORITE_BRAND = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1035
        )
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1036)
        )
        EVENT_BOOKING_INTEREST = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1038)
        )
        DESTINATION_COUNTRY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1039)
        )
        DESTINATION_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1040
        )
        DEPARTURE_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1041
        )
        DEPARTURE_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1042
        )
        DEPARTURE_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1043
        )
        RETURN_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1044)
        NUMBER_OF_TRAVELERS = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1045)
        )
        TRAVEL_BUDGET = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1046
        )
        TRAVEL_ACCOMMODATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1047)
        )
    class LeadFormFieldUserInputType(metaclass=_LeadFormFieldUserInputType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(0)
    UNKNOWN = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1)
    FULL_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(2)
    GIVEN_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(6)
    FAMILY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(7)
    EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(3)
    PHONE_NUMBER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(4)
    POSTAL_CODE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(5)
    CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(9)
    REGION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(10)
    COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(11)
    WORK_EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(12)
    COMPANY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(13)
    WORK_PHONE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(14)
    JOB_TITLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(15)
    VEHICLE_MODEL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1001)
    VEHICLE_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1002)
    PREFERRED_DEALERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1003
    )
    VEHICLE_PURCHASE_TIMELINE = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1004)
    )
    VEHICLE_OWNERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1005
    )
    VEHICLE_PAYMENT_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1009
    )
    VEHICLE_CONDITION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1010
    )
    COMPANY_SIZE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1006)
    ANNUAL_SALES = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1007)
    YEARS_IN_BUSINESS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1008
    )
    JOB_DEPARTMENT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1011)
    JOB_ROLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1012)
    EDUCATION_PROGRAM = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1013
    )
    EDUCATION_COURSE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1014)
    PRODUCT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1016)
    SERVICE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1017)
    OFFER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1018)
    CATEGORY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1019)
    PREFERRED_CONTACT_METHOD = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1020)
    )
    PREFERRED_LOCATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1021
    )
    PREFERRED_CONTACT_TIME = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1022)
    )
    PURCHASE_TIMELINE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1023
    )
    YEARS_OF_EXPERIENCE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1048
    )
    JOB_INDUSTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1049)
    LEVEL_OF_EDUCATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1050
    )
    PROPERTY_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1024)
    REALTOR_HELP_GOAL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1025
    )
    PROPERTY_COMMUNITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1026
    )
    PRICE_RANGE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1027)
    NUMBER_OF_BEDROOMS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1028
    )
    FURNISHED_PROPERTY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1029
    )
    PETS_ALLOWED_PROPERTY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1030
    )
    NEXT_PLANNED_PURCHASE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1031
    )
    EVENT_SIGNUP_INTEREST = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1033
    )
    PREFERRED_SHOPPING_PLACES = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1034)
    )
    FAVORITE_BRAND = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1035)
    TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1036)
    )
    EVENT_BOOKING_INTEREST = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1038)
    )
    DESTINATION_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1039
    )
    DESTINATION_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1040)
    DEPARTURE_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1041
    )
    DEPARTURE_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1042)
    DEPARTURE_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1043)
    RETURN_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1044)
    NUMBER_OF_TRAVELERS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1045
    )
    TRAVEL_BUDGET = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1046)
    TRAVEL_ACCOMMODATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1047
    )
    def __init__(
        self,
    ) -> None: ...

global___LeadFormFieldUserInputTypeEnum = LeadFormFieldUserInputTypeEnum
