"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.shared_criterion_pb2
import grpc

from .shared_criterion_service_pb2 import *

class SharedCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetSharedCriterion(
        self,
        request: global___GetSharedCriterionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.shared_criterion_pb2.SharedCriterion: ...
    def MutateSharedCriteria(
        self,
        request: global___MutateSharedCriteriaRequest,
    ) -> global___MutateSharedCriteriaResponse: ...

class SharedCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSharedCriterion(
        self,
        request: global___GetSharedCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.shared_criterion_pb2.SharedCriterion: ...
    @abc.abstractmethod
    def MutateSharedCriteria(
        self,
        request: global___MutateSharedCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateSharedCriteriaResponse: ...

def add_SharedCriterionServiceServicer_to_server(
    servicer: SharedCriterionServiceServicer, server: grpc.Server
) -> None: ...
