"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedMappingCriterionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedMappingCriterionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedMappingCriterionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(0)
        UNKNOWN = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(1)
        LOCATION_EXTENSION_TARGETING = (
            FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(4)
        )
        DSA_PAGE_FEED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(3)
    class FeedMappingCriterionType(metaclass=_FeedMappingCriterionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(0)
    UNKNOWN = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(1)
    LOCATION_EXTENSION_TARGETING = (
        FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(4)
    )
    DSA_PAGE_FEED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___FeedMappingCriterionTypeEnum = FeedMappingCriterionTypeEnum
