"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_feed_pb2
import grpc

from .campaign_feed_service_pb2 import *

class CampaignFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignFeed(
        self,
        request: global___GetCampaignFeedRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_feed_pb2.CampaignFeed: ...
    def MutateCampaignFeeds(
        self,
        request: global___MutateCampaignFeedsRequest,
    ) -> global___MutateCampaignFeedsResponse: ...

class CampaignFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignFeed(
        self,
        request: global___GetCampaignFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_feed_pb2.CampaignFeed: ...
    @abc.abstractmethod
    def MutateCampaignFeeds(
        self,
        request: global___MutateCampaignFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignFeedsResponse: ...

def add_CampaignFeedServiceServicer_to_server(
    servicer: CampaignFeedServiceServicer, server: grpc.Server
) -> None: ...
