"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccessRoleEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccessRole(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AccessRole.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccessRoleEnum.AccessRole.V(0)
        UNKNOWN = AccessRoleEnum.AccessRole.V(1)
        ADMIN = AccessRoleEnum.AccessRole.V(2)
        STANDARD = AccessRoleEnum.AccessRole.V(3)
        READ_ONLY = AccessRoleEnum.AccessRole.V(4)
        EMAIL_ONLY = AccessRoleEnum.AccessRole.V(5)
    class AccessRole(metaclass=_AccessRole):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccessRoleEnum.AccessRole.V(0)
    UNKNOWN = AccessRoleEnum.AccessRole.V(1)
    ADMIN = AccessRoleEnum.AccessRole.V(2)
    STANDARD = AccessRoleEnum.AccessRole.V(3)
    READ_ONLY = AccessRoleEnum.AccessRole.V(4)
    EMAIL_ONLY = AccessRoleEnum.AccessRole.V(5)
    def __init__(
        self,
    ) -> None: ...

global___AccessRoleEnum = AccessRoleEnum
