"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetPerformanceLabelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetPerformanceLabel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AssetPerformanceLabel.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(0)
        UNKNOWN = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(1)
        PENDING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(2)
        LEARNING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(3)
        LOW = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(4)
        GOOD = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(5)
        BEST = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(6)
    class AssetPerformanceLabel(metaclass=_AssetPerformanceLabel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(0)
    UNKNOWN = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(1)
    PENDING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(2)
    LEARNING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(3)
    LOW = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(4)
    GOOD = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(5)
    BEST = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AssetPerformanceLabelEnum = AssetPerformanceLabelEnum
