"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2
import grpc

from .keyword_plan_campaign_keyword_service_pb2 import *

class KeywordPlanCampaignKeywordServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanCampaignKeyword(
        self,
        request: global___GetKeywordPlanCampaignKeywordRequest,
    ) -> google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword: ...
    def MutateKeywordPlanCampaignKeywords(
        self,
        request: global___MutateKeywordPlanCampaignKeywordsRequest,
    ) -> global___MutateKeywordPlanCampaignKeywordsResponse: ...

class KeywordPlanCampaignKeywordServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanCampaignKeyword(
        self,
        request: global___GetKeywordPlanCampaignKeywordRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword: ...
    @abc.abstractmethod
    def MutateKeywordPlanCampaignKeywords(
        self,
        request: global___MutateKeywordPlanCampaignKeywordsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanCampaignKeywordsResponse: ...

def add_KeywordPlanCampaignKeywordServiceServicer_to_server(
    servicer: KeywordPlanCampaignKeywordServiceServicer, server: grpc.Server
) -> None: ...
