"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_asset_pb2
import grpc

from .campaign_asset_service_pb2 import *

class CampaignAssetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignAsset(
        self,
        request: global___GetCampaignAssetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset: ...
    def MutateCampaignAssets(
        self,
        request: global___MutateCampaignAssetsRequest,
    ) -> global___MutateCampaignAssetsResponse: ...

class CampaignAssetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignAsset(
        self,
        request: global___GetCampaignAssetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset: ...
    @abc.abstractmethod
    def MutateCampaignAssets(
        self,
        request: global___MutateCampaignAssetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignAssetsResponse: ...

def add_CampaignAssetServiceServicer_to_server(
    servicer: CampaignAssetServiceServicer, server: grpc.Server
) -> None: ...
