"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_item_set_pb2
import grpc

from .feed_item_set_service_pb2 import *

class FeedItemSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItemSet(
        self,
        request: global___GetFeedItemSetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_pb2.FeedItemSet: ...
    def MutateFeedItemSets(
        self,
        request: global___MutateFeedItemSetsRequest,
    ) -> global___MutateFeedItemSetsResponse: ...

class FeedItemSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItemSet(
        self,
        request: global___GetFeedItemSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_pb2.FeedItemSet: ...
    @abc.abstractmethod
    def MutateFeedItemSets(
        self,
        request: global___MutateFeedItemSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemSetsResponse: ...

def add_FeedItemSetServiceServicer_to_server(
    servicer: FeedItemSetServiceServicer, server: grpc.Server
) -> None: ...
