"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ContextErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ContextError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContextError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ContextErrorEnum.ContextError.V(0)
        UNKNOWN = ContextErrorEnum.ContextError.V(1)
        OPERATION_NOT_PERMITTED_FOR_CONTEXT = ContextErrorEnum.ContextError.V(2)
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = ContextErrorEnum.ContextError.V(
            3
        )
    class ContextError(metaclass=_ContextError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ContextErrorEnum.ContextError.V(0)
    UNKNOWN = ContextErrorEnum.ContextError.V(1)
    OPERATION_NOT_PERMITTED_FOR_CONTEXT = ContextErrorEnum.ContextError.V(2)
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = ContextErrorEnum.ContextError.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ContextErrorEnum = ContextErrorEnum
