"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemQualityDisapprovalReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemQualityDisapprovalReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemQualityDisapprovalReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(0)
        )
        UNKNOWN = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(1)
        )
        PRICE_TABLE_REPETITIVE_HEADERS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(2)
        )
        PRICE_TABLE_REPETITIVE_DESCRIPTION = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(3)
        )
        PRICE_TABLE_INCONSISTENT_ROWS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(4)
        )
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(5)
        )
        PRICE_UNSUPPORTED_LANGUAGE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(6)
        )
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(7)
        )
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(8)
        )
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(9)
        )
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(10)
        )
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(11)
        )
        PRICE_TABLE_ROW_UNRATEABLE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(12)
        )
        PRICE_TABLE_ROW_PRICE_INVALID = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(13)
        )
        PRICE_TABLE_ROW_URL_INVALID = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(14)
        )
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(15)
        )
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(16)
        )
        STRUCTURED_SNIPPETS_REPEATED_VALUES = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(17)
        )
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(18)
        )
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(19)
        )
    class FeedItemQualityDisapprovalReason(metaclass=_FeedItemQualityDisapprovalReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(0)
    )
    UNKNOWN = FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(1)
    PRICE_TABLE_REPETITIVE_HEADERS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(2)
    )
    PRICE_TABLE_REPETITIVE_DESCRIPTION = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(3)
    )
    PRICE_TABLE_INCONSISTENT_ROWS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(4)
    )
    PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(5)
    )
    PRICE_UNSUPPORTED_LANGUAGE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(6)
    )
    PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(7)
    )
    PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(8)
    )
    PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(9)
    )
    PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(10)
    )
    PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(11)
    )
    PRICE_TABLE_ROW_UNRATEABLE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(12)
    )
    PRICE_TABLE_ROW_PRICE_INVALID = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(13)
    )
    PRICE_TABLE_ROW_URL_INVALID = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(14)
    )
    PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(15)
    )
    STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(16)
    )
    STRUCTURED_SNIPPETS_REPEATED_VALUES = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(17)
    )
    STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(18)
    )
    STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(19)
    )
    def __init__(
        self,
    ) -> None: ...

global___FeedItemQualityDisapprovalReasonEnum = FeedItemQualityDisapprovalReasonEnum
