"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2
import grpc

from .campaign_criterion_service_pb2 import *

class CampaignCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignCriterion(
        self,
        request: global___GetCampaignCriterionRequest,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
    def MutateCampaignCriteria(
        self,
        request: global___MutateCampaignCriteriaRequest,
    ) -> global___MutateCampaignCriteriaResponse: ...

class CampaignCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignCriterion(
        self,
        request: global___GetCampaignCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
    @abc.abstractmethod
    def MutateCampaignCriteria(
        self,
        request: global___MutateCampaignCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignCriteriaResponse: ...

def add_CampaignCriterionServiceServicer_to_server(
    servicer: CampaignCriterionServiceServicer, server: grpc.Server
) -> None: ...
