"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoRegistrationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _YoutubeVideoRegistrationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            YoutubeVideoRegistrationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(
            0
        )
        UNKNOWN = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(1)
        VIDEO_NOT_FOUND = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(2)
        )
        VIDEO_NOT_ACCESSIBLE = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(3)
        )
        VIDEO_NOT_ELIGIBLE = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(4)
        )
    class YoutubeVideoRegistrationError(metaclass=_YoutubeVideoRegistrationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(0)
    UNKNOWN = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(1)
    VIDEO_NOT_FOUND = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(
        2
    )
    VIDEO_NOT_ACCESSIBLE = (
        YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(3)
    )
    VIDEO_NOT_ELIGIBLE = (
        YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___YoutubeVideoRegistrationErrorEnum = YoutubeVideoRegistrationErrorEnum
