"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.customer_user_access_pb2
import grpc

from .customer_user_access_service_pb2 import *

class CustomerUserAccessServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerUserAccess(
        self,
        request: global___GetCustomerUserAccessRequest,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_pb2.CustomerUserAccess: ...
    def MutateCustomerUserAccess(
        self,
        request: global___MutateCustomerUserAccessRequest,
    ) -> global___MutateCustomerUserAccessResponse: ...

class CustomerUserAccessServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerUserAccess(
        self,
        request: global___GetCustomerUserAccessRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_pb2.CustomerUserAccess: ...
    @abc.abstractmethod
    def MutateCustomerUserAccess(
        self,
        request: global___MutateCustomerUserAccessRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerUserAccessResponse: ...

def add_CustomerUserAccessServiceServicer_to_server(
    servicer: CustomerUserAccessServiceServicer, server: grpc.Server
) -> None: ...
