"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetingDimensionEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetingDimension(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetingDimension.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TargetingDimensionEnum.TargetingDimension.V(0)
        UNKNOWN = TargetingDimensionEnum.TargetingDimension.V(1)
        KEYWORD = TargetingDimensionEnum.TargetingDimension.V(2)
        AUDIENCE = TargetingDimensionEnum.TargetingDimension.V(3)
        TOPIC = TargetingDimensionEnum.TargetingDimension.V(4)
        GENDER = TargetingDimensionEnum.TargetingDimension.V(5)
        AGE_RANGE = TargetingDimensionEnum.TargetingDimension.V(6)
        PLACEMENT = TargetingDimensionEnum.TargetingDimension.V(7)
        PARENTAL_STATUS = TargetingDimensionEnum.TargetingDimension.V(8)
        INCOME_RANGE = TargetingDimensionEnum.TargetingDimension.V(9)
    class TargetingDimension(metaclass=_TargetingDimension):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TargetingDimensionEnum.TargetingDimension.V(0)
    UNKNOWN = TargetingDimensionEnum.TargetingDimension.V(1)
    KEYWORD = TargetingDimensionEnum.TargetingDimension.V(2)
    AUDIENCE = TargetingDimensionEnum.TargetingDimension.V(3)
    TOPIC = TargetingDimensionEnum.TargetingDimension.V(4)
    GENDER = TargetingDimensionEnum.TargetingDimension.V(5)
    AGE_RANGE = TargetingDimensionEnum.TargetingDimension.V(6)
    PLACEMENT = TargetingDimensionEnum.TargetingDimension.V(7)
    PARENTAL_STATUS = TargetingDimensionEnum.TargetingDimension.V(8)
    INCOME_RANGE = TargetingDimensionEnum.TargetingDimension.V(9)
    def __init__(
        self,
    ) -> None: ...

global___TargetingDimensionEnum = TargetingDimensionEnum
