"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClientLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerClientLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerClientLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(0)
        UNKNOWN = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(1)
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(2)
        )
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(3)
        )
        CYCLIC_LINK_NOT_ALLOWED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(
            4
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(5)
        )
        CLIENT_HAS_TOO_MANY_INVITATIONS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(6)
        )
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(7)
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(8)
        )
        CLIENT_HAS_TOO_MANY_MANAGERS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(9)
        )
    class CustomerClientLinkError(metaclass=_CustomerClientLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(0)
    UNKNOWN = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(1)
    CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(2)
    )
    CLIENT_ALREADY_MANAGED_IN_HIERARCHY = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(3)
    )
    CYCLIC_LINK_NOT_ALLOWED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(4)
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(5)
    )
    CLIENT_HAS_TOO_MANY_INVITATIONS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(6)
    )
    CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(7)
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(8)
    )
    CLIENT_HAS_TOO_MANY_MANAGERS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(9)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerClientLinkErrorEnum = CustomerClientLinkErrorEnum
