"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetFieldTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetFieldType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetFieldType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetFieldTypeEnum.AssetFieldType.V(0)
        UNKNOWN = AssetFieldTypeEnum.AssetFieldType.V(1)
        HEADLINE = AssetFieldTypeEnum.AssetFieldType.V(2)
        DESCRIPTION = AssetFieldTypeEnum.AssetFieldType.V(3)
        MANDATORY_AD_TEXT = AssetFieldTypeEnum.AssetFieldType.V(4)
        MARKETING_IMAGE = AssetFieldTypeEnum.AssetFieldType.V(5)
        MEDIA_BUNDLE = AssetFieldTypeEnum.AssetFieldType.V(6)
        YOUTUBE_VIDEO = AssetFieldTypeEnum.AssetFieldType.V(7)
    class AssetFieldType(metaclass=_AssetFieldType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetFieldTypeEnum.AssetFieldType.V(0)
    UNKNOWN = AssetFieldTypeEnum.AssetFieldType.V(1)
    HEADLINE = AssetFieldTypeEnum.AssetFieldType.V(2)
    DESCRIPTION = AssetFieldTypeEnum.AssetFieldType.V(3)
    MANDATORY_AD_TEXT = AssetFieldTypeEnum.AssetFieldType.V(4)
    MARKETING_IMAGE = AssetFieldTypeEnum.AssetFieldType.V(5)
    MEDIA_BUNDLE = AssetFieldTypeEnum.AssetFieldType.V(6)
    YOUTUBE_VIDEO = AssetFieldTypeEnum.AssetFieldType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AssetFieldTypeEnum = AssetFieldTypeEnum
