"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.tag_snippet_pb2
import google.ads.google_ads.v5.proto.enums.attribution_model_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2
import google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2
import google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class AttributionModelSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ATTRIBUTION_MODEL_FIELD_NUMBER: builtins.int
        DATA_DRIVEN_MODEL_STATUS_FIELD_NUMBER: builtins.int
        attribution_model: google.ads.google_ads.v5.proto.enums.attribution_model_pb2.AttributionModelEnum.AttributionModel.V = (
            ...
        )
        data_driven_model_status: google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2.DataDrivenModelStatusEnum.DataDrivenModelStatus.V = (
            ...
        )
        def __init__(
            self,
            *,
            attribution_model: google.ads.google_ads.v5.proto.enums.attribution_model_pb2.AttributionModelEnum.AttributionModel.V = ...,
            data_driven_model_status: google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2.DataDrivenModelStatusEnum.DataDrivenModelStatus.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "attribution_model",
                b"attribution_model",
                "data_driven_model_status",
                b"data_driven_model_status",
            ],
        ) -> None: ...
    class ValueSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DEFAULT_VALUE_FIELD_NUMBER: builtins.int
        DEFAULT_CURRENCY_CODE_FIELD_NUMBER: builtins.int
        ALWAYS_USE_DEFAULT_VALUE_FIELD_NUMBER: builtins.int
        default_value: builtins.float = ...
        default_currency_code: typing.Text = ...
        always_use_default_value: builtins.bool = ...
        def __init__(
            self,
            *,
            default_value: builtins.float = ...,
            default_currency_code: typing.Text = ...,
            always_use_default_value: builtins.bool = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_always_use_default_value", b"_always_use_default_value"
            ],
        ) -> typing_extensions.Literal["always_use_default_value"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_default_currency_code", b"_default_currency_code"
            ],
        ) -> typing_extensions.Literal["default_currency_code"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_default_value", b"_default_value"],
        ) -> typing_extensions.Literal["default_value"]: ...
    class ThirdPartyAppAnalyticsSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EVENT_NAME_FIELD_NUMBER: builtins.int
        event_name: typing.Text = ...
        def __init__(
            self,
            *,
            event_name: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_event_name", b"_event_name"]
        ) -> typing_extensions.Literal["event_name"]: ...
    class FirebaseSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EVENT_NAME_FIELD_NUMBER: builtins.int
        PROJECT_ID_FIELD_NUMBER: builtins.int
        event_name: typing.Text = ...
        project_id: typing.Text = ...
        def __init__(
            self,
            *,
            event_name: typing.Text = ...,
            project_id: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_event_name", b"_event_name"]
        ) -> typing_extensions.Literal["event_name"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_project_id", b"_project_id"]
        ) -> typing_extensions.Literal["project_id"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    OWNER_CUSTOMER_FIELD_NUMBER: builtins.int
    INCLUDE_IN_CONVERSIONS_METRIC_FIELD_NUMBER: builtins.int
    CLICK_THROUGH_LOOKBACK_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_LOOKBACK_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    VALUE_SETTINGS_FIELD_NUMBER: builtins.int
    COUNTING_TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTION_MODEL_SETTINGS_FIELD_NUMBER: builtins.int
    TAG_SNIPPETS_FIELD_NUMBER: builtins.int
    PHONE_CALL_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    MOBILE_APP_VENDOR_FIELD_NUMBER: builtins.int
    FIREBASE_SETTINGS_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_SETTINGS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2.ConversionActionStatusEnum.ConversionActionStatus.V = (
        ...
    )
    type: google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2.ConversionActionTypeEnum.ConversionActionType.V = (
        ...
    )
    category: google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = (
        ...
    )
    owner_customer: typing.Text = ...
    include_in_conversions_metric: builtins.bool = ...
    click_through_lookback_window_days: builtins.int = ...
    view_through_lookback_window_days: builtins.int = ...
    counting_type: google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2.ConversionActionCountingTypeEnum.ConversionActionCountingType.V = (
        ...
    )
    phone_call_duration_seconds: builtins.int = ...
    app_id: typing.Text = ...
    mobile_app_vendor: google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = (
        ...
    )
    @property
    def value_settings(self) -> global___ConversionAction.ValueSettings: ...
    @property
    def attribution_model_settings(
        self,
    ) -> global___ConversionAction.AttributionModelSettings: ...
    @property
    def tag_snippets(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.tag_snippet_pb2.TagSnippet
    ]: ...
    @property
    def firebase_settings(self) -> global___ConversionAction.FirebaseSettings: ...
    @property
    def third_party_app_analytics_settings(
        self,
    ) -> global___ConversionAction.ThirdPartyAppAnalyticsSettings: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2.ConversionActionStatusEnum.ConversionActionStatus.V = ...,
        type: google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2.ConversionActionTypeEnum.ConversionActionType.V = ...,
        category: google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = ...,
        owner_customer: typing.Text = ...,
        include_in_conversions_metric: builtins.bool = ...,
        click_through_lookback_window_days: builtins.int = ...,
        view_through_lookback_window_days: builtins.int = ...,
        value_settings: typing.Optional[global___ConversionAction.ValueSettings] = ...,
        counting_type: google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2.ConversionActionCountingTypeEnum.ConversionActionCountingType.V = ...,
        attribution_model_settings: typing.Optional[
            global___ConversionAction.AttributionModelSettings
        ] = ...,
        tag_snippets: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.tag_snippet_pb2.TagSnippet
            ]
        ] = ...,
        phone_call_duration_seconds: builtins.int = ...,
        app_id: typing.Text = ...,
        mobile_app_vendor: google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = ...,
        firebase_settings: typing.Optional[
            global___ConversionAction.FirebaseSettings
        ] = ...,
        third_party_app_analytics_settings: typing.Optional[
            global___ConversionAction.ThirdPartyAppAnalyticsSettings
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "category",
            b"category",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "counting_type",
            b"counting_type",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "mobile_app_vendor",
            b"mobile_app_vendor",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "tag_snippets",
            b"tag_snippets",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "type",
            b"type",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
        ],
    ) -> typing_extensions.Literal["click_through_lookback_window_days"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_include_in_conversions_metric", b"_include_in_conversions_metric"
        ],
    ) -> typing_extensions.Literal["include_in_conversions_metric"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_owner_customer", b"_owner_customer"],
    ) -> typing_extensions.Literal["owner_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_call_duration_seconds", b"_phone_call_duration_seconds"
        ],
    ) -> typing_extensions.Literal["phone_call_duration_seconds"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_view_through_lookback_window_days", b"_view_through_lookback_window_days"
        ],
    ) -> typing_extensions.Literal["view_through_lookback_window_days"]: ...

global___ConversionAction = ConversionAction
