"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(0)
        UNKNOWN = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(1)
        PENDING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(2)
        RUNNING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(3)
        SUCCESS = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(4)
        FAILED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(5)
    class OfflineUserDataJobStatus(metaclass=_OfflineUserDataJobStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(0)
    UNKNOWN = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(1)
    PENDING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(2)
    RUNNING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(3)
    SUCCESS = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(4)
    FAILED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobStatusEnum = OfflineUserDataJobStatusEnum
