"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdDestinationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdDestinationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdDestinationType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdDestinationTypeEnum.AdDestinationType.V(0)
        UNKNOWN = AdDestinationTypeEnum.AdDestinationType.V(1)
        NOT_APPLICABLE = AdDestinationTypeEnum.AdDestinationType.V(2)
        WEBSITE = AdDestinationTypeEnum.AdDestinationType.V(3)
        APP_DEEP_LINK = AdDestinationTypeEnum.AdDestinationType.V(4)
        APP_STORE = AdDestinationTypeEnum.AdDestinationType.V(5)
        PHONE_CALL = AdDestinationTypeEnum.AdDestinationType.V(6)
        MAP_DIRECTIONS = AdDestinationTypeEnum.AdDestinationType.V(7)
        LOCATION_LISTING = AdDestinationTypeEnum.AdDestinationType.V(8)
        MESSAGE = AdDestinationTypeEnum.AdDestinationType.V(9)
        LEAD_FORM = AdDestinationTypeEnum.AdDestinationType.V(10)
        YOUTUBE = AdDestinationTypeEnum.AdDestinationType.V(11)
        UNMODELED_FOR_CONVERSIONS = AdDestinationTypeEnum.AdDestinationType.V(12)
    class AdDestinationType(metaclass=_AdDestinationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdDestinationTypeEnum.AdDestinationType.V(0)
    UNKNOWN = AdDestinationTypeEnum.AdDestinationType.V(1)
    NOT_APPLICABLE = AdDestinationTypeEnum.AdDestinationType.V(2)
    WEBSITE = AdDestinationTypeEnum.AdDestinationType.V(3)
    APP_DEEP_LINK = AdDestinationTypeEnum.AdDestinationType.V(4)
    APP_STORE = AdDestinationTypeEnum.AdDestinationType.V(5)
    PHONE_CALL = AdDestinationTypeEnum.AdDestinationType.V(6)
    MAP_DIRECTIONS = AdDestinationTypeEnum.AdDestinationType.V(7)
    LOCATION_LISTING = AdDestinationTypeEnum.AdDestinationType.V(8)
    MESSAGE = AdDestinationTypeEnum.AdDestinationType.V(9)
    LEAD_FORM = AdDestinationTypeEnum.AdDestinationType.V(10)
    YOUTUBE = AdDestinationTypeEnum.AdDestinationType.V(11)
    UNMODELED_FOR_CONVERSIONS = AdDestinationTypeEnum.AdDestinationType.V(12)
    def __init__(
        self,
    ) -> None: ...

global___AdDestinationTypeEnum = AdDestinationTypeEnum
