"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupErrorEnum.AdGroupError.V(0)
        UNKNOWN = AdGroupErrorEnum.AdGroupError.V(1)
        DUPLICATE_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(2)
        INVALID_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(3)
        ADVERTISER_NOT_ON_CONTENT_NETWORK = AdGroupErrorEnum.AdGroupError.V(5)
        BID_TOO_BIG = AdGroupErrorEnum.AdGroupError.V(6)
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = AdGroupErrorEnum.AdGroupError.V(7)
        MISSING_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(8)
        ADGROUP_LABEL_DOES_NOT_EXIST = AdGroupErrorEnum.AdGroupError.V(9)
        ADGROUP_LABEL_ALREADY_EXISTS = AdGroupErrorEnum.AdGroupError.V(10)
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = AdGroupErrorEnum.AdGroupError.V(11)
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = (
            AdGroupErrorEnum.AdGroupError.V(12)
        )
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = (
            AdGroupErrorEnum.AdGroupError.V(13)
        )
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = (
            AdGroupErrorEnum.AdGroupError.V(14)
        )
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = (
            AdGroupErrorEnum.AdGroupError.V(15)
        )
    class AdGroupError(metaclass=_AdGroupError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupErrorEnum.AdGroupError.V(0)
    UNKNOWN = AdGroupErrorEnum.AdGroupError.V(1)
    DUPLICATE_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(2)
    INVALID_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(3)
    ADVERTISER_NOT_ON_CONTENT_NETWORK = AdGroupErrorEnum.AdGroupError.V(5)
    BID_TOO_BIG = AdGroupErrorEnum.AdGroupError.V(6)
    BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = AdGroupErrorEnum.AdGroupError.V(7)
    MISSING_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(8)
    ADGROUP_LABEL_DOES_NOT_EXIST = AdGroupErrorEnum.AdGroupError.V(9)
    ADGROUP_LABEL_ALREADY_EXISTS = AdGroupErrorEnum.AdGroupError.V(10)
    INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = AdGroupErrorEnum.AdGroupError.V(11)
    AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = (
        AdGroupErrorEnum.AdGroupError.V(12)
    )
    ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = (
        AdGroupErrorEnum.AdGroupError.V(13)
    )
    CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = (
        AdGroupErrorEnum.AdGroupError.V(14)
    )
    PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = (
        AdGroupErrorEnum.AdGroupError.V(15)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupErrorEnum = AdGroupErrorEnum
