"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2
import google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_CONSTANT_PARENT_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    LOCALIZED_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    country_code: typing.Text = ...
    product_bidding_category_constant_parent: typing.Text = ...
    level: google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2.ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V = (
        ...
    )
    language_code: typing.Text = ...
    localized_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        country_code: typing.Text = ...,
        product_bidding_category_constant_parent: typing.Text = ...,
        level: google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = ...,
        status: google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2.ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V = ...,
        language_code: typing.Text = ...,
        localized_name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "level",
            b"level",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_language_code", b"_language_code"],
    ) -> typing_extensions.Literal["language_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_localized_name", b"_localized_name"],
    ) -> typing_extensions.Literal["localized_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
        ],
    ) -> typing_extensions.Literal["product_bidding_category_constant_parent"]: ...

global___ProductBiddingCategoryConstant = ProductBiddingCategoryConstant
