"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MinuteOfHourEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MinuteOfHour(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MinuteOfHour.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MinuteOfHourEnum.MinuteOfHour.V(0)
        UNKNOWN = MinuteOfHourEnum.MinuteOfHour.V(1)
        ZERO = MinuteOfHourEnum.MinuteOfHour.V(2)
        FIFTEEN = MinuteOfHourEnum.MinuteOfHour.V(3)
        THIRTY = MinuteOfHourEnum.MinuteOfHour.V(4)
        FORTY_FIVE = MinuteOfHourEnum.MinuteOfHour.V(5)
    class MinuteOfHour(metaclass=_MinuteOfHour):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MinuteOfHourEnum.MinuteOfHour.V(0)
    UNKNOWN = MinuteOfHourEnum.MinuteOfHour.V(1)
    ZERO = MinuteOfHourEnum.MinuteOfHour.V(2)
    FIFTEEN = MinuteOfHourEnum.MinuteOfHour.V(3)
    THIRTY = MinuteOfHourEnum.MinuteOfHour.V(4)
    FORTY_FIVE = MinuteOfHourEnum.MinuteOfHour.V(5)
    def __init__(
        self,
    ) -> None: ...

global___MinuteOfHourEnum = MinuteOfHourEnum
