"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MessagePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MessagePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MessagePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(0)
        UNKNOWN = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(1)
        BUSINESS_NAME = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(2)
        COUNTRY_CODE = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(3)
        PHONE_NUMBER = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(4)
        MESSAGE_EXTENSION_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(
            5
        )
        MESSAGE_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(6)
    class MessagePlaceholderField(metaclass=_MessagePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(0)
    UNKNOWN = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(1)
    BUSINESS_NAME = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(2)
    COUNTRY_CODE = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(3)
    PHONE_NUMBER = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(4)
    MESSAGE_EXTENSION_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(5)
    MESSAGE_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(6)
    def __init__(
        self,
    ) -> None: ...

global___MessagePlaceholderFieldEnum = MessagePlaceholderFieldEnum
