"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2
import google.ads.google_ads.v6.proto.enums.account_budget_status_pb2
import google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2
import google.ads.google_ads.v6.proto.enums.time_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PendingAccountBudgetProposal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ACCOUNT_BUDGET_PROPOSAL_FIELD_NUMBER: builtins.int
        PROPOSAL_TYPE_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        START_DATE_TIME_FIELD_NUMBER: builtins.int
        PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
        NOTES_FIELD_NUMBER: builtins.int
        CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
        END_DATE_TIME_FIELD_NUMBER: builtins.int
        END_TIME_TYPE_FIELD_NUMBER: builtins.int
        SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
        SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
        account_budget_proposal: typing.Text = ...
        proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = (
            ...
        )
        name: typing.Text = ...
        start_date_time: typing.Text = ...
        purchase_order_number: typing.Text = ...
        notes: typing.Text = ...
        creation_date_time: typing.Text = ...
        end_date_time: typing.Text = ...
        end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
            ...
        )
        spending_limit_micros: builtins.int = ...
        spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
            ...
        )
        def __init__(
            self,
            *,
            account_budget_proposal: typing.Text = ...,
            proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = ...,
            name: typing.Text = ...,
            start_date_time: typing.Text = ...,
            purchase_order_number: typing.Text = ...,
            notes: typing.Text = ...,
            creation_date_time: typing.Text = ...,
            end_date_time: typing.Text = ...,
            end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
            spending_limit_micros: builtins.int = ...,
            spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "proposal_type",
                b"proposal_type",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_account_budget_proposal", b"_account_budget_proposal"
            ],
        ) -> typing_extensions.Literal["account_budget_proposal"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions.Literal["creation_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_name", b"_name"]
        ) -> typing_extensions.Literal["name"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_notes", b"_notes"]
        ) -> typing_extensions.Literal["notes"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions.Literal["purchase_order_number"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions.Literal["start_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["end_time", b"end_time"]
        ) -> typing_extensions.Literal["end_date_time", "end_time_type"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["spending_limit", b"spending_limit"],
        ) -> typing_extensions.Literal[
            "spending_limit_micros", "spending_limit_type"
        ]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROPOSED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    TOTAL_ADJUSTMENTS_MICROS_FIELD_NUMBER: builtins.int
    AMOUNT_SERVED_MICROS_FIELD_NUMBER: builtins.int
    PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
    NOTES_FIELD_NUMBER: builtins.int
    PENDING_PROPOSAL_FIELD_NUMBER: builtins.int
    PROPOSED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    ADJUSTED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    ADJUSTED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    billing_setup: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.account_budget_status_pb2.AccountBudgetStatusEnum.AccountBudgetStatus.V = (
        ...
    )
    name: typing.Text = ...
    proposed_start_date_time: typing.Text = ...
    approved_start_date_time: typing.Text = ...
    total_adjustments_micros: builtins.int = ...
    amount_served_micros: builtins.int = ...
    purchase_order_number: typing.Text = ...
    notes: typing.Text = ...
    proposed_end_date_time: typing.Text = ...
    proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    approved_end_date_time: typing.Text = ...
    approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_spending_limit_micros: builtins.int = ...
    proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    approved_spending_limit_micros: builtins.int = ...
    approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    adjusted_spending_limit_micros: builtins.int = ...
    adjusted_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    @property
    def pending_proposal(
        self,
    ) -> global___AccountBudget.PendingAccountBudgetProposal: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        billing_setup: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.account_budget_status_pb2.AccountBudgetStatusEnum.AccountBudgetStatus.V = ...,
        name: typing.Text = ...,
        proposed_start_date_time: typing.Text = ...,
        approved_start_date_time: typing.Text = ...,
        total_adjustments_micros: builtins.int = ...,
        amount_served_micros: builtins.int = ...,
        purchase_order_number: typing.Text = ...,
        notes: typing.Text = ...,
        pending_proposal: typing.Optional[
            global___AccountBudget.PendingAccountBudgetProposal
        ] = ...,
        proposed_end_date_time: typing.Text = ...,
        proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        approved_end_date_time: typing.Text = ...,
        approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_spending_limit_micros: builtins.int = ...,
        proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        approved_spending_limit_micros: builtins.int = ...,
        approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        adjusted_spending_limit_micros: builtins.int = ...,
        adjusted_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "amount_served_micros",
            b"amount_served_micros",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_adjustments_micros",
            b"total_adjustments_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions.Literal["approved_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions.Literal["billing_setup"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_notes", b"_notes"]
    ) -> typing_extensions.Literal["notes"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_proposed_start_date_time", b"_proposed_start_date_time"
        ],
    ) -> typing_extensions.Literal["proposed_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_purchase_order_number", b"_purchase_order_number"
        ],
    ) -> typing_extensions.Literal["purchase_order_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "adjusted_spending_limit", b"adjusted_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "adjusted_spending_limit_micros", "adjusted_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions.Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...

global___AccountBudget = AccountBudget
