"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    DURATION_MILLIS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: typing.Text = ...
    channel_id: typing.Text = ...
    duration_millis: builtins.int = ...
    title: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Text = ...,
        channel_id: typing.Text = ...,
        duration_millis: builtins.int = ...,
        title: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "title",
            b"title",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "resource_name",
            b"resource_name",
            "title",
            b"title",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_channel_id", b"_channel_id"]
    ) -> typing_extensions.Literal["channel_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_duration_millis", b"_duration_millis"],
    ) -> typing_extensions.Literal["duration_millis"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_title", b"_title"]
    ) -> typing_extensions.Literal["title"]: ...

global___Video = Video
