"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingStrategyErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingStrategyError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BiddingStrategyError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingStrategyErrorEnum.BiddingStrategyError.V(0)
        UNKNOWN = BiddingStrategyErrorEnum.BiddingStrategyError.V(1)
        DUPLICATE_NAME = BiddingStrategyErrorEnum.BiddingStrategyError.V(2)
        CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(3)
        )
        CANNOT_REMOVE_ASSOCIATED_STRATEGY = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(4)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(5)
        )
        INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(6)
        )
    class BiddingStrategyError(metaclass=_BiddingStrategyError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingStrategyErrorEnum.BiddingStrategyError.V(0)
    UNKNOWN = BiddingStrategyErrorEnum.BiddingStrategyError.V(1)
    DUPLICATE_NAME = BiddingStrategyErrorEnum.BiddingStrategyError.V(2)
    CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = (
        BiddingStrategyErrorEnum.BiddingStrategyError.V(3)
    )
    CANNOT_REMOVE_ASSOCIATED_STRATEGY = BiddingStrategyErrorEnum.BiddingStrategyError.V(
        4
    )
    BIDDING_STRATEGY_NOT_SUPPORTED = BiddingStrategyErrorEnum.BiddingStrategyError.V(5)
    INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = (
        BiddingStrategyErrorEnum.BiddingStrategyError.V(6)
    )
    def __init__(
        self,
    ) -> None: ...

global___BiddingStrategyErrorEnum = BiddingStrategyErrorEnum
