"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MonthOfYearEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MonthOfYear(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MonthOfYear.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MonthOfYearEnum.MonthOfYear.V(0)
        UNKNOWN = MonthOfYearEnum.MonthOfYear.V(1)
        JANUARY = MonthOfYearEnum.MonthOfYear.V(2)
        FEBRUARY = MonthOfYearEnum.MonthOfYear.V(3)
        MARCH = MonthOfYearEnum.MonthOfYear.V(4)
        APRIL = MonthOfYearEnum.MonthOfYear.V(5)
        MAY = MonthOfYearEnum.MonthOfYear.V(6)
        JUNE = MonthOfYearEnum.MonthOfYear.V(7)
        JULY = MonthOfYearEnum.MonthOfYear.V(8)
        AUGUST = MonthOfYearEnum.MonthOfYear.V(9)
        SEPTEMBER = MonthOfYearEnum.MonthOfYear.V(10)
        OCTOBER = MonthOfYearEnum.MonthOfYear.V(11)
        NOVEMBER = MonthOfYearEnum.MonthOfYear.V(12)
        DECEMBER = MonthOfYearEnum.MonthOfYear.V(13)
    class MonthOfYear(metaclass=_MonthOfYear):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MonthOfYearEnum.MonthOfYear.V(0)
    UNKNOWN = MonthOfYearEnum.MonthOfYear.V(1)
    JANUARY = MonthOfYearEnum.MonthOfYear.V(2)
    FEBRUARY = MonthOfYearEnum.MonthOfYear.V(3)
    MARCH = MonthOfYearEnum.MonthOfYear.V(4)
    APRIL = MonthOfYearEnum.MonthOfYear.V(5)
    MAY = MonthOfYearEnum.MonthOfYear.V(6)
    JUNE = MonthOfYearEnum.MonthOfYear.V(7)
    JULY = MonthOfYearEnum.MonthOfYear.V(8)
    AUGUST = MonthOfYearEnum.MonthOfYear.V(9)
    SEPTEMBER = MonthOfYearEnum.MonthOfYear.V(10)
    OCTOBER = MonthOfYearEnum.MonthOfYear.V(11)
    NOVEMBER = MonthOfYearEnum.MonthOfYear.V(12)
    DECEMBER = MonthOfYearEnum.MonthOfYear.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MonthOfYearEnum = MonthOfYearEnum
