"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperatingSystemVersionConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OS_MAJOR_VERSION_FIELD_NUMBER: builtins.int
    OS_MINOR_VERSION_FIELD_NUMBER: builtins.int
    OPERATOR_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    os_major_version: builtins.int = ...
    os_minor_version: builtins.int = ...
    operator_type: google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2.OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        os_major_version: builtins.int = ...,
        os_minor_version: builtins.int = ...,
        operator_type: google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2.OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_os_major_version",
            b"_os_major_version",
            "_os_minor_version",
            b"_os_minor_version",
            "id",
            b"id",
            "name",
            b"name",
            "os_major_version",
            b"os_major_version",
            "os_minor_version",
            b"os_minor_version",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_os_major_version",
            b"_os_major_version",
            "_os_minor_version",
            b"_os_minor_version",
            "id",
            b"id",
            "name",
            b"name",
            "operator_type",
            b"operator_type",
            "os_major_version",
            b"os_major_version",
            "os_minor_version",
            b"os_minor_version",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_os_major_version", b"_os_major_version"
        ],
    ) -> typing_extensions.Literal["os_major_version"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_os_minor_version", b"_os_minor_version"
        ],
    ) -> typing_extensions.Literal["os_minor_version"]: ...

global___OperatingSystemVersionConstant = OperatingSystemVersionConstant
