"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TravelPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TravelPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TravelPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(0)
        UNKNOWN = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(1)
        DESTINATION_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(2)
        ORIGIN_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(3)
        TITLE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(4)
        DESTINATION_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(5)
        ORIGIN_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(6)
        PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(7)
        FORMATTED_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(8)
        SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(10)
        IMAGE_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(11)
        CATEGORY = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(12)
        CONTEXTUAL_KEYWORDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(13)
        DESTINATION_ADDRESS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(14)
        FINAL_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(15)
        FINAL_MOBILE_URLS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(16)
        TRACKING_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(17)
        ANDROID_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(18)
        SIMILAR_DESTINATION_IDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(
            19
        )
        IOS_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(20)
        IOS_APP_STORE_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(21)
    class TravelPlaceholderField(metaclass=_TravelPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(0)
    UNKNOWN = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(1)
    DESTINATION_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(2)
    ORIGIN_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(3)
    TITLE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(4)
    DESTINATION_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(5)
    ORIGIN_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(6)
    PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(7)
    FORMATTED_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(8)
    SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(10)
    IMAGE_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(11)
    CATEGORY = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(12)
    CONTEXTUAL_KEYWORDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(13)
    DESTINATION_ADDRESS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(14)
    FINAL_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(15)
    FINAL_MOBILE_URLS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(16)
    TRACKING_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(17)
    ANDROID_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(18)
    SIMILAR_DESTINATION_IDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(19)
    IOS_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(20)
    IOS_APP_STORE_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___TravelPlaceholderFieldEnum = TravelPlaceholderFieldEnum
