"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.user_interest_pb2
import grpc

from .user_interest_service_pb2 import *

class UserInterestServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetUserInterest(
        self,
        request: global___GetUserInterestRequest,
    ) -> google.ads.google_ads.v5.proto.resources.user_interest_pb2.UserInterest: ...

class UserInterestServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUserInterest(
        self,
        request: global___GetUserInterestRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.user_interest_pb2.UserInterest: ...

def add_UserInterestServiceServicer_to_server(
    servicer: UserInterestServiceServicer, server: grpc.Server
) -> None: ...
