"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BudgetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BudgetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BudgetType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BudgetTypeEnum.BudgetType.V(0)
        UNKNOWN = BudgetTypeEnum.BudgetType.V(1)
        STANDARD = BudgetTypeEnum.BudgetType.V(2)
        HOTEL_ADS_COMMISSION = BudgetTypeEnum.BudgetType.V(3)
        FIXED_CPA = BudgetTypeEnum.BudgetType.V(4)
    class BudgetType(metaclass=_BudgetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BudgetTypeEnum.BudgetType.V(0)
    UNKNOWN = BudgetTypeEnum.BudgetType.V(1)
    STANDARD = BudgetTypeEnum.BudgetType.V(2)
    HOTEL_ADS_COMMISSION = BudgetTypeEnum.BudgetType.V(3)
    FIXED_CPA = BudgetTypeEnum.BudgetType.V(4)
    def __init__(
        self,
    ) -> None: ...

global___BudgetTypeEnum = BudgetTypeEnum
