"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetGeoTargetConstantRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetGeoTargetConstantRequest = GetGeoTargetConstantRequest

class SuggestGeoTargetConstantsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class LocationNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NAMES_FIELD_NUMBER: builtins.int
        @property
        def names(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            names: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["names", b"names"]
        ) -> None: ...
    class GeoTargets(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
        @property
        def geo_target_constants(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            geo_target_constants: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "geo_target_constants", b"geo_target_constants"
            ],
        ) -> None: ...
    LOCALE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LOCATION_NAMES_FIELD_NUMBER: builtins.int
    GEO_TARGETS_FIELD_NUMBER: builtins.int
    @property
    def locale(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def location_names(
        self,
    ) -> global___SuggestGeoTargetConstantsRequest.LocationNames: ...
    @property
    def geo_targets(self) -> global___SuggestGeoTargetConstantsRequest.GeoTargets: ...
    def __init__(
        self,
        *,
        locale: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        location_names: typing.Optional[
            global___SuggestGeoTargetConstantsRequest.LocationNames
        ] = ...,
        geo_targets: typing.Optional[
            global___SuggestGeoTargetConstantsRequest.GeoTargets
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["query", b"query"]
    ) -> typing_extensions.Literal["location_names", "geo_targets"]: ...

global___SuggestGeoTargetConstantsRequest = SuggestGeoTargetConstantsRequest

class SuggestGeoTargetConstantsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_TARGET_CONSTANT_SUGGESTIONS_FIELD_NUMBER: builtins.int
    @property
    def geo_target_constant_suggestions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GeoTargetConstantSuggestion
    ]: ...
    def __init__(
        self,
        *,
        geo_target_constant_suggestions: typing.Optional[
            typing.Iterable[global___GeoTargetConstantSuggestion]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant_suggestions", b"geo_target_constant_suggestions"
        ],
    ) -> None: ...

global___SuggestGeoTargetConstantsResponse = SuggestGeoTargetConstantsResponse

class GeoTargetConstantSuggestion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOCALE_FIELD_NUMBER: builtins.int
    REACH_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_PARENTS_FIELD_NUMBER: builtins.int
    @property
    def locale(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def reach(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def search_term(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def geo_target_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    @property
    def geo_target_constant_parents(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
    ]: ...
    def __init__(
        self,
        *,
        locale: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        reach: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        search_term: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        geo_target_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
        ] = ...,
        geo_target_constant_parents: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "geo_target_constant_parents",
            b"geo_target_constant_parents",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

global___GeoTargetConstantSuggestion = GeoTargetConstantSuggestion
