"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.feed_item_target_pb2
import grpc

from .feed_item_target_service_pb2 import *

class FeedItemTargetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItemTarget(
        self,
        request: global___GetFeedItemTargetRequest,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    def MutateFeedItemTargets(
        self,
        request: global___MutateFeedItemTargetsRequest,
    ) -> global___MutateFeedItemTargetsResponse: ...

class FeedItemTargetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItemTarget(
        self,
        request: global___GetFeedItemTargetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    @abc.abstractmethod
    def MutateFeedItemTargets(
        self,
        request: global___MutateFeedItemTargetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemTargetsResponse: ...

def add_FeedItemTargetServiceServicer_to_server(
    servicer: FeedItemTargetServiceServicer, server: grpc.Server
) -> None: ...
