"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeographicView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_TYPE_FIELD_NUMBER: builtins.int
    COUNTRY_CRITERION_ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    location_type: google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2.GeoTargetingTypeEnum.GeoTargetingType.V = (
        ...
    )
    @property
    def country_criterion_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        location_type: google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2.GeoTargetingTypeEnum.GeoTargetingType.V = ...,
        country_criterion_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_criterion_id", b"country_criterion_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "country_criterion_id",
            b"country_criterion_id",
            "location_type",
            b"location_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___GeographicView = GeographicView
