"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.user_list_pb2
import grpc

from .user_list_service_pb2 import *

class UserListServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetUserList(
        self,
        request: global___GetUserListRequest,
    ) -> google.ads.google_ads.v5.proto.resources.user_list_pb2.UserList: ...
    def MutateUserLists(
        self,
        request: global___MutateUserListsRequest,
    ) -> global___MutateUserListsResponse: ...

class UserListServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUserList(
        self,
        request: global___GetUserListRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.user_list_pb2.UserList: ...
    @abc.abstractmethod
    def MutateUserLists(
        self,
        request: global___MutateUserListsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateUserListsResponse: ...

def add_UserListServiceServicer_to_server(
    servicer: UserListServiceServicer, server: grpc.Server
) -> None: ...
