"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListSizeRangeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListSizeRange(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserListSizeRange.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListSizeRangeEnum.UserListSizeRange.V(0)
        UNKNOWN = UserListSizeRangeEnum.UserListSizeRange.V(1)
        LESS_THAN_FIVE_HUNDRED = UserListSizeRangeEnum.UserListSizeRange.V(2)
        LESS_THAN_ONE_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(3)
        ONE_THOUSAND_TO_TEN_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(4)
        TEN_THOUSAND_TO_FIFTY_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(5)
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(6)
        )
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(7)
        )
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(8)
        )
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = (
            UserListSizeRangeEnum.UserListSizeRange.V(9)
        )
        ONE_MILLION_TO_TWO_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(10)
        TWO_MILLION_TO_THREE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(11)
        THREE_MILLION_TO_FIVE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(12)
        FIVE_MILLION_TO_TEN_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(13)
        TEN_MILLION_TO_TWENTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(14)
        TWENTY_MILLION_TO_THIRTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(15)
        THIRTY_MILLION_TO_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(16)
        OVER_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(17)
    class UserListSizeRange(metaclass=_UserListSizeRange):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListSizeRangeEnum.UserListSizeRange.V(0)
    UNKNOWN = UserListSizeRangeEnum.UserListSizeRange.V(1)
    LESS_THAN_FIVE_HUNDRED = UserListSizeRangeEnum.UserListSizeRange.V(2)
    LESS_THAN_ONE_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(3)
    ONE_THOUSAND_TO_TEN_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(4)
    TEN_THOUSAND_TO_FIFTY_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(5)
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(
        6
    )
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = (
        UserListSizeRangeEnum.UserListSizeRange.V(7)
    )
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = (
        UserListSizeRangeEnum.UserListSizeRange.V(8)
    )
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(9)
    ONE_MILLION_TO_TWO_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(10)
    TWO_MILLION_TO_THREE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(11)
    THREE_MILLION_TO_FIVE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(12)
    FIVE_MILLION_TO_TEN_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(13)
    TEN_MILLION_TO_TWENTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(14)
    TWENTY_MILLION_TO_THIRTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(15)
    THIRTY_MILLION_TO_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(16)
    OVER_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(17)
    def __init__(
        self,
    ) -> None: ...

global___UserListSizeRangeEnum = UserListSizeRangeEnum
