"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdCustomizerErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdCustomizerError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdCustomizerError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdCustomizerErrorEnum.AdCustomizerError.V(0)
        UNKNOWN = AdCustomizerErrorEnum.AdCustomizerError.V(1)
        COUNTDOWN_INVALID_DATE_FORMAT = AdCustomizerErrorEnum.AdCustomizerError.V(2)
        COUNTDOWN_DATE_IN_PAST = AdCustomizerErrorEnum.AdCustomizerError.V(3)
        COUNTDOWN_INVALID_LOCALE = AdCustomizerErrorEnum.AdCustomizerError.V(4)
        COUNTDOWN_INVALID_START_DAYS_BEFORE = AdCustomizerErrorEnum.AdCustomizerError.V(
            5
        )
        UNKNOWN_USER_LIST = AdCustomizerErrorEnum.AdCustomizerError.V(6)
    class AdCustomizerError(metaclass=_AdCustomizerError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdCustomizerErrorEnum.AdCustomizerError.V(0)
    UNKNOWN = AdCustomizerErrorEnum.AdCustomizerError.V(1)
    COUNTDOWN_INVALID_DATE_FORMAT = AdCustomizerErrorEnum.AdCustomizerError.V(2)
    COUNTDOWN_DATE_IN_PAST = AdCustomizerErrorEnum.AdCustomizerError.V(3)
    COUNTDOWN_INVALID_LOCALE = AdCustomizerErrorEnum.AdCustomizerError.V(4)
    COUNTDOWN_INVALID_START_DAYS_BEFORE = AdCustomizerErrorEnum.AdCustomizerError.V(5)
    UNKNOWN_USER_LIST = AdCustomizerErrorEnum.AdCustomizerError.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AdCustomizerErrorEnum = AdCustomizerErrorEnum
