"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccessReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccessReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AccessReason.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccessReasonEnum.AccessReason.V(0)
        UNKNOWN = AccessReasonEnum.AccessReason.V(1)
        OWNED = AccessReasonEnum.AccessReason.V(2)
        SHARED = AccessReasonEnum.AccessReason.V(3)
        LICENSED = AccessReasonEnum.AccessReason.V(4)
        SUBSCRIBED = AccessReasonEnum.AccessReason.V(5)
        AFFILIATED = AccessReasonEnum.AccessReason.V(6)
    class AccessReason(metaclass=_AccessReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccessReasonEnum.AccessReason.V(0)
    UNKNOWN = AccessReasonEnum.AccessReason.V(1)
    OWNED = AccessReasonEnum.AccessReason.V(2)
    SHARED = AccessReasonEnum.AccessReason.V(3)
    LICENSED = AccessReasonEnum.AccessReason.V(4)
    SUBSCRIBED = AccessReasonEnum.AccessReason.V(5)
    AFFILIATED = AccessReasonEnum.AccessReason.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AccessReasonEnum = AccessReasonEnum
