"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MatchingFunctionContextTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MatchingFunctionContextType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MatchingFunctionContextType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(0)
        UNKNOWN = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(1)
        FEED_ITEM_ID = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(2)
        DEVICE_NAME = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(3)
    class MatchingFunctionContextType(metaclass=_MatchingFunctionContextType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(0)
    UNKNOWN = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(1)
    FEED_ITEM_ID = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(2)
    DEVICE_NAME = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___MatchingFunctionContextTypeEnum = MatchingFunctionContextTypeEnum
