"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.media_file_pb2
import grpc

from .media_file_service_pb2 import *

class MediaFileServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetMediaFile(
        self,
        request: global___GetMediaFileRequest,
    ) -> google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile: ...
    def MutateMediaFiles(
        self,
        request: global___MutateMediaFilesRequest,
    ) -> global___MutateMediaFilesResponse: ...

class MediaFileServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetMediaFile(
        self,
        request: global___GetMediaFileRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile: ...
    @abc.abstractmethod
    def MutateMediaFiles(
        self,
        request: global___MutateMediaFilesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateMediaFilesResponse: ...

def add_MediaFileServiceServicer_to_server(
    servicer: MediaFileServiceServicer, server: grpc.Server
) -> None: ...
