"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    LANDING_PAGE_FIELD_NUMBER: builtins.int
    PAGE_URL_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_MATCHING_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_URL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def search_term(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def headline(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def landing_page(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def page_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def has_negative_keyword(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_matching_keyword(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_negative_url(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        search_term: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        headline: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        landing_page: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        page_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        has_negative_keyword: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        has_matching_keyword: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        has_negative_url: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

global___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView
