"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DynamicLocationSetFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LABELS_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FILTER_FIELD_NUMBER: builtins.int
    labels: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def business_name_filter(self) -> global___BusinessNameFilter: ...
    def __init__(
        self,
        *,
        labels: typing.Optional[typing.Iterable[typing.Text]] = ...,
        business_name_filter: typing.Optional[global___BusinessNameFilter] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "business_name_filter", b"business_name_filter"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "business_name_filter", b"business_name_filter", "labels", b"labels"
        ],
    ) -> None: ...

global___DynamicLocationSetFilter = DynamicLocationSetFilter

class BusinessNameFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    FILTER_TYPE_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    filter_type: google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2.FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType.V = (
        ...
    )
    def __init__(
        self,
        *,
        business_name: typing.Text = ...,
        filter_type: google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2.FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "business_name", b"business_name", "filter_type", b"filter_type"
        ],
    ) -> None: ...

global___BusinessNameFilter = BusinessNameFilter

class DynamicAffiliateLocationSetFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_IDS_FIELD_NUMBER: builtins.int
    chain_ids: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.int
    ] = ...
    def __init__(
        self,
        *,
        chain_ids: typing.Optional[typing.Iterable[builtins.int]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["chain_ids", b"chain_ids"]
    ) -> None: ...

global___DynamicAffiliateLocationSetFilter = DynamicAffiliateLocationSetFilter
