"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BiddingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingErrorEnum.BiddingError.V(0)
        UNKNOWN = BiddingErrorEnum.BiddingError.V(1)
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = BiddingErrorEnum.BiddingError.V(2)
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = BiddingErrorEnum.BiddingError.V(7)
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(10)
        INVALID_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(14)
        INVALID_BID = BiddingErrorEnum.BiddingError.V(17)
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
            BiddingErrorEnum.BiddingError.V(18)
        )
        CONVERSION_TRACKING_NOT_ENABLED = BiddingErrorEnum.BiddingError.V(19)
        NOT_ENOUGH_CONVERSIONS = BiddingErrorEnum.BiddingError.V(20)
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = BiddingErrorEnum.BiddingError.V(
            21
        )
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = (
            BiddingErrorEnum.BiddingError.V(23)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = (
            BiddingErrorEnum.BiddingError.V(24)
        )
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = BiddingErrorEnum.BiddingError.V(
            25
        )
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = (
            BiddingErrorEnum.BiddingError.V(26)
        )
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = (
            BiddingErrorEnum.BiddingError.V(27)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = (
            BiddingErrorEnum.BiddingError.V(28)
        )
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = (
            BiddingErrorEnum.BiddingError.V(29)
        )
        BID_TOO_SMALL = BiddingErrorEnum.BiddingError.V(30)
        BID_TOO_BIG = BiddingErrorEnum.BiddingError.V(31)
        BID_TOO_MANY_FRACTIONAL_DIGITS = BiddingErrorEnum.BiddingError.V(32)
        INVALID_DOMAIN_NAME = BiddingErrorEnum.BiddingError.V(33)
        NOT_COMPATIBLE_WITH_PAYMENT_MODE = BiddingErrorEnum.BiddingError.V(34)
        NOT_COMPATIBLE_WITH_BUDGET_TYPE = BiddingErrorEnum.BiddingError.V(35)
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(36)
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = (
            BiddingErrorEnum.BiddingError.V(37)
        )
    class BiddingError(metaclass=_BiddingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingErrorEnum.BiddingError.V(0)
    UNKNOWN = BiddingErrorEnum.BiddingError.V(1)
    BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = BiddingErrorEnum.BiddingError.V(2)
    CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = BiddingErrorEnum.BiddingError.V(7)
    INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(10)
    INVALID_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(14)
    INVALID_BID = BiddingErrorEnum.BiddingError.V(17)
    BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = BiddingErrorEnum.BiddingError.V(
        18
    )
    CONVERSION_TRACKING_NOT_ENABLED = BiddingErrorEnum.BiddingError.V(19)
    NOT_ENOUGH_CONVERSIONS = BiddingErrorEnum.BiddingError.V(20)
    CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = BiddingErrorEnum.BiddingError.V(21)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = (
        BiddingErrorEnum.BiddingError.V(23)
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = BiddingErrorEnum.BiddingError.V(
        24
    )
    PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = BiddingErrorEnum.BiddingError.V(25)
    PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = BiddingErrorEnum.BiddingError.V(26)
    BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = (
        BiddingErrorEnum.BiddingError.V(27)
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = (
        BiddingErrorEnum.BiddingError.V(28)
    )
    BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = (
        BiddingErrorEnum.BiddingError.V(29)
    )
    BID_TOO_SMALL = BiddingErrorEnum.BiddingError.V(30)
    BID_TOO_BIG = BiddingErrorEnum.BiddingError.V(31)
    BID_TOO_MANY_FRACTIONAL_DIGITS = BiddingErrorEnum.BiddingError.V(32)
    INVALID_DOMAIN_NAME = BiddingErrorEnum.BiddingError.V(33)
    NOT_COMPATIBLE_WITH_PAYMENT_MODE = BiddingErrorEnum.BiddingError.V(34)
    NOT_COMPATIBLE_WITH_BUDGET_TYPE = BiddingErrorEnum.BiddingError.V(35)
    NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(36)
    BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = (
        BiddingErrorEnum.BiddingError.V(37)
    )
    def __init__(
        self,
    ) -> None: ...

global___BiddingErrorEnum = BiddingErrorEnum
