"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2
import google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2
import google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    status: google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = (
        ...
    )
    name: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = (
        ...
    )
    description: typing.Text = ...
    @property
    def members(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CustomInterestMember
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        status: google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = ...,
        name: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = ...,
        description: typing.Text = ...,
        members: typing.Optional[typing.Iterable[global___CustomInterestMember]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "description",
            b"description",
            "id",
            b"id",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "description",
            b"description",
            "id",
            b"id",
            "members",
            b"members",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___CustomInterest = CustomInterest

class CustomInterestMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEMBER_TYPE_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    member_type: google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = (
        ...
    )
    parameter: typing.Text = ...
    def __init__(
        self,
        *,
        member_type: google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = ...,
        parameter: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_parameter", b"_parameter", "parameter", b"parameter"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_parameter",
            b"_parameter",
            "member_type",
            b"member_type",
            "parameter",
            b"parameter",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_parameter", b"_parameter"]
    ) -> typing_extensions.Literal["parameter"]: ...

global___CustomInterestMember = CustomInterestMember
