"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExperimentErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignExperimentError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignExperimentError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignExperimentErrorEnum.CampaignExperimentError.V(0)
        UNKNOWN = CampaignExperimentErrorEnum.CampaignExperimentError.V(1)
        DUPLICATE_NAME = CampaignExperimentErrorEnum.CampaignExperimentError.V(2)
        INVALID_TRANSITION = CampaignExperimentErrorEnum.CampaignExperimentError.V(3)
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(4)
        )
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(5)
        )
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(6)
        )
        CUSTOMER_CANNOT_CREATE_EXPERIMENT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(7)
        )
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(8)
        )
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(9)
        )
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(10)
        )
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(11)
        )
    class CampaignExperimentError(metaclass=_CampaignExperimentError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignExperimentErrorEnum.CampaignExperimentError.V(0)
    UNKNOWN = CampaignExperimentErrorEnum.CampaignExperimentError.V(1)
    DUPLICATE_NAME = CampaignExperimentErrorEnum.CampaignExperimentError.V(2)
    INVALID_TRANSITION = CampaignExperimentErrorEnum.CampaignExperimentError.V(3)
    CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(4)
    )
    CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(5)
    )
    CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(6)
    )
    CUSTOMER_CANNOT_CREATE_EXPERIMENT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(7)
    )
    CAMPAIGN_CANNOT_CREATE_EXPERIMENT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(8)
    )
    EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(9)
    )
    EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(10)
    )
    CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(11)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignExperimentErrorEnum = CampaignExperimentErrorEnum
