"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_label_pb2
import grpc

from .campaign_label_service_pb2 import *

class CampaignLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignLabel(
        self,
        request: global___GetCampaignLabelRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_label_pb2.CampaignLabel: ...
    def MutateCampaignLabels(
        self,
        request: global___MutateCampaignLabelsRequest,
    ) -> global___MutateCampaignLabelsResponse: ...

class CampaignLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignLabel(
        self,
        request: global___GetCampaignLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_label_pb2.CampaignLabel: ...
    @abc.abstractmethod
    def MutateCampaignLabels(
        self,
        request: global___MutateCampaignLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignLabelsResponse: ...

def add_CampaignLabelServiceServicer_to_server(
    servicer: CampaignLabelServiceServicer, server: grpc.Server
) -> None: ...
