"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterionApprovalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupCriterionApprovalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupCriterionApprovalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(0)
        )
        UNKNOWN = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(1)
        APPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(
            2
        )
        DISAPPROVED = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(3)
        )
        PENDING_REVIEW = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(4)
        )
        UNDER_REVIEW = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(5)
        )
    class AdGroupCriterionApprovalStatus(metaclass=_AdGroupCriterionApprovalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(0)
    UNKNOWN = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(1)
    APPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(2)
    DISAPPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(3)
    PENDING_REVIEW = (
        AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(4)
    )
    UNDER_REVIEW = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(
        5
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupCriterionApprovalStatusEnum = AdGroupCriterionApprovalStatusEnum
