"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSetLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemSetLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemSetLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(0)
        UNKNOWN = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(1)
        FEED_ID_MISMATCH = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(2)
        NO_MUTATE_ALLOWED_FOR_DYNAMIC_SET = (
            FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(3)
        )
    class FeedItemSetLinkError(metaclass=_FeedItemSetLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(0)
    UNKNOWN = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(1)
    FEED_ID_MISMATCH = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(2)
    NO_MUTATE_ALLOWED_FOR_DYNAMIC_SET = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(
        3
    )
    def __init__(
        self,
    ) -> None: ...

global___FeedItemSetLinkErrorEnum = FeedItemSetLinkErrorEnum
