"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MobileDeviceConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MANUFACTURER_NAME_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    manufacturer_name: typing.Text = ...
    operating_system_name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2.MobileDeviceTypeEnum.MobileDeviceType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        manufacturer_name: typing.Text = ...,
        operating_system_name: typing.Text = ...,
        type: google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2.MobileDeviceTypeEnum.MobileDeviceType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
            "resource_name",
            b"resource_name",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_manufacturer_name", b"_manufacturer_name"
        ],
    ) -> typing_extensions.Literal["manufacturer_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_operating_system_name", b"_operating_system_name"
        ],
    ) -> typing_extensions.Literal["operating_system_name"]: ...

global___MobileDeviceConstant = MobileDeviceConstant
