"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountLinkStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccountLinkStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccountLinkStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccountLinkStatusEnum.AccountLinkStatus.V(0)
        UNKNOWN = AccountLinkStatusEnum.AccountLinkStatus.V(1)
        ENABLED = AccountLinkStatusEnum.AccountLinkStatus.V(2)
        REMOVED = AccountLinkStatusEnum.AccountLinkStatus.V(3)
        REQUESTED = AccountLinkStatusEnum.AccountLinkStatus.V(4)
        PENDING_APPROVAL = AccountLinkStatusEnum.AccountLinkStatus.V(5)
    class AccountLinkStatus(metaclass=_AccountLinkStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccountLinkStatusEnum.AccountLinkStatus.V(0)
    UNKNOWN = AccountLinkStatusEnum.AccountLinkStatus.V(1)
    ENABLED = AccountLinkStatusEnum.AccountLinkStatus.V(2)
    REMOVED = AccountLinkStatusEnum.AccountLinkStatus.V(3)
    REQUESTED = AccountLinkStatusEnum.AccountLinkStatus.V(4)
    PENDING_APPROVAL = AccountLinkStatusEnum.AccountLinkStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___AccountLinkStatusEnum = AccountLinkStatusEnum
