"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    @property
    def youtube_video_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        youtube_video_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["youtube_video_id", b"youtube_video_id"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["youtube_video_id", b"youtube_video_id"],
    ) -> None: ...

global___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    FULL_SIZE_FIELD_NUMBER: builtins.int
    mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    @property
    def file_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def full_size(self) -> global___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
        file_size: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        full_size: typing.Optional[global___ImageDimension] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "data", b"data", "file_size", b"file_size", "full_size", b"full_size"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...

global___ImageAsset = ImageAsset

class ImageDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_PIXELS_FIELD_NUMBER: builtins.int
    WIDTH_PIXELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def height_pixels(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def width_pixels(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        height_pixels: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        width_pixels: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...

global___ImageDimension = ImageDimension

class TextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> None: ...

global___TextAsset = TextAsset

class BookOnGoogleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___BookOnGoogleAsset = BookOnGoogleAsset
