"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaFileErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaFileError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaFileError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaFileErrorEnum.MediaFileError.V(0)
        UNKNOWN = MediaFileErrorEnum.MediaFileError.V(1)
        CANNOT_CREATE_STANDARD_ICON = MediaFileErrorEnum.MediaFileError.V(2)
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = (
            MediaFileErrorEnum.MediaFileError.V(3)
        )
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = MediaFileErrorEnum.MediaFileError.V(4)
        DUPLICATE_MEDIA = MediaFileErrorEnum.MediaFileError.V(5)
        EMPTY_FIELD = MediaFileErrorEnum.MediaFileError.V(6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = MediaFileErrorEnum.MediaFileError.V(7)
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(8)
        INVALID_MEDIA_FILE_ID = MediaFileErrorEnum.MediaFileError.V(9)
        INVALID_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(10)
        INVALID_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(11)
        INVALID_MIME_TYPE = MediaFileErrorEnum.MediaFileError.V(12)
        INVALID_REFERENCE_ID = MediaFileErrorEnum.MediaFileError.V(13)
        INVALID_YOU_TUBE_ID = MediaFileErrorEnum.MediaFileError.V(14)
        MEDIA_FILE_FAILED_TRANSCODING = MediaFileErrorEnum.MediaFileError.V(15)
        MEDIA_NOT_TRANSCODED = MediaFileErrorEnum.MediaFileError.V(16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(
            17
        )
        NO_FIELDS_SPECIFIED = MediaFileErrorEnum.MediaFileError.V(18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = MediaFileErrorEnum.MediaFileError.V(19)
        TOO_LONG = MediaFileErrorEnum.MediaFileError.V(20)
        UNSUPPORTED_TYPE = MediaFileErrorEnum.MediaFileError.V(21)
        YOU_TUBE_SERVICE_UNAVAILABLE = MediaFileErrorEnum.MediaFileError.V(22)
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = MediaFileErrorEnum.MediaFileError.V(
            23
        )
        YOU_TUBE_VIDEO_NOT_FOUND = MediaFileErrorEnum.MediaFileError.V(24)
    class MediaFileError(metaclass=_MediaFileError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaFileErrorEnum.MediaFileError.V(0)
    UNKNOWN = MediaFileErrorEnum.MediaFileError.V(1)
    CANNOT_CREATE_STANDARD_ICON = MediaFileErrorEnum.MediaFileError.V(2)
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = MediaFileErrorEnum.MediaFileError.V(
        3
    )
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = MediaFileErrorEnum.MediaFileError.V(4)
    DUPLICATE_MEDIA = MediaFileErrorEnum.MediaFileError.V(5)
    EMPTY_FIELD = MediaFileErrorEnum.MediaFileError.V(6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = MediaFileErrorEnum.MediaFileError.V(7)
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(8)
    INVALID_MEDIA_FILE_ID = MediaFileErrorEnum.MediaFileError.V(9)
    INVALID_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(10)
    INVALID_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(11)
    INVALID_MIME_TYPE = MediaFileErrorEnum.MediaFileError.V(12)
    INVALID_REFERENCE_ID = MediaFileErrorEnum.MediaFileError.V(13)
    INVALID_YOU_TUBE_ID = MediaFileErrorEnum.MediaFileError.V(14)
    MEDIA_FILE_FAILED_TRANSCODING = MediaFileErrorEnum.MediaFileError.V(15)
    MEDIA_NOT_TRANSCODED = MediaFileErrorEnum.MediaFileError.V(16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(17)
    NO_FIELDS_SPECIFIED = MediaFileErrorEnum.MediaFileError.V(18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = MediaFileErrorEnum.MediaFileError.V(19)
    TOO_LONG = MediaFileErrorEnum.MediaFileError.V(20)
    UNSUPPORTED_TYPE = MediaFileErrorEnum.MediaFileError.V(21)
    YOU_TUBE_SERVICE_UNAVAILABLE = MediaFileErrorEnum.MediaFileError.V(22)
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = MediaFileErrorEnum.MediaFileError.V(23)
    YOU_TUBE_VIDEO_NOT_FOUND = MediaFileErrorEnum.MediaFileError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___MediaFileErrorEnum = MediaFileErrorEnum
