"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SimulationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SimulationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SimulationType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SimulationTypeEnum.SimulationType.V(0)
        UNKNOWN = SimulationTypeEnum.SimulationType.V(1)
        CPC_BID = SimulationTypeEnum.SimulationType.V(2)
        CPV_BID = SimulationTypeEnum.SimulationType.V(3)
        TARGET_CPA = SimulationTypeEnum.SimulationType.V(4)
        BID_MODIFIER = SimulationTypeEnum.SimulationType.V(5)
        TARGET_ROAS = SimulationTypeEnum.SimulationType.V(6)
        PERCENT_CPC_BID = SimulationTypeEnum.SimulationType.V(7)
    class SimulationType(metaclass=_SimulationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SimulationTypeEnum.SimulationType.V(0)
    UNKNOWN = SimulationTypeEnum.SimulationType.V(1)
    CPC_BID = SimulationTypeEnum.SimulationType.V(2)
    CPV_BID = SimulationTypeEnum.SimulationType.V(3)
    TARGET_CPA = SimulationTypeEnum.SimulationType.V(4)
    BID_MODIFIER = SimulationTypeEnum.SimulationType.V(5)
    TARGET_ROAS = SimulationTypeEnum.SimulationType.V(6)
    PERCENT_CPC_BID = SimulationTypeEnum.SimulationType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___SimulationTypeEnum = SimulationTypeEnum
