"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ManagerLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ManagerLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ManagerLinkError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ManagerLinkErrorEnum.ManagerLinkError.V(0)
        UNKNOWN = ManagerLinkErrorEnum.ManagerLinkError.V(1)
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = ManagerLinkErrorEnum.ManagerLinkError.V(2)
        TOO_MANY_MANAGERS = ManagerLinkErrorEnum.ManagerLinkError.V(3)
        TOO_MANY_INVITES = ManagerLinkErrorEnum.ManagerLinkError.V(4)
        ALREADY_INVITED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(5)
        ALREADY_MANAGED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(6)
        ALREADY_MANAGED_IN_HIERARCHY = ManagerLinkErrorEnum.ManagerLinkError.V(7)
        DUPLICATE_CHILD_FOUND = ManagerLinkErrorEnum.ManagerLinkError.V(8)
        CLIENT_HAS_NO_ADMIN_USER = ManagerLinkErrorEnum.ManagerLinkError.V(9)
        MAX_DEPTH_EXCEEDED = ManagerLinkErrorEnum.ManagerLinkError.V(10)
        CYCLE_NOT_ALLOWED = ManagerLinkErrorEnum.ManagerLinkError.V(11)
        TOO_MANY_ACCOUNTS = ManagerLinkErrorEnum.ManagerLinkError.V(12)
        TOO_MANY_ACCOUNTS_AT_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(13)
        NON_OWNER_USER_CANNOT_MODIFY_LINK = ManagerLinkErrorEnum.ManagerLinkError.V(14)
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = ManagerLinkErrorEnum.ManagerLinkError.V(
            15
        )
        CLIENT_OUTSIDE_TREE = ManagerLinkErrorEnum.ManagerLinkError.V(16)
        INVALID_STATUS_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(17)
        INVALID_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(18)
    class ManagerLinkError(metaclass=_ManagerLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ManagerLinkErrorEnum.ManagerLinkError.V(0)
    UNKNOWN = ManagerLinkErrorEnum.ManagerLinkError.V(1)
    ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = ManagerLinkErrorEnum.ManagerLinkError.V(2)
    TOO_MANY_MANAGERS = ManagerLinkErrorEnum.ManagerLinkError.V(3)
    TOO_MANY_INVITES = ManagerLinkErrorEnum.ManagerLinkError.V(4)
    ALREADY_INVITED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(5)
    ALREADY_MANAGED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(6)
    ALREADY_MANAGED_IN_HIERARCHY = ManagerLinkErrorEnum.ManagerLinkError.V(7)
    DUPLICATE_CHILD_FOUND = ManagerLinkErrorEnum.ManagerLinkError.V(8)
    CLIENT_HAS_NO_ADMIN_USER = ManagerLinkErrorEnum.ManagerLinkError.V(9)
    MAX_DEPTH_EXCEEDED = ManagerLinkErrorEnum.ManagerLinkError.V(10)
    CYCLE_NOT_ALLOWED = ManagerLinkErrorEnum.ManagerLinkError.V(11)
    TOO_MANY_ACCOUNTS = ManagerLinkErrorEnum.ManagerLinkError.V(12)
    TOO_MANY_ACCOUNTS_AT_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(13)
    NON_OWNER_USER_CANNOT_MODIFY_LINK = ManagerLinkErrorEnum.ManagerLinkError.V(14)
    SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = ManagerLinkErrorEnum.ManagerLinkError.V(15)
    CLIENT_OUTSIDE_TREE = ManagerLinkErrorEnum.ManagerLinkError.V(16)
    INVALID_STATUS_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(17)
    INVALID_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(18)
    def __init__(
        self,
    ) -> None: ...

global___ManagerLinkErrorEnum = ManagerLinkErrorEnum
