"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ClickType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClickType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ClickTypeEnum.ClickType.V(0)
        UNKNOWN = ClickTypeEnum.ClickType.V(1)
        APP_DEEPLINK = ClickTypeEnum.ClickType.V(2)
        BREADCRUMBS = ClickTypeEnum.ClickType.V(3)
        BROADBAND_PLAN = ClickTypeEnum.ClickType.V(4)
        CALL_TRACKING = ClickTypeEnum.ClickType.V(5)
        CALLS = ClickTypeEnum.ClickType.V(6)
        CLICK_ON_ENGAGEMENT_AD = ClickTypeEnum.ClickType.V(7)
        GET_DIRECTIONS = ClickTypeEnum.ClickType.V(8)
        LOCATION_EXPANSION = ClickTypeEnum.ClickType.V(9)
        LOCATION_FORMAT_CALL = ClickTypeEnum.ClickType.V(10)
        LOCATION_FORMAT_DIRECTIONS = ClickTypeEnum.ClickType.V(11)
        LOCATION_FORMAT_IMAGE = ClickTypeEnum.ClickType.V(12)
        LOCATION_FORMAT_LANDING_PAGE = ClickTypeEnum.ClickType.V(13)
        LOCATION_FORMAT_MAP = ClickTypeEnum.ClickType.V(14)
        LOCATION_FORMAT_STORE_INFO = ClickTypeEnum.ClickType.V(15)
        LOCATION_FORMAT_TEXT = ClickTypeEnum.ClickType.V(16)
        MOBILE_CALL_TRACKING = ClickTypeEnum.ClickType.V(17)
        OFFER_PRINTS = ClickTypeEnum.ClickType.V(18)
        OTHER = ClickTypeEnum.ClickType.V(19)
        PRODUCT_EXTENSION_CLICKS = ClickTypeEnum.ClickType.V(20)
        PRODUCT_LISTING_AD_CLICKS = ClickTypeEnum.ClickType.V(21)
        SITELINKS = ClickTypeEnum.ClickType.V(22)
        STORE_LOCATOR = ClickTypeEnum.ClickType.V(23)
        URL_CLICKS = ClickTypeEnum.ClickType.V(25)
        VIDEO_APP_STORE_CLICKS = ClickTypeEnum.ClickType.V(26)
        VIDEO_CALL_TO_ACTION_CLICKS = ClickTypeEnum.ClickType.V(27)
        VIDEO_CARD_ACTION_HEADLINE_CLICKS = ClickTypeEnum.ClickType.V(28)
        VIDEO_END_CAP_CLICKS = ClickTypeEnum.ClickType.V(29)
        VIDEO_WEBSITE_CLICKS = ClickTypeEnum.ClickType.V(30)
        VISUAL_SITELINKS = ClickTypeEnum.ClickType.V(31)
        WIRELESS_PLAN = ClickTypeEnum.ClickType.V(32)
        PRODUCT_LISTING_AD_LOCAL = ClickTypeEnum.ClickType.V(33)
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = ClickTypeEnum.ClickType.V(34)
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = ClickTypeEnum.ClickType.V(35)
        PRODUCT_LISTING_ADS_COUPON = ClickTypeEnum.ClickType.V(36)
        PRODUCT_LISTING_AD_TRANSACTABLE = ClickTypeEnum.ClickType.V(37)
        PRODUCT_AD_APP_DEEPLINK = ClickTypeEnum.ClickType.V(38)
        SHOWCASE_AD_CATEGORY_LINK = ClickTypeEnum.ClickType.V(39)
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK = ClickTypeEnum.ClickType.V(40)
        SHOWCASE_AD_ONLINE_PRODUCT_LINK = ClickTypeEnum.ClickType.V(42)
        SHOWCASE_AD_LOCAL_PRODUCT_LINK = ClickTypeEnum.ClickType.V(43)
        PROMOTION_EXTENSION = ClickTypeEnum.ClickType.V(44)
        SWIPEABLE_GALLERY_AD_HEADLINE = ClickTypeEnum.ClickType.V(45)
        SWIPEABLE_GALLERY_AD_SWIPES = ClickTypeEnum.ClickType.V(46)
        SWIPEABLE_GALLERY_AD_SEE_MORE = ClickTypeEnum.ClickType.V(47)
        SWIPEABLE_GALLERY_AD_SITELINK_ONE = ClickTypeEnum.ClickType.V(48)
        SWIPEABLE_GALLERY_AD_SITELINK_TWO = ClickTypeEnum.ClickType.V(49)
        SWIPEABLE_GALLERY_AD_SITELINK_THREE = ClickTypeEnum.ClickType.V(50)
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR = ClickTypeEnum.ClickType.V(51)
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE = ClickTypeEnum.ClickType.V(52)
        HOTEL_PRICE = ClickTypeEnum.ClickType.V(53)
        PRICE_EXTENSION = ClickTypeEnum.ClickType.V(54)
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = ClickTypeEnum.ClickType.V(55)
        SHOPPING_COMPARISON_LISTING = ClickTypeEnum.ClickType.V(56)
    class ClickType(metaclass=_ClickType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ClickTypeEnum.ClickType.V(0)
    UNKNOWN = ClickTypeEnum.ClickType.V(1)
    APP_DEEPLINK = ClickTypeEnum.ClickType.V(2)
    BREADCRUMBS = ClickTypeEnum.ClickType.V(3)
    BROADBAND_PLAN = ClickTypeEnum.ClickType.V(4)
    CALL_TRACKING = ClickTypeEnum.ClickType.V(5)
    CALLS = ClickTypeEnum.ClickType.V(6)
    CLICK_ON_ENGAGEMENT_AD = ClickTypeEnum.ClickType.V(7)
    GET_DIRECTIONS = ClickTypeEnum.ClickType.V(8)
    LOCATION_EXPANSION = ClickTypeEnum.ClickType.V(9)
    LOCATION_FORMAT_CALL = ClickTypeEnum.ClickType.V(10)
    LOCATION_FORMAT_DIRECTIONS = ClickTypeEnum.ClickType.V(11)
    LOCATION_FORMAT_IMAGE = ClickTypeEnum.ClickType.V(12)
    LOCATION_FORMAT_LANDING_PAGE = ClickTypeEnum.ClickType.V(13)
    LOCATION_FORMAT_MAP = ClickTypeEnum.ClickType.V(14)
    LOCATION_FORMAT_STORE_INFO = ClickTypeEnum.ClickType.V(15)
    LOCATION_FORMAT_TEXT = ClickTypeEnum.ClickType.V(16)
    MOBILE_CALL_TRACKING = ClickTypeEnum.ClickType.V(17)
    OFFER_PRINTS = ClickTypeEnum.ClickType.V(18)
    OTHER = ClickTypeEnum.ClickType.V(19)
    PRODUCT_EXTENSION_CLICKS = ClickTypeEnum.ClickType.V(20)
    PRODUCT_LISTING_AD_CLICKS = ClickTypeEnum.ClickType.V(21)
    SITELINKS = ClickTypeEnum.ClickType.V(22)
    STORE_LOCATOR = ClickTypeEnum.ClickType.V(23)
    URL_CLICKS = ClickTypeEnum.ClickType.V(25)
    VIDEO_APP_STORE_CLICKS = ClickTypeEnum.ClickType.V(26)
    VIDEO_CALL_TO_ACTION_CLICKS = ClickTypeEnum.ClickType.V(27)
    VIDEO_CARD_ACTION_HEADLINE_CLICKS = ClickTypeEnum.ClickType.V(28)
    VIDEO_END_CAP_CLICKS = ClickTypeEnum.ClickType.V(29)
    VIDEO_WEBSITE_CLICKS = ClickTypeEnum.ClickType.V(30)
    VISUAL_SITELINKS = ClickTypeEnum.ClickType.V(31)
    WIRELESS_PLAN = ClickTypeEnum.ClickType.V(32)
    PRODUCT_LISTING_AD_LOCAL = ClickTypeEnum.ClickType.V(33)
    PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = ClickTypeEnum.ClickType.V(34)
    PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = ClickTypeEnum.ClickType.V(35)
    PRODUCT_LISTING_ADS_COUPON = ClickTypeEnum.ClickType.V(36)
    PRODUCT_LISTING_AD_TRANSACTABLE = ClickTypeEnum.ClickType.V(37)
    PRODUCT_AD_APP_DEEPLINK = ClickTypeEnum.ClickType.V(38)
    SHOWCASE_AD_CATEGORY_LINK = ClickTypeEnum.ClickType.V(39)
    SHOWCASE_AD_LOCAL_STOREFRONT_LINK = ClickTypeEnum.ClickType.V(40)
    SHOWCASE_AD_ONLINE_PRODUCT_LINK = ClickTypeEnum.ClickType.V(42)
    SHOWCASE_AD_LOCAL_PRODUCT_LINK = ClickTypeEnum.ClickType.V(43)
    PROMOTION_EXTENSION = ClickTypeEnum.ClickType.V(44)
    SWIPEABLE_GALLERY_AD_HEADLINE = ClickTypeEnum.ClickType.V(45)
    SWIPEABLE_GALLERY_AD_SWIPES = ClickTypeEnum.ClickType.V(46)
    SWIPEABLE_GALLERY_AD_SEE_MORE = ClickTypeEnum.ClickType.V(47)
    SWIPEABLE_GALLERY_AD_SITELINK_ONE = ClickTypeEnum.ClickType.V(48)
    SWIPEABLE_GALLERY_AD_SITELINK_TWO = ClickTypeEnum.ClickType.V(49)
    SWIPEABLE_GALLERY_AD_SITELINK_THREE = ClickTypeEnum.ClickType.V(50)
    SWIPEABLE_GALLERY_AD_SITELINK_FOUR = ClickTypeEnum.ClickType.V(51)
    SWIPEABLE_GALLERY_AD_SITELINK_FIVE = ClickTypeEnum.ClickType.V(52)
    HOTEL_PRICE = ClickTypeEnum.ClickType.V(53)
    PRICE_EXTENSION = ClickTypeEnum.ClickType.V(54)
    HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = ClickTypeEnum.ClickType.V(55)
    SHOPPING_COMPARISON_LISTING = ClickTypeEnum.ClickType.V(56)
    def __init__(
        self,
    ) -> None: ...

global___ClickTypeEnum = ClickTypeEnum
