"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsFieldDataTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GoogleAdsFieldDataType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GoogleAdsFieldDataType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(0)
        UNKNOWN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(1)
        BOOLEAN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(2)
        DATE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(3)
        DOUBLE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(4)
        ENUM = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(5)
        FLOAT = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(6)
        INT32 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(7)
        INT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(8)
        MESSAGE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(9)
        RESOURCE_NAME = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(10)
        STRING = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(11)
        UINT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(12)
    class GoogleAdsFieldDataType(metaclass=_GoogleAdsFieldDataType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(0)
    UNKNOWN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(1)
    BOOLEAN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(2)
    DATE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(3)
    DOUBLE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(4)
    ENUM = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(5)
    FLOAT = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(6)
    INT32 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(7)
    INT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(8)
    MESSAGE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(9)
    RESOURCE_NAME = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(10)
    STRING = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(11)
    UINT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(12)
    def __init__(
        self,
    ) -> None: ...

global___GoogleAdsFieldDataTypeEnum = GoogleAdsFieldDataTypeEnum
