"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2
import google.ads.google_ads.v6.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_TITLE_FIELD_NUMBER: builtins.int
    youtube_video_id: typing.Text = ...
    youtube_video_title: typing.Text = ...
    def __init__(
        self,
        *,
        youtube_video_id: typing.Text = ...,
        youtube_video_title: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
            "youtube_video_title",
            b"youtube_video_title",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions.Literal["youtube_video_id"]: ...

global___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...

global___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    FULL_SIZE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    file_size: builtins.int = ...
    mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def full_size(self) -> global___ImageDimension: ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        file_size: builtins.int = ...,
        mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        full_size: typing.Optional[global___ImageDimension] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_file_size", b"_file_size"]
    ) -> typing_extensions.Literal["file_size"]: ...

global___ImageAsset = ImageAsset

class ImageDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_PIXELS_FIELD_NUMBER: builtins.int
    WIDTH_PIXELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    height_pixels: builtins.int = ...
    width_pixels: builtins.int = ...
    url: typing.Text = ...
    def __init__(
        self,
        *,
        height_pixels: builtins.int = ...,
        width_pixels: builtins.int = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions.Literal["height_pixels"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_width_pixels", b"_width_pixels"]
    ) -> typing_extensions.Literal["width_pixels"]: ...

global___ImageDimension = ImageDimension

class TextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___TextAsset = TextAsset

class LeadFormAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TYPE_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_DESCRIPTION_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRIVACY_POLICY_URL_FIELD_NUMBER: builtins.int
    POST_SUBMIT_HEADLINE_FIELD_NUMBER: builtins.int
    POST_SUBMIT_DESCRIPTION_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    DELIVERY_METHODS_FIELD_NUMBER: builtins.int
    POST_SUBMIT_CALL_TO_ACTION_TYPE_FIELD_NUMBER: builtins.int
    BACKGROUND_IMAGE_ASSET_FIELD_NUMBER: builtins.int
    DESIRED_INTENT_FIELD_NUMBER: builtins.int
    CUSTOM_DISCLOSURE_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2.LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V = (
        ...
    )
    call_to_action_description: typing.Text = ...
    headline: typing.Text = ...
    description: typing.Text = ...
    privacy_policy_url: typing.Text = ...
    post_submit_headline: typing.Text = ...
    post_submit_description: typing.Text = ...
    post_submit_call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType.V = (
        ...
    )
    background_image_asset: typing.Text = ...
    desired_intent: google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2.LeadFormDesiredIntentEnum.LeadFormDesiredIntent.V = (
        ...
    )
    custom_disclosure: typing.Text = ...
    @property
    def fields(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LeadFormField
    ]: ...
    @property
    def delivery_methods(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LeadFormDeliveryMethod
    ]: ...
    def __init__(
        self,
        *,
        business_name: typing.Text = ...,
        call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2.LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V = ...,
        call_to_action_description: typing.Text = ...,
        headline: typing.Text = ...,
        description: typing.Text = ...,
        privacy_policy_url: typing.Text = ...,
        post_submit_headline: typing.Text = ...,
        post_submit_description: typing.Text = ...,
        fields: typing.Optional[typing.Iterable[global___LeadFormField]] = ...,
        delivery_methods: typing.Optional[
            typing.Iterable[global___LeadFormDeliveryMethod]
        ] = ...,
        post_submit_call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType.V = ...,
        background_image_asset: typing.Text = ...,
        desired_intent: google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2.LeadFormDesiredIntentEnum.LeadFormDesiredIntent.V = ...,
        custom_disclosure: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "custom_disclosure",
            b"custom_disclosure",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "business_name",
            b"business_name",
            "call_to_action_description",
            b"call_to_action_description",
            "call_to_action_type",
            b"call_to_action_type",
            "custom_disclosure",
            b"custom_disclosure",
            "delivery_methods",
            b"delivery_methods",
            "description",
            b"description",
            "desired_intent",
            b"desired_intent",
            "fields",
            b"fields",
            "headline",
            b"headline",
            "post_submit_call_to_action_type",
            b"post_submit_call_to_action_type",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
            "privacy_policy_url",
            b"privacy_policy_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_background_image_asset", b"_background_image_asset"
        ],
    ) -> typing_extensions.Literal["background_image_asset"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_custom_disclosure", b"_custom_disclosure"
        ],
    ) -> typing_extensions.Literal["custom_disclosure"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_post_submit_description", b"_post_submit_description"
        ],
    ) -> typing_extensions.Literal["post_submit_description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_post_submit_headline", b"_post_submit_headline"
        ],
    ) -> typing_extensions.Literal["post_submit_headline"]: ...

global___LeadFormAsset = LeadFormAsset

class LeadFormField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INPUT_TYPE_FIELD_NUMBER: builtins.int
    SINGLE_CHOICE_ANSWERS_FIELD_NUMBER: builtins.int
    input_type: google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V = (
        ...
    )
    @property
    def single_choice_answers(self) -> global___LeadFormSingleChoiceAnswers: ...
    def __init__(
        self,
        *,
        input_type: google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V = ...,
        single_choice_answers: typing.Optional[
            global___LeadFormSingleChoiceAnswers
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "answers", b"answers", "single_choice_answers", b"single_choice_answers"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "answers",
            b"answers",
            "input_type",
            b"input_type",
            "single_choice_answers",
            b"single_choice_answers",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["answers", b"answers"]
    ) -> typing_extensions.Literal["single_choice_answers"]: ...

global___LeadFormField = LeadFormField

class LeadFormSingleChoiceAnswers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ANSWERS_FIELD_NUMBER: builtins.int
    answers: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        answers: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["answers", b"answers"]
    ) -> None: ...

global___LeadFormSingleChoiceAnswers = LeadFormSingleChoiceAnswers

class LeadFormDeliveryMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def webhook(self) -> global___WebhookDelivery: ...
    def __init__(
        self,
        *,
        webhook: typing.Optional[global___WebhookDelivery] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["delivery_details", b"delivery_details"],
    ) -> typing_extensions.Literal["webhook"]: ...

global___LeadFormDeliveryMethod = LeadFormDeliveryMethod

class WebhookDelivery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADVERTISER_WEBHOOK_URL_FIELD_NUMBER: builtins.int
    GOOGLE_SECRET_FIELD_NUMBER: builtins.int
    PAYLOAD_SCHEMA_VERSION_FIELD_NUMBER: builtins.int
    advertiser_webhook_url: typing.Text = ...
    google_secret: typing.Text = ...
    payload_schema_version: builtins.int = ...
    def __init__(
        self,
        *,
        advertiser_webhook_url: typing.Text = ...,
        google_secret: typing.Text = ...,
        payload_schema_version: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_advertiser_webhook_url", b"_advertiser_webhook_url"
        ],
    ) -> typing_extensions.Literal["advertiser_webhook_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_google_secret", b"_google_secret"],
    ) -> typing_extensions.Literal["google_secret"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payload_schema_version", b"_payload_schema_version"
        ],
    ) -> typing_extensions.Literal["payload_schema_version"]: ...

global___WebhookDelivery = WebhookDelivery

class BookOnGoogleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___BookOnGoogleAsset = BookOnGoogleAsset
