"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_SET_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DYNAMIC_LOCATION_SET_FILTER_FIELD_NUMBER: builtins.int
    DYNAMIC_AFFILIATE_LOCATION_SET_FILTER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    feed: typing.Text = ...
    feed_item_set_id: builtins.int = ...
    display_name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2.FeedItemSetStatusEnum.FeedItemSetStatus.V = (
        ...
    )
    @property
    def dynamic_location_set_filter(
        self,
    ) -> google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicLocationSetFilter: ...
    @property
    def dynamic_affiliate_location_set_filter(
        self,
    ) -> google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicAffiliateLocationSetFilter: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Text = ...,
        feed_item_set_id: builtins.int = ...,
        display_name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2.FeedItemSetStatusEnum.FeedItemSetStatus.V = ...,
        dynamic_location_set_filter: typing.Optional[
            google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicLocationSetFilter
        ] = ...,
        dynamic_affiliate_location_set_filter: typing.Optional[
            google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicAffiliateLocationSetFilter
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
            "feed",
            b"feed",
            "feed_item_set_id",
            b"feed_item_set_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "dynamic_set_filter", b"dynamic_set_filter"
        ],
    ) -> typing_extensions.Literal[
        "dynamic_location_set_filter", "dynamic_affiliate_location_set_filter"
    ]: ...

global___FeedItemSet = FeedItemSet
