"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.domain_category_pb2
import grpc

from .domain_category_service_pb2 import *

class DomainCategoryServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetDomainCategory(
        self,
        request: global___GetDomainCategoryRequest,
    ) -> google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory: ...

class DomainCategoryServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDomainCategory(
        self,
        request: global___GetDomainCategoryRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory: ...

def add_DomainCategoryServiceServicer_to_server(
    servicer: DomainCategoryServiceServicer, server: grpc.Server
) -> None: ...
