"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RecommendationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RecommendationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RecommendationType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RecommendationTypeEnum.RecommendationType.V(0)
        UNKNOWN = RecommendationTypeEnum.RecommendationType.V(1)
        CAMPAIGN_BUDGET = RecommendationTypeEnum.RecommendationType.V(2)
        KEYWORD = RecommendationTypeEnum.RecommendationType.V(3)
        TEXT_AD = RecommendationTypeEnum.RecommendationType.V(4)
        TARGET_CPA_OPT_IN = RecommendationTypeEnum.RecommendationType.V(5)
        MAXIMIZE_CONVERSIONS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(6)
        ENHANCED_CPC_OPT_IN = RecommendationTypeEnum.RecommendationType.V(7)
        SEARCH_PARTNERS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(8)
        MAXIMIZE_CLICKS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(9)
        OPTIMIZE_AD_ROTATION = RecommendationTypeEnum.RecommendationType.V(10)
        CALLOUT_EXTENSION = RecommendationTypeEnum.RecommendationType.V(11)
        SITELINK_EXTENSION = RecommendationTypeEnum.RecommendationType.V(12)
        CALL_EXTENSION = RecommendationTypeEnum.RecommendationType.V(13)
        KEYWORD_MATCH_TYPE = RecommendationTypeEnum.RecommendationType.V(14)
        MOVE_UNUSED_BUDGET = RecommendationTypeEnum.RecommendationType.V(15)
    class RecommendationType(metaclass=_RecommendationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RecommendationTypeEnum.RecommendationType.V(0)
    UNKNOWN = RecommendationTypeEnum.RecommendationType.V(1)
    CAMPAIGN_BUDGET = RecommendationTypeEnum.RecommendationType.V(2)
    KEYWORD = RecommendationTypeEnum.RecommendationType.V(3)
    TEXT_AD = RecommendationTypeEnum.RecommendationType.V(4)
    TARGET_CPA_OPT_IN = RecommendationTypeEnum.RecommendationType.V(5)
    MAXIMIZE_CONVERSIONS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(6)
    ENHANCED_CPC_OPT_IN = RecommendationTypeEnum.RecommendationType.V(7)
    SEARCH_PARTNERS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(8)
    MAXIMIZE_CLICKS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(9)
    OPTIMIZE_AD_ROTATION = RecommendationTypeEnum.RecommendationType.V(10)
    CALLOUT_EXTENSION = RecommendationTypeEnum.RecommendationType.V(11)
    SITELINK_EXTENSION = RecommendationTypeEnum.RecommendationType.V(12)
    CALL_EXTENSION = RecommendationTypeEnum.RecommendationType.V(13)
    KEYWORD_MATCH_TYPE = RecommendationTypeEnum.RecommendationType.V(14)
    MOVE_UNUSED_BUDGET = RecommendationTypeEnum.RecommendationType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___RecommendationTypeEnum = RecommendationTypeEnum
