"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(0)
        UNKNOWN = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(1)
        ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(2)
        ID2 = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(3)
        ITEM_TITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(4)
        ITEM_SUBTITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(5)
        ITEM_DESCRIPTION = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(6)
        ITEM_ADDRESS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(7)
        PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(8)
        FORMATTED_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(9)
        SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(10)
        FORMATTED_SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(11)
        IMAGE_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(12)
        ITEM_CATEGORY = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(13)
        FINAL_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(14)
        FINAL_MOBILE_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(15)
        TRACKING_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(16)
        CONTEXTUAL_KEYWORDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(17)
        ANDROID_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(18)
        SIMILAR_IDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(19)
        IOS_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(20)
        IOS_APP_STORE_ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(21)
    class CustomPlaceholderField(metaclass=_CustomPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(0)
    UNKNOWN = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(1)
    ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(2)
    ID2 = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(3)
    ITEM_TITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(4)
    ITEM_SUBTITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(5)
    ITEM_DESCRIPTION = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(6)
    ITEM_ADDRESS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(7)
    PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(8)
    FORMATTED_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(9)
    SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(10)
    FORMATTED_SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(11)
    IMAGE_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(12)
    ITEM_CATEGORY = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(13)
    FINAL_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(14)
    FINAL_MOBILE_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(15)
    TRACKING_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(16)
    CONTEXTUAL_KEYWORDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(17)
    ANDROID_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(18)
    SIMILAR_IDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(19)
    IOS_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(20)
    IOS_APP_STORE_ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___CustomPlaceholderFieldEnum = CustomPlaceholderFieldEnum
