"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusResourceTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusResourceType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusResourceType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(0)
        UNKNOWN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(1)
        AD_GROUP = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(3)
        AD_GROUP_AD = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(4)
        AD_GROUP_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(5)
        CAMPAIGN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(6)
        CAMPAIGN_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(7)
        FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(9)
        FEED_ITEM = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(10)
        AD_GROUP_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(11)
        CAMPAIGN_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(12)
        AD_GROUP_BID_MODIFIER = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(
            13
        )
    class ChangeStatusResourceType(metaclass=_ChangeStatusResourceType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(0)
    UNKNOWN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(1)
    AD_GROUP = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(3)
    AD_GROUP_AD = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(4)
    AD_GROUP_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(5)
    CAMPAIGN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(6)
    CAMPAIGN_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(7)
    FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(9)
    FEED_ITEM = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(10)
    AD_GROUP_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(11)
    CAMPAIGN_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(12)
    AD_GROUP_BID_MODIFIER = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusResourceTypeEnum = ChangeStatusResourceTypeEnum
