"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TimeZoneErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TimeZoneError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TimeZoneError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TimeZoneErrorEnum.TimeZoneError.V(0)
        UNKNOWN = TimeZoneErrorEnum.TimeZoneError.V(1)
        INVALID_TIME_ZONE = TimeZoneErrorEnum.TimeZoneError.V(5)
    class TimeZoneError(metaclass=_TimeZoneError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TimeZoneErrorEnum.TimeZoneError.V(0)
    UNKNOWN = TimeZoneErrorEnum.TimeZoneError.V(1)
    INVALID_TIME_ZONE = TimeZoneErrorEnum.TimeZoneError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___TimeZoneErrorEnum = TimeZoneErrorEnum
