"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetCustomerUserAccessInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetCustomerUserAccessInvitationRequest = GetCustomerUserAccessInvitationRequest

class MutateCustomerUserAccessInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operation(self) -> global___CustomerUserAccessInvitationOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[
            global___CustomerUserAccessInvitationOperation
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

global___MutateCustomerUserAccessInvitationRequest = (
    MutateCustomerUserAccessInvitationRequest
)

class CustomerUserAccessInvitationOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___CustomerUserAccessInvitationOperation = CustomerUserAccessInvitationOperation

class MutateCustomerUserAccessInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateCustomerUserAccessInvitationResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[
            global___MutateCustomerUserAccessInvitationResult
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateCustomerUserAccessInvitationResponse = (
    MutateCustomerUserAccessInvitationResponse
)

class MutateCustomerUserAccessInvitationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateCustomerUserAccessInvitationResult = (
    MutateCustomerUserAccessInvitationResult
)
