"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CampaignError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignErrorEnum.CampaignError.V(0)
        UNKNOWN = CampaignErrorEnum.CampaignError.V(1)
        CANNOT_TARGET_CONTENT_NETWORK = CampaignErrorEnum.CampaignError.V(3)
        CANNOT_TARGET_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(4)
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = (
            CampaignErrorEnum.CampaignError.V(5)
        )
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = (
            CampaignErrorEnum.CampaignError.V(6)
        )
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = CampaignErrorEnum.CampaignError.V(7)
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(8)
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = (
            CampaignErrorEnum.CampaignError.V(9)
        )
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = (
            CampaignErrorEnum.CampaignError.V(10)
        )
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = CampaignErrorEnum.CampaignError.V(11)
        DUPLICATE_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(12)
        INCOMPATIBLE_CAMPAIGN_FIELD = CampaignErrorEnum.CampaignError.V(13)
        INVALID_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(14)
        INVALID_AD_SERVING_OPTIMIZATION_STATUS = CampaignErrorEnum.CampaignError.V(15)
        INVALID_TRACKING_URL = CampaignErrorEnum.CampaignError.V(16)
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = (
            CampaignErrorEnum.CampaignError.V(17)
        )
        MAX_IMPRESSIONS_NOT_IN_RANGE = CampaignErrorEnum.CampaignError.V(18)
        TIME_UNIT_NOT_SUPPORTED = CampaignErrorEnum.CampaignError.V(19)
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = (
            CampaignErrorEnum.CampaignError.V(20)
        )
        BUDGET_CANNOT_BE_SHARED = CampaignErrorEnum.CampaignError.V(21)
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET = CampaignErrorEnum.CampaignError.V(22)
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = (
            CampaignErrorEnum.CampaignError.V(23)
        )
        CAMPAIGN_LABEL_DOES_NOT_EXIST = CampaignErrorEnum.CampaignError.V(24)
        CAMPAIGN_LABEL_ALREADY_EXISTS = CampaignErrorEnum.CampaignError.V(25)
        MISSING_SHOPPING_SETTING = CampaignErrorEnum.CampaignError.V(26)
        INVALID_SHOPPING_SALES_COUNTRY = CampaignErrorEnum.CampaignError.V(27)
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
            CampaignErrorEnum.CampaignError.V(31)
        )
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE = CampaignErrorEnum.CampaignError.V(32)
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = CampaignErrorEnum.CampaignError.V(33)
        CANNOT_SET_AD_ROTATION_MODE = CampaignErrorEnum.CampaignError.V(34)
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = CampaignErrorEnum.CampaignError.V(
            35
        )
        CANNOT_SET_DATE_TO_PAST = CampaignErrorEnum.CampaignError.V(36)
        MISSING_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(37)
        INVALID_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(38)
        MISSING_HOTEL_SETTING = CampaignErrorEnum.CampaignError.V(39)
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = (
            CampaignErrorEnum.CampaignError.V(40)
        )
        APP_NOT_FOUND = CampaignErrorEnum.CampaignError.V(41)
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = (
            CampaignErrorEnum.CampaignError.V(42)
        )
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = (
            CampaignErrorEnum.CampaignError.V(43)
        )
        INSUFFICIENT_APP_INSTALLS_COUNT = CampaignErrorEnum.CampaignError.V(44)
        SENSITIVE_CATEGORY_APP = CampaignErrorEnum.CampaignError.V(45)
    class CampaignError(metaclass=_CampaignError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignErrorEnum.CampaignError.V(0)
    UNKNOWN = CampaignErrorEnum.CampaignError.V(1)
    CANNOT_TARGET_CONTENT_NETWORK = CampaignErrorEnum.CampaignError.V(3)
    CANNOT_TARGET_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(4)
    CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = (
        CampaignErrorEnum.CampaignError.V(5)
    )
    CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = CampaignErrorEnum.CampaignError.V(6)
    CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = CampaignErrorEnum.CampaignError.V(7)
    CANNOT_TARGET_PARTNER_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(8)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = (
        CampaignErrorEnum.CampaignError.V(9)
    )
    CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = (
        CampaignErrorEnum.CampaignError.V(10)
    )
    CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = CampaignErrorEnum.CampaignError.V(11)
    DUPLICATE_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(12)
    INCOMPATIBLE_CAMPAIGN_FIELD = CampaignErrorEnum.CampaignError.V(13)
    INVALID_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(14)
    INVALID_AD_SERVING_OPTIMIZATION_STATUS = CampaignErrorEnum.CampaignError.V(15)
    INVALID_TRACKING_URL = CampaignErrorEnum.CampaignError.V(16)
    CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = (
        CampaignErrorEnum.CampaignError.V(17)
    )
    MAX_IMPRESSIONS_NOT_IN_RANGE = CampaignErrorEnum.CampaignError.V(18)
    TIME_UNIT_NOT_SUPPORTED = CampaignErrorEnum.CampaignError.V(19)
    INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = CampaignErrorEnum.CampaignError.V(
        20
    )
    BUDGET_CANNOT_BE_SHARED = CampaignErrorEnum.CampaignError.V(21)
    CAMPAIGN_CANNOT_USE_SHARED_BUDGET = CampaignErrorEnum.CampaignError.V(22)
    CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = CampaignErrorEnum.CampaignError.V(23)
    CAMPAIGN_LABEL_DOES_NOT_EXIST = CampaignErrorEnum.CampaignError.V(24)
    CAMPAIGN_LABEL_ALREADY_EXISTS = CampaignErrorEnum.CampaignError.V(25)
    MISSING_SHOPPING_SETTING = CampaignErrorEnum.CampaignError.V(26)
    INVALID_SHOPPING_SALES_COUNTRY = CampaignErrorEnum.CampaignError.V(27)
    ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
        CampaignErrorEnum.CampaignError.V(31)
    )
    INVALID_ADVERTISING_CHANNEL_SUB_TYPE = CampaignErrorEnum.CampaignError.V(32)
    AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = CampaignErrorEnum.CampaignError.V(33)
    CANNOT_SET_AD_ROTATION_MODE = CampaignErrorEnum.CampaignError.V(34)
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = CampaignErrorEnum.CampaignError.V(35)
    CANNOT_SET_DATE_TO_PAST = CampaignErrorEnum.CampaignError.V(36)
    MISSING_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(37)
    INVALID_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(38)
    MISSING_HOTEL_SETTING = CampaignErrorEnum.CampaignError.V(39)
    CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = (
        CampaignErrorEnum.CampaignError.V(40)
    )
    APP_NOT_FOUND = CampaignErrorEnum.CampaignError.V(41)
    SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = (
        CampaignErrorEnum.CampaignError.V(42)
    )
    MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = CampaignErrorEnum.CampaignError.V(
        43
    )
    INSUFFICIENT_APP_INSTALLS_COUNT = CampaignErrorEnum.CampaignError.V(44)
    SENSITIVE_CATEGORY_APP = CampaignErrorEnum.CampaignError.V(45)
    def __init__(
        self,
    ) -> None: ...

global___CampaignErrorEnum = CampaignErrorEnum
