"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class VanityPharmaTextEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _VanityPharmaText(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VanityPharmaText.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = VanityPharmaTextEnum.VanityPharmaText.V(0)
        UNKNOWN = VanityPharmaTextEnum.VanityPharmaText.V(1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(2)
        PRESCRIPTION_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(3)
        PRESCRIPTION_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(4)
        PRESCRIPTION_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(5)
        MEDICAL_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(6)
        MEDICAL_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(7)
        PREVENTATIVE_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(8)
        PREVENTATIVE_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(9)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(
            10
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(
            11
        )
        PRESCRIPTION_VACCINE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(12)
        PRESCRIPTION_VACCINE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(13)
    class VanityPharmaText(metaclass=_VanityPharmaText):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = VanityPharmaTextEnum.VanityPharmaText.V(0)
    UNKNOWN = VanityPharmaTextEnum.VanityPharmaText.V(1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(2)
    PRESCRIPTION_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(3)
    PRESCRIPTION_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(4)
    PRESCRIPTION_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(5)
    MEDICAL_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(6)
    MEDICAL_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(7)
    PREVENTATIVE_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(8)
    PREVENTATIVE_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(9)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(10)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(11)
    PRESCRIPTION_VACCINE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(12)
    PRESCRIPTION_VACCINE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(13)
    def __init__(
        self,
    ) -> None: ...

global___VanityPharmaTextEnum = VanityPharmaTextEnum
