"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraftStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignDraftStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignDraftStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignDraftStatusEnum.CampaignDraftStatus.V(0)
        UNKNOWN = CampaignDraftStatusEnum.CampaignDraftStatus.V(1)
        PROPOSED = CampaignDraftStatusEnum.CampaignDraftStatus.V(2)
        REMOVED = CampaignDraftStatusEnum.CampaignDraftStatus.V(3)
        PROMOTING = CampaignDraftStatusEnum.CampaignDraftStatus.V(5)
        PROMOTED = CampaignDraftStatusEnum.CampaignDraftStatus.V(4)
        PROMOTE_FAILED = CampaignDraftStatusEnum.CampaignDraftStatus.V(6)
    class CampaignDraftStatus(metaclass=_CampaignDraftStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignDraftStatusEnum.CampaignDraftStatus.V(0)
    UNKNOWN = CampaignDraftStatusEnum.CampaignDraftStatus.V(1)
    PROPOSED = CampaignDraftStatusEnum.CampaignDraftStatus.V(2)
    REMOVED = CampaignDraftStatusEnum.CampaignDraftStatus.V(3)
    PROMOTING = CampaignDraftStatusEnum.CampaignDraftStatus.V(5)
    PROMOTED = CampaignDraftStatusEnum.CampaignDraftStatus.V(4)
    PROMOTE_FAILED = CampaignDraftStatusEnum.CampaignDraftStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___CampaignDraftStatusEnum = CampaignDraftStatusEnum
