"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignBudgetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignBudgetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignBudgetError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignBudgetErrorEnum.CampaignBudgetError.V(0)
        UNKNOWN = CampaignBudgetErrorEnum.CampaignBudgetError.V(1)
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(17)
        )
        CAMPAIGN_BUDGET_REMOVED = CampaignBudgetErrorEnum.CampaignBudgetError.V(2)
        CAMPAIGN_BUDGET_IN_USE = CampaignBudgetErrorEnum.CampaignBudgetError.V(3)
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(4)
        )
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(6)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(7)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(8)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(9)
        )
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(10)
        )
        DUPLICATE_NAME = CampaignBudgetErrorEnum.CampaignBudgetError.V(11)
        MONEY_AMOUNT_IN_WRONG_CURRENCY = CampaignBudgetErrorEnum.CampaignBudgetError.V(
            12
        )
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(13)
        )
        MONEY_AMOUNT_TOO_LARGE = CampaignBudgetErrorEnum.CampaignBudgetError.V(14)
        NEGATIVE_MONEY_AMOUNT = CampaignBudgetErrorEnum.CampaignBudgetError.V(15)
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(16)
        )
        TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(18)
        )
    class CampaignBudgetError(metaclass=_CampaignBudgetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignBudgetErrorEnum.CampaignBudgetError.V(0)
    UNKNOWN = CampaignBudgetErrorEnum.CampaignBudgetError.V(1)
    CAMPAIGN_BUDGET_CANNOT_BE_SHARED = CampaignBudgetErrorEnum.CampaignBudgetError.V(17)
    CAMPAIGN_BUDGET_REMOVED = CampaignBudgetErrorEnum.CampaignBudgetError.V(2)
    CAMPAIGN_BUDGET_IN_USE = CampaignBudgetErrorEnum.CampaignBudgetError.V(3)
    CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(4)
    )
    CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(6)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(7)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(8)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(9)
    )
    CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(10)
    )
    DUPLICATE_NAME = CampaignBudgetErrorEnum.CampaignBudgetError.V(11)
    MONEY_AMOUNT_IN_WRONG_CURRENCY = CampaignBudgetErrorEnum.CampaignBudgetError.V(12)
    MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(13)
    )
    MONEY_AMOUNT_TOO_LARGE = CampaignBudgetErrorEnum.CampaignBudgetError.V(14)
    NEGATIVE_MONEY_AMOUNT = CampaignBudgetErrorEnum.CampaignBudgetError.V(15)
    NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(16)
    )
    TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(18)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignBudgetErrorEnum = CampaignBudgetErrorEnum
