"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.matching_function_pb2
import google.ads.google_ads.v5.proto.enums.feed_link_status_pb2
import google.ads.google_ads.v5.proto.enums.placeholder_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPES_FIELD_NUMBER: builtins.int
    MATCHING_FUNCTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placeholder_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V
    ] = ...
    status: google.ads.google_ads.v5.proto.enums.feed_link_status_pb2.FeedLinkStatusEnum.FeedLinkStatus.V = (
        ...
    )
    @property
    def feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def matching_function(
        self,
    ) -> google.ads.google_ads.v5.proto.common.matching_function_pb2.MatchingFunction: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        placeholder_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V
            ]
        ] = ...,
        matching_function: typing.Optional[
            google.ads.google_ads.v5.proto.common.matching_function_pb2.MatchingFunction
        ] = ...,
        status: google.ads.google_ads.v5.proto.enums.feed_link_status_pb2.FeedLinkStatusEnum.FeedLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "feed", b"feed", "matching_function", b"matching_function"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "feed",
            b"feed",
            "matching_function",
            b"matching_function",
            "placeholder_types",
            b"placeholder_types",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

global___CustomerFeed = CustomerFeed
