"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LabelErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LabelError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LabelError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LabelErrorEnum.LabelError.V(0)
        UNKNOWN = LabelErrorEnum.LabelError.V(1)
        CANNOT_APPLY_INACTIVE_LABEL = LabelErrorEnum.LabelError.V(2)
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(
            3
        )
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(
            4
        )
        EXCEEDED_LABEL_LIMIT_PER_TYPE = LabelErrorEnum.LabelError.V(5)
        INVALID_RESOURCE_FOR_MANAGER_LABEL = LabelErrorEnum.LabelError.V(6)
        DUPLICATE_NAME = LabelErrorEnum.LabelError.V(7)
        INVALID_LABEL_NAME = LabelErrorEnum.LabelError.V(8)
        CANNOT_ATTACH_LABEL_TO_DRAFT = LabelErrorEnum.LabelError.V(9)
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = LabelErrorEnum.LabelError.V(10)
    class LabelError(metaclass=_LabelError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LabelErrorEnum.LabelError.V(0)
    UNKNOWN = LabelErrorEnum.LabelError.V(1)
    CANNOT_APPLY_INACTIVE_LABEL = LabelErrorEnum.LabelError.V(2)
    CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(3)
    CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(4)
    EXCEEDED_LABEL_LIMIT_PER_TYPE = LabelErrorEnum.LabelError.V(5)
    INVALID_RESOURCE_FOR_MANAGER_LABEL = LabelErrorEnum.LabelError.V(6)
    DUPLICATE_NAME = LabelErrorEnum.LabelError.V(7)
    INVALID_LABEL_NAME = LabelErrorEnum.LabelError.V(8)
    CANNOT_ATTACH_LABEL_TO_DRAFT = LabelErrorEnum.LabelError.V(9)
    CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = LabelErrorEnum.LabelError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___LabelErrorEnum = LabelErrorEnum
