"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2
import google.ads.google_ads.v5.proto.enums.month_of_year_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVG_MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCH_VOLUMES_FIELD_NUMBER: builtins.int
    COMPETITION_FIELD_NUMBER: builtins.int
    COMPETITION_INDEX_FIELD_NUMBER: builtins.int
    LOW_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    HIGH_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    competition: google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = (
        ...
    )
    @property
    def avg_monthly_searches(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MonthlySearchVolume
    ]: ...
    @property
    def competition_index(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def low_top_of_page_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def high_top_of_page_bid_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        monthly_search_volumes: typing.Optional[
            typing.Iterable[global___MonthlySearchVolume]
        ] = ...,
        competition: google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = ...,
        competition_index: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        low_top_of_page_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        high_top_of_page_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...

global___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    month: google.ads.google_ads.v5.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    @property
    def year(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def monthly_searches(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        year: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        month: google.ads.google_ads.v5.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
        monthly_searches: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "month", b"month", "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> None: ...

global___MonthlySearchVolume = MonthlySearchVolume
