"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerFeedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerFeedErrorEnum.CustomerFeedError.V(0)
        UNKNOWN = CustomerFeedErrorEnum.CustomerFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            CustomerFeedErrorEnum.CustomerFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(3)
        CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = (
            CustomerFeedErrorEnum.CustomerFeedError.V(4)
        )
        CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(
            5
        )
        INVALID_PLACEHOLDER_TYPE = CustomerFeedErrorEnum.CustomerFeedError.V(6)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            CustomerFeedErrorEnum.CustomerFeedError.V(7)
        )
        PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = (
            CustomerFeedErrorEnum.CustomerFeedError.V(8)
        )
    class CustomerFeedError(metaclass=_CustomerFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerFeedErrorEnum.CustomerFeedError.V(0)
    UNKNOWN = CustomerFeedErrorEnum.CustomerFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        CustomerFeedErrorEnum.CustomerFeedError.V(2)
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(3)
    CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = (
        CustomerFeedErrorEnum.CustomerFeedError.V(4)
    )
    CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(5)
    INVALID_PLACEHOLDER_TYPE = CustomerFeedErrorEnum.CustomerFeedError.V(6)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
        CustomerFeedErrorEnum.CustomerFeedError.V(7)
    )
    PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = (
        CustomerFeedErrorEnum.CustomerFeedError.V(8)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerFeedErrorEnum = CustomerFeedErrorEnum
