"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_pb2
import grpc

from .feed_service_pb2 import *

class FeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeed(
        self,
        request: global___GetFeedRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_pb2.Feed: ...
    def MutateFeeds(
        self,
        request: global___MutateFeedsRequest,
    ) -> global___MutateFeedsResponse: ...

class FeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeed(
        self,
        request: global___GetFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_pb2.Feed: ...
    @abc.abstractmethod
    def MutateFeeds(
        self,
        request: global___MutateFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedsResponse: ...

def add_FeedServiceServicer_to_server(
    servicer: FeedServiceServicer, server: grpc.Server
) -> None: ...
