"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductCustomAttributeIndexEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductCustomAttributeIndex(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductCustomAttributeIndex.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(0)
        UNKNOWN = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(1)
        INDEX0 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(7)
        INDEX1 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(8)
        INDEX2 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(9)
        INDEX3 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(10)
        INDEX4 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(11)
    class ProductCustomAttributeIndex(metaclass=_ProductCustomAttributeIndex):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(0)
    UNKNOWN = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(1)
    INDEX0 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(7)
    INDEX1 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(8)
    INDEX2 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(9)
    INDEX3 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(10)
    INDEX4 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(11)
    def __init__(
        self,
    ) -> None: ...

global___ProductCustomAttributeIndexEnum = ProductCustomAttributeIndexEnum
