"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2
import grpc

from .shopping_performance_view_service_pb2 import *

class ShoppingPerformanceViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetShoppingPerformanceView(
        self,
        request: global___GetShoppingPerformanceViewRequest,
    ) -> google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView: ...

class ShoppingPerformanceViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetShoppingPerformanceView(
        self,
        request: global___GetShoppingPerformanceViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView: ...

def add_ShoppingPerformanceViewServiceServicer_to_server(
    servicer: ShoppingPerformanceViewServiceServicer, server: grpc.Server
) -> None: ...
