"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.custom_interest_pb2
import grpc

from .custom_interest_service_pb2 import *

class CustomInterestServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomInterest(
        self,
        request: global___GetCustomInterestRequest,
    ) -> google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest: ...
    def MutateCustomInterests(
        self,
        request: global___MutateCustomInterestsRequest,
    ) -> global___MutateCustomInterestsResponse: ...

class CustomInterestServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomInterest(
        self,
        request: global___GetCustomInterestRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest: ...
    @abc.abstractmethod
    def MutateCustomInterests(
        self,
        request: global___MutateCustomInterestsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomInterestsResponse: ...

def add_CustomInterestServiceServicer_to_server(
    servicer: CustomInterestServiceServicer, server: grpc.Server
) -> None: ...
