"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.payments_account_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListPaymentsAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["customer_id", b"customer_id"]
    ) -> None: ...

global___ListPaymentsAccountsRequest = ListPaymentsAccountsRequest

class ListPaymentsAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAYMENTS_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def payments_accounts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.resources.payments_account_pb2.PaymentsAccount
    ]: ...
    def __init__(
        self,
        *,
        payments_accounts: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.resources.payments_account_pb2.PaymentsAccount
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "payments_accounts", b"payments_accounts"
        ],
    ) -> None: ...

global___ListPaymentsAccountsResponse = ListPaymentsAccountsResponse
