"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AuthorizationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AuthorizationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AuthorizationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AuthorizationErrorEnum.AuthorizationError.V(0)
        UNKNOWN = AuthorizationErrorEnum.AuthorizationError.V(1)
        USER_PERMISSION_DENIED = AuthorizationErrorEnum.AuthorizationError.V(2)
        DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = AuthorizationErrorEnum.AuthorizationError.V(
            13
        )
        DEVELOPER_TOKEN_PROHIBITED = AuthorizationErrorEnum.AuthorizationError.V(4)
        PROJECT_DISABLED = AuthorizationErrorEnum.AuthorizationError.V(5)
        AUTHORIZATION_ERROR = AuthorizationErrorEnum.AuthorizationError.V(6)
        ACTION_NOT_PERMITTED = AuthorizationErrorEnum.AuthorizationError.V(7)
        INCOMPLETE_SIGNUP = AuthorizationErrorEnum.AuthorizationError.V(8)
        CUSTOMER_NOT_ENABLED = AuthorizationErrorEnum.AuthorizationError.V(24)
        MISSING_TOS = AuthorizationErrorEnum.AuthorizationError.V(9)
        DEVELOPER_TOKEN_NOT_APPROVED = AuthorizationErrorEnum.AuthorizationError.V(10)
        INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = (
            AuthorizationErrorEnum.AuthorizationError.V(11)
        )
        SERVICE_ACCESS_DENIED = AuthorizationErrorEnum.AuthorizationError.V(12)
        ACCESS_DENIED_FOR_ACCOUNT_TYPE = AuthorizationErrorEnum.AuthorizationError.V(25)
    class AuthorizationError(metaclass=_AuthorizationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AuthorizationErrorEnum.AuthorizationError.V(0)
    UNKNOWN = AuthorizationErrorEnum.AuthorizationError.V(1)
    USER_PERMISSION_DENIED = AuthorizationErrorEnum.AuthorizationError.V(2)
    DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = AuthorizationErrorEnum.AuthorizationError.V(13)
    DEVELOPER_TOKEN_PROHIBITED = AuthorizationErrorEnum.AuthorizationError.V(4)
    PROJECT_DISABLED = AuthorizationErrorEnum.AuthorizationError.V(5)
    AUTHORIZATION_ERROR = AuthorizationErrorEnum.AuthorizationError.V(6)
    ACTION_NOT_PERMITTED = AuthorizationErrorEnum.AuthorizationError.V(7)
    INCOMPLETE_SIGNUP = AuthorizationErrorEnum.AuthorizationError.V(8)
    CUSTOMER_NOT_ENABLED = AuthorizationErrorEnum.AuthorizationError.V(24)
    MISSING_TOS = AuthorizationErrorEnum.AuthorizationError.V(9)
    DEVELOPER_TOKEN_NOT_APPROVED = AuthorizationErrorEnum.AuthorizationError.V(10)
    INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = (
        AuthorizationErrorEnum.AuthorizationError.V(11)
    )
    SERVICE_ACCESS_DENIED = AuthorizationErrorEnum.AuthorizationError.V(12)
    ACCESS_DENIED_FOR_ACCOUNT_TYPE = AuthorizationErrorEnum.AuthorizationError.V(25)
    def __init__(
        self,
    ) -> None: ...

global___AuthorizationErrorEnum = AuthorizationErrorEnum
