"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PriceExtensionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PriceExtensionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PriceExtensionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PriceExtensionTypeEnum.PriceExtensionType.V(0)
        UNKNOWN = PriceExtensionTypeEnum.PriceExtensionType.V(1)
        BRANDS = PriceExtensionTypeEnum.PriceExtensionType.V(2)
        EVENTS = PriceExtensionTypeEnum.PriceExtensionType.V(3)
        LOCATIONS = PriceExtensionTypeEnum.PriceExtensionType.V(4)
        NEIGHBORHOODS = PriceExtensionTypeEnum.PriceExtensionType.V(5)
        PRODUCT_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(6)
        PRODUCT_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(7)
        SERVICES = PriceExtensionTypeEnum.PriceExtensionType.V(8)
        SERVICE_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(9)
        SERVICE_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(10)
    class PriceExtensionType(metaclass=_PriceExtensionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PriceExtensionTypeEnum.PriceExtensionType.V(0)
    UNKNOWN = PriceExtensionTypeEnum.PriceExtensionType.V(1)
    BRANDS = PriceExtensionTypeEnum.PriceExtensionType.V(2)
    EVENTS = PriceExtensionTypeEnum.PriceExtensionType.V(3)
    LOCATIONS = PriceExtensionTypeEnum.PriceExtensionType.V(4)
    NEIGHBORHOODS = PriceExtensionTypeEnum.PriceExtensionType.V(5)
    PRODUCT_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(6)
    PRODUCT_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(7)
    SERVICES = PriceExtensionTypeEnum.PriceExtensionType.V(8)
    SERVICE_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(9)
    SERVICE_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(10)
    def __init__(
        self,
    ) -> None: ...

global___PriceExtensionTypeEnum = PriceExtensionTypeEnum
