"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.placement_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DetailPlacementView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_TARGET_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    PLACEMENT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placement: typing.Text = ...
    display_name: typing.Text = ...
    group_placement_target_url: typing.Text = ...
    target_url: typing.Text = ...
    placement_type: google.ads.google_ads.v6.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placement: typing.Text = ...,
        display_name: typing.Text = ...,
        group_placement_target_url: typing.Text = ...,
        target_url: typing.Text = ...,
        placement_type: google.ads.google_ads.v6.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_display_name",
            b"_display_name",
            "_group_placement_target_url",
            b"_group_placement_target_url",
            "_placement",
            b"_placement",
            "_target_url",
            b"_target_url",
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_display_name",
            b"_display_name",
            "_group_placement_target_url",
            b"_group_placement_target_url",
            "_placement",
            b"_placement",
            "_target_url",
            b"_target_url",
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_display_name", b"_display_name"]
    ) -> typing_extensions.Literal["display_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_group_placement_target_url", b"_group_placement_target_url"
        ],
    ) -> typing_extensions.Literal["group_placement_target_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_placement", b"_placement"]
    ) -> typing_extensions.Literal["placement"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_url", b"_target_url"]
    ) -> typing_extensions.Literal["target_url"]: ...

global___DetailPlacementView = DetailPlacementView
