"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.placement_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DetailPlacementView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_TARGET_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    PLACEMENT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placement_type: google.ads.google_ads.v5.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = (
        ...
    )
    @property
    def placement(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def display_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def group_placement_target_url(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def target_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placement: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        display_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        group_placement_target_url: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        target_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        placement_type: google.ads.google_ads.v5.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...

global___DetailPlacementView = DetailPlacementView
