"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2
import google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Metrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ABSOLUTE_TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CPM_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CTR_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABILITY_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_COST_MICROS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_VIEWABILITY_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_CLICK_TO_CALL_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_DIRECTIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_MENU_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_ORDER_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_OTHER_ENGAGEMENT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_VISIT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_WEBSITE_FIELD_NUMBER: builtins.int
    AVERAGE_COST_FIELD_NUMBER: builtins.int
    AVERAGE_CPC_FIELD_NUMBER: builtins.int
    AVERAGE_CPE_FIELD_NUMBER: builtins.int
    AVERAGE_CPM_FIELD_NUMBER: builtins.int
    AVERAGE_CPV_FIELD_NUMBER: builtins.int
    AVERAGE_PAGE_VIEWS_FIELD_NUMBER: builtins.int
    AVERAGE_TIME_ON_SITE_FIELD_NUMBER: builtins.int
    BENCHMARK_AVERAGE_MAX_CPC_FIELD_NUMBER: builtins.int
    BENCHMARK_CTR_FIELD_NUMBER: builtins.int
    BOUNCE_RATE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    COMBINED_QUERIES_FIELD_NUMBER: builtins.int
    CONTENT_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONTENT_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_RECEIVED_REQUEST_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONTENT_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    COST_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_PER_CONVERSION_FIELD_NUMBER: builtins.int
    COST_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    CROSS_DEVICE_CONVERSIONS_FIELD_NUMBER: builtins.int
    CTR_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ENGAGEMENT_RATE_FIELD_NUMBER: builtins.int
    ENGAGEMENTS_FIELD_NUMBER: builtins.int
    HOTEL_AVERAGE_LEAD_VALUE_MICROS_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_DIFFERENCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    HOTEL_ELIGIBLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    HISTORICAL_CREATIVE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_LANDING_PAGE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_SEARCH_PREDICTED_CTR_FIELD_NUMBER: builtins.int
    GMAIL_FORWARDS_FIELD_NUMBER: builtins.int
    GMAIL_SAVES_FIELD_NUMBER: builtins.int
    GMAIL_SECONDARY_CLICKS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FROM_STORE_REACH_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    INTERACTION_RATE_FIELD_NUMBER: builtins.int
    INTERACTIONS_FIELD_NUMBER: builtins.int
    INTERACTION_EVENT_TYPES_FIELD_NUMBER: builtins.int
    INVALID_CLICK_RATE_FIELD_NUMBER: builtins.int
    INVALID_CLICKS_FIELD_NUMBER: builtins.int
    MESSAGE_CHATS_FIELD_NUMBER: builtins.int
    MESSAGE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    MESSAGE_CHAT_RATE_FIELD_NUMBER: builtins.int
    MOBILE_FRIENDLY_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_QUERIES_FIELD_NUMBER: builtins.int
    PERCENT_NEW_VISITORS_FIELD_NUMBER: builtins.int
    PHONE_CALLS_FIELD_NUMBER: builtins.int
    PHONE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PHONE_THROUGH_RATE_FIELD_NUMBER: builtins.int
    RELATIVE_CTR_FIELD_NUMBER: builtins.int
    SEARCH_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_CLICK_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_EXACT_MATCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SPEED_SCORE_FIELD_NUMBER: builtins.int
    TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALID_ACCELERATED_MOBILE_PAGES_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSION_FIELD_NUMBER: builtins.int
    VALUE_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_100_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_25_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_50_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_75_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEW_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEWS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_CONVERSIONS_FIELD_NUMBER: builtins.int
    historical_creative_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_landing_page_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_search_predicted_ctr: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    interaction_event_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
    ] = ...
    @property
    def absolute_top_impression_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_cpm(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_measurability(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_measurable_cost_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_measurable_impressions(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_viewability(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_click_to_call(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_directions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_menu(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_order(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_other_engagement(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_store_visit(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_store_website(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpc(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpe(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpm(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpv(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_page_views(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_time_on_site(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def benchmark_average_max_cpc(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def benchmark_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bounce_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def combined_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def combined_clicks_per_query(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def combined_queries(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def content_budget_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def content_impression_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversion_last_received_request_date_time(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def conversion_last_conversion_date(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def content_rank_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_per_all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_per_conversion(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_per_current_model_attributed_conversion(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cross_device_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def engagement_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def engagements(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def hotel_average_lead_value_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def hotel_price_difference_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def hotel_eligible_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def historical_quality_score(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_forwards(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_saves(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_secondary_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions_from_store_reach(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def interaction_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def interactions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def invalid_click_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def invalid_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_chats(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_chat_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def mobile_friendly_clicks_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def organic_clicks_per_query(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def organic_impressions_per_query(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_queries(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def percent_new_visitors(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def phone_calls(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def phone_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def phone_through_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def relative_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_click_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_exact_match_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_impression_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def speed_score(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_impression_percentage(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def valid_accelerated_mobile_pages_clicks_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_conversion(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_current_model_attributed_conversion(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_100_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_25_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_50_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_75_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_view_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_views(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def view_through_conversions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        absolute_top_impression_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_cpm: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_ctr: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_measurability: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_measurable_cost_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_measurable_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_viewability: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_click_to_call: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_directions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_menu: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_order: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_other_engagement: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_store_visit: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_store_website: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        average_cost: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpc: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpe: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpm: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpv: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_page_views: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        average_time_on_site: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        benchmark_average_max_cpc: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        benchmark_ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        bounce_rate: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        combined_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        combined_clicks_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        combined_queries: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        content_budget_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        content_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversion_last_received_request_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        conversion_last_conversion_date: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        content_rank_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_per_all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cost_per_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cost_per_current_model_attributed_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cross_device_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        current_model_attributed_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        engagement_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        engagements: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        hotel_average_lead_value_micros: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        hotel_price_difference_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        hotel_eligible_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        historical_creative_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_landing_page_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_quality_score: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        historical_search_predicted_ctr: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        gmail_forwards: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        gmail_saves: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        gmail_secondary_clicks: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        impressions_from_store_reach: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        interaction_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        interactions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        interaction_event_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
            ]
        ] = ...,
        invalid_click_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        invalid_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        message_chats: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        message_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        message_chat_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        mobile_friendly_clicks_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        organic_clicks_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        organic_impressions_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_queries: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        percent_new_visitors: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        phone_calls: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        phone_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        phone_through_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        relative_ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        search_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_click_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_exact_match_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        speed_score: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_impression_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        valid_accelerated_mobile_pages_clicks_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_current_model_attributed_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_100_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_25_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_50_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_75_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_view_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_views: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        view_through_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_quality_score",
            b"historical_quality_score",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_100_rate",
            b"video_quartile_100_rate",
            "video_quartile_25_rate",
            b"video_quartile_25_rate",
            "video_quartile_50_rate",
            b"video_quartile_50_rate",
            "video_quartile_75_rate",
            b"video_quartile_75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_creative_quality_score",
            b"historical_creative_quality_score",
            "historical_landing_page_quality_score",
            b"historical_landing_page_quality_score",
            "historical_quality_score",
            b"historical_quality_score",
            "historical_search_predicted_ctr",
            b"historical_search_predicted_ctr",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_event_types",
            b"interaction_event_types",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_100_rate",
            b"video_quartile_100_rate",
            "video_quartile_25_rate",
            b"video_quartile_25_rate",
            "video_quartile_50_rate",
            b"video_quartile_50_rate",
            "video_quartile_75_rate",
            b"video_quartile_75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> None: ...

global___Metrics = Metrics
