"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdvertisingChannelTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdvertisingChannelType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdvertisingChannelType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(0)
        UNKNOWN = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(1)
        SEARCH = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(2)
        DISPLAY = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(3)
        SHOPPING = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(4)
        HOTEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(5)
        VIDEO = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(6)
        MULTI_CHANNEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(7)
        LOCAL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(8)
        SMART = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(9)
    class AdvertisingChannelType(metaclass=_AdvertisingChannelType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(0)
    UNKNOWN = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(1)
    SEARCH = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(2)
    DISPLAY = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(3)
    SHOPPING = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(4)
    HOTEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(5)
    VIDEO = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(6)
    MULTI_CHANNEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(7)
    LOCAL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(8)
    SMART = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(9)
    def __init__(
        self,
    ) -> None: ...

global___AdvertisingChannelTypeEnum = AdvertisingChannelTypeEnum
