"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.custom_audience_pb2
import grpc

from .custom_audience_service_pb2 import *

class CustomAudienceServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomAudience(
        self,
        request: global___GetCustomAudienceRequest,
    ) -> google.ads.google_ads.v6.proto.resources.custom_audience_pb2.CustomAudience: ...
    def MutateCustomAudiences(
        self,
        request: global___MutateCustomAudiencesRequest,
    ) -> global___MutateCustomAudiencesResponse: ...

class CustomAudienceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomAudience(
        self,
        request: global___GetCustomAudienceRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.custom_audience_pb2.CustomAudience: ...
    @abc.abstractmethod
    def MutateCustomAudiences(
        self,
        request: global___MutateCustomAudiencesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomAudiencesResponse: ...

def add_CustomAudienceServiceServicer_to_server(
    servicer: CustomAudienceServiceServicer, server: grpc.Server
) -> None: ...
