"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QueryError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QueryError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QueryErrorEnum.QueryError.V(0)
        UNKNOWN = QueryErrorEnum.QueryError.V(1)
        QUERY_ERROR = QueryErrorEnum.QueryError.V(50)
        BAD_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(18)
        BAD_ESCAPE_SEQUENCE = QueryErrorEnum.QueryError.V(7)
        BAD_FIELD_NAME = QueryErrorEnum.QueryError.V(12)
        BAD_LIMIT_VALUE = QueryErrorEnum.QueryError.V(15)
        BAD_NUMBER = QueryErrorEnum.QueryError.V(5)
        BAD_OPERATOR = QueryErrorEnum.QueryError.V(3)
        BAD_PARAMETER_NAME = QueryErrorEnum.QueryError.V(61)
        BAD_PARAMETER_VALUE = QueryErrorEnum.QueryError.V(62)
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(45)
        BAD_SYMBOL = QueryErrorEnum.QueryError.V(2)
        BAD_VALUE = QueryErrorEnum.QueryError.V(4)
        DATE_RANGE_TOO_WIDE = QueryErrorEnum.QueryError.V(36)
        DATE_RANGE_TOO_NARROW = QueryErrorEnum.QueryError.V(60)
        EXPECTED_AND = QueryErrorEnum.QueryError.V(30)
        EXPECTED_BY = QueryErrorEnum.QueryError.V(14)
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(37)
        EXPECTED_FILTERS_ON_DATE_RANGE = QueryErrorEnum.QueryError.V(55)
        EXPECTED_FROM = QueryErrorEnum.QueryError.V(44)
        EXPECTED_LIST = QueryErrorEnum.QueryError.V(41)
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(16)
        EXPECTED_SELECT = QueryErrorEnum.QueryError.V(13)
        EXPECTED_SINGLE_VALUE = QueryErrorEnum.QueryError.V(42)
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(29)
        INVALID_DATE_FORMAT = QueryErrorEnum.QueryError.V(38)
        INVALID_STRING_VALUE = QueryErrorEnum.QueryError.V(57)
        INVALID_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(26)
        INVALID_VALUE_WITH_DURING_OPERATOR = QueryErrorEnum.QueryError.V(22)
        INVALID_VALUE_WITH_LIKE_OPERATOR = QueryErrorEnum.QueryError.V(56)
        OPERATOR_FIELD_MISMATCH = QueryErrorEnum.QueryError.V(35)
        PROHIBITED_EMPTY_LIST_IN_CONDITION = QueryErrorEnum.QueryError.V(28)
        PROHIBITED_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(54)
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(31)
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = QueryErrorEnum.QueryError.V(40)
        PROHIBITED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(23)
        PROHIBITED_FIELD_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(24)
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(43)
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(48)
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(58)
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(49)
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(51)
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = (
            QueryErrorEnum.QueryError.V(53)
        )
        LIMIT_VALUE_TOO_LOW = QueryErrorEnum.QueryError.V(25)
        PROHIBITED_NEWLINE_IN_STRING = QueryErrorEnum.QueryError.V(8)
        PROHIBITED_VALUE_COMBINATION_IN_LIST = QueryErrorEnum.QueryError.V(10)
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = (
            QueryErrorEnum.QueryError.V(21)
        )
        STRING_NOT_TERMINATED = QueryErrorEnum.QueryError.V(6)
        TOO_MANY_SEGMENTS = QueryErrorEnum.QueryError.V(34)
        UNEXPECTED_END_OF_QUERY = QueryErrorEnum.QueryError.V(9)
        UNEXPECTED_FROM_CLAUSE = QueryErrorEnum.QueryError.V(47)
        UNRECOGNIZED_FIELD = QueryErrorEnum.QueryError.V(32)
        UNEXPECTED_INPUT = QueryErrorEnum.QueryError.V(11)
        REQUESTED_METRICS_FOR_MANAGER = QueryErrorEnum.QueryError.V(59)
        FILTER_HAS_TOO_MANY_VALUES = QueryErrorEnum.QueryError.V(63)
    class QueryError(metaclass=_QueryError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QueryErrorEnum.QueryError.V(0)
    UNKNOWN = QueryErrorEnum.QueryError.V(1)
    QUERY_ERROR = QueryErrorEnum.QueryError.V(50)
    BAD_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(18)
    BAD_ESCAPE_SEQUENCE = QueryErrorEnum.QueryError.V(7)
    BAD_FIELD_NAME = QueryErrorEnum.QueryError.V(12)
    BAD_LIMIT_VALUE = QueryErrorEnum.QueryError.V(15)
    BAD_NUMBER = QueryErrorEnum.QueryError.V(5)
    BAD_OPERATOR = QueryErrorEnum.QueryError.V(3)
    BAD_PARAMETER_NAME = QueryErrorEnum.QueryError.V(61)
    BAD_PARAMETER_VALUE = QueryErrorEnum.QueryError.V(62)
    BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(45)
    BAD_SYMBOL = QueryErrorEnum.QueryError.V(2)
    BAD_VALUE = QueryErrorEnum.QueryError.V(4)
    DATE_RANGE_TOO_WIDE = QueryErrorEnum.QueryError.V(36)
    DATE_RANGE_TOO_NARROW = QueryErrorEnum.QueryError.V(60)
    EXPECTED_AND = QueryErrorEnum.QueryError.V(30)
    EXPECTED_BY = QueryErrorEnum.QueryError.V(14)
    EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(37)
    EXPECTED_FILTERS_ON_DATE_RANGE = QueryErrorEnum.QueryError.V(55)
    EXPECTED_FROM = QueryErrorEnum.QueryError.V(44)
    EXPECTED_LIST = QueryErrorEnum.QueryError.V(41)
    EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(16)
    EXPECTED_SELECT = QueryErrorEnum.QueryError.V(13)
    EXPECTED_SINGLE_VALUE = QueryErrorEnum.QueryError.V(42)
    EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(29)
    INVALID_DATE_FORMAT = QueryErrorEnum.QueryError.V(38)
    INVALID_STRING_VALUE = QueryErrorEnum.QueryError.V(57)
    INVALID_VALUE_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(26)
    INVALID_VALUE_WITH_DURING_OPERATOR = QueryErrorEnum.QueryError.V(22)
    INVALID_VALUE_WITH_LIKE_OPERATOR = QueryErrorEnum.QueryError.V(56)
    OPERATOR_FIELD_MISMATCH = QueryErrorEnum.QueryError.V(35)
    PROHIBITED_EMPTY_LIST_IN_CONDITION = QueryErrorEnum.QueryError.V(28)
    PROHIBITED_ENUM_CONSTANT = QueryErrorEnum.QueryError.V(54)
    PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(31)
    PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = QueryErrorEnum.QueryError.V(40)
    PROHIBITED_FIELD_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(23)
    PROHIBITED_FIELD_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(24)
    PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = QueryErrorEnum.QueryError.V(43)
    PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = QueryErrorEnum.QueryError.V(48)
    PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(58)
    PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(49)
    PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = QueryErrorEnum.QueryError.V(51)
    PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = (
        QueryErrorEnum.QueryError.V(53)
    )
    LIMIT_VALUE_TOO_LOW = QueryErrorEnum.QueryError.V(25)
    PROHIBITED_NEWLINE_IN_STRING = QueryErrorEnum.QueryError.V(8)
    PROHIBITED_VALUE_COMBINATION_IN_LIST = QueryErrorEnum.QueryError.V(10)
    PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = QueryErrorEnum.QueryError.V(21)
    STRING_NOT_TERMINATED = QueryErrorEnum.QueryError.V(6)
    TOO_MANY_SEGMENTS = QueryErrorEnum.QueryError.V(34)
    UNEXPECTED_END_OF_QUERY = QueryErrorEnum.QueryError.V(9)
    UNEXPECTED_FROM_CLAUSE = QueryErrorEnum.QueryError.V(47)
    UNRECOGNIZED_FIELD = QueryErrorEnum.QueryError.V(32)
    UNEXPECTED_INPUT = QueryErrorEnum.QueryError.V(11)
    REQUESTED_METRICS_FOR_MANAGER = QueryErrorEnum.QueryError.V(59)
    FILTER_HAS_TOO_MANY_VALUES = QueryErrorEnum.QueryError.V(63)
    def __init__(
        self,
    ) -> None: ...

global___QueryErrorEnum = QueryErrorEnum
