"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionFeedItemErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionFeedItemError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtensionFeedItemError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(0)
        UNKNOWN = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(1)
        VALUE_OUT_OF_RANGE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(2)
        URL_LIST_TOO_LONG = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(3)
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(4)
        )
        CANNOT_SET_WITH_FINAL_URLS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(5)
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(6)
        )
        INVALID_PHONE_NUMBER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(7)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(8)
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(9)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(10)
        )
        DISALLOWED_NUMBER_TYPE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(11)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(12)
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(13)
        )
        INVALID_CALL_CONVERSION_ACTION = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(14)
        )
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(15)
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(16)
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(17)
        )
        INVALID_APP_ID = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(18)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(19)
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(20)
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(21)
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(22)
        )
        INCONSISTENT_CURRENCY_CODES = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(23)
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(24)
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(25)
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(26)
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(27)
        )
        UNSUPPORTED_VALUE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(28)
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(29)
        )
        INVALID_DEVICE_PREFERENCE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            30
        )
        INVALID_SCHEDULE_END = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(31)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(32)
        )
        INVALID_SNIPPETS_HEADER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            33
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(34)
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(35)
        )
        CONFLICTING_CALL_CONVERSION_SETTINGS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(36)
        )
        EXTENSION_TYPE_MISMATCH = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
            37
        )
        EXTENSION_SUBTYPE_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(38)
        )
        EXTENSION_TYPE_UNSUPPORTED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(39)
        )
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(40)
        )
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(41)
        )
        INVALID_PRICE_FORMAT = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(42)
        PROMOTION_INVALID_TIME = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(43)
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(44)
        )
        CONCRETE_EXTENSION_TYPE_REQUIRED = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(45)
        )
        SCHEDULE_END_NOT_AFTER_START = (
            ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(46)
        )
    class ExtensionFeedItemError(metaclass=_ExtensionFeedItemError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(0)
    UNKNOWN = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(1)
    VALUE_OUT_OF_RANGE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(2)
    URL_LIST_TOO_LONG = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(3)
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(4)
    )
    CANNOT_SET_WITH_FINAL_URLS = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(5)
    CANNOT_SET_WITHOUT_FINAL_URLS = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        6
    )
    INVALID_PHONE_NUMBER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(7)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(8)
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(9)
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(10)
    )
    DISALLOWED_NUMBER_TYPE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(11)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(12)
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(13)
    )
    INVALID_CALL_CONVERSION_ACTION = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(14)
    )
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(15)
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(16)
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(17)
    )
    INVALID_APP_ID = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(18)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(19)
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(20)
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(21)
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(22)
    )
    INCONSISTENT_CURRENCY_CODES = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        23
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(24)
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(25)
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(26)
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(27)
    )
    UNSUPPORTED_VALUE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(28)
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(29)
    )
    INVALID_DEVICE_PREFERENCE = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(30)
    INVALID_SCHEDULE_END = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(31)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(32)
    )
    INVALID_SNIPPETS_HEADER = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(33)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(34)
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(35)
    )
    CONFLICTING_CALL_CONVERSION_SETTINGS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(36)
    )
    EXTENSION_TYPE_MISMATCH = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(37)
    EXTENSION_SUBTYPE_REQUIRED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(38)
    EXTENSION_TYPE_UNSUPPORTED = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(39)
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(40)
    )
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(41)
    )
    INVALID_PRICE_FORMAT = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(42)
    PROMOTION_INVALID_TIME = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(43)
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(44)
    )
    CONCRETE_EXTENSION_TYPE_REQUIRED = (
        ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(45)
    )
    SCHEDULE_END_NOT_AFTER_START = ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V(
        46
    )
    def __init__(
        self,
    ) -> None: ...

global___ExtensionFeedItemErrorEnum = ExtensionFeedItemErrorEnum
