"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2
import grpc

from .ad_group_extension_setting_service_pb2 import *

class AdGroupExtensionSettingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupExtensionSetting(
        self,
        request: global___GetAdGroupExtensionSettingRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting: ...
    def MutateAdGroupExtensionSettings(
        self,
        request: global___MutateAdGroupExtensionSettingsRequest,
    ) -> global___MutateAdGroupExtensionSettingsResponse: ...

class AdGroupExtensionSettingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupExtensionSetting(
        self,
        request: global___GetAdGroupExtensionSettingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting: ...
    @abc.abstractmethod
    def MutateAdGroupExtensionSettings(
        self,
        request: global___MutateAdGroupExtensionSettingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupExtensionSettingsResponse: ...

def add_AdGroupExtensionSettingServiceServicer_to_server(
    servicer: AdGroupExtensionSettingServiceServicer, server: grpc.Server
) -> None: ...
