"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerManagerLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerManagerLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerManagerLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(0)
        UNKNOWN = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(1)
        NO_PENDING_INVITE = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(2)
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(3)
        )
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(4)
        )
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(5)
        )
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(6)
        )
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(7)
        )
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(8)
        )
        DUPLICATE_CHILD_FOUND = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(
            9
        )
        TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = (
            CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(10)
        )
    class CustomerManagerLinkError(metaclass=_CustomerManagerLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(0)
    UNKNOWN = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(1)
    NO_PENDING_INVITE = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(2)
    SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(3)
    )
    MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(4)
    )
    CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(5)
    )
    CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(6)
    )
    CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(7)
    )
    CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(8)
    )
    DUPLICATE_CHILD_FOUND = CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(9)
    TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = (
        CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V(10)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerManagerLinkErrorEnum = CustomerManagerLinkErrorEnum
