"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_label_pb2
import grpc

from .ad_group_label_service_pb2 import *

class AdGroupLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupLabel(
        self,
        request: global___GetAdGroupLabelRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_label_pb2.AdGroupLabel: ...
    def MutateAdGroupLabels(
        self,
        request: global___MutateAdGroupLabelsRequest,
    ) -> global___MutateAdGroupLabelsResponse: ...

class AdGroupLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupLabel(
        self,
        request: global___GetAdGroupLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_label_pb2.AdGroupLabel: ...
    @abc.abstractmethod
    def MutateAdGroupLabels(
        self,
        request: global___MutateAdGroupLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupLabelsResponse: ...

def add_AdGroupLabelServiceServicer_to_server(
    servicer: AdGroupLabelServiceServicer, server: grpc.Server
) -> None: ...
