"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionCountingTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionCountingType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionCountingType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(0)
        UNKNOWN = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(1)
        ONE_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(
            2
        )
        MANY_PER_CLICK = (
            ConversionActionCountingTypeEnum.ConversionActionCountingType.V(3)
        )
    class ConversionActionCountingType(metaclass=_ConversionActionCountingType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(0)
    UNKNOWN = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(1)
    ONE_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(2)
    MANY_PER_CLICK = ConversionActionCountingTypeEnum.ConversionActionCountingType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionCountingTypeEnum = ConversionActionCountingTypeEnum
