"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PromotionExtensionOccasionEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PromotionExtensionOccasion(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PromotionExtensionOccasion.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(0)
        UNKNOWN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(1)
        NEW_YEARS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(2)
        CHINESE_NEW_YEAR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            3
        )
        VALENTINES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(4)
        EASTER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(5)
        MOTHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(6)
        FATHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(7)
        LABOR_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(8)
        BACK_TO_SCHOOL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(9)
        HALLOWEEN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(10)
        BLACK_FRIDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(11)
        CYBER_MONDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(12)
        CHRISTMAS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(13)
        BOXING_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(14)
        INDEPENDENCE_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            15
        )
        NATIONAL_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(16)
        END_OF_SEASON = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(17)
        WINTER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(18)
        SUMMER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(19)
        FALL_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(20)
        SPRING_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(21)
        RAMADAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(22)
        EID_AL_FITR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(23)
        EID_AL_ADHA = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(24)
        SINGLES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(25)
        WOMENS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(26)
        HOLI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(27)
        PARENTS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(28)
        ST_NICHOLAS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(
            29
        )
        CARNIVAL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(30)
        EPIPHANY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(31)
        ROSH_HASHANAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(32)
        PASSOVER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(33)
        HANUKKAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(34)
        DIWALI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(35)
        NAVRATRI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(36)
        SONGKRAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(37)
        YEAR_END_GIFT = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(38)
    class PromotionExtensionOccasion(metaclass=_PromotionExtensionOccasion):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(0)
    UNKNOWN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(1)
    NEW_YEARS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(2)
    CHINESE_NEW_YEAR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(3)
    VALENTINES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(4)
    EASTER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(5)
    MOTHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(6)
    FATHERS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(7)
    LABOR_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(8)
    BACK_TO_SCHOOL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(9)
    HALLOWEEN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(10)
    BLACK_FRIDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(11)
    CYBER_MONDAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(12)
    CHRISTMAS = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(13)
    BOXING_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(14)
    INDEPENDENCE_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(15)
    NATIONAL_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(16)
    END_OF_SEASON = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(17)
    WINTER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(18)
    SUMMER_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(19)
    FALL_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(20)
    SPRING_SALE = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(21)
    RAMADAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(22)
    EID_AL_FITR = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(23)
    EID_AL_ADHA = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(24)
    SINGLES_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(25)
    WOMENS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(26)
    HOLI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(27)
    PARENTS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(28)
    ST_NICHOLAS_DAY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(29)
    CARNIVAL = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(30)
    EPIPHANY = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(31)
    ROSH_HASHANAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(32)
    PASSOVER = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(33)
    HANUKKAH = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(34)
    DIWALI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(35)
    NAVRATRI = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(36)
    SONGKRAN = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(37)
    YEAR_END_GIFT = PromotionExtensionOccasionEnum.PromotionExtensionOccasion.V(38)
    def __init__(
        self,
    ) -> None: ...

global___PromotionExtensionOccasionEnum = PromotionExtensionOccasionEnum
