"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerMatchUploadKeyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerMatchUploadKeyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerMatchUploadKeyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(0)
        UNKNOWN = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(1)
        CONTACT_INFO = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(2)
        CRM_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(3)
        MOBILE_ADVERTISING_ID = (
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(4)
        )
    class CustomerMatchUploadKeyType(metaclass=_CustomerMatchUploadKeyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(0)
    UNKNOWN = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(1)
    CONTACT_INFO = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(2)
    CRM_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(3)
    MOBILE_ADVERTISING_ID = CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V(
        4
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerMatchUploadKeyTypeEnum = CustomerMatchUploadKeyTypeEnum
