"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.change_status_operation_pb2
import google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    LAST_CHANGE_DATE_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    RESOURCE_STATUS_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    resource_type: google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2.ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V = (
        ...
    )
    resource_status: google.ads.google_ads.v4.proto.enums.change_status_operation_pb2.ChangeStatusOperationEnum.ChangeStatusOperation.V = (
        ...
    )
    @property
    def last_change_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_ad(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_criterion(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_criterion(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def feed_item(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group_bid_modifier(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        last_change_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        resource_type: google.ads.google_ads.v4.proto.enums.change_status_resource_type_pb2.ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        resource_status: google.ads.google_ads.v4.proto.enums.change_status_operation_pb2.ChangeStatusOperationEnum.ChangeStatusOperation.V = ...,
        ad_group_ad: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_criterion: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        campaign_criterion: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        feed_item: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        campaign_feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group_bid_modifier: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
            "resource_name",
            b"resource_name",
            "resource_status",
            b"resource_status",
            "resource_type",
            b"resource_type",
        ],
    ) -> None: ...

global___ChangeStatus = ChangeStatus
