"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(0)
        UNKNOWN = ChangeStatusErrorEnum.ChangeStatusError.V(1)
        START_DATE_TOO_OLD = ChangeStatusErrorEnum.ChangeStatusError.V(3)
        CHANGE_DATE_RANGE_INFINITE = ChangeStatusErrorEnum.ChangeStatusError.V(4)
        CHANGE_DATE_RANGE_NEGATIVE = ChangeStatusErrorEnum.ChangeStatusError.V(5)
        LIMIT_NOT_SPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(6)
        INVALID_LIMIT_CLAUSE = ChangeStatusErrorEnum.ChangeStatusError.V(7)
    class ChangeStatusError(metaclass=_ChangeStatusError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(0)
    UNKNOWN = ChangeStatusErrorEnum.ChangeStatusError.V(1)
    START_DATE_TOO_OLD = ChangeStatusErrorEnum.ChangeStatusError.V(3)
    CHANGE_DATE_RANGE_INFINITE = ChangeStatusErrorEnum.ChangeStatusError.V(4)
    CHANGE_DATE_RANGE_NEGATIVE = ChangeStatusErrorEnum.ChangeStatusError.V(5)
    LIMIT_NOT_SPECIFIED = ChangeStatusErrorEnum.ChangeStatusError.V(6)
    INVALID_LIMIT_CLAUSE = ChangeStatusErrorEnum.ChangeStatusError.V(7)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusErrorEnum = ChangeStatusErrorEnum
