"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PriceExtensionPriceUnitEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PriceExtensionPriceUnit(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PriceExtensionPriceUnit.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(0)
        UNKNOWN = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(1)
        PER_HOUR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(2)
        PER_DAY = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(3)
        PER_WEEK = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(4)
        PER_MONTH = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(5)
        PER_YEAR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(6)
        PER_NIGHT = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(7)
    class PriceExtensionPriceUnit(metaclass=_PriceExtensionPriceUnit):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(0)
    UNKNOWN = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(1)
    PER_HOUR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(2)
    PER_DAY = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(3)
    PER_WEEK = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(4)
    PER_MONTH = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(5)
    PER_YEAR = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(6)
    PER_NIGHT = PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PriceExtensionPriceUnitEnum = PriceExtensionPriceUnitEnum
