"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupCriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupCriterionError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(0)
        UNKNOWN = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(1)
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(2)
        )
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(3)
        )
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(4)
        )
        TOO_MANY_OPERATIONS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(5)
        CANT_UPDATE_NEGATIVE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(6)
        CONCRETE_TYPE_REQUIRED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(7)
        BID_INCOMPATIBLE_WITH_ADGROUP = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(8)
        )
        CANNOT_TARGET_AND_EXCLUDE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(9)
        ILLEGAL_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(10)
        INVALID_KEYWORD_TEXT = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(11)
        INVALID_DESTINATION_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(12)
        MISSING_DESTINATION_URL_TAG = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(
            13
        )
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(14)
        )
        INVALID_USER_STATUS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(15)
        CANNOT_ADD_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(16)
        CANNOT_EXCLUDE_CRITERIA_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(17)
        )
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(27)
        )
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(28)
        )
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(29)
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(30)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(31)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(32)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(33)
        )
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(34)
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(35)
        )
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(36)
        )
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(37)
        )
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
            AdGroupCriterionErrorEnum.AdGroupCriterionError.V(38)
        )
    class AdGroupCriterionError(metaclass=_AdGroupCriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(0)
    UNKNOWN = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(1)
    AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(2)
    )
    AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(3)
    )
    CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(4)
    )
    TOO_MANY_OPERATIONS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(5)
    CANT_UPDATE_NEGATIVE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(6)
    CONCRETE_TYPE_REQUIRED = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(7)
    BID_INCOMPATIBLE_WITH_ADGROUP = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(8)
    CANNOT_TARGET_AND_EXCLUDE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(9)
    ILLEGAL_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(10)
    INVALID_KEYWORD_TEXT = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(11)
    INVALID_DESTINATION_URL = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(12)
    MISSING_DESTINATION_URL_TAG = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(13)
    KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(14)
    )
    INVALID_USER_STATUS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(15)
    CANNOT_ADD_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(16)
    CANNOT_EXCLUDE_CRITERIA_TYPE = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(17)
    CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(27)
    )
    OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(28)
    )
    CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(29)
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = AdGroupCriterionErrorEnum.AdGroupCriterionError.V(
        30
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(31)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(32)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(33)
    )
    CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(34)
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(35)
    )
    CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(36)
    )
    FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(37)
    )
    FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE = (
        AdGroupCriterionErrorEnum.AdGroupCriterionError.V(38)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupCriterionErrorEnum = AdGroupCriterionErrorEnum
