"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionTypeEnum.ConversionActionType.V(0)
        UNKNOWN = ConversionActionTypeEnum.ConversionActionType.V(1)
        AD_CALL = ConversionActionTypeEnum.ConversionActionType.V(2)
        CLICK_TO_CALL = ConversionActionTypeEnum.ConversionActionType.V(3)
        GOOGLE_PLAY_DOWNLOAD = ConversionActionTypeEnum.ConversionActionType.V(4)
        GOOGLE_PLAY_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(5)
        UPLOAD_CALLS = ConversionActionTypeEnum.ConversionActionType.V(6)
        UPLOAD_CLICKS = ConversionActionTypeEnum.ConversionActionType.V(7)
        WEBPAGE = ConversionActionTypeEnum.ConversionActionType.V(8)
        WEBSITE_CALL = ConversionActionTypeEnum.ConversionActionType.V(9)
        STORE_SALES_DIRECT_UPLOAD = ConversionActionTypeEnum.ConversionActionType.V(10)
        STORE_SALES = ConversionActionTypeEnum.ConversionActionType.V(11)
        FIREBASE_ANDROID_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(
            12
        )
        FIREBASE_ANDROID_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(13)
        )
        FIREBASE_ANDROID_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(14)
        FIREBASE_IOS_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(15)
        FIREBASE_IOS_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(
            16
        )
        FIREBASE_IOS_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(17)
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = (
            ConversionActionTypeEnum.ConversionActionType.V(18)
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(19)
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = (
            ConversionActionTypeEnum.ConversionActionType.V(20)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = (
            ConversionActionTypeEnum.ConversionActionType.V(21)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = (
            ConversionActionTypeEnum.ConversionActionType.V(22)
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = (
            ConversionActionTypeEnum.ConversionActionType.V(23)
        )
    class ConversionActionType(metaclass=_ConversionActionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionTypeEnum.ConversionActionType.V(0)
    UNKNOWN = ConversionActionTypeEnum.ConversionActionType.V(1)
    AD_CALL = ConversionActionTypeEnum.ConversionActionType.V(2)
    CLICK_TO_CALL = ConversionActionTypeEnum.ConversionActionType.V(3)
    GOOGLE_PLAY_DOWNLOAD = ConversionActionTypeEnum.ConversionActionType.V(4)
    GOOGLE_PLAY_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(5)
    UPLOAD_CALLS = ConversionActionTypeEnum.ConversionActionType.V(6)
    UPLOAD_CLICKS = ConversionActionTypeEnum.ConversionActionType.V(7)
    WEBPAGE = ConversionActionTypeEnum.ConversionActionType.V(8)
    WEBSITE_CALL = ConversionActionTypeEnum.ConversionActionType.V(9)
    STORE_SALES_DIRECT_UPLOAD = ConversionActionTypeEnum.ConversionActionType.V(10)
    STORE_SALES = ConversionActionTypeEnum.ConversionActionType.V(11)
    FIREBASE_ANDROID_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(12)
    FIREBASE_ANDROID_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(
        13
    )
    FIREBASE_ANDROID_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(14)
    FIREBASE_IOS_FIRST_OPEN = ConversionActionTypeEnum.ConversionActionType.V(15)
    FIREBASE_IOS_IN_APP_PURCHASE = ConversionActionTypeEnum.ConversionActionType.V(16)
    FIREBASE_IOS_CUSTOM = ConversionActionTypeEnum.ConversionActionType.V(17)
    THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = (
        ConversionActionTypeEnum.ConversionActionType.V(18)
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = (
        ConversionActionTypeEnum.ConversionActionType.V(19)
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = (
        ConversionActionTypeEnum.ConversionActionType.V(20)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = (
        ConversionActionTypeEnum.ConversionActionType.V(21)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = (
        ConversionActionTypeEnum.ConversionActionType.V(22)
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = (
        ConversionActionTypeEnum.ConversionActionType.V(23)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionTypeEnum = ConversionActionTypeEnum
