"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NewResourceCreationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _NewResourceCreationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NewResourceCreationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = NewResourceCreationErrorEnum.NewResourceCreationError.V(0)
        UNKNOWN = NewResourceCreationErrorEnum.NewResourceCreationError.V(1)
        CANNOT_SET_ID_FOR_CREATE = (
            NewResourceCreationErrorEnum.NewResourceCreationError.V(2)
        )
        DUPLICATE_TEMP_IDS = NewResourceCreationErrorEnum.NewResourceCreationError.V(3)
        TEMP_ID_RESOURCE_HAD_ERRORS = (
            NewResourceCreationErrorEnum.NewResourceCreationError.V(4)
        )
    class NewResourceCreationError(metaclass=_NewResourceCreationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = NewResourceCreationErrorEnum.NewResourceCreationError.V(0)
    UNKNOWN = NewResourceCreationErrorEnum.NewResourceCreationError.V(1)
    CANNOT_SET_ID_FOR_CREATE = NewResourceCreationErrorEnum.NewResourceCreationError.V(
        2
    )
    DUPLICATE_TEMP_IDS = NewResourceCreationErrorEnum.NewResourceCreationError.V(3)
    TEMP_ID_RESOURCE_HAD_ERRORS = (
        NewResourceCreationErrorEnum.NewResourceCreationError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___NewResourceCreationErrorEnum = NewResourceCreationErrorEnum
