"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_pb2
import grpc

from .campaign_service_pb2 import *

class CampaignServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaign(
        self,
        request: global___GetCampaignRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_pb2.Campaign: ...
    def MutateCampaigns(
        self,
        request: global___MutateCampaignsRequest,
    ) -> global___MutateCampaignsResponse: ...

class CampaignServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaign(
        self,
        request: global___GetCampaignRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_pb2.Campaign: ...
    @abc.abstractmethod
    def MutateCampaigns(
        self,
        request: global___MutateCampaignsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignsResponse: ...

def add_CampaignServiceServicer_to_server(
    servicer: CampaignServiceServicer, server: grpc.Server
) -> None: ...
