"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CriterionError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionErrorEnum.CriterionError.V(0)
        UNKNOWN = CriterionErrorEnum.CriterionError.V(1)
        CONCRETE_TYPE_REQUIRED = CriterionErrorEnum.CriterionError.V(2)
        INVALID_EXCLUDED_CATEGORY = CriterionErrorEnum.CriterionError.V(3)
        INVALID_KEYWORD_TEXT = CriterionErrorEnum.CriterionError.V(4)
        KEYWORD_TEXT_TOO_LONG = CriterionErrorEnum.CriterionError.V(5)
        KEYWORD_HAS_TOO_MANY_WORDS = CriterionErrorEnum.CriterionError.V(6)
        KEYWORD_HAS_INVALID_CHARS = CriterionErrorEnum.CriterionError.V(7)
        INVALID_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(8)
        INVALID_USER_LIST = CriterionErrorEnum.CriterionError.V(9)
        INVALID_USER_INTEREST = CriterionErrorEnum.CriterionError.V(10)
        INVALID_FORMAT_FOR_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(11)
        PLACEMENT_URL_IS_TOO_LONG = CriterionErrorEnum.CriterionError.V(12)
        PLACEMENT_URL_HAS_ILLEGAL_CHAR = CriterionErrorEnum.CriterionError.V(13)
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = CriterionErrorEnum.CriterionError.V(
            14
        )
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = (
            CriterionErrorEnum.CriterionError.V(15)
        )
        INVALID_TOPIC_PATH = CriterionErrorEnum.CriterionError.V(16)
        INVALID_YOUTUBE_CHANNEL_ID = CriterionErrorEnum.CriterionError.V(17)
        INVALID_YOUTUBE_VIDEO_ID = CriterionErrorEnum.CriterionError.V(18)
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(19)
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(20)
        YOUTUBE_URL_UNSUPPORTED = CriterionErrorEnum.CriterionError.V(21)
        CANNOT_EXCLUDE_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(22)
        CANNOT_ADD_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(23)
        CANNOT_EXCLUDE_SIMILAR_USER_LIST = CriterionErrorEnum.CriterionError.V(26)
        CANNOT_ADD_CLOSED_USER_LIST = CriterionErrorEnum.CriterionError.V(27)
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(28)
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(29)
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(30)
        )
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(31)
        )
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(32)
        )
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = (
            CriterionErrorEnum.CriterionError.V(33)
        )
        INVALID_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(122)
        INVALID_CUSTOM_AFFINITY = CriterionErrorEnum.CriterionError.V(96)
        INVALID_CUSTOM_INTENT = CriterionErrorEnum.CriterionError.V(97)
        INVALID_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(121)
        INVALID_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(34)
        INVALID_IP_FORMAT = CriterionErrorEnum.CriterionError.V(35)
        INVALID_MOBILE_APP = CriterionErrorEnum.CriterionError.V(36)
        INVALID_MOBILE_APP_CATEGORY = CriterionErrorEnum.CriterionError.V(37)
        INVALID_CRITERION_ID = CriterionErrorEnum.CriterionError.V(38)
        CANNOT_TARGET_CRITERION = CriterionErrorEnum.CriterionError.V(39)
        CANNOT_TARGET_OBSOLETE_CRITERION = CriterionErrorEnum.CriterionError.V(40)
        CRITERION_ID_AND_TYPE_MISMATCH = CriterionErrorEnum.CriterionError.V(41)
        INVALID_PROXIMITY_RADIUS = CriterionErrorEnum.CriterionError.V(42)
        INVALID_PROXIMITY_RADIUS_UNITS = CriterionErrorEnum.CriterionError.V(43)
        INVALID_STREETADDRESS_LENGTH = CriterionErrorEnum.CriterionError.V(44)
        INVALID_CITYNAME_LENGTH = CriterionErrorEnum.CriterionError.V(45)
        INVALID_REGIONCODE_LENGTH = CriterionErrorEnum.CriterionError.V(46)
        INVALID_REGIONNAME_LENGTH = CriterionErrorEnum.CriterionError.V(47)
        INVALID_POSTALCODE_LENGTH = CriterionErrorEnum.CriterionError.V(48)
        INVALID_COUNTRY_CODE = CriterionErrorEnum.CriterionError.V(49)
        INVALID_LATITUDE = CriterionErrorEnum.CriterionError.V(50)
        INVALID_LONGITUDE = CriterionErrorEnum.CriterionError.V(51)
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = (
            CriterionErrorEnum.CriterionError.V(52)
        )
        INVALID_PROXIMITY_ADDRESS = CriterionErrorEnum.CriterionError.V(53)
        INVALID_USER_DOMAIN_NAME = CriterionErrorEnum.CriterionError.V(54)
        CRITERION_PARAMETER_TOO_LONG = CriterionErrorEnum.CriterionError.V(55)
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP = CriterionErrorEnum.CriterionError.V(56)
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = (
            CriterionErrorEnum.CriterionError.V(57)
        )
        AD_SCHEDULE_INVALID_TIME_INTERVAL = CriterionErrorEnum.CriterionError.V(58)
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = (
            CriterionErrorEnum.CriterionError.V(59)
        )
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = (
            CriterionErrorEnum.CriterionError.V(60)
        )
        CANNOT_BID_MODIFY_CRITERION_TYPE = CriterionErrorEnum.CriterionError.V(61)
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = (
            CriterionErrorEnum.CriterionError.V(62)
        )
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION = CriterionErrorEnum.CriterionError.V(63)
        BID_MODIFIER_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(64)
        FEED_ID_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(65)
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(66)
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = (
            CriterionErrorEnum.CriterionError.V(67)
        )
        CANNOT_EXCLUDE_CRITERION = CriterionErrorEnum.CriterionError.V(68)
        CANNOT_REMOVE_CRITERION = CriterionErrorEnum.CriterionError.V(69)
        INVALID_PRODUCT_BIDDING_CATEGORY = CriterionErrorEnum.CriterionError.V(76)
        MISSING_SHOPPING_SETTING = CriterionErrorEnum.CriterionError.V(77)
        INVALID_MATCHING_FUNCTION = CriterionErrorEnum.CriterionError.V(78)
        LOCATION_FILTER_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(79)
        INVALID_FEED_FOR_LOCATION_FILTER = CriterionErrorEnum.CriterionError.V(98)
        LOCATION_FILTER_INVALID = CriterionErrorEnum.CriterionError.V(80)
        CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS = (
            CriterionErrorEnum.CriterionError.V(123)
        )
        INVALID_LOCATION_GROUP_RADIUS = CriterionErrorEnum.CriterionError.V(124)
        INVALID_LOCATION_GROUP_RADIUS_UNIT = CriterionErrorEnum.CriterionError.V(125)
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = (
            CriterionErrorEnum.CriterionError.V(81)
        )
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = (
            CriterionErrorEnum.CriterionError.V(82)
        )
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = (
            CriterionErrorEnum.CriterionError.V(83)
        )
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = (
            CriterionErrorEnum.CriterionError.V(84)
        )
        INVALID_WEBPAGE_CONDITION = CriterionErrorEnum.CriterionError.V(85)
        INVALID_WEBPAGE_CONDITION_URL = CriterionErrorEnum.CriterionError.V(86)
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = CriterionErrorEnum.CriterionError.V(87)
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = (
            CriterionErrorEnum.CriterionError.V(88)
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = (
            CriterionErrorEnum.CriterionError.V(89)
        )
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = (
            CriterionErrorEnum.CriterionError.V(90)
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = (
            CriterionErrorEnum.CriterionError.V(91)
        )
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = (
            CriterionErrorEnum.CriterionError.V(92)
        )
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = (
            CriterionErrorEnum.CriterionError.V(93)
        )
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = (
            CriterionErrorEnum.CriterionError.V(94)
        )
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = (
            CriterionErrorEnum.CriterionError.V(95)
        )
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(99)
        )
        CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS = (
            CriterionErrorEnum.CriterionError.V(126)
        )
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = CriterionErrorEnum.CriterionError.V(
            100
        )
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS = CriterionErrorEnum.CriterionError.V(101)
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = CriterionErrorEnum.CriterionError.V(
            102
        )
        DUPLICATE_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(103)
        DUPLICATE_LISTING_DIMENSION_VALUE = CriterionErrorEnum.CriterionError.V(104)
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = (
            CriterionErrorEnum.CriterionError.V(105)
        )
        INVALID_LISTING_GROUP_HIERARCHY = CriterionErrorEnum.CriterionError.V(106)
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = CriterionErrorEnum.CriterionError.V(
            107
        )
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = (
            CriterionErrorEnum.CriterionError.V(108)
        )
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = (
            CriterionErrorEnum.CriterionError.V(109)
        )
        LISTING_GROUP_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(110)
        LISTING_GROUP_DOES_NOT_EXIST = CriterionErrorEnum.CriterionError.V(111)
        LISTING_GROUP_CANNOT_BE_REMOVED = CriterionErrorEnum.CriterionError.V(112)
        INVALID_LISTING_GROUP_TYPE = CriterionErrorEnum.CriterionError.V(113)
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = CriterionErrorEnum.CriterionError.V(
            114
        )
        LISTING_SCOPE_TOO_LONG = CriterionErrorEnum.CriterionError.V(115)
        LISTING_SCOPE_TOO_MANY_DIMENSIONS = CriterionErrorEnum.CriterionError.V(116)
        LISTING_GROUP_TOO_LONG = CriterionErrorEnum.CriterionError.V(117)
        LISTING_GROUP_TREE_TOO_DEEP = CriterionErrorEnum.CriterionError.V(118)
        INVALID_LISTING_DIMENSION = CriterionErrorEnum.CriterionError.V(119)
        INVALID_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(120)
        ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY = (
            CriterionErrorEnum.CriterionError.V(127)
        )
        CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(
            128
        )
        INVALID_COMBINED_AUDIENCE_ID = CriterionErrorEnum.CriterionError.V(129)
        CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(130)
    class CriterionError(metaclass=_CriterionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionErrorEnum.CriterionError.V(0)
    UNKNOWN = CriterionErrorEnum.CriterionError.V(1)
    CONCRETE_TYPE_REQUIRED = CriterionErrorEnum.CriterionError.V(2)
    INVALID_EXCLUDED_CATEGORY = CriterionErrorEnum.CriterionError.V(3)
    INVALID_KEYWORD_TEXT = CriterionErrorEnum.CriterionError.V(4)
    KEYWORD_TEXT_TOO_LONG = CriterionErrorEnum.CriterionError.V(5)
    KEYWORD_HAS_TOO_MANY_WORDS = CriterionErrorEnum.CriterionError.V(6)
    KEYWORD_HAS_INVALID_CHARS = CriterionErrorEnum.CriterionError.V(7)
    INVALID_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(8)
    INVALID_USER_LIST = CriterionErrorEnum.CriterionError.V(9)
    INVALID_USER_INTEREST = CriterionErrorEnum.CriterionError.V(10)
    INVALID_FORMAT_FOR_PLACEMENT_URL = CriterionErrorEnum.CriterionError.V(11)
    PLACEMENT_URL_IS_TOO_LONG = CriterionErrorEnum.CriterionError.V(12)
    PLACEMENT_URL_HAS_ILLEGAL_CHAR = CriterionErrorEnum.CriterionError.V(13)
    PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = CriterionErrorEnum.CriterionError.V(14)
    PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = (
        CriterionErrorEnum.CriterionError.V(15)
    )
    INVALID_TOPIC_PATH = CriterionErrorEnum.CriterionError.V(16)
    INVALID_YOUTUBE_CHANNEL_ID = CriterionErrorEnum.CriterionError.V(17)
    INVALID_YOUTUBE_VIDEO_ID = CriterionErrorEnum.CriterionError.V(18)
    YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(19)
    YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = CriterionErrorEnum.CriterionError.V(20)
    YOUTUBE_URL_UNSUPPORTED = CriterionErrorEnum.CriterionError.V(21)
    CANNOT_EXCLUDE_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(22)
    CANNOT_ADD_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(23)
    CANNOT_EXCLUDE_SIMILAR_USER_LIST = CriterionErrorEnum.CriterionError.V(26)
    CANNOT_ADD_CLOSED_USER_LIST = CriterionErrorEnum.CriterionError.V(27)
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(28)
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(29)
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(30)
    )
    CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = CriterionErrorEnum.CriterionError.V(
        31
    )
    CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(32)
    )
    CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = (
        CriterionErrorEnum.CriterionError.V(33)
    )
    INVALID_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(122)
    INVALID_CUSTOM_AFFINITY = CriterionErrorEnum.CriterionError.V(96)
    INVALID_CUSTOM_INTENT = CriterionErrorEnum.CriterionError.V(97)
    INVALID_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(121)
    INVALID_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(34)
    INVALID_IP_FORMAT = CriterionErrorEnum.CriterionError.V(35)
    INVALID_MOBILE_APP = CriterionErrorEnum.CriterionError.V(36)
    INVALID_MOBILE_APP_CATEGORY = CriterionErrorEnum.CriterionError.V(37)
    INVALID_CRITERION_ID = CriterionErrorEnum.CriterionError.V(38)
    CANNOT_TARGET_CRITERION = CriterionErrorEnum.CriterionError.V(39)
    CANNOT_TARGET_OBSOLETE_CRITERION = CriterionErrorEnum.CriterionError.V(40)
    CRITERION_ID_AND_TYPE_MISMATCH = CriterionErrorEnum.CriterionError.V(41)
    INVALID_PROXIMITY_RADIUS = CriterionErrorEnum.CriterionError.V(42)
    INVALID_PROXIMITY_RADIUS_UNITS = CriterionErrorEnum.CriterionError.V(43)
    INVALID_STREETADDRESS_LENGTH = CriterionErrorEnum.CriterionError.V(44)
    INVALID_CITYNAME_LENGTH = CriterionErrorEnum.CriterionError.V(45)
    INVALID_REGIONCODE_LENGTH = CriterionErrorEnum.CriterionError.V(46)
    INVALID_REGIONNAME_LENGTH = CriterionErrorEnum.CriterionError.V(47)
    INVALID_POSTALCODE_LENGTH = CriterionErrorEnum.CriterionError.V(48)
    INVALID_COUNTRY_CODE = CriterionErrorEnum.CriterionError.V(49)
    INVALID_LATITUDE = CriterionErrorEnum.CriterionError.V(50)
    INVALID_LONGITUDE = CriterionErrorEnum.CriterionError.V(51)
    PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = (
        CriterionErrorEnum.CriterionError.V(52)
    )
    INVALID_PROXIMITY_ADDRESS = CriterionErrorEnum.CriterionError.V(53)
    INVALID_USER_DOMAIN_NAME = CriterionErrorEnum.CriterionError.V(54)
    CRITERION_PARAMETER_TOO_LONG = CriterionErrorEnum.CriterionError.V(55)
    AD_SCHEDULE_TIME_INTERVALS_OVERLAP = CriterionErrorEnum.CriterionError.V(56)
    AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = (
        CriterionErrorEnum.CriterionError.V(57)
    )
    AD_SCHEDULE_INVALID_TIME_INTERVAL = CriterionErrorEnum.CriterionError.V(58)
    AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = CriterionErrorEnum.CriterionError.V(
        59
    )
    AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = CriterionErrorEnum.CriterionError.V(
        60
    )
    CANNOT_BID_MODIFY_CRITERION_TYPE = CriterionErrorEnum.CriterionError.V(61)
    CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = (
        CriterionErrorEnum.CriterionError.V(62)
    )
    CANNOT_BID_MODIFY_NEGATIVE_CRITERION = CriterionErrorEnum.CriterionError.V(63)
    BID_MODIFIER_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(64)
    FEED_ID_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(65)
    ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = CriterionErrorEnum.CriterionError.V(66)
    CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = CriterionErrorEnum.CriterionError.V(67)
    CANNOT_EXCLUDE_CRITERION = CriterionErrorEnum.CriterionError.V(68)
    CANNOT_REMOVE_CRITERION = CriterionErrorEnum.CriterionError.V(69)
    INVALID_PRODUCT_BIDDING_CATEGORY = CriterionErrorEnum.CriterionError.V(76)
    MISSING_SHOPPING_SETTING = CriterionErrorEnum.CriterionError.V(77)
    INVALID_MATCHING_FUNCTION = CriterionErrorEnum.CriterionError.V(78)
    LOCATION_FILTER_NOT_ALLOWED = CriterionErrorEnum.CriterionError.V(79)
    INVALID_FEED_FOR_LOCATION_FILTER = CriterionErrorEnum.CriterionError.V(98)
    LOCATION_FILTER_INVALID = CriterionErrorEnum.CriterionError.V(80)
    CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS = (
        CriterionErrorEnum.CriterionError.V(123)
    )
    INVALID_LOCATION_GROUP_RADIUS = CriterionErrorEnum.CriterionError.V(124)
    INVALID_LOCATION_GROUP_RADIUS_UNIT = CriterionErrorEnum.CriterionError.V(125)
    CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = (
        CriterionErrorEnum.CriterionError.V(81)
    )
    HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = (
        CriterionErrorEnum.CriterionError.V(82)
    )
    HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = (
        CriterionErrorEnum.CriterionError.V(83)
    )
    FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = CriterionErrorEnum.CriterionError.V(84)
    INVALID_WEBPAGE_CONDITION = CriterionErrorEnum.CriterionError.V(85)
    INVALID_WEBPAGE_CONDITION_URL = CriterionErrorEnum.CriterionError.V(86)
    WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = CriterionErrorEnum.CriterionError.V(87)
    WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = CriterionErrorEnum.CriterionError.V(88)
    WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = CriterionErrorEnum.CriterionError.V(89)
    WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = (
        CriterionErrorEnum.CriterionError.V(90)
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = CriterionErrorEnum.CriterionError.V(
        91
    )
    WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = CriterionErrorEnum.CriterionError.V(
        92
    )
    WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = (
        CriterionErrorEnum.CriterionError.V(93)
    )
    WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = (
        CriterionErrorEnum.CriterionError.V(94)
    )
    WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = (
        CriterionErrorEnum.CriterionError.V(95)
    )
    CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = (
        CriterionErrorEnum.CriterionError.V(99)
    )
    CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS = CriterionErrorEnum.CriterionError.V(
        126
    )
    LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = CriterionErrorEnum.CriterionError.V(100)
    LISTING_SCOPE_TOO_MANY_IN_OPERATORS = CriterionErrorEnum.CriterionError.V(101)
    LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = CriterionErrorEnum.CriterionError.V(102)
    DUPLICATE_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(103)
    DUPLICATE_LISTING_DIMENSION_VALUE = CriterionErrorEnum.CriterionError.V(104)
    CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = CriterionErrorEnum.CriterionError.V(
        105
    )
    INVALID_LISTING_GROUP_HIERARCHY = CriterionErrorEnum.CriterionError.V(106)
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = CriterionErrorEnum.CriterionError.V(107)
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = (
        CriterionErrorEnum.CriterionError.V(108)
    )
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = (
        CriterionErrorEnum.CriterionError.V(109)
    )
    LISTING_GROUP_ALREADY_EXISTS = CriterionErrorEnum.CriterionError.V(110)
    LISTING_GROUP_DOES_NOT_EXIST = CriterionErrorEnum.CriterionError.V(111)
    LISTING_GROUP_CANNOT_BE_REMOVED = CriterionErrorEnum.CriterionError.V(112)
    INVALID_LISTING_GROUP_TYPE = CriterionErrorEnum.CriterionError.V(113)
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = CriterionErrorEnum.CriterionError.V(114)
    LISTING_SCOPE_TOO_LONG = CriterionErrorEnum.CriterionError.V(115)
    LISTING_SCOPE_TOO_MANY_DIMENSIONS = CriterionErrorEnum.CriterionError.V(116)
    LISTING_GROUP_TOO_LONG = CriterionErrorEnum.CriterionError.V(117)
    LISTING_GROUP_TREE_TOO_DEEP = CriterionErrorEnum.CriterionError.V(118)
    INVALID_LISTING_DIMENSION = CriterionErrorEnum.CriterionError.V(119)
    INVALID_LISTING_DIMENSION_TYPE = CriterionErrorEnum.CriterionError.V(120)
    ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY = (
        CriterionErrorEnum.CriterionError.V(127)
    )
    CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE = CriterionErrorEnum.CriterionError.V(128)
    INVALID_COMBINED_AUDIENCE_ID = CriterionErrorEnum.CriterionError.V(129)
    CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE = CriterionErrorEnum.CriterionError.V(130)
    def __init__(
        self,
    ) -> None: ...

global___CriterionErrorEnum = CriterionErrorEnum
