"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MobileAppVendorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MobileAppVendor(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MobileAppVendor.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MobileAppVendorEnum.MobileAppVendor.V(0)
        UNKNOWN = MobileAppVendorEnum.MobileAppVendor.V(1)
        APPLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(2)
        GOOGLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(3)
    class MobileAppVendor(metaclass=_MobileAppVendor):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MobileAppVendorEnum.MobileAppVendor.V(0)
    UNKNOWN = MobileAppVendorEnum.MobileAppVendor.V(1)
    APPLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(2)
    GOOGLE_APP_STORE = MobileAppVendorEnum.MobileAppVendor.V(3)
    def __init__(
        self,
    ) -> None: ...

global___MobileAppVendorEnum = MobileAppVendorEnum
