"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyApprovalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyApprovalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyApprovalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(0)
        UNKNOWN = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(1)
        DISAPPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(2)
        APPROVED_LIMITED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(3)
        APPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(4)
        AREA_OF_INTEREST_ONLY = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(5)
    class PolicyApprovalStatus(metaclass=_PolicyApprovalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(0)
    UNKNOWN = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(1)
    DISAPPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(2)
    APPROVED_LIMITED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(3)
    APPROVED = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(4)
    AREA_OF_INTEREST_ONLY = PolicyApprovalStatusEnum.PolicyApprovalStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___PolicyApprovalStatusEnum = PolicyApprovalStatusEnum
