"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtensionType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionTypeEnum.ExtensionType.V(0)
        UNKNOWN = ExtensionTypeEnum.ExtensionType.V(1)
        NONE = ExtensionTypeEnum.ExtensionType.V(2)
        APP = ExtensionTypeEnum.ExtensionType.V(3)
        CALL = ExtensionTypeEnum.ExtensionType.V(4)
        CALLOUT = ExtensionTypeEnum.ExtensionType.V(5)
        MESSAGE = ExtensionTypeEnum.ExtensionType.V(6)
        PRICE = ExtensionTypeEnum.ExtensionType.V(7)
        PROMOTION = ExtensionTypeEnum.ExtensionType.V(8)
        SITELINK = ExtensionTypeEnum.ExtensionType.V(10)
        STRUCTURED_SNIPPET = ExtensionTypeEnum.ExtensionType.V(11)
        LOCATION = ExtensionTypeEnum.ExtensionType.V(12)
        AFFILIATE_LOCATION = ExtensionTypeEnum.ExtensionType.V(13)
        HOTEL_CALLOUT = ExtensionTypeEnum.ExtensionType.V(15)
    class ExtensionType(metaclass=_ExtensionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionTypeEnum.ExtensionType.V(0)
    UNKNOWN = ExtensionTypeEnum.ExtensionType.V(1)
    NONE = ExtensionTypeEnum.ExtensionType.V(2)
    APP = ExtensionTypeEnum.ExtensionType.V(3)
    CALL = ExtensionTypeEnum.ExtensionType.V(4)
    CALLOUT = ExtensionTypeEnum.ExtensionType.V(5)
    MESSAGE = ExtensionTypeEnum.ExtensionType.V(6)
    PRICE = ExtensionTypeEnum.ExtensionType.V(7)
    PROMOTION = ExtensionTypeEnum.ExtensionType.V(8)
    SITELINK = ExtensionTypeEnum.ExtensionType.V(10)
    STRUCTURED_SNIPPET = ExtensionTypeEnum.ExtensionType.V(11)
    LOCATION = ExtensionTypeEnum.ExtensionType.V(12)
    AFFILIATE_LOCATION = ExtensionTypeEnum.ExtensionType.V(13)
    HOTEL_CALLOUT = ExtensionTypeEnum.ExtensionType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___ExtensionTypeEnum = ExtensionTypeEnum
