"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemTargetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemTargetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemTargetError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemTargetErrorEnum.FeedItemTargetError.V(0)
        UNKNOWN = FeedItemTargetErrorEnum.FeedItemTargetError.V(1)
        MUST_SET_TARGET_ONEOF_ON_CREATE = FeedItemTargetErrorEnum.FeedItemTargetError.V(
            2
        )
        FEED_ITEM_TARGET_ALREADY_EXISTS = FeedItemTargetErrorEnum.FeedItemTargetError.V(
            3
        )
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(4)
        )
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(5)
        )
        TOO_MANY_SCHEDULES_PER_DAY = FeedItemTargetErrorEnum.FeedItemTargetError.V(6)
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = (
            FeedItemTargetErrorEnum.FeedItemTargetError.V(7)
        )
        DUPLICATE_AD_SCHEDULE = FeedItemTargetErrorEnum.FeedItemTargetError.V(8)
        DUPLICATE_KEYWORD = FeedItemTargetErrorEnum.FeedItemTargetError.V(9)
    class FeedItemTargetError(metaclass=_FeedItemTargetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemTargetErrorEnum.FeedItemTargetError.V(0)
    UNKNOWN = FeedItemTargetErrorEnum.FeedItemTargetError.V(1)
    MUST_SET_TARGET_ONEOF_ON_CREATE = FeedItemTargetErrorEnum.FeedItemTargetError.V(2)
    FEED_ITEM_TARGET_ALREADY_EXISTS = FeedItemTargetErrorEnum.FeedItemTargetError.V(3)
    FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = FeedItemTargetErrorEnum.FeedItemTargetError.V(
        4
    )
    TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = (
        FeedItemTargetErrorEnum.FeedItemTargetError.V(5)
    )
    TOO_MANY_SCHEDULES_PER_DAY = FeedItemTargetErrorEnum.FeedItemTargetError.V(6)
    CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = (
        FeedItemTargetErrorEnum.FeedItemTargetError.V(7)
    )
    DUPLICATE_AD_SCHEDULE = FeedItemTargetErrorEnum.FeedItemTargetError.V(8)
    DUPLICATE_KEYWORD = FeedItemTargetErrorEnum.FeedItemTargetError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemTargetErrorEnum = FeedItemTargetErrorEnum
