"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_draft_pb2
import google.longrunning.operations_pb2
import grpc

from .campaign_draft_service_pb2 import *

class CampaignDraftServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignDraft(
        self,
        request: global___GetCampaignDraftRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_draft_pb2.CampaignDraft: ...
    def MutateCampaignDrafts(
        self,
        request: global___MutateCampaignDraftsRequest,
    ) -> global___MutateCampaignDraftsResponse: ...
    def PromoteCampaignDraft(
        self,
        request: global___PromoteCampaignDraftRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...
    def ListCampaignDraftAsyncErrors(
        self,
        request: global___ListCampaignDraftAsyncErrorsRequest,
    ) -> global___ListCampaignDraftAsyncErrorsResponse: ...

class CampaignDraftServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignDraft(
        self,
        request: global___GetCampaignDraftRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_draft_pb2.CampaignDraft: ...
    @abc.abstractmethod
    def MutateCampaignDrafts(
        self,
        request: global___MutateCampaignDraftsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignDraftsResponse: ...
    @abc.abstractmethod
    def PromoteCampaignDraft(
        self,
        request: global___PromoteCampaignDraftRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...
    @abc.abstractmethod
    def ListCampaignDraftAsyncErrors(
        self,
        request: global___ListCampaignDraftAsyncErrorsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListCampaignDraftAsyncErrorsResponse: ...

def add_CampaignDraftServiceServicer_to_server(
    servicer: CampaignDraftServiceServicer, server: grpc.Server
) -> None: ...
