"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetTypeEnum.AssetType.V(0)
        UNKNOWN = AssetTypeEnum.AssetType.V(1)
        YOUTUBE_VIDEO = AssetTypeEnum.AssetType.V(2)
        MEDIA_BUNDLE = AssetTypeEnum.AssetType.V(3)
        IMAGE = AssetTypeEnum.AssetType.V(4)
        TEXT = AssetTypeEnum.AssetType.V(5)
        LEAD_FORM = AssetTypeEnum.AssetType.V(6)
        BOOK_ON_GOOGLE = AssetTypeEnum.AssetType.V(7)
    class AssetType(metaclass=_AssetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetTypeEnum.AssetType.V(0)
    UNKNOWN = AssetTypeEnum.AssetType.V(1)
    YOUTUBE_VIDEO = AssetTypeEnum.AssetType.V(2)
    MEDIA_BUNDLE = AssetTypeEnum.AssetType.V(3)
    IMAGE = AssetTypeEnum.AssetType.V(4)
    TEXT = AssetTypeEnum.AssetType.V(5)
    LEAD_FORM = AssetTypeEnum.AssetType.V(6)
    BOOK_ON_GOOGLE = AssetTypeEnum.AssetType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AssetTypeEnum = AssetTypeEnum
