"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MerchantCenterLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MERCHANT_CENTER_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    merchant_center_account_name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2.MerchantCenterLinkStatusEnum.MerchantCenterLinkStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        merchant_center_account_name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.merchant_center_link_status_pb2.MerchantCenterLinkStatusEnum.MerchantCenterLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_merchant_center_account_name",
            b"_merchant_center_account_name",
            "id",
            b"id",
            "merchant_center_account_name",
            b"merchant_center_account_name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_merchant_center_account_name",
            b"_merchant_center_account_name",
            "id",
            b"id",
            "merchant_center_account_name",
            b"merchant_center_account_name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_merchant_center_account_name", b"_merchant_center_account_name"
        ],
    ) -> typing_extensions.Literal["merchant_center_account_name"]: ...

global___MerchantCenterLink = MerchantCenterLink
