"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TEST_ACCOUNT_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    client_customer: typing.Text = ...
    hidden: builtins.bool = ...
    level: builtins.int = ...
    time_zone: typing.Text = ...
    test_account: builtins.bool = ...
    manager: builtins.bool = ...
    descriptive_name: typing.Text = ...
    currency_code: typing.Text = ...
    id: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Text = ...,
        hidden: builtins.bool = ...,
        level: builtins.int = ...,
        time_zone: typing.Text = ...,
        test_account: builtins.bool = ...,
        manager: builtins.bool = ...,
        descriptive_name: typing.Text = ...,
        currency_code: typing.Text = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_client_customer", b"_client_customer"],
    ) -> typing_extensions.Literal["client_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions.Literal["descriptive_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hidden", b"_hidden"]
    ) -> typing_extensions.Literal["hidden"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_level", b"_level"]
    ) -> typing_extensions.Literal["level"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_manager", b"_manager"]
    ) -> typing_extensions.Literal["manager"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_test_account", b"_test_account"]
    ) -> typing_extensions.Literal["test_account"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions.Literal["time_zone"]: ...

global___CustomerClient = CustomerClient
