"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PaymentModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PaymentMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PaymentMode.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PaymentModeEnum.PaymentMode.V(0)
        UNKNOWN = PaymentModeEnum.PaymentMode.V(1)
        CLICKS = PaymentModeEnum.PaymentMode.V(4)
        CONVERSION_VALUE = PaymentModeEnum.PaymentMode.V(5)
        CONVERSIONS = PaymentModeEnum.PaymentMode.V(6)
        GUEST_STAY = PaymentModeEnum.PaymentMode.V(7)
    class PaymentMode(metaclass=_PaymentMode):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PaymentModeEnum.PaymentMode.V(0)
    UNKNOWN = PaymentModeEnum.PaymentMode.V(1)
    CLICKS = PaymentModeEnum.PaymentMode.V(4)
    CONVERSION_VALUE = PaymentModeEnum.PaymentMode.V(5)
    CONVERSIONS = PaymentModeEnum.PaymentMode.V(6)
    GUEST_STAY = PaymentModeEnum.PaymentMode.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PaymentModeEnum = PaymentModeEnum
