"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomAudienceMemberTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomAudienceMemberType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomAudienceMemberType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(0)
        UNKNOWN = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(1)
        KEYWORD = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(2)
        URL = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(3)
        PLACE_CATEGORY = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(4)
        APP = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(5)
    class CustomAudienceMemberType(metaclass=_CustomAudienceMemberType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(0)
    UNKNOWN = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(1)
    KEYWORD = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(2)
    URL = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(3)
    PLACE_CATEGORY = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(4)
    APP = CustomAudienceMemberTypeEnum.CustomAudienceMemberType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___CustomAudienceMemberTypeEnum = CustomAudienceMemberTypeEnum
