"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingStrategyTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingStrategyType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BiddingStrategyType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingStrategyTypeEnum.BiddingStrategyType.V(0)
        UNKNOWN = BiddingStrategyTypeEnum.BiddingStrategyType.V(1)
        COMMISSION = BiddingStrategyTypeEnum.BiddingStrategyType.V(16)
        ENHANCED_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(2)
        MANUAL_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(3)
        MANUAL_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(4)
        MANUAL_CPV = BiddingStrategyTypeEnum.BiddingStrategyType.V(13)
        MAXIMIZE_CONVERSIONS = BiddingStrategyTypeEnum.BiddingStrategyType.V(10)
        MAXIMIZE_CONVERSION_VALUE = BiddingStrategyTypeEnum.BiddingStrategyType.V(11)
        PAGE_ONE_PROMOTED = BiddingStrategyTypeEnum.BiddingStrategyType.V(5)
        PERCENT_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(12)
        TARGET_CPA = BiddingStrategyTypeEnum.BiddingStrategyType.V(6)
        TARGET_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(14)
        TARGET_IMPRESSION_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(15)
        TARGET_OUTRANK_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(7)
        TARGET_ROAS = BiddingStrategyTypeEnum.BiddingStrategyType.V(8)
        TARGET_SPEND = BiddingStrategyTypeEnum.BiddingStrategyType.V(9)
    class BiddingStrategyType(metaclass=_BiddingStrategyType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingStrategyTypeEnum.BiddingStrategyType.V(0)
    UNKNOWN = BiddingStrategyTypeEnum.BiddingStrategyType.V(1)
    COMMISSION = BiddingStrategyTypeEnum.BiddingStrategyType.V(16)
    ENHANCED_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(2)
    MANUAL_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(3)
    MANUAL_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(4)
    MANUAL_CPV = BiddingStrategyTypeEnum.BiddingStrategyType.V(13)
    MAXIMIZE_CONVERSIONS = BiddingStrategyTypeEnum.BiddingStrategyType.V(10)
    MAXIMIZE_CONVERSION_VALUE = BiddingStrategyTypeEnum.BiddingStrategyType.V(11)
    PAGE_ONE_PROMOTED = BiddingStrategyTypeEnum.BiddingStrategyType.V(5)
    PERCENT_CPC = BiddingStrategyTypeEnum.BiddingStrategyType.V(12)
    TARGET_CPA = BiddingStrategyTypeEnum.BiddingStrategyType.V(6)
    TARGET_CPM = BiddingStrategyTypeEnum.BiddingStrategyType.V(14)
    TARGET_IMPRESSION_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(15)
    TARGET_OUTRANK_SHARE = BiddingStrategyTypeEnum.BiddingStrategyType.V(7)
    TARGET_ROAS = BiddingStrategyTypeEnum.BiddingStrategyType.V(8)
    TARGET_SPEND = BiddingStrategyTypeEnum.BiddingStrategyType.V(9)
    def __init__(
        self,
    ) -> None: ...

global___BiddingStrategyTypeEnum = BiddingStrategyTypeEnum
