"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallConversionReportingStateEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CallConversionReportingState(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CallConversionReportingState.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CallConversionReportingStateEnum.CallConversionReportingState.V(0)
        UNKNOWN = CallConversionReportingStateEnum.CallConversionReportingState.V(1)
        DISABLED = CallConversionReportingStateEnum.CallConversionReportingState.V(2)
        USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION = (
            CallConversionReportingStateEnum.CallConversionReportingState.V(3)
        )
        USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION = (
            CallConversionReportingStateEnum.CallConversionReportingState.V(4)
        )
    class CallConversionReportingState(metaclass=_CallConversionReportingState):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CallConversionReportingStateEnum.CallConversionReportingState.V(0)
    UNKNOWN = CallConversionReportingStateEnum.CallConversionReportingState.V(1)
    DISABLED = CallConversionReportingStateEnum.CallConversionReportingState.V(2)
    USE_ACCOUNT_LEVEL_CALL_CONVERSION_ACTION = (
        CallConversionReportingStateEnum.CallConversionReportingState.V(3)
    )
    USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION = (
        CallConversionReportingStateEnum.CallConversionReportingState.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___CallConversionReportingStateEnum = CallConversionReportingStateEnum
