"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AgeRangeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AgeRangeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AgeRangeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AgeRangeTypeEnum.AgeRangeType.V(0)
        UNKNOWN = AgeRangeTypeEnum.AgeRangeType.V(1)
        AGE_RANGE_18_24 = AgeRangeTypeEnum.AgeRangeType.V(503001)
        AGE_RANGE_25_34 = AgeRangeTypeEnum.AgeRangeType.V(503002)
        AGE_RANGE_35_44 = AgeRangeTypeEnum.AgeRangeType.V(503003)
        AGE_RANGE_45_54 = AgeRangeTypeEnum.AgeRangeType.V(503004)
        AGE_RANGE_55_64 = AgeRangeTypeEnum.AgeRangeType.V(503005)
        AGE_RANGE_65_UP = AgeRangeTypeEnum.AgeRangeType.V(503006)
        AGE_RANGE_UNDETERMINED = AgeRangeTypeEnum.AgeRangeType.V(503999)
    class AgeRangeType(metaclass=_AgeRangeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AgeRangeTypeEnum.AgeRangeType.V(0)
    UNKNOWN = AgeRangeTypeEnum.AgeRangeType.V(1)
    AGE_RANGE_18_24 = AgeRangeTypeEnum.AgeRangeType.V(503001)
    AGE_RANGE_25_34 = AgeRangeTypeEnum.AgeRangeType.V(503002)
    AGE_RANGE_35_44 = AgeRangeTypeEnum.AgeRangeType.V(503003)
    AGE_RANGE_45_54 = AgeRangeTypeEnum.AgeRangeType.V(503004)
    AGE_RANGE_55_64 = AgeRangeTypeEnum.AgeRangeType.V(503005)
    AGE_RANGE_65_UP = AgeRangeTypeEnum.AgeRangeType.V(503006)
    AGE_RANGE_UNDETERMINED = AgeRangeTypeEnum.AgeRangeType.V(503999)
    def __init__(
        self,
    ) -> None: ...

global___AgeRangeTypeEnum = AgeRangeTypeEnum
