"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperationAccessDeniedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OperationAccessDeniedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OperationAccessDeniedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(0)
        UNKNOWN = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(1)
        ACTION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(2)
        )
        CREATE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(3)
        )
        REMOVE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(4)
        )
        UPDATE_OPERATION_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(5)
        )
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(6)
        )
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(7)
        )
        CREATE_AS_REMOVED_NOT_PERMITTED = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(8)
        )
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(9)
        )
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(10)
        )
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER = (
            OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(11)
        )
    class OperationAccessDeniedError(metaclass=_OperationAccessDeniedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(0)
    UNKNOWN = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(1)
    ACTION_NOT_PERMITTED = OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(
        2
    )
    CREATE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(3)
    )
    REMOVE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(4)
    )
    UPDATE_OPERATION_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(5)
    )
    MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(6)
    )
    OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(7)
    )
    CREATE_AS_REMOVED_NOT_PERMITTED = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(8)
    )
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(9)
    )
    OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(10)
    )
    MUTATE_NOT_PERMITTED_FOR_CUSTOMER = (
        OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V(11)
    )
    def __init__(
        self,
    ) -> None: ...

global___OperationAccessDeniedErrorEnum = OperationAccessDeniedErrorEnum
