"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DomainCategory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    COVERAGE_FRACTION_FIELD_NUMBER: builtins.int
    CATEGORY_RANK_FIELD_NUMBER: builtins.int
    HAS_CHILDREN_FIELD_NUMBER: builtins.int
    RECOMMENDED_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def category(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def domain(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def coverage_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def category_rank(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def has_children(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def recommended_cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        category: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        domain: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        coverage_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        category_rank: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        has_children: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        recommended_cpc_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___DomainCategory = DomainCategory
