"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.offline_user_data_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UploadUserDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    CUSTOMER_MATCH_USER_LIST_METADATA_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserDataOperation
    ]: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[typing.Iterable[global___UserDataOperation]] = ...,
        customer_match_user_list_metadata: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.CustomerMatchUserListMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
            "operations",
            b"operations",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["metadata", b"metadata"]
    ) -> typing_extensions.Literal["customer_match_user_list_metadata"]: ...

global___UploadUserDataRequest = UploadUserDataRequest

class UserDataOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    @property
    def remove(
        self,
    ) -> google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
        remove: typing.Optional[
            google.ads.google_ads.v4.proto.common.offline_user_data_pb2.UserData
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___UserDataOperation = UserDataOperation

class UploadUserDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPLOAD_DATE_TIME_FIELD_NUMBER: builtins.int
    RECEIVED_OPERATIONS_COUNT_FIELD_NUMBER: builtins.int
    @property
    def upload_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def received_operations_count(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        upload_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        received_operations_count: typing.Optional[
            google.protobuf.wrappers_pb2.Int32Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> None: ...

global___UploadUserDataResponse = UploadUserDataResponse
