"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FinalAppUrl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OS_TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    os_type: google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2.AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType.V = (
        ...
    )
    url: typing.Text = ...
    def __init__(
        self,
        *,
        os_type: google.ads.google_ads.v5.proto.enums.app_url_operating_system_type_pb2.AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType.V = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_url", b"_url", "os_type", b"os_type", "url", b"url"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...

global___FinalAppUrl = FinalAppUrl
