"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupFeedError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupFeedErrorEnum.AdGroupFeedError.V(0)
        UNKNOWN = AdGroupFeedErrorEnum.AdGroupFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(3)
        ADGROUP_FEED_ALREADY_EXISTS = AdGroupFeedErrorEnum.AdGroupFeedError.V(4)
        CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(5)
        )
        INVALID_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(6)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            AdGroupFeedErrorEnum.AdGroupFeedError.V(7)
        )
        NO_EXISTING_LOCATION_CUSTOMER_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(8)
    class AdGroupFeedError(metaclass=_AdGroupFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupFeedErrorEnum.AdGroupFeedError.V(0)
    UNKNOWN = AdGroupFeedErrorEnum.AdGroupFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(
        2
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(3)
    ADGROUP_FEED_ALREADY_EXISTS = AdGroupFeedErrorEnum.AdGroupFeedError.V(4)
    CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(5)
    INVALID_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(6)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = AdGroupFeedErrorEnum.AdGroupFeedError.V(
        7
    )
    NO_EXISTING_LOCATION_CUSTOMER_FEED = AdGroupFeedErrorEnum.AdGroupFeedError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupFeedErrorEnum = AdGroupFeedErrorEnum
