"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomAudienceErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomAudienceError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomAudienceError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomAudienceErrorEnum.CustomAudienceError.V(0)
        UNKNOWN = CustomAudienceErrorEnum.CustomAudienceError.V(1)
        NAME_ALREADY_USED = CustomAudienceErrorEnum.CustomAudienceError.V(2)
        CANNOT_REMOVE_WHILE_IN_USE = CustomAudienceErrorEnum.CustomAudienceError.V(3)
        RESOURCE_ALREADY_REMOVED = CustomAudienceErrorEnum.CustomAudienceError.V(4)
        MEMBER_TYPE_AND_PARAMETER_ALREADY_EXISTED = (
            CustomAudienceErrorEnum.CustomAudienceError.V(5)
        )
        INVALID_MEMBER_TYPE = CustomAudienceErrorEnum.CustomAudienceError.V(6)
        MEMBER_TYPE_AND_VALUE_DOES_NOT_MATCH = (
            CustomAudienceErrorEnum.CustomAudienceError.V(7)
        )
        POLICY_VIOLATION = CustomAudienceErrorEnum.CustomAudienceError.V(8)
        INVALID_TYPE_CHANGE = CustomAudienceErrorEnum.CustomAudienceError.V(9)
    class CustomAudienceError(metaclass=_CustomAudienceError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomAudienceErrorEnum.CustomAudienceError.V(0)
    UNKNOWN = CustomAudienceErrorEnum.CustomAudienceError.V(1)
    NAME_ALREADY_USED = CustomAudienceErrorEnum.CustomAudienceError.V(2)
    CANNOT_REMOVE_WHILE_IN_USE = CustomAudienceErrorEnum.CustomAudienceError.V(3)
    RESOURCE_ALREADY_REMOVED = CustomAudienceErrorEnum.CustomAudienceError.V(4)
    MEMBER_TYPE_AND_PARAMETER_ALREADY_EXISTED = (
        CustomAudienceErrorEnum.CustomAudienceError.V(5)
    )
    INVALID_MEMBER_TYPE = CustomAudienceErrorEnum.CustomAudienceError.V(6)
    MEMBER_TYPE_AND_VALUE_DOES_NOT_MATCH = (
        CustomAudienceErrorEnum.CustomAudienceError.V(7)
    )
    POLICY_VIOLATION = CustomAudienceErrorEnum.CustomAudienceError.V(8)
    INVALID_TYPE_CHANGE = CustomAudienceErrorEnum.CustomAudienceError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___CustomAudienceErrorEnum = CustomAudienceErrorEnum
