"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingSourceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingSource(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BiddingSource.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingSourceEnum.BiddingSource.V(0)
        UNKNOWN = BiddingSourceEnum.BiddingSource.V(1)
        CAMPAIGN_BIDDING_STRATEGY = BiddingSourceEnum.BiddingSource.V(5)
        AD_GROUP = BiddingSourceEnum.BiddingSource.V(6)
        AD_GROUP_CRITERION = BiddingSourceEnum.BiddingSource.V(7)
    class BiddingSource(metaclass=_BiddingSource):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingSourceEnum.BiddingSource.V(0)
    UNKNOWN = BiddingSourceEnum.BiddingSource.V(1)
    CAMPAIGN_BIDDING_STRATEGY = BiddingSourceEnum.BiddingSource.V(5)
    AD_GROUP = BiddingSourceEnum.BiddingSource.V(6)
    AD_GROUP_CRITERION = BiddingSourceEnum.BiddingSource.V(7)
    def __init__(
        self,
    ) -> None: ...

global___BiddingSourceEnum = BiddingSourceEnum
