"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LeadFormCallToActionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LeadFormCallToActionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LeadFormCallToActionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(0)
        UNKNOWN = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(1)
        LEARN_MORE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(2)
        GET_QUOTE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(3)
        APPLY_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(4)
        SIGN_UP = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(5)
        CONTACT_US = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(6)
        SUBSCRIBE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(7)
        DOWNLOAD = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(8)
        BOOK_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(9)
        GET_OFFER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(10)
        REGISTER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(11)
        GET_INFO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(12)
        REQUEST_DEMO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(13)
        JOIN_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(14)
        GET_STARTED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(15)
    class LeadFormCallToActionType(metaclass=_LeadFormCallToActionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(0)
    UNKNOWN = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(1)
    LEARN_MORE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(2)
    GET_QUOTE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(3)
    APPLY_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(4)
    SIGN_UP = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(5)
    CONTACT_US = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(6)
    SUBSCRIBE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(7)
    DOWNLOAD = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(8)
    BOOK_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(9)
    GET_OFFER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(10)
    REGISTER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(11)
    GET_INFO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(12)
    REQUEST_DEMO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(13)
    JOIN_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(14)
    GET_STARTED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___LeadFormCallToActionTypeEnum = LeadFormCallToActionTypeEnum
