"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2
import google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2
import google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    @property
    def channel(self) -> global___CriterionCategoryChannelAvailability: ...
    @property
    def locale(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CriterionCategoryLocaleAvailability
    ]: ...
    def __init__(
        self,
        *,
        channel: typing.Optional[global___CriterionCategoryChannelAvailability] = ...,
        locale: typing.Optional[
            typing.Iterable[global___CriterionCategoryLocaleAvailability]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["channel", b"channel"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel", b"channel", "locale", b"locale"
        ],
    ) -> None: ...

global___CriterionCategoryAvailability = CriterionCategoryAvailability

class CriterionCategoryChannelAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVAILABILITY_MODE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    INCLUDE_DEFAULT_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V = (
        ...
    )
    advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = (
        ...
    )
    advertising_channel_sub_type: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V
    ] = ...
    @property
    def include_default_channel_sub_type(
        self,
    ) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V = ...,
        advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = ...,
        advertising_channel_sub_type: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V
            ]
        ] = ...,
        include_default_channel_sub_type: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "include_default_channel_sub_type", b"include_default_channel_sub_type"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "availability_mode",
            b"availability_mode",
            "include_default_channel_sub_type",
            b"include_default_channel_sub_type",
        ],
    ) -> None: ...

global___CriterionCategoryChannelAvailability = CriterionCategoryChannelAvailability

class CriterionCategoryLocaleAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVAILABILITY_MODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V = (
        ...
    )
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_code", b"country_code", "language_code", b"language_code"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "availability_mode",
            b"availability_mode",
            "country_code",
            b"country_code",
            "language_code",
            b"language_code",
        ],
    ) -> None: ...

global___CriterionCategoryLocaleAvailability = CriterionCategoryLocaleAvailability
