"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LocationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LocationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LocationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(0)
        UNKNOWN = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(1)
        BUSINESS_NAME = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(2)
        ADDRESS_LINE_1 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(3)
        ADDRESS_LINE_2 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(4)
        CITY = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(5)
        PROVINCE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(6)
        POSTAL_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(7)
        COUNTRY_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(8)
        PHONE_NUMBER = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(9)
    class LocationPlaceholderField(metaclass=_LocationPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(0)
    UNKNOWN = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(1)
    BUSINESS_NAME = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(2)
    ADDRESS_LINE_1 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(3)
    ADDRESS_LINE_2 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(4)
    CITY = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(5)
    PROVINCE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(6)
    POSTAL_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(7)
    COUNTRY_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(8)
    PHONE_NUMBER = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(9)
    def __init__(
        self,
    ) -> None: ...

global___LocationPlaceholderFieldEnum = LocationPlaceholderFieldEnum
