"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ImagePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ImagePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ImagePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(0)
        UNKNOWN = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(1)
        ASSET_ID = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(2)
    class ImagePlaceholderField(metaclass=_ImagePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(0)
    UNKNOWN = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(1)
    ASSET_ID = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(2)
    def __init__(
        self,
    ) -> None: ...

global___ImagePlaceholderFieldEnum = ImagePlaceholderFieldEnum
