"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedMappingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedMappingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedMappingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedMappingErrorEnum.FeedMappingError.V(0)
        UNKNOWN = FeedMappingErrorEnum.FeedMappingError.V(1)
        INVALID_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(2)
        INVALID_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(3)
        INVALID_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(4)
        INVALID_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(5)
        NO_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(7)
        FEED_ATTRIBUTE_TYPE_MISMATCH = FeedMappingErrorEnum.FeedMappingError.V(8)
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = (
            FeedMappingErrorEnum.FeedMappingError.V(9)
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = (
            FeedMappingErrorEnum.FeedMappingError.V(10)
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(
            11
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = (
            FeedMappingErrorEnum.FeedMappingError.V(12)
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
            13
        )
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(
            14
        )
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = (
            FeedMappingErrorEnum.FeedMappingError.V(15)
        )
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = FeedMappingErrorEnum.FeedMappingError.V(
            16
        )
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = (
            FeedMappingErrorEnum.FeedMappingError.V(17)
        )
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = (
            FeedMappingErrorEnum.FeedMappingError.V(18)
        )
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
            19
        )
    class FeedMappingError(metaclass=_FeedMappingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedMappingErrorEnum.FeedMappingError.V(0)
    UNKNOWN = FeedMappingErrorEnum.FeedMappingError.V(1)
    INVALID_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(2)
    INVALID_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(3)
    INVALID_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(4)
    INVALID_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(5)
    NO_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(7)
    FEED_ATTRIBUTE_TYPE_MISMATCH = FeedMappingErrorEnum.FeedMappingError.V(8)
    CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = (
        FeedMappingErrorEnum.FeedMappingError.V(9)
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(10)
    MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(11)
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
        12
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(13)
    UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(14)
    LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = (
        FeedMappingErrorEnum.FeedMappingError.V(15)
    )
    CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = FeedMappingErrorEnum.FeedMappingError.V(16)
    INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = (
        FeedMappingErrorEnum.FeedMappingError.V(17)
    )
    INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = (
        FeedMappingErrorEnum.FeedMappingError.V(18)
    )
    ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = FeedMappingErrorEnum.FeedMappingError.V(19)
    def __init__(
        self,
    ) -> None: ...

global___FeedMappingErrorEnum = FeedMappingErrorEnum
