"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperatingSystemVersionOperatorTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OperatingSystemVersionOperatorType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OperatingSystemVersionOperatorType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                0
            )
        )
        UNKNOWN = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                1
            )
        )
        EQUALS_TO = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                2
            )
        )
        GREATER_THAN_EQUALS_TO = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                4
            )
        )
    class OperatingSystemVersionOperatorType(
        metaclass=_OperatingSystemVersionOperatorType
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(0)
    )
    UNKNOWN = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(1)
    )
    EQUALS_TO = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(2)
    )
    GREATER_THAN_EQUALS_TO = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___OperatingSystemVersionOperatorTypeEnum = OperatingSystemVersionOperatorTypeEnum
