"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.resources.batch_job_pb2
import google.ads.google_ads.v5.proto.services.google_ads_service_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MutateBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operation(self) -> global___BatchJobOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[global___BatchJobOperation] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

global___MutateBatchJobRequest = MutateBatchJobRequest

class BatchJobOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v5.proto.resources.batch_job_pb2.BatchJob: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v5.proto.resources.batch_job_pb2.BatchJob
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create"]: ...

global___BatchJobOperation = BatchJobOperation

class MutateBatchJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateBatchJobResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[global___MutateBatchJobResult] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateBatchJobResponse = MutateBatchJobResponse

class MutateBatchJobResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateBatchJobResult = MutateBatchJobResult

class GetBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetBatchJobRequest = GetBatchJobRequest

class RunBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___RunBatchJobRequest = RunBatchJobRequest

class AddBatchJobOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    MUTATE_OPERATIONS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    sequence_token: typing.Text = ...
    @property
    def mutate_operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        sequence_token: typing.Text = ...,
        mutate_operations: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperation
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operations",
            b"mutate_operations",
            "resource_name",
            b"resource_name",
            "sequence_token",
            b"sequence_token",
        ],
    ) -> None: ...

global___AddBatchJobOperationsRequest = AddBatchJobOperationsRequest

class AddBatchJobOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    total_operations: builtins.int = ...
    next_sequence_token: typing.Text = ...
    def __init__(
        self,
        *,
        total_operations: builtins.int = ...,
        next_sequence_token: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_sequence_token",
            b"next_sequence_token",
            "total_operations",
            b"total_operations",
        ],
    ) -> None: ...

global___AddBatchJobOperationsResponse = AddBatchJobOperationsResponse

class ListBatchJobResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___ListBatchJobResultsRequest = ListBatchJobResultsRequest

class ListBatchJobResultsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BatchJobResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[typing.Iterable[global___BatchJobResult]] = ...,
        next_page_token: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token", b"next_page_token", "results", b"results"
        ],
    ) -> None: ...

global___ListBatchJobResultsResponse = ListBatchJobResultsResponse

class BatchJobResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATION_INDEX_FIELD_NUMBER: builtins.int
    MUTATE_OPERATION_RESPONSE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    operation_index: builtins.int = ...
    @property
    def mutate_operation_response(
        self,
    ) -> google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperationResponse: ...
    @property
    def status(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        operation_index: builtins.int = ...,
        mutate_operation_response: typing.Optional[
            google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperationResponse
        ] = ...,
        status: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "status",
            b"status",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "operation_index",
            b"operation_index",
            "status",
            b"status",
        ],
    ) -> None: ...

global___BatchJobResult = BatchJobResult
