"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemTargetTypeEnum.FeedItemTargetType.V(0)
        UNKNOWN = FeedItemTargetTypeEnum.FeedItemTargetType.V(1)
        CAMPAIGN = FeedItemTargetTypeEnum.FeedItemTargetType.V(2)
        AD_GROUP = FeedItemTargetTypeEnum.FeedItemTargetType.V(3)
        CRITERION = FeedItemTargetTypeEnum.FeedItemTargetType.V(4)
    class FeedItemTargetType(metaclass=_FeedItemTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemTargetTypeEnum.FeedItemTargetType.V(0)
    UNKNOWN = FeedItemTargetTypeEnum.FeedItemTargetType.V(1)
    CAMPAIGN = FeedItemTargetTypeEnum.FeedItemTargetType.V(2)
    AD_GROUP = FeedItemTargetTypeEnum.FeedItemTargetType.V(3)
    CRITERION = FeedItemTargetTypeEnum.FeedItemTargetType.V(4)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemTargetTypeEnum = FeedItemTargetTypeEnum
