"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanCampaignKeyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    MATCH_TYPE_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    match_type: google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
        ...
    )
    @property
    def keyword_plan_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def negative(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        keyword_plan_campaign: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        match_type: google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
        negative: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "negative",
            b"negative",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "match_type",
            b"match_type",
            "negative",
            b"negative",
            "resource_name",
            b"resource_name",
            "text",
            b"text",
        ],
    ) -> None: ...

global___KeywordPlanCampaignKeyword = KeywordPlanCampaignKeyword
