"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .conversion_adjustment_upload_service_pb2 import *

class ConversionAdjustmentUploadServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadConversionAdjustments(
        self,
        request: global___UploadConversionAdjustmentsRequest,
    ) -> global___UploadConversionAdjustmentsResponse: ...

class ConversionAdjustmentUploadServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadConversionAdjustments(
        self,
        request: global___UploadConversionAdjustmentsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadConversionAdjustmentsResponse: ...

def add_ConversionAdjustmentUploadServiceServicer_to_server(
    servicer: ConversionAdjustmentUploadServiceServicer, server: grpc.Server
) -> None: ...
