"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraftErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignDraftError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignDraftError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignDraftErrorEnum.CampaignDraftError.V(0)
        UNKNOWN = CampaignDraftErrorEnum.CampaignDraftError.V(1)
        DUPLICATE_DRAFT_NAME = CampaignDraftErrorEnum.CampaignDraftError.V(2)
        INVALID_STATUS_TRANSITION_FROM_REMOVED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(3)
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(4)
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(5)
        )
        CUSTOMER_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(6)
        CAMPAIGN_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(7)
        INVALID_DRAFT_CHANGE = CampaignDraftErrorEnum.CampaignDraftError.V(8)
        INVALID_STATUS_TRANSITION = CampaignDraftErrorEnum.CampaignDraftError.V(9)
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(10)
        )
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = (
            CampaignDraftErrorEnum.CampaignDraftError.V(11)
        )
    class CampaignDraftError(metaclass=_CampaignDraftError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignDraftErrorEnum.CampaignDraftError.V(0)
    UNKNOWN = CampaignDraftErrorEnum.CampaignDraftError.V(1)
    DUPLICATE_DRAFT_NAME = CampaignDraftErrorEnum.CampaignDraftError.V(2)
    INVALID_STATUS_TRANSITION_FROM_REMOVED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(3)
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(4)
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(5)
    )
    CUSTOMER_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(6)
    CAMPAIGN_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(7)
    INVALID_DRAFT_CHANGE = CampaignDraftErrorEnum.CampaignDraftError.V(8)
    INVALID_STATUS_TRANSITION = CampaignDraftErrorEnum.CampaignDraftError.V(9)
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(10)
    )
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = CampaignDraftErrorEnum.CampaignDraftError.V(
        11
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignDraftErrorEnum = CampaignDraftErrorEnum
