"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusOperationEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusOperation(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusOperation.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusOperationEnum.ChangeStatusOperation.V(0)
        UNKNOWN = ChangeStatusOperationEnum.ChangeStatusOperation.V(1)
        ADDED = ChangeStatusOperationEnum.ChangeStatusOperation.V(2)
        CHANGED = ChangeStatusOperationEnum.ChangeStatusOperation.V(3)
        REMOVED = ChangeStatusOperationEnum.ChangeStatusOperation.V(4)
    class ChangeStatusOperation(metaclass=_ChangeStatusOperation):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusOperationEnum.ChangeStatusOperation.V(0)
    UNKNOWN = ChangeStatusOperationEnum.ChangeStatusOperation.V(1)
    ADDED = ChangeStatusOperationEnum.ChangeStatusOperation.V(2)
    CHANGED = ChangeStatusOperationEnum.ChangeStatusOperation.V(3)
    REMOVED = ChangeStatusOperationEnum.ChangeStatusOperation.V(4)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusOperationEnum = ChangeStatusOperationEnum
