"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeEventResourceTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeEventResourceType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeEventResourceType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(0)
        UNKNOWN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(1)
        AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(2)
        AD_GROUP = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(3)
        AD_GROUP_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(4)
        CAMPAIGN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(5)
        CAMPAIGN_BUDGET = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(6)
        AD_GROUP_BID_MODIFIER = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(7)
        CAMPAIGN_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(8)
        FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(9)
        FEED_ITEM = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(10)
        CAMPAIGN_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(11)
        AD_GROUP_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(12)
        AD_GROUP_AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(13)
    class ChangeEventResourceType(metaclass=_ChangeEventResourceType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(0)
    UNKNOWN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(1)
    AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(2)
    AD_GROUP = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(3)
    AD_GROUP_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(4)
    CAMPAIGN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(5)
    CAMPAIGN_BUDGET = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(6)
    AD_GROUP_BID_MODIFIER = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(7)
    CAMPAIGN_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(8)
    FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(9)
    FEED_ITEM = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(10)
    CAMPAIGN_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(11)
    AD_GROUP_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(12)
    AD_GROUP_AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeEventResourceTypeEnum = ChangeEventResourceTypeEnum
