"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelRateTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelRateType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HotelRateType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelRateTypeEnum.HotelRateType.V(0)
        UNKNOWN = HotelRateTypeEnum.HotelRateType.V(1)
        UNAVAILABLE = HotelRateTypeEnum.HotelRateType.V(2)
        PUBLIC_RATE = HotelRateTypeEnum.HotelRateType.V(3)
        QUALIFIED_RATE = HotelRateTypeEnum.HotelRateType.V(4)
        PRIVATE_RATE = HotelRateTypeEnum.HotelRateType.V(5)
    class HotelRateType(metaclass=_HotelRateType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelRateTypeEnum.HotelRateType.V(0)
    UNKNOWN = HotelRateTypeEnum.HotelRateType.V(1)
    UNAVAILABLE = HotelRateTypeEnum.HotelRateType.V(2)
    PUBLIC_RATE = HotelRateTypeEnum.HotelRateType.V(3)
    QUALIFIED_RATE = HotelRateTypeEnum.HotelRateType.V(4)
    PRIVATE_RATE = HotelRateTypeEnum.HotelRateType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___HotelRateTypeEnum = HotelRateTypeEnum
