"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdSharingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdSharingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdSharingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdSharingErrorEnum.AdSharingError.V(0)
        UNKNOWN = AdSharingErrorEnum.AdSharingError.V(1)
        AD_GROUP_ALREADY_CONTAINS_AD = AdSharingErrorEnum.AdSharingError.V(2)
        INCOMPATIBLE_AD_UNDER_AD_GROUP = AdSharingErrorEnum.AdSharingError.V(3)
        CANNOT_SHARE_INACTIVE_AD = AdSharingErrorEnum.AdSharingError.V(4)
    class AdSharingError(metaclass=_AdSharingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdSharingErrorEnum.AdSharingError.V(0)
    UNKNOWN = AdSharingErrorEnum.AdSharingError.V(1)
    AD_GROUP_ALREADY_CONTAINS_AD = AdSharingErrorEnum.AdSharingError.V(2)
    INCOMPATIBLE_AD_UNDER_AD_GROUP = AdSharingErrorEnum.AdSharingError.V(3)
    CANNOT_SHARE_INACTIVE_AD = AdSharingErrorEnum.AdSharingError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___AdSharingErrorEnum = AdSharingErrorEnum
