"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class InternalErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _InternalError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[InternalError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = InternalErrorEnum.InternalError.V(0)
        UNKNOWN = InternalErrorEnum.InternalError.V(1)
        INTERNAL_ERROR = InternalErrorEnum.InternalError.V(2)
        ERROR_CODE_NOT_PUBLISHED = InternalErrorEnum.InternalError.V(3)
        TRANSIENT_ERROR = InternalErrorEnum.InternalError.V(4)
        DEADLINE_EXCEEDED = InternalErrorEnum.InternalError.V(5)
    class InternalError(metaclass=_InternalError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = InternalErrorEnum.InternalError.V(0)
    UNKNOWN = InternalErrorEnum.InternalError.V(1)
    INTERNAL_ERROR = InternalErrorEnum.InternalError.V(2)
    ERROR_CODE_NOT_PUBLISHED = InternalErrorEnum.InternalError.V(3)
    TRANSIENT_ERROR = InternalErrorEnum.InternalError.V(4)
    DEADLINE_EXCEEDED = InternalErrorEnum.InternalError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___InternalErrorEnum = InternalErrorEnum
