"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2
import grpc

from .bidding_strategy_service_pb2 import *

class BiddingStrategyServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetBiddingStrategy(
        self,
        request: global___GetBiddingStrategyRequest,
    ) -> google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy: ...
    def MutateBiddingStrategies(
        self,
        request: global___MutateBiddingStrategiesRequest,
    ) -> global___MutateBiddingStrategiesResponse: ...

class BiddingStrategyServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetBiddingStrategy(
        self,
        request: global___GetBiddingStrategyRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy: ...
    @abc.abstractmethod
    def MutateBiddingStrategies(
        self,
        request: global___MutateBiddingStrategiesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateBiddingStrategiesResponse: ...

def add_BiddingStrategyServiceServicer_to_server(
    servicer: BiddingStrategyServiceServicer, server: grpc.Server
) -> None: ...
