"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.policy_pb2
import google.ads.google_ads.v5.proto.common.value_pb2
import google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2
import google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2
import google.ads.google_ads.v5.proto.errors.account_link_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2
import google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2
import google.ads.google_ads.v5.proto.errors.adx_error_pb2
import google.ads.google_ads.v5.proto.errors.asset_error_pb2
import google.ads.google_ads.v5.proto.errors.asset_link_error_pb2
import google.ads.google_ads.v5.proto.errors.authentication_error_pb2
import google.ads.google_ads.v5.proto.errors.authorization_error_pb2
import google.ads.google_ads.v5.proto.errors.batch_job_error_pb2
import google.ads.google_ads.v5.proto.errors.bidding_error_pb2
import google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2
import google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2
import google.ads.google_ads.v5.proto.errors.change_status_error_pb2
import google.ads.google_ads.v5.proto.errors.collection_size_error_pb2
import google.ads.google_ads.v5.proto.errors.context_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.country_code_error_pb2
import google.ads.google_ads.v5.proto.errors.criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.currency_code_error_pb2
import google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2
import google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2
import google.ads.google_ads.v5.proto.errors.database_error_pb2
import google.ads.google_ads.v5.proto.errors.date_error_pb2
import google.ads.google_ads.v5.proto.errors.date_range_error_pb2
import google.ads.google_ads.v5.proto.errors.distinct_error_pb2
import google.ads.google_ads.v5.proto.errors.enum_error_pb2
import google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2
import google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2
import google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2
import google.ads.google_ads.v5.proto.errors.field_error_pb2
import google.ads.google_ads.v5.proto.errors.field_mask_error_pb2
import google.ads.google_ads.v5.proto.errors.function_error_pb2
import google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2
import google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2
import google.ads.google_ads.v5.proto.errors.header_error_pb2
import google.ads.google_ads.v5.proto.errors.id_error_pb2
import google.ads.google_ads.v5.proto.errors.image_error_pb2
import google.ads.google_ads.v5.proto.errors.internal_error_pb2
import google.ads.google_ads.v5.proto.errors.invoice_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2
import google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2
import google.ads.google_ads.v5.proto.errors.label_error_pb2
import google.ads.google_ads.v5.proto.errors.language_code_error_pb2
import google.ads.google_ads.v5.proto.errors.list_operation_error_pb2
import google.ads.google_ads.v5.proto.errors.manager_link_error_pb2
import google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2
import google.ads.google_ads.v5.proto.errors.media_file_error_pb2
import google.ads.google_ads.v5.proto.errors.media_upload_error_pb2
import google.ads.google_ads.v5.proto.errors.multiplier_error_pb2
import google.ads.google_ads.v5.proto.errors.mutate_error_pb2
import google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2
import google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2
import google.ads.google_ads.v5.proto.errors.not_empty_error_pb2
import google.ads.google_ads.v5.proto.errors.null_error_pb2
import google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2
import google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2
import google.ads.google_ads.v5.proto.errors.operator_error_pb2
import google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2
import google.ads.google_ads.v5.proto.errors.payments_account_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2
import google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2
import google.ads.google_ads.v5.proto.errors.query_error_pb2
import google.ads.google_ads.v5.proto.errors.quota_error_pb2
import google.ads.google_ads.v5.proto.errors.range_error_pb2
import google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2
import google.ads.google_ads.v5.proto.errors.recommendation_error_pb2
import google.ads.google_ads.v5.proto.errors.region_code_error_pb2
import google.ads.google_ads.v5.proto.errors.request_error_pb2
import google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2
import google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2
import google.ads.google_ads.v5.proto.errors.setting_error_pb2
import google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2
import google.ads.google_ads.v5.proto.errors.shared_set_error_pb2
import google.ads.google_ads.v5.proto.errors.size_limit_error_pb2
import google.ads.google_ads.v5.proto.errors.string_format_error_pb2
import google.ads.google_ads.v5.proto.errors.string_length_error_pb2
import google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2
import google.ads.google_ads.v5.proto.errors.time_zone_error_pb2
import google.ads.google_ads.v5.proto.errors.url_field_error_pb2
import google.ads.google_ads.v5.proto.errors.user_data_error_pb2
import google.ads.google_ads.v5.proto.errors.user_list_error_pb2
import google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ERRORS_FIELD_NUMBER: builtins.int
    @property
    def errors(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GoogleAdsError
    ]: ...
    def __init__(
        self,
        *,
        errors: typing.Optional[typing.Iterable[global___GoogleAdsError]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["errors", b"errors"]
    ) -> None: ...

global___GoogleAdsFailure = GoogleAdsFailure

class GoogleAdsError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ERROR_CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    @property
    def error_code(self) -> global___ErrorCode: ...
    @property
    def trigger(self) -> google.ads.google_ads.v5.proto.common.value_pb2.Value: ...
    @property
    def location(self) -> global___ErrorLocation: ...
    @property
    def details(self) -> global___ErrorDetails: ...
    def __init__(
        self,
        *,
        error_code: typing.Optional[global___ErrorCode] = ...,
        message: typing.Text = ...,
        trigger: typing.Optional[
            google.ads.google_ads.v5.proto.common.value_pb2.Value
        ] = ...,
        location: typing.Optional[global___ErrorLocation] = ...,
        details: typing.Optional[global___ErrorDetails] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "trigger",
            b"trigger",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "details",
            b"details",
            "error_code",
            b"error_code",
            "location",
            b"location",
            "message",
            b"message",
            "trigger",
            b"trigger",
        ],
    ) -> None: ...

global___GoogleAdsError = GoogleAdsError

class ErrorCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ERROR_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_ERROR_FIELD_NUMBER: builtins.int
    URL_FIELD_ERROR_FIELD_NUMBER: builtins.int
    LIST_OPERATION_ERROR_FIELD_NUMBER: builtins.int
    QUERY_ERROR_FIELD_NUMBER: builtins.int
    MUTATE_ERROR_FIELD_NUMBER: builtins.int
    FIELD_MASK_ERROR_FIELD_NUMBER: builtins.int
    AUTHORIZATION_ERROR_FIELD_NUMBER: builtins.int
    INTERNAL_ERROR_FIELD_NUMBER: builtins.int
    QUOTA_ERROR_FIELD_NUMBER: builtins.int
    AD_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_ERROR_FIELD_NUMBER: builtins.int
    AUTHENTICATION_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    AD_CUSTOMIZER_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_ERROR_FIELD_NUMBER: builtins.int
    AD_SHARING_ERROR_FIELD_NUMBER: builtins.int
    ADX_ERROR_FIELD_NUMBER: builtins.int
    ASSET_ERROR_FIELD_NUMBER: builtins.int
    BIDDING_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    COLLECTION_SIZE_ERROR_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_ERROR_FIELD_NUMBER: builtins.int
    CRITERION_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_ERROR_FIELD_NUMBER: builtins.int
    DATE_ERROR_FIELD_NUMBER: builtins.int
    DATE_RANGE_ERROR_FIELD_NUMBER: builtins.int
    DISTINCT_ERROR_FIELD_NUMBER: builtins.int
    FEED_ATTRIBUTE_REFERENCE_ERROR_FIELD_NUMBER: builtins.int
    FUNCTION_ERROR_FIELD_NUMBER: builtins.int
    FUNCTION_PARSING_ERROR_FIELD_NUMBER: builtins.int
    ID_ERROR_FIELD_NUMBER: builtins.int
    IMAGE_ERROR_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    MEDIA_FILE_ERROR_FIELD_NUMBER: builtins.int
    MULTIPLIER_ERROR_FIELD_NUMBER: builtins.int
    NEW_RESOURCE_CREATION_ERROR_FIELD_NUMBER: builtins.int
    NOT_EMPTY_ERROR_FIELD_NUMBER: builtins.int
    NULL_ERROR_FIELD_NUMBER: builtins.int
    OPERATOR_ERROR_FIELD_NUMBER: builtins.int
    RANGE_ERROR_FIELD_NUMBER: builtins.int
    RECOMMENDATION_ERROR_FIELD_NUMBER: builtins.int
    REGION_CODE_ERROR_FIELD_NUMBER: builtins.int
    SETTING_ERROR_FIELD_NUMBER: builtins.int
    STRING_FORMAT_ERROR_FIELD_NUMBER: builtins.int
    STRING_LENGTH_ERROR_FIELD_NUMBER: builtins.int
    OPERATION_ACCESS_DENIED_ERROR_FIELD_NUMBER: builtins.int
    RESOURCE_ACCESS_DENIED_ERROR_FIELD_NUMBER: builtins.int
    RESOURCE_COUNT_LIMIT_EXCEEDED_ERROR_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_REGISTRATION_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_ERROR_FIELD_NUMBER: builtins.int
    CONTEXT_ERROR_FIELD_NUMBER: builtins.int
    FIELD_ERROR_FIELD_NUMBER: builtins.int
    SHARED_SET_ERROR_FIELD_NUMBER: builtins.int
    SHARED_CRITERION_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_SHARED_SET_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_ADJUSTMENT_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    CONVERSION_UPLOAD_ERROR_FIELD_NUMBER: builtins.int
    HEADER_ERROR_FIELD_NUMBER: builtins.int
    DATABASE_ERROR_FIELD_NUMBER: builtins.int
    POLICY_FINDING_ERROR_FIELD_NUMBER: builtins.int
    ENUM_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_KEYWORD_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_KEYWORD_ERROR_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_IDEA_ERROR_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_PROPOSAL_ERROR_FIELD_NUMBER: builtins.int
    USER_LIST_ERROR_FIELD_NUMBER: builtins.int
    CHANGE_STATUS_ERROR_FIELD_NUMBER: builtins.int
    FEED_ERROR_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_SUGGESTION_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_ERROR_FIELD_NUMBER: builtins.int
    LABEL_ERROR_FIELD_NUMBER: builtins.int
    BILLING_SETUP_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_CLIENT_LINK_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGER_LINK_ERROR_FIELD_NUMBER: builtins.int
    FEED_MAPPING_ERROR_FIELD_NUMBER: builtins.int
    CUSTOMER_FEED_ERROR_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_ERROR_FIELD_NUMBER: builtins.int
    CUSTOM_INTEREST_ERROR_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXPERIMENT_ERROR_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEM_ERROR_FIELD_NUMBER: builtins.int
    AD_PARAMETER_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_VALIDATION_ERROR_FIELD_NUMBER: builtins.int
    EXTENSION_SETTING_ERROR_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_ERROR_FIELD_NUMBER: builtins.int
    POLICY_VIOLATION_ERROR_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    POLICY_VALIDATION_PARAMETER_ERROR_FIELD_NUMBER: builtins.int
    SIZE_LIMIT_ERROR_FIELD_NUMBER: builtins.int
    OFFLINE_USER_DATA_JOB_ERROR_FIELD_NUMBER: builtins.int
    NOT_ALLOWLISTED_ERROR_FIELD_NUMBER: builtins.int
    MANAGER_LINK_ERROR_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_ERROR_FIELD_NUMBER: builtins.int
    ACCESS_INVITATION_ERROR_FIELD_NUMBER: builtins.int
    REACH_PLAN_ERROR_FIELD_NUMBER: builtins.int
    INVOICE_ERROR_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ERROR_FIELD_NUMBER: builtins.int
    TIME_ZONE_ERROR_FIELD_NUMBER: builtins.int
    ASSET_LINK_ERROR_FIELD_NUMBER: builtins.int
    USER_DATA_ERROR_FIELD_NUMBER: builtins.int
    BATCH_JOB_ERROR_FIELD_NUMBER: builtins.int
    ACCOUNT_LINK_ERROR_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_LINK_ERROR_FIELD_NUMBER: builtins.int
    request_error: google.ads.google_ads.v5.proto.errors.request_error_pb2.RequestErrorEnum.RequestError.V = (
        ...
    )
    bidding_strategy_error: google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2.BiddingStrategyErrorEnum.BiddingStrategyError.V = (
        ...
    )
    url_field_error: google.ads.google_ads.v5.proto.errors.url_field_error_pb2.UrlFieldErrorEnum.UrlFieldError.V = (
        ...
    )
    list_operation_error: google.ads.google_ads.v5.proto.errors.list_operation_error_pb2.ListOperationErrorEnum.ListOperationError.V = (
        ...
    )
    query_error: google.ads.google_ads.v5.proto.errors.query_error_pb2.QueryErrorEnum.QueryError.V = (
        ...
    )
    mutate_error: google.ads.google_ads.v5.proto.errors.mutate_error_pb2.MutateErrorEnum.MutateError.V = (
        ...
    )
    field_mask_error: google.ads.google_ads.v5.proto.errors.field_mask_error_pb2.FieldMaskErrorEnum.FieldMaskError.V = (
        ...
    )
    authorization_error: google.ads.google_ads.v5.proto.errors.authorization_error_pb2.AuthorizationErrorEnum.AuthorizationError.V = (
        ...
    )
    internal_error: google.ads.google_ads.v5.proto.errors.internal_error_pb2.InternalErrorEnum.InternalError.V = (
        ...
    )
    quota_error: google.ads.google_ads.v5.proto.errors.quota_error_pb2.QuotaErrorEnum.QuotaError.V = (
        ...
    )
    ad_error: google.ads.google_ads.v5.proto.errors.ad_error_pb2.AdErrorEnum.AdError.V = (
        ...
    )
    ad_group_error: google.ads.google_ads.v5.proto.errors.ad_group_error_pb2.AdGroupErrorEnum.AdGroupError.V = (
        ...
    )
    campaign_budget_error: google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2.CampaignBudgetErrorEnum.CampaignBudgetError.V = (
        ...
    )
    campaign_error: google.ads.google_ads.v5.proto.errors.campaign_error_pb2.CampaignErrorEnum.CampaignError.V = (
        ...
    )
    authentication_error: google.ads.google_ads.v5.proto.errors.authentication_error_pb2.AuthenticationErrorEnum.AuthenticationError.V = (
        ...
    )
    ad_group_criterion_error: google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2.AdGroupCriterionErrorEnum.AdGroupCriterionError.V = (
        ...
    )
    ad_customizer_error: google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2.AdCustomizerErrorEnum.AdCustomizerError.V = (
        ...
    )
    ad_group_ad_error: google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2.AdGroupAdErrorEnum.AdGroupAdError.V = (
        ...
    )
    ad_sharing_error: google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2.AdSharingErrorEnum.AdSharingError.V = (
        ...
    )
    adx_error: google.ads.google_ads.v5.proto.errors.adx_error_pb2.AdxErrorEnum.AdxError.V = (
        ...
    )
    asset_error: google.ads.google_ads.v5.proto.errors.asset_error_pb2.AssetErrorEnum.AssetError.V = (
        ...
    )
    bidding_error: google.ads.google_ads.v5.proto.errors.bidding_error_pb2.BiddingErrorEnum.BiddingError.V = (
        ...
    )
    campaign_criterion_error: google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2.CampaignCriterionErrorEnum.CampaignCriterionError.V = (
        ...
    )
    collection_size_error: google.ads.google_ads.v5.proto.errors.collection_size_error_pb2.CollectionSizeErrorEnum.CollectionSizeError.V = (
        ...
    )
    country_code_error: google.ads.google_ads.v5.proto.errors.country_code_error_pb2.CountryCodeErrorEnum.CountryCodeError.V = (
        ...
    )
    criterion_error: google.ads.google_ads.v5.proto.errors.criterion_error_pb2.CriterionErrorEnum.CriterionError.V = (
        ...
    )
    customer_error: google.ads.google_ads.v5.proto.errors.customer_error_pb2.CustomerErrorEnum.CustomerError.V = (
        ...
    )
    date_error: google.ads.google_ads.v5.proto.errors.date_error_pb2.DateErrorEnum.DateError.V = (
        ...
    )
    date_range_error: google.ads.google_ads.v5.proto.errors.date_range_error_pb2.DateRangeErrorEnum.DateRangeError.V = (
        ...
    )
    distinct_error: google.ads.google_ads.v5.proto.errors.distinct_error_pb2.DistinctErrorEnum.DistinctError.V = (
        ...
    )
    feed_attribute_reference_error: google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V = (
        ...
    )
    function_error: google.ads.google_ads.v5.proto.errors.function_error_pb2.FunctionErrorEnum.FunctionError.V = (
        ...
    )
    function_parsing_error: google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2.FunctionParsingErrorEnum.FunctionParsingError.V = (
        ...
    )
    id_error: google.ads.google_ads.v5.proto.errors.id_error_pb2.IdErrorEnum.IdError.V = (
        ...
    )
    image_error: google.ads.google_ads.v5.proto.errors.image_error_pb2.ImageErrorEnum.ImageError.V = (
        ...
    )
    language_code_error: google.ads.google_ads.v5.proto.errors.language_code_error_pb2.LanguageCodeErrorEnum.LanguageCodeError.V = (
        ...
    )
    media_bundle_error: google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2.MediaBundleErrorEnum.MediaBundleError.V = (
        ...
    )
    media_upload_error: google.ads.google_ads.v5.proto.errors.media_upload_error_pb2.MediaUploadErrorEnum.MediaUploadError.V = (
        ...
    )
    media_file_error: google.ads.google_ads.v5.proto.errors.media_file_error_pb2.MediaFileErrorEnum.MediaFileError.V = (
        ...
    )
    multiplier_error: google.ads.google_ads.v5.proto.errors.multiplier_error_pb2.MultiplierErrorEnum.MultiplierError.V = (
        ...
    )
    new_resource_creation_error: google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2.NewResourceCreationErrorEnum.NewResourceCreationError.V = (
        ...
    )
    not_empty_error: google.ads.google_ads.v5.proto.errors.not_empty_error_pb2.NotEmptyErrorEnum.NotEmptyError.V = (
        ...
    )
    null_error: google.ads.google_ads.v5.proto.errors.null_error_pb2.NullErrorEnum.NullError.V = (
        ...
    )
    operator_error: google.ads.google_ads.v5.proto.errors.operator_error_pb2.OperatorErrorEnum.OperatorError.V = (
        ...
    )
    range_error: google.ads.google_ads.v5.proto.errors.range_error_pb2.RangeErrorEnum.RangeError.V = (
        ...
    )
    recommendation_error: google.ads.google_ads.v5.proto.errors.recommendation_error_pb2.RecommendationErrorEnum.RecommendationError.V = (
        ...
    )
    region_code_error: google.ads.google_ads.v5.proto.errors.region_code_error_pb2.RegionCodeErrorEnum.RegionCodeError.V = (
        ...
    )
    setting_error: google.ads.google_ads.v5.proto.errors.setting_error_pb2.SettingErrorEnum.SettingError.V = (
        ...
    )
    string_format_error: google.ads.google_ads.v5.proto.errors.string_format_error_pb2.StringFormatErrorEnum.StringFormatError.V = (
        ...
    )
    string_length_error: google.ads.google_ads.v5.proto.errors.string_length_error_pb2.StringLengthErrorEnum.StringLengthError.V = (
        ...
    )
    operation_access_denied_error: google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2.OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V = (
        ...
    )
    resource_access_denied_error: google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2.ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError.V = (
        ...
    )
    resource_count_limit_exceeded_error: google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2.ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V = (
        ...
    )
    youtube_video_registration_error: google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2.YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V = (
        ...
    )
    ad_group_bid_modifier_error: google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2.AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V = (
        ...
    )
    context_error: google.ads.google_ads.v5.proto.errors.context_error_pb2.ContextErrorEnum.ContextError.V = (
        ...
    )
    field_error: google.ads.google_ads.v5.proto.errors.field_error_pb2.FieldErrorEnum.FieldError.V = (
        ...
    )
    shared_set_error: google.ads.google_ads.v5.proto.errors.shared_set_error_pb2.SharedSetErrorEnum.SharedSetError.V = (
        ...
    )
    shared_criterion_error: google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2.SharedCriterionErrorEnum.SharedCriterionError.V = (
        ...
    )
    campaign_shared_set_error: google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2.CampaignSharedSetErrorEnum.CampaignSharedSetError.V = (
        ...
    )
    conversion_action_error: google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2.ConversionActionErrorEnum.ConversionActionError.V = (
        ...
    )
    conversion_adjustment_upload_error: google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2.ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V = (
        ...
    )
    conversion_upload_error: google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2.ConversionUploadErrorEnum.ConversionUploadError.V = (
        ...
    )
    header_error: google.ads.google_ads.v5.proto.errors.header_error_pb2.HeaderErrorEnum.HeaderError.V = (
        ...
    )
    database_error: google.ads.google_ads.v5.proto.errors.database_error_pb2.DatabaseErrorEnum.DatabaseError.V = (
        ...
    )
    policy_finding_error: google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2.PolicyFindingErrorEnum.PolicyFindingError.V = (
        ...
    )
    enum_error: google.ads.google_ads.v5.proto.errors.enum_error_pb2.EnumErrorEnum.EnumError.V = (
        ...
    )
    keyword_plan_error: google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2.KeywordPlanErrorEnum.KeywordPlanError.V = (
        ...
    )
    keyword_plan_campaign_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2.KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V = (
        ...
    )
    keyword_plan_campaign_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2.KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordError.V = (
        ...
    )
    keyword_plan_ad_group_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2.KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError.V = (
        ...
    )
    keyword_plan_ad_group_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2.KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V = (
        ...
    )
    keyword_plan_idea_error: google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2.KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError.V = (
        ...
    )
    account_budget_proposal_error: google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2.AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V = (
        ...
    )
    user_list_error: google.ads.google_ads.v5.proto.errors.user_list_error_pb2.UserListErrorEnum.UserListError.V = (
        ...
    )
    change_status_error: google.ads.google_ads.v5.proto.errors.change_status_error_pb2.ChangeStatusErrorEnum.ChangeStatusError.V = (
        ...
    )
    feed_error: google.ads.google_ads.v5.proto.errors.feed_error_pb2.FeedErrorEnum.FeedError.V = (
        ...
    )
    geo_target_constant_suggestion_error: google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V = (
        ...
    )
    campaign_draft_error: google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2.CampaignDraftErrorEnum.CampaignDraftError.V = (
        ...
    )
    feed_item_error: google.ads.google_ads.v5.proto.errors.feed_item_error_pb2.FeedItemErrorEnum.FeedItemError.V = (
        ...
    )
    label_error: google.ads.google_ads.v5.proto.errors.label_error_pb2.LabelErrorEnum.LabelError.V = (
        ...
    )
    billing_setup_error: google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2.BillingSetupErrorEnum.BillingSetupError.V = (
        ...
    )
    customer_client_link_error: google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2.CustomerClientLinkErrorEnum.CustomerClientLinkError.V = (
        ...
    )
    customer_manager_link_error: google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2.CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V = (
        ...
    )
    feed_mapping_error: google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2.FeedMappingErrorEnum.FeedMappingError.V = (
        ...
    )
    customer_feed_error: google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2.CustomerFeedErrorEnum.CustomerFeedError.V = (
        ...
    )
    ad_group_feed_error: google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2.AdGroupFeedErrorEnum.AdGroupFeedError.V = (
        ...
    )
    campaign_feed_error: google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2.CampaignFeedErrorEnum.CampaignFeedError.V = (
        ...
    )
    custom_interest_error: google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2.CustomInterestErrorEnum.CustomInterestError.V = (
        ...
    )
    campaign_experiment_error: google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2.CampaignExperimentErrorEnum.CampaignExperimentError.V = (
        ...
    )
    extension_feed_item_error: google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2.ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V = (
        ...
    )
    ad_parameter_error: google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2.AdParameterErrorEnum.AdParameterError.V = (
        ...
    )
    feed_item_validation_error: google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = (
        ...
    )
    extension_setting_error: google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2.ExtensionSettingErrorEnum.ExtensionSettingError.V = (
        ...
    )
    feed_item_target_error: google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2.FeedItemTargetErrorEnum.FeedItemTargetError.V = (
        ...
    )
    policy_violation_error: google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2.PolicyViolationErrorEnum.PolicyViolationError.V = (
        ...
    )
    partial_failure_error: google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2.PartialFailureErrorEnum.PartialFailureError.V = (
        ...
    )
    policy_validation_parameter_error: google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2.PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V = (
        ...
    )
    size_limit_error: google.ads.google_ads.v5.proto.errors.size_limit_error_pb2.SizeLimitErrorEnum.SizeLimitError.V = (
        ...
    )
    offline_user_data_job_error: google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2.OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V = (
        ...
    )
    not_allowlisted_error: google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2.NotAllowlistedErrorEnum.NotAllowlistedError.V = (
        ...
    )
    manager_link_error: google.ads.google_ads.v5.proto.errors.manager_link_error_pb2.ManagerLinkErrorEnum.ManagerLinkError.V = (
        ...
    )
    currency_code_error: google.ads.google_ads.v5.proto.errors.currency_code_error_pb2.CurrencyCodeErrorEnum.CurrencyCodeError.V = (
        ...
    )
    access_invitation_error: google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2.AccessInvitationErrorEnum.AccessInvitationError.V = (
        ...
    )
    reach_plan_error: google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2.ReachPlanErrorEnum.ReachPlanError.V = (
        ...
    )
    invoice_error: google.ads.google_ads.v5.proto.errors.invoice_error_pb2.InvoiceErrorEnum.InvoiceError.V = (
        ...
    )
    payments_account_error: google.ads.google_ads.v5.proto.errors.payments_account_error_pb2.PaymentsAccountErrorEnum.PaymentsAccountError.V = (
        ...
    )
    time_zone_error: google.ads.google_ads.v5.proto.errors.time_zone_error_pb2.TimeZoneErrorEnum.TimeZoneError.V = (
        ...
    )
    asset_link_error: google.ads.google_ads.v5.proto.errors.asset_link_error_pb2.AssetLinkErrorEnum.AssetLinkError.V = (
        ...
    )
    user_data_error: google.ads.google_ads.v5.proto.errors.user_data_error_pb2.UserDataErrorEnum.UserDataError.V = (
        ...
    )
    batch_job_error: google.ads.google_ads.v5.proto.errors.batch_job_error_pb2.BatchJobErrorEnum.BatchJobError.V = (
        ...
    )
    account_link_error: google.ads.google_ads.v5.proto.errors.account_link_error_pb2.AccountLinkErrorEnum.AccountLinkError.V = (
        ...
    )
    third_party_app_analytics_link_error: google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2.ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V = (
        ...
    )
    def __init__(
        self,
        *,
        request_error: google.ads.google_ads.v5.proto.errors.request_error_pb2.RequestErrorEnum.RequestError.V = ...,
        bidding_strategy_error: google.ads.google_ads.v5.proto.errors.bidding_strategy_error_pb2.BiddingStrategyErrorEnum.BiddingStrategyError.V = ...,
        url_field_error: google.ads.google_ads.v5.proto.errors.url_field_error_pb2.UrlFieldErrorEnum.UrlFieldError.V = ...,
        list_operation_error: google.ads.google_ads.v5.proto.errors.list_operation_error_pb2.ListOperationErrorEnum.ListOperationError.V = ...,
        query_error: google.ads.google_ads.v5.proto.errors.query_error_pb2.QueryErrorEnum.QueryError.V = ...,
        mutate_error: google.ads.google_ads.v5.proto.errors.mutate_error_pb2.MutateErrorEnum.MutateError.V = ...,
        field_mask_error: google.ads.google_ads.v5.proto.errors.field_mask_error_pb2.FieldMaskErrorEnum.FieldMaskError.V = ...,
        authorization_error: google.ads.google_ads.v5.proto.errors.authorization_error_pb2.AuthorizationErrorEnum.AuthorizationError.V = ...,
        internal_error: google.ads.google_ads.v5.proto.errors.internal_error_pb2.InternalErrorEnum.InternalError.V = ...,
        quota_error: google.ads.google_ads.v5.proto.errors.quota_error_pb2.QuotaErrorEnum.QuotaError.V = ...,
        ad_error: google.ads.google_ads.v5.proto.errors.ad_error_pb2.AdErrorEnum.AdError.V = ...,
        ad_group_error: google.ads.google_ads.v5.proto.errors.ad_group_error_pb2.AdGroupErrorEnum.AdGroupError.V = ...,
        campaign_budget_error: google.ads.google_ads.v5.proto.errors.campaign_budget_error_pb2.CampaignBudgetErrorEnum.CampaignBudgetError.V = ...,
        campaign_error: google.ads.google_ads.v5.proto.errors.campaign_error_pb2.CampaignErrorEnum.CampaignError.V = ...,
        authentication_error: google.ads.google_ads.v5.proto.errors.authentication_error_pb2.AuthenticationErrorEnum.AuthenticationError.V = ...,
        ad_group_criterion_error: google.ads.google_ads.v5.proto.errors.ad_group_criterion_error_pb2.AdGroupCriterionErrorEnum.AdGroupCriterionError.V = ...,
        ad_customizer_error: google.ads.google_ads.v5.proto.errors.ad_customizer_error_pb2.AdCustomizerErrorEnum.AdCustomizerError.V = ...,
        ad_group_ad_error: google.ads.google_ads.v5.proto.errors.ad_group_ad_error_pb2.AdGroupAdErrorEnum.AdGroupAdError.V = ...,
        ad_sharing_error: google.ads.google_ads.v5.proto.errors.ad_sharing_error_pb2.AdSharingErrorEnum.AdSharingError.V = ...,
        adx_error: google.ads.google_ads.v5.proto.errors.adx_error_pb2.AdxErrorEnum.AdxError.V = ...,
        asset_error: google.ads.google_ads.v5.proto.errors.asset_error_pb2.AssetErrorEnum.AssetError.V = ...,
        bidding_error: google.ads.google_ads.v5.proto.errors.bidding_error_pb2.BiddingErrorEnum.BiddingError.V = ...,
        campaign_criterion_error: google.ads.google_ads.v5.proto.errors.campaign_criterion_error_pb2.CampaignCriterionErrorEnum.CampaignCriterionError.V = ...,
        collection_size_error: google.ads.google_ads.v5.proto.errors.collection_size_error_pb2.CollectionSizeErrorEnum.CollectionSizeError.V = ...,
        country_code_error: google.ads.google_ads.v5.proto.errors.country_code_error_pb2.CountryCodeErrorEnum.CountryCodeError.V = ...,
        criterion_error: google.ads.google_ads.v5.proto.errors.criterion_error_pb2.CriterionErrorEnum.CriterionError.V = ...,
        customer_error: google.ads.google_ads.v5.proto.errors.customer_error_pb2.CustomerErrorEnum.CustomerError.V = ...,
        date_error: google.ads.google_ads.v5.proto.errors.date_error_pb2.DateErrorEnum.DateError.V = ...,
        date_range_error: google.ads.google_ads.v5.proto.errors.date_range_error_pb2.DateRangeErrorEnum.DateRangeError.V = ...,
        distinct_error: google.ads.google_ads.v5.proto.errors.distinct_error_pb2.DistinctErrorEnum.DistinctError.V = ...,
        feed_attribute_reference_error: google.ads.google_ads.v5.proto.errors.feed_attribute_reference_error_pb2.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V = ...,
        function_error: google.ads.google_ads.v5.proto.errors.function_error_pb2.FunctionErrorEnum.FunctionError.V = ...,
        function_parsing_error: google.ads.google_ads.v5.proto.errors.function_parsing_error_pb2.FunctionParsingErrorEnum.FunctionParsingError.V = ...,
        id_error: google.ads.google_ads.v5.proto.errors.id_error_pb2.IdErrorEnum.IdError.V = ...,
        image_error: google.ads.google_ads.v5.proto.errors.image_error_pb2.ImageErrorEnum.ImageError.V = ...,
        language_code_error: google.ads.google_ads.v5.proto.errors.language_code_error_pb2.LanguageCodeErrorEnum.LanguageCodeError.V = ...,
        media_bundle_error: google.ads.google_ads.v5.proto.errors.media_bundle_error_pb2.MediaBundleErrorEnum.MediaBundleError.V = ...,
        media_upload_error: google.ads.google_ads.v5.proto.errors.media_upload_error_pb2.MediaUploadErrorEnum.MediaUploadError.V = ...,
        media_file_error: google.ads.google_ads.v5.proto.errors.media_file_error_pb2.MediaFileErrorEnum.MediaFileError.V = ...,
        multiplier_error: google.ads.google_ads.v5.proto.errors.multiplier_error_pb2.MultiplierErrorEnum.MultiplierError.V = ...,
        new_resource_creation_error: google.ads.google_ads.v5.proto.errors.new_resource_creation_error_pb2.NewResourceCreationErrorEnum.NewResourceCreationError.V = ...,
        not_empty_error: google.ads.google_ads.v5.proto.errors.not_empty_error_pb2.NotEmptyErrorEnum.NotEmptyError.V = ...,
        null_error: google.ads.google_ads.v5.proto.errors.null_error_pb2.NullErrorEnum.NullError.V = ...,
        operator_error: google.ads.google_ads.v5.proto.errors.operator_error_pb2.OperatorErrorEnum.OperatorError.V = ...,
        range_error: google.ads.google_ads.v5.proto.errors.range_error_pb2.RangeErrorEnum.RangeError.V = ...,
        recommendation_error: google.ads.google_ads.v5.proto.errors.recommendation_error_pb2.RecommendationErrorEnum.RecommendationError.V = ...,
        region_code_error: google.ads.google_ads.v5.proto.errors.region_code_error_pb2.RegionCodeErrorEnum.RegionCodeError.V = ...,
        setting_error: google.ads.google_ads.v5.proto.errors.setting_error_pb2.SettingErrorEnum.SettingError.V = ...,
        string_format_error: google.ads.google_ads.v5.proto.errors.string_format_error_pb2.StringFormatErrorEnum.StringFormatError.V = ...,
        string_length_error: google.ads.google_ads.v5.proto.errors.string_length_error_pb2.StringLengthErrorEnum.StringLengthError.V = ...,
        operation_access_denied_error: google.ads.google_ads.v5.proto.errors.operation_access_denied_error_pb2.OperationAccessDeniedErrorEnum.OperationAccessDeniedError.V = ...,
        resource_access_denied_error: google.ads.google_ads.v5.proto.errors.resource_access_denied_error_pb2.ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError.V = ...,
        resource_count_limit_exceeded_error: google.ads.google_ads.v5.proto.errors.resource_count_limit_exceeded_error_pb2.ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V = ...,
        youtube_video_registration_error: google.ads.google_ads.v5.proto.errors.youtube_video_registration_error_pb2.YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V = ...,
        ad_group_bid_modifier_error: google.ads.google_ads.v5.proto.errors.ad_group_bid_modifier_error_pb2.AdGroupBidModifierErrorEnum.AdGroupBidModifierError.V = ...,
        context_error: google.ads.google_ads.v5.proto.errors.context_error_pb2.ContextErrorEnum.ContextError.V = ...,
        field_error: google.ads.google_ads.v5.proto.errors.field_error_pb2.FieldErrorEnum.FieldError.V = ...,
        shared_set_error: google.ads.google_ads.v5.proto.errors.shared_set_error_pb2.SharedSetErrorEnum.SharedSetError.V = ...,
        shared_criterion_error: google.ads.google_ads.v5.proto.errors.shared_criterion_error_pb2.SharedCriterionErrorEnum.SharedCriterionError.V = ...,
        campaign_shared_set_error: google.ads.google_ads.v5.proto.errors.campaign_shared_set_error_pb2.CampaignSharedSetErrorEnum.CampaignSharedSetError.V = ...,
        conversion_action_error: google.ads.google_ads.v5.proto.errors.conversion_action_error_pb2.ConversionActionErrorEnum.ConversionActionError.V = ...,
        conversion_adjustment_upload_error: google.ads.google_ads.v5.proto.errors.conversion_adjustment_upload_error_pb2.ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError.V = ...,
        conversion_upload_error: google.ads.google_ads.v5.proto.errors.conversion_upload_error_pb2.ConversionUploadErrorEnum.ConversionUploadError.V = ...,
        header_error: google.ads.google_ads.v5.proto.errors.header_error_pb2.HeaderErrorEnum.HeaderError.V = ...,
        database_error: google.ads.google_ads.v5.proto.errors.database_error_pb2.DatabaseErrorEnum.DatabaseError.V = ...,
        policy_finding_error: google.ads.google_ads.v5.proto.errors.policy_finding_error_pb2.PolicyFindingErrorEnum.PolicyFindingError.V = ...,
        enum_error: google.ads.google_ads.v5.proto.errors.enum_error_pb2.EnumErrorEnum.EnumError.V = ...,
        keyword_plan_error: google.ads.google_ads.v5.proto.errors.keyword_plan_error_pb2.KeywordPlanErrorEnum.KeywordPlanError.V = ...,
        keyword_plan_campaign_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_error_pb2.KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError.V = ...,
        keyword_plan_campaign_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_campaign_keyword_error_pb2.KeywordPlanCampaignKeywordErrorEnum.KeywordPlanCampaignKeywordError.V = ...,
        keyword_plan_ad_group_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_error_pb2.KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError.V = ...,
        keyword_plan_ad_group_keyword_error: google.ads.google_ads.v5.proto.errors.keyword_plan_ad_group_keyword_error_pb2.KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordError.V = ...,
        keyword_plan_idea_error: google.ads.google_ads.v5.proto.errors.keyword_plan_idea_error_pb2.KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError.V = ...,
        account_budget_proposal_error: google.ads.google_ads.v5.proto.errors.account_budget_proposal_error_pb2.AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V = ...,
        user_list_error: google.ads.google_ads.v5.proto.errors.user_list_error_pb2.UserListErrorEnum.UserListError.V = ...,
        change_status_error: google.ads.google_ads.v5.proto.errors.change_status_error_pb2.ChangeStatusErrorEnum.ChangeStatusError.V = ...,
        feed_error: google.ads.google_ads.v5.proto.errors.feed_error_pb2.FeedErrorEnum.FeedError.V = ...,
        geo_target_constant_suggestion_error: google.ads.google_ads.v5.proto.errors.geo_target_constant_suggestion_error_pb2.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError.V = ...,
        campaign_draft_error: google.ads.google_ads.v5.proto.errors.campaign_draft_error_pb2.CampaignDraftErrorEnum.CampaignDraftError.V = ...,
        feed_item_error: google.ads.google_ads.v5.proto.errors.feed_item_error_pb2.FeedItemErrorEnum.FeedItemError.V = ...,
        label_error: google.ads.google_ads.v5.proto.errors.label_error_pb2.LabelErrorEnum.LabelError.V = ...,
        billing_setup_error: google.ads.google_ads.v5.proto.errors.billing_setup_error_pb2.BillingSetupErrorEnum.BillingSetupError.V = ...,
        customer_client_link_error: google.ads.google_ads.v5.proto.errors.customer_client_link_error_pb2.CustomerClientLinkErrorEnum.CustomerClientLinkError.V = ...,
        customer_manager_link_error: google.ads.google_ads.v5.proto.errors.customer_manager_link_error_pb2.CustomerManagerLinkErrorEnum.CustomerManagerLinkError.V = ...,
        feed_mapping_error: google.ads.google_ads.v5.proto.errors.feed_mapping_error_pb2.FeedMappingErrorEnum.FeedMappingError.V = ...,
        customer_feed_error: google.ads.google_ads.v5.proto.errors.customer_feed_error_pb2.CustomerFeedErrorEnum.CustomerFeedError.V = ...,
        ad_group_feed_error: google.ads.google_ads.v5.proto.errors.ad_group_feed_error_pb2.AdGroupFeedErrorEnum.AdGroupFeedError.V = ...,
        campaign_feed_error: google.ads.google_ads.v5.proto.errors.campaign_feed_error_pb2.CampaignFeedErrorEnum.CampaignFeedError.V = ...,
        custom_interest_error: google.ads.google_ads.v5.proto.errors.custom_interest_error_pb2.CustomInterestErrorEnum.CustomInterestError.V = ...,
        campaign_experiment_error: google.ads.google_ads.v5.proto.errors.campaign_experiment_error_pb2.CampaignExperimentErrorEnum.CampaignExperimentError.V = ...,
        extension_feed_item_error: google.ads.google_ads.v5.proto.errors.extension_feed_item_error_pb2.ExtensionFeedItemErrorEnum.ExtensionFeedItemError.V = ...,
        ad_parameter_error: google.ads.google_ads.v5.proto.errors.ad_parameter_error_pb2.AdParameterErrorEnum.AdParameterError.V = ...,
        feed_item_validation_error: google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2.FeedItemValidationErrorEnum.FeedItemValidationError.V = ...,
        extension_setting_error: google.ads.google_ads.v5.proto.errors.extension_setting_error_pb2.ExtensionSettingErrorEnum.ExtensionSettingError.V = ...,
        feed_item_target_error: google.ads.google_ads.v5.proto.errors.feed_item_target_error_pb2.FeedItemTargetErrorEnum.FeedItemTargetError.V = ...,
        policy_violation_error: google.ads.google_ads.v5.proto.errors.policy_violation_error_pb2.PolicyViolationErrorEnum.PolicyViolationError.V = ...,
        partial_failure_error: google.ads.google_ads.v5.proto.errors.partial_failure_error_pb2.PartialFailureErrorEnum.PartialFailureError.V = ...,
        policy_validation_parameter_error: google.ads.google_ads.v5.proto.errors.policy_validation_parameter_error_pb2.PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V = ...,
        size_limit_error: google.ads.google_ads.v5.proto.errors.size_limit_error_pb2.SizeLimitErrorEnum.SizeLimitError.V = ...,
        offline_user_data_job_error: google.ads.google_ads.v5.proto.errors.offline_user_data_job_error_pb2.OfflineUserDataJobErrorEnum.OfflineUserDataJobError.V = ...,
        not_allowlisted_error: google.ads.google_ads.v5.proto.errors.not_allowlisted_error_pb2.NotAllowlistedErrorEnum.NotAllowlistedError.V = ...,
        manager_link_error: google.ads.google_ads.v5.proto.errors.manager_link_error_pb2.ManagerLinkErrorEnum.ManagerLinkError.V = ...,
        currency_code_error: google.ads.google_ads.v5.proto.errors.currency_code_error_pb2.CurrencyCodeErrorEnum.CurrencyCodeError.V = ...,
        access_invitation_error: google.ads.google_ads.v5.proto.errors.access_invitation_error_pb2.AccessInvitationErrorEnum.AccessInvitationError.V = ...,
        reach_plan_error: google.ads.google_ads.v5.proto.errors.reach_plan_error_pb2.ReachPlanErrorEnum.ReachPlanError.V = ...,
        invoice_error: google.ads.google_ads.v5.proto.errors.invoice_error_pb2.InvoiceErrorEnum.InvoiceError.V = ...,
        payments_account_error: google.ads.google_ads.v5.proto.errors.payments_account_error_pb2.PaymentsAccountErrorEnum.PaymentsAccountError.V = ...,
        time_zone_error: google.ads.google_ads.v5.proto.errors.time_zone_error_pb2.TimeZoneErrorEnum.TimeZoneError.V = ...,
        asset_link_error: google.ads.google_ads.v5.proto.errors.asset_link_error_pb2.AssetLinkErrorEnum.AssetLinkError.V = ...,
        user_data_error: google.ads.google_ads.v5.proto.errors.user_data_error_pb2.UserDataErrorEnum.UserDataError.V = ...,
        batch_job_error: google.ads.google_ads.v5.proto.errors.batch_job_error_pb2.BatchJobErrorEnum.BatchJobError.V = ...,
        account_link_error: google.ads.google_ads.v5.proto.errors.account_link_error_pb2.AccountLinkErrorEnum.AccountLinkError.V = ...,
        third_party_app_analytics_link_error: google.ads.google_ads.v5.proto.errors.third_party_app_analytics_link_error_pb2.ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkError.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "access_invitation_error",
            b"access_invitation_error",
            "account_budget_proposal_error",
            b"account_budget_proposal_error",
            "account_link_error",
            b"account_link_error",
            "ad_customizer_error",
            b"ad_customizer_error",
            "ad_error",
            b"ad_error",
            "ad_group_ad_error",
            b"ad_group_ad_error",
            "ad_group_bid_modifier_error",
            b"ad_group_bid_modifier_error",
            "ad_group_criterion_error",
            b"ad_group_criterion_error",
            "ad_group_error",
            b"ad_group_error",
            "ad_group_feed_error",
            b"ad_group_feed_error",
            "ad_parameter_error",
            b"ad_parameter_error",
            "ad_sharing_error",
            b"ad_sharing_error",
            "adx_error",
            b"adx_error",
            "asset_error",
            b"asset_error",
            "asset_link_error",
            b"asset_link_error",
            "authentication_error",
            b"authentication_error",
            "authorization_error",
            b"authorization_error",
            "batch_job_error",
            b"batch_job_error",
            "bidding_error",
            b"bidding_error",
            "bidding_strategy_error",
            b"bidding_strategy_error",
            "billing_setup_error",
            b"billing_setup_error",
            "campaign_budget_error",
            b"campaign_budget_error",
            "campaign_criterion_error",
            b"campaign_criterion_error",
            "campaign_draft_error",
            b"campaign_draft_error",
            "campaign_error",
            b"campaign_error",
            "campaign_experiment_error",
            b"campaign_experiment_error",
            "campaign_feed_error",
            b"campaign_feed_error",
            "campaign_shared_set_error",
            b"campaign_shared_set_error",
            "change_status_error",
            b"change_status_error",
            "collection_size_error",
            b"collection_size_error",
            "context_error",
            b"context_error",
            "conversion_action_error",
            b"conversion_action_error",
            "conversion_adjustment_upload_error",
            b"conversion_adjustment_upload_error",
            "conversion_upload_error",
            b"conversion_upload_error",
            "country_code_error",
            b"country_code_error",
            "criterion_error",
            b"criterion_error",
            "currency_code_error",
            b"currency_code_error",
            "custom_interest_error",
            b"custom_interest_error",
            "customer_client_link_error",
            b"customer_client_link_error",
            "customer_error",
            b"customer_error",
            "customer_feed_error",
            b"customer_feed_error",
            "customer_manager_link_error",
            b"customer_manager_link_error",
            "database_error",
            b"database_error",
            "date_error",
            b"date_error",
            "date_range_error",
            b"date_range_error",
            "distinct_error",
            b"distinct_error",
            "enum_error",
            b"enum_error",
            "error_code",
            b"error_code",
            "extension_feed_item_error",
            b"extension_feed_item_error",
            "extension_setting_error",
            b"extension_setting_error",
            "feed_attribute_reference_error",
            b"feed_attribute_reference_error",
            "feed_error",
            b"feed_error",
            "feed_item_error",
            b"feed_item_error",
            "feed_item_target_error",
            b"feed_item_target_error",
            "feed_item_validation_error",
            b"feed_item_validation_error",
            "feed_mapping_error",
            b"feed_mapping_error",
            "field_error",
            b"field_error",
            "field_mask_error",
            b"field_mask_error",
            "function_error",
            b"function_error",
            "function_parsing_error",
            b"function_parsing_error",
            "geo_target_constant_suggestion_error",
            b"geo_target_constant_suggestion_error",
            "header_error",
            b"header_error",
            "id_error",
            b"id_error",
            "image_error",
            b"image_error",
            "internal_error",
            b"internal_error",
            "invoice_error",
            b"invoice_error",
            "keyword_plan_ad_group_error",
            b"keyword_plan_ad_group_error",
            "keyword_plan_ad_group_keyword_error",
            b"keyword_plan_ad_group_keyword_error",
            "keyword_plan_campaign_error",
            b"keyword_plan_campaign_error",
            "keyword_plan_campaign_keyword_error",
            b"keyword_plan_campaign_keyword_error",
            "keyword_plan_error",
            b"keyword_plan_error",
            "keyword_plan_idea_error",
            b"keyword_plan_idea_error",
            "label_error",
            b"label_error",
            "language_code_error",
            b"language_code_error",
            "list_operation_error",
            b"list_operation_error",
            "manager_link_error",
            b"manager_link_error",
            "media_bundle_error",
            b"media_bundle_error",
            "media_file_error",
            b"media_file_error",
            "media_upload_error",
            b"media_upload_error",
            "multiplier_error",
            b"multiplier_error",
            "mutate_error",
            b"mutate_error",
            "new_resource_creation_error",
            b"new_resource_creation_error",
            "not_allowlisted_error",
            b"not_allowlisted_error",
            "not_empty_error",
            b"not_empty_error",
            "null_error",
            b"null_error",
            "offline_user_data_job_error",
            b"offline_user_data_job_error",
            "operation_access_denied_error",
            b"operation_access_denied_error",
            "operator_error",
            b"operator_error",
            "partial_failure_error",
            b"partial_failure_error",
            "payments_account_error",
            b"payments_account_error",
            "policy_finding_error",
            b"policy_finding_error",
            "policy_validation_parameter_error",
            b"policy_validation_parameter_error",
            "policy_violation_error",
            b"policy_violation_error",
            "query_error",
            b"query_error",
            "quota_error",
            b"quota_error",
            "range_error",
            b"range_error",
            "reach_plan_error",
            b"reach_plan_error",
            "recommendation_error",
            b"recommendation_error",
            "region_code_error",
            b"region_code_error",
            "request_error",
            b"request_error",
            "resource_access_denied_error",
            b"resource_access_denied_error",
            "resource_count_limit_exceeded_error",
            b"resource_count_limit_exceeded_error",
            "setting_error",
            b"setting_error",
            "shared_criterion_error",
            b"shared_criterion_error",
            "shared_set_error",
            b"shared_set_error",
            "size_limit_error",
            b"size_limit_error",
            "string_format_error",
            b"string_format_error",
            "string_length_error",
            b"string_length_error",
            "third_party_app_analytics_link_error",
            b"third_party_app_analytics_link_error",
            "time_zone_error",
            b"time_zone_error",
            "url_field_error",
            b"url_field_error",
            "user_data_error",
            b"user_data_error",
            "user_list_error",
            b"user_list_error",
            "youtube_video_registration_error",
            b"youtube_video_registration_error",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["error_code", b"error_code"]
    ) -> typing_extensions.Literal[
        "request_error",
        "bidding_strategy_error",
        "url_field_error",
        "list_operation_error",
        "query_error",
        "mutate_error",
        "field_mask_error",
        "authorization_error",
        "internal_error",
        "quota_error",
        "ad_error",
        "ad_group_error",
        "campaign_budget_error",
        "campaign_error",
        "authentication_error",
        "ad_group_criterion_error",
        "ad_customizer_error",
        "ad_group_ad_error",
        "ad_sharing_error",
        "adx_error",
        "asset_error",
        "bidding_error",
        "campaign_criterion_error",
        "collection_size_error",
        "country_code_error",
        "criterion_error",
        "customer_error",
        "date_error",
        "date_range_error",
        "distinct_error",
        "feed_attribute_reference_error",
        "function_error",
        "function_parsing_error",
        "id_error",
        "image_error",
        "language_code_error",
        "media_bundle_error",
        "media_upload_error",
        "media_file_error",
        "multiplier_error",
        "new_resource_creation_error",
        "not_empty_error",
        "null_error",
        "operator_error",
        "range_error",
        "recommendation_error",
        "region_code_error",
        "setting_error",
        "string_format_error",
        "string_length_error",
        "operation_access_denied_error",
        "resource_access_denied_error",
        "resource_count_limit_exceeded_error",
        "youtube_video_registration_error",
        "ad_group_bid_modifier_error",
        "context_error",
        "field_error",
        "shared_set_error",
        "shared_criterion_error",
        "campaign_shared_set_error",
        "conversion_action_error",
        "conversion_adjustment_upload_error",
        "conversion_upload_error",
        "header_error",
        "database_error",
        "policy_finding_error",
        "enum_error",
        "keyword_plan_error",
        "keyword_plan_campaign_error",
        "keyword_plan_campaign_keyword_error",
        "keyword_plan_ad_group_error",
        "keyword_plan_ad_group_keyword_error",
        "keyword_plan_idea_error",
        "account_budget_proposal_error",
        "user_list_error",
        "change_status_error",
        "feed_error",
        "geo_target_constant_suggestion_error",
        "campaign_draft_error",
        "feed_item_error",
        "label_error",
        "billing_setup_error",
        "customer_client_link_error",
        "customer_manager_link_error",
        "feed_mapping_error",
        "customer_feed_error",
        "ad_group_feed_error",
        "campaign_feed_error",
        "custom_interest_error",
        "campaign_experiment_error",
        "extension_feed_item_error",
        "ad_parameter_error",
        "feed_item_validation_error",
        "extension_setting_error",
        "feed_item_target_error",
        "policy_violation_error",
        "partial_failure_error",
        "policy_validation_parameter_error",
        "size_limit_error",
        "offline_user_data_job_error",
        "not_allowlisted_error",
        "manager_link_error",
        "currency_code_error",
        "access_invitation_error",
        "reach_plan_error",
        "invoice_error",
        "payments_account_error",
        "time_zone_error",
        "asset_link_error",
        "user_data_error",
        "batch_job_error",
        "account_link_error",
        "third_party_app_analytics_link_error",
    ]: ...

global___ErrorCode = ErrorCode

class ErrorLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class FieldPathElement(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FIELD_NAME_FIELD_NUMBER: builtins.int
        INDEX_FIELD_NUMBER: builtins.int
        field_name: typing.Text = ...
        @property
        def index(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            field_name: typing.Text = ...,
            index: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["index", b"index"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "field_name", b"field_name", "index", b"index"
            ],
        ) -> None: ...
    FIELD_PATH_ELEMENTS_FIELD_NUMBER: builtins.int
    @property
    def field_path_elements(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ErrorLocation.FieldPathElement
    ]: ...
    def __init__(
        self,
        *,
        field_path_elements: typing.Optional[
            typing.Iterable[global___ErrorLocation.FieldPathElement]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "field_path_elements", b"field_path_elements"
        ],
    ) -> None: ...

global___ErrorLocation = ErrorLocation

class ErrorDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UNPUBLISHED_ERROR_CODE_FIELD_NUMBER: builtins.int
    POLICY_VIOLATION_DETAILS_FIELD_NUMBER: builtins.int
    POLICY_FINDING_DETAILS_FIELD_NUMBER: builtins.int
    QUOTA_ERROR_DETAILS_FIELD_NUMBER: builtins.int
    unpublished_error_code: typing.Text = ...
    @property
    def policy_violation_details(self) -> global___PolicyViolationDetails: ...
    @property
    def policy_finding_details(self) -> global___PolicyFindingDetails: ...
    @property
    def quota_error_details(self) -> global___QuotaErrorDetails: ...
    def __init__(
        self,
        *,
        unpublished_error_code: typing.Text = ...,
        policy_violation_details: typing.Optional[
            global___PolicyViolationDetails
        ] = ...,
        policy_finding_details: typing.Optional[global___PolicyFindingDetails] = ...,
        quota_error_details: typing.Optional[global___QuotaErrorDetails] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "policy_finding_details",
            b"policy_finding_details",
            "policy_violation_details",
            b"policy_violation_details",
            "quota_error_details",
            b"quota_error_details",
            "unpublished_error_code",
            b"unpublished_error_code",
        ],
    ) -> None: ...

global___ErrorDetails = ErrorDetails

class PolicyViolationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTERNAL_POLICY_DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    EXTERNAL_POLICY_NAME_FIELD_NUMBER: builtins.int
    IS_EXEMPTIBLE_FIELD_NUMBER: builtins.int
    external_policy_description: typing.Text = ...
    external_policy_name: typing.Text = ...
    is_exemptible: builtins.bool = ...
    @property
    def key(
        self,
    ) -> google.ads.google_ads.v5.proto.common.policy_pb2.PolicyViolationKey: ...
    def __init__(
        self,
        *,
        external_policy_description: typing.Text = ...,
        key: typing.Optional[
            google.ads.google_ads.v5.proto.common.policy_pb2.PolicyViolationKey
        ] = ...,
        external_policy_name: typing.Text = ...,
        is_exemptible: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["key", b"key"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "external_policy_description",
            b"external_policy_description",
            "external_policy_name",
            b"external_policy_name",
            "is_exemptible",
            b"is_exemptible",
            "key",
            b"key",
        ],
    ) -> None: ...

global___PolicyViolationDetails = PolicyViolationDetails

class PolicyFindingDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "policy_topic_entries", b"policy_topic_entries"
        ],
    ) -> None: ...

global___PolicyFindingDetails = PolicyFindingDetails

class QuotaErrorDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QuotaRateScope(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaRateScope.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QuotaErrorDetails.QuotaRateScope.V(0)
        UNKNOWN = QuotaErrorDetails.QuotaRateScope.V(1)
        ACCOUNT = QuotaErrorDetails.QuotaRateScope.V(2)
        DEVELOPER = QuotaErrorDetails.QuotaRateScope.V(3)
    class QuotaRateScope(metaclass=_QuotaRateScope):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QuotaErrorDetails.QuotaRateScope.V(0)
    UNKNOWN = QuotaErrorDetails.QuotaRateScope.V(1)
    ACCOUNT = QuotaErrorDetails.QuotaRateScope.V(2)
    DEVELOPER = QuotaErrorDetails.QuotaRateScope.V(3)

    RATE_SCOPE_FIELD_NUMBER: builtins.int
    RATE_NAME_FIELD_NUMBER: builtins.int
    RETRY_DELAY_FIELD_NUMBER: builtins.int
    rate_scope: global___QuotaErrorDetails.QuotaRateScope.V = ...
    rate_name: typing.Text = ...
    @property
    def retry_delay(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        rate_scope: global___QuotaErrorDetails.QuotaRateScope.V = ...,
        rate_name: typing.Text = ...,
        retry_delay: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["retry_delay", b"retry_delay"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "rate_name",
            b"rate_name",
            "rate_scope",
            b"rate_scope",
            "retry_delay",
            b"retry_delay",
        ],
    ) -> None: ...

global___QuotaErrorDetails = QuotaErrorDetails
