"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedAttributeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedAttributeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedAttributeType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedAttributeTypeEnum.FeedAttributeType.V(0)
        UNKNOWN = FeedAttributeTypeEnum.FeedAttributeType.V(1)
        INT64 = FeedAttributeTypeEnum.FeedAttributeType.V(2)
        DOUBLE = FeedAttributeTypeEnum.FeedAttributeType.V(3)
        STRING = FeedAttributeTypeEnum.FeedAttributeType.V(4)
        BOOLEAN = FeedAttributeTypeEnum.FeedAttributeType.V(5)
        URL = FeedAttributeTypeEnum.FeedAttributeType.V(6)
        DATE_TIME = FeedAttributeTypeEnum.FeedAttributeType.V(7)
        INT64_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(8)
        DOUBLE_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(9)
        STRING_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(10)
        BOOLEAN_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(11)
        URL_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(12)
        DATE_TIME_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(13)
        PRICE = FeedAttributeTypeEnum.FeedAttributeType.V(14)
    class FeedAttributeType(metaclass=_FeedAttributeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedAttributeTypeEnum.FeedAttributeType.V(0)
    UNKNOWN = FeedAttributeTypeEnum.FeedAttributeType.V(1)
    INT64 = FeedAttributeTypeEnum.FeedAttributeType.V(2)
    DOUBLE = FeedAttributeTypeEnum.FeedAttributeType.V(3)
    STRING = FeedAttributeTypeEnum.FeedAttributeType.V(4)
    BOOLEAN = FeedAttributeTypeEnum.FeedAttributeType.V(5)
    URL = FeedAttributeTypeEnum.FeedAttributeType.V(6)
    DATE_TIME = FeedAttributeTypeEnum.FeedAttributeType.V(7)
    INT64_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(8)
    DOUBLE_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(9)
    STRING_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(10)
    BOOLEAN_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(11)
    URL_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(12)
    DATE_TIME_LIST = FeedAttributeTypeEnum.FeedAttributeType.V(13)
    PRICE = FeedAttributeTypeEnum.FeedAttributeType.V(14)
    def __init__(
        self,
    ) -> None: ...

global___FeedAttributeTypeEnum = FeedAttributeTypeEnum
