"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2
import google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Metrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ABSOLUTE_TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CPM_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CTR_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABILITY_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_COST_MICROS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_VIEWABILITY_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_CLICK_TO_CALL_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_DIRECTIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_MENU_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_ORDER_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_OTHER_ENGAGEMENT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_VISIT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_WEBSITE_FIELD_NUMBER: builtins.int
    AVERAGE_COST_FIELD_NUMBER: builtins.int
    AVERAGE_CPC_FIELD_NUMBER: builtins.int
    AVERAGE_CPE_FIELD_NUMBER: builtins.int
    AVERAGE_CPM_FIELD_NUMBER: builtins.int
    AVERAGE_CPV_FIELD_NUMBER: builtins.int
    AVERAGE_PAGE_VIEWS_FIELD_NUMBER: builtins.int
    AVERAGE_TIME_ON_SITE_FIELD_NUMBER: builtins.int
    BENCHMARK_AVERAGE_MAX_CPC_FIELD_NUMBER: builtins.int
    BENCHMARK_CTR_FIELD_NUMBER: builtins.int
    BOUNCE_RATE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    COMBINED_QUERIES_FIELD_NUMBER: builtins.int
    CONTENT_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONTENT_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_RECEIVED_REQUEST_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONTENT_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    COST_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_PER_CONVERSION_FIELD_NUMBER: builtins.int
    COST_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    CROSS_DEVICE_CONVERSIONS_FIELD_NUMBER: builtins.int
    CTR_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ENGAGEMENT_RATE_FIELD_NUMBER: builtins.int
    ENGAGEMENTS_FIELD_NUMBER: builtins.int
    HOTEL_AVERAGE_LEAD_VALUE_MICROS_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_DIFFERENCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    HOTEL_ELIGIBLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    HISTORICAL_CREATIVE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_LANDING_PAGE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_SEARCH_PREDICTED_CTR_FIELD_NUMBER: builtins.int
    GMAIL_FORWARDS_FIELD_NUMBER: builtins.int
    GMAIL_SAVES_FIELD_NUMBER: builtins.int
    GMAIL_SECONDARY_CLICKS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FROM_STORE_REACH_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    INTERACTION_RATE_FIELD_NUMBER: builtins.int
    INTERACTIONS_FIELD_NUMBER: builtins.int
    INTERACTION_EVENT_TYPES_FIELD_NUMBER: builtins.int
    INVALID_CLICK_RATE_FIELD_NUMBER: builtins.int
    INVALID_CLICKS_FIELD_NUMBER: builtins.int
    MESSAGE_CHATS_FIELD_NUMBER: builtins.int
    MESSAGE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    MESSAGE_CHAT_RATE_FIELD_NUMBER: builtins.int
    MOBILE_FRIENDLY_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_QUERIES_FIELD_NUMBER: builtins.int
    PERCENT_NEW_VISITORS_FIELD_NUMBER: builtins.int
    PHONE_CALLS_FIELD_NUMBER: builtins.int
    PHONE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PHONE_THROUGH_RATE_FIELD_NUMBER: builtins.int
    RELATIVE_CTR_FIELD_NUMBER: builtins.int
    SEARCH_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_CLICK_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_EXACT_MATCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SPEED_SCORE_FIELD_NUMBER: builtins.int
    TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALID_ACCELERATED_MOBILE_PAGES_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSION_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSIONS_BY_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    VALUE_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P100_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P25_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P50_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_P75_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEW_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEWS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_CONVERSIONS_FIELD_NUMBER: builtins.int
    absolute_top_impression_percentage: builtins.float = ...
    active_view_cpm: builtins.float = ...
    active_view_ctr: builtins.float = ...
    active_view_impressions: builtins.int = ...
    active_view_measurability: builtins.float = ...
    active_view_measurable_cost_micros: builtins.int = ...
    active_view_measurable_impressions: builtins.int = ...
    active_view_viewability: builtins.float = ...
    all_conversions_from_interactions_rate: builtins.float = ...
    all_conversions_value: builtins.float = ...
    all_conversions_value_by_conversion_date: builtins.float = ...
    all_conversions: builtins.float = ...
    all_conversions_by_conversion_date: builtins.float = ...
    all_conversions_value_per_cost: builtins.float = ...
    all_conversions_from_click_to_call: builtins.float = ...
    all_conversions_from_directions: builtins.float = ...
    all_conversions_from_interactions_value_per_interaction: builtins.float = ...
    all_conversions_from_menu: builtins.float = ...
    all_conversions_from_order: builtins.float = ...
    all_conversions_from_other_engagement: builtins.float = ...
    all_conversions_from_store_visit: builtins.float = ...
    all_conversions_from_store_website: builtins.float = ...
    average_cost: builtins.float = ...
    average_cpc: builtins.float = ...
    average_cpe: builtins.float = ...
    average_cpm: builtins.float = ...
    average_cpv: builtins.float = ...
    average_page_views: builtins.float = ...
    average_time_on_site: builtins.float = ...
    benchmark_average_max_cpc: builtins.float = ...
    benchmark_ctr: builtins.float = ...
    bounce_rate: builtins.float = ...
    clicks: builtins.int = ...
    combined_clicks: builtins.int = ...
    combined_clicks_per_query: builtins.float = ...
    combined_queries: builtins.int = ...
    content_budget_lost_impression_share: builtins.float = ...
    content_impression_share: builtins.float = ...
    conversion_last_received_request_date_time: typing.Text = ...
    conversion_last_conversion_date: typing.Text = ...
    content_rank_lost_impression_share: builtins.float = ...
    conversions_from_interactions_rate: builtins.float = ...
    conversions_value: builtins.float = ...
    conversions_value_by_conversion_date: builtins.float = ...
    conversions_value_per_cost: builtins.float = ...
    conversions_from_interactions_value_per_interaction: builtins.float = ...
    conversions: builtins.float = ...
    conversions_by_conversion_date: builtins.float = ...
    cost_micros: builtins.int = ...
    cost_per_all_conversions: builtins.float = ...
    cost_per_conversion: builtins.float = ...
    cost_per_current_model_attributed_conversion: builtins.float = ...
    cross_device_conversions: builtins.float = ...
    ctr: builtins.float = ...
    current_model_attributed_conversions: builtins.float = ...
    current_model_attributed_conversions_from_interactions_rate: builtins.float = ...
    current_model_attributed_conversions_from_interactions_value_per_interaction: builtins.float = (
        ...
    )
    current_model_attributed_conversions_value: builtins.float = ...
    current_model_attributed_conversions_value_per_cost: builtins.float = ...
    engagement_rate: builtins.float = ...
    engagements: builtins.int = ...
    hotel_average_lead_value_micros: builtins.float = ...
    hotel_price_difference_percentage: builtins.float = ...
    hotel_eligible_impressions: builtins.int = ...
    historical_creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_landing_page_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_quality_score: builtins.int = ...
    historical_search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    gmail_forwards: builtins.int = ...
    gmail_saves: builtins.int = ...
    gmail_secondary_clicks: builtins.int = ...
    impressions_from_store_reach: builtins.int = ...
    impressions: builtins.int = ...
    interaction_rate: builtins.float = ...
    interactions: builtins.int = ...
    interaction_event_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
    ] = ...
    invalid_click_rate: builtins.float = ...
    invalid_clicks: builtins.int = ...
    message_chats: builtins.int = ...
    message_impressions: builtins.int = ...
    message_chat_rate: builtins.float = ...
    mobile_friendly_clicks_percentage: builtins.float = ...
    organic_clicks: builtins.int = ...
    organic_clicks_per_query: builtins.float = ...
    organic_impressions: builtins.int = ...
    organic_impressions_per_query: builtins.float = ...
    organic_queries: builtins.int = ...
    percent_new_visitors: builtins.float = ...
    phone_calls: builtins.int = ...
    phone_impressions: builtins.int = ...
    phone_through_rate: builtins.float = ...
    relative_ctr: builtins.float = ...
    search_absolute_top_impression_share: builtins.float = ...
    search_budget_lost_absolute_top_impression_share: builtins.float = ...
    search_budget_lost_impression_share: builtins.float = ...
    search_budget_lost_top_impression_share: builtins.float = ...
    search_click_share: builtins.float = ...
    search_exact_match_impression_share: builtins.float = ...
    search_impression_share: builtins.float = ...
    search_rank_lost_absolute_top_impression_share: builtins.float = ...
    search_rank_lost_impression_share: builtins.float = ...
    search_rank_lost_top_impression_share: builtins.float = ...
    search_top_impression_share: builtins.float = ...
    speed_score: builtins.int = ...
    top_impression_percentage: builtins.float = ...
    valid_accelerated_mobile_pages_clicks_percentage: builtins.float = ...
    value_per_all_conversions: builtins.float = ...
    value_per_all_conversions_by_conversion_date: builtins.float = ...
    value_per_conversion: builtins.float = ...
    value_per_conversions_by_conversion_date: builtins.float = ...
    value_per_current_model_attributed_conversion: builtins.float = ...
    video_quartile_p100_rate: builtins.float = ...
    video_quartile_p25_rate: builtins.float = ...
    video_quartile_p50_rate: builtins.float = ...
    video_quartile_p75_rate: builtins.float = ...
    video_view_rate: builtins.float = ...
    video_views: builtins.int = ...
    view_through_conversions: builtins.int = ...
    def __init__(
        self,
        *,
        absolute_top_impression_percentage: builtins.float = ...,
        active_view_cpm: builtins.float = ...,
        active_view_ctr: builtins.float = ...,
        active_view_impressions: builtins.int = ...,
        active_view_measurability: builtins.float = ...,
        active_view_measurable_cost_micros: builtins.int = ...,
        active_view_measurable_impressions: builtins.int = ...,
        active_view_viewability: builtins.float = ...,
        all_conversions_from_interactions_rate: builtins.float = ...,
        all_conversions_value: builtins.float = ...,
        all_conversions_value_by_conversion_date: builtins.float = ...,
        all_conversions: builtins.float = ...,
        all_conversions_by_conversion_date: builtins.float = ...,
        all_conversions_value_per_cost: builtins.float = ...,
        all_conversions_from_click_to_call: builtins.float = ...,
        all_conversions_from_directions: builtins.float = ...,
        all_conversions_from_interactions_value_per_interaction: builtins.float = ...,
        all_conversions_from_menu: builtins.float = ...,
        all_conversions_from_order: builtins.float = ...,
        all_conversions_from_other_engagement: builtins.float = ...,
        all_conversions_from_store_visit: builtins.float = ...,
        all_conversions_from_store_website: builtins.float = ...,
        average_cost: builtins.float = ...,
        average_cpc: builtins.float = ...,
        average_cpe: builtins.float = ...,
        average_cpm: builtins.float = ...,
        average_cpv: builtins.float = ...,
        average_page_views: builtins.float = ...,
        average_time_on_site: builtins.float = ...,
        benchmark_average_max_cpc: builtins.float = ...,
        benchmark_ctr: builtins.float = ...,
        bounce_rate: builtins.float = ...,
        clicks: builtins.int = ...,
        combined_clicks: builtins.int = ...,
        combined_clicks_per_query: builtins.float = ...,
        combined_queries: builtins.int = ...,
        content_budget_lost_impression_share: builtins.float = ...,
        content_impression_share: builtins.float = ...,
        conversion_last_received_request_date_time: typing.Text = ...,
        conversion_last_conversion_date: typing.Text = ...,
        content_rank_lost_impression_share: builtins.float = ...,
        conversions_from_interactions_rate: builtins.float = ...,
        conversions_value: builtins.float = ...,
        conversions_value_by_conversion_date: builtins.float = ...,
        conversions_value_per_cost: builtins.float = ...,
        conversions_from_interactions_value_per_interaction: builtins.float = ...,
        conversions: builtins.float = ...,
        conversions_by_conversion_date: builtins.float = ...,
        cost_micros: builtins.int = ...,
        cost_per_all_conversions: builtins.float = ...,
        cost_per_conversion: builtins.float = ...,
        cost_per_current_model_attributed_conversion: builtins.float = ...,
        cross_device_conversions: builtins.float = ...,
        ctr: builtins.float = ...,
        current_model_attributed_conversions: builtins.float = ...,
        current_model_attributed_conversions_from_interactions_rate: builtins.float = ...,
        current_model_attributed_conversions_from_interactions_value_per_interaction: builtins.float = ...,
        current_model_attributed_conversions_value: builtins.float = ...,
        current_model_attributed_conversions_value_per_cost: builtins.float = ...,
        engagement_rate: builtins.float = ...,
        engagements: builtins.int = ...,
        hotel_average_lead_value_micros: builtins.float = ...,
        hotel_price_difference_percentage: builtins.float = ...,
        hotel_eligible_impressions: builtins.int = ...,
        historical_creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_landing_page_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_quality_score: builtins.int = ...,
        historical_search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        gmail_forwards: builtins.int = ...,
        gmail_saves: builtins.int = ...,
        gmail_secondary_clicks: builtins.int = ...,
        impressions_from_store_reach: builtins.int = ...,
        impressions: builtins.int = ...,
        interaction_rate: builtins.float = ...,
        interactions: builtins.int = ...,
        interaction_event_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
            ]
        ] = ...,
        invalid_click_rate: builtins.float = ...,
        invalid_clicks: builtins.int = ...,
        message_chats: builtins.int = ...,
        message_impressions: builtins.int = ...,
        message_chat_rate: builtins.float = ...,
        mobile_friendly_clicks_percentage: builtins.float = ...,
        organic_clicks: builtins.int = ...,
        organic_clicks_per_query: builtins.float = ...,
        organic_impressions: builtins.int = ...,
        organic_impressions_per_query: builtins.float = ...,
        organic_queries: builtins.int = ...,
        percent_new_visitors: builtins.float = ...,
        phone_calls: builtins.int = ...,
        phone_impressions: builtins.int = ...,
        phone_through_rate: builtins.float = ...,
        relative_ctr: builtins.float = ...,
        search_absolute_top_impression_share: builtins.float = ...,
        search_budget_lost_absolute_top_impression_share: builtins.float = ...,
        search_budget_lost_impression_share: builtins.float = ...,
        search_budget_lost_top_impression_share: builtins.float = ...,
        search_click_share: builtins.float = ...,
        search_exact_match_impression_share: builtins.float = ...,
        search_impression_share: builtins.float = ...,
        search_rank_lost_absolute_top_impression_share: builtins.float = ...,
        search_rank_lost_impression_share: builtins.float = ...,
        search_rank_lost_top_impression_share: builtins.float = ...,
        search_top_impression_share: builtins.float = ...,
        speed_score: builtins.int = ...,
        top_impression_percentage: builtins.float = ...,
        valid_accelerated_mobile_pages_clicks_percentage: builtins.float = ...,
        value_per_all_conversions: builtins.float = ...,
        value_per_all_conversions_by_conversion_date: builtins.float = ...,
        value_per_conversion: builtins.float = ...,
        value_per_conversions_by_conversion_date: builtins.float = ...,
        value_per_current_model_attributed_conversion: builtins.float = ...,
        video_quartile_p100_rate: builtins.float = ...,
        video_quartile_p25_rate: builtins.float = ...,
        video_quartile_p50_rate: builtins.float = ...,
        video_quartile_p75_rate: builtins.float = ...,
        video_view_rate: builtins.float = ...,
        video_views: builtins.int = ...,
        view_through_conversions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_quality_score",
            b"historical_quality_score",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_all_conversions_by_conversion_date",
            b"value_per_all_conversions_by_conversion_date",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_conversions_by_conversion_date",
            b"value_per_conversions_by_conversion_date",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_by_conversion_date",
            b"all_conversions_by_conversion_date",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_by_conversion_date",
            b"all_conversions_value_by_conversion_date",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_by_conversion_date",
            b"conversions_by_conversion_date",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_by_conversion_date",
            b"conversions_value_by_conversion_date",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_creative_quality_score",
            b"historical_creative_quality_score",
            "historical_landing_page_quality_score",
            b"historical_landing_page_quality_score",
            "historical_quality_score",
            b"historical_quality_score",
            "historical_search_predicted_ctr",
            b"historical_search_predicted_ctr",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_event_types",
            b"interaction_event_types",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_all_conversions_by_conversion_date",
            b"value_per_all_conversions_by_conversion_date",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_conversions_by_conversion_date",
            b"value_per_conversions_by_conversion_date",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
        ],
    ) -> typing_extensions.Literal["absolute_top_impression_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_active_view_cpm", b"_active_view_cpm"],
    ) -> typing_extensions.Literal["active_view_cpm"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_active_view_ctr", b"_active_view_ctr"],
    ) -> typing_extensions.Literal["active_view_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_impressions", b"_active_view_impressions"
        ],
    ) -> typing_extensions.Literal["active_view_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurability", b"_active_view_measurability"
        ],
    ) -> typing_extensions.Literal["active_view_measurability"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
        ],
    ) -> typing_extensions.Literal["active_view_measurable_cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
        ],
    ) -> typing_extensions.Literal["active_view_measurable_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_active_view_viewability", b"_active_view_viewability"
        ],
    ) -> typing_extensions.Literal["active_view_viewability"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_all_conversions", b"_all_conversions"],
    ) -> typing_extensions.Literal["all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_click_to_call"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_directions", b"_all_conversions_from_directions"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_directions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_interactions_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "all_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_menu", b"_all_conversions_from_menu"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_menu"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_order", b"_all_conversions_from_order"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_order"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_other_engagement"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_store_visit", b"_all_conversions_from_store_visit"
        ],
    ) -> typing_extensions.Literal["all_conversions_from_store_visit"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
        ],
    ) -> typing_extensions.Literal["all_conversions_from_store_website"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_value", b"_all_conversions_value"
        ],
    ) -> typing_extensions.Literal["all_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_all_conversions_value_per_cost", b"_all_conversions_value_per_cost"
        ],
    ) -> typing_extensions.Literal["all_conversions_value_per_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cost", b"_average_cost"]
    ) -> typing_extensions.Literal["average_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpc", b"_average_cpc"]
    ) -> typing_extensions.Literal["average_cpc"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpe", b"_average_cpe"]
    ) -> typing_extensions.Literal["average_cpe"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpm", b"_average_cpm"]
    ) -> typing_extensions.Literal["average_cpm"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_average_cpv", b"_average_cpv"]
    ) -> typing_extensions.Literal["average_cpv"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_average_page_views", b"_average_page_views"
        ],
    ) -> typing_extensions.Literal["average_page_views"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_average_time_on_site", b"_average_time_on_site"
        ],
    ) -> typing_extensions.Literal["average_time_on_site"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_benchmark_average_max_cpc", b"_benchmark_average_max_cpc"
        ],
    ) -> typing_extensions.Literal["benchmark_average_max_cpc"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_benchmark_ctr", b"_benchmark_ctr"],
    ) -> typing_extensions.Literal["benchmark_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bounce_rate", b"_bounce_rate"]
    ) -> typing_extensions.Literal["bounce_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_combined_clicks", b"_combined_clicks"],
    ) -> typing_extensions.Literal["combined_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_combined_clicks_per_query", b"_combined_clicks_per_query"
        ],
    ) -> typing_extensions.Literal["combined_clicks_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_combined_queries", b"_combined_queries"
        ],
    ) -> typing_extensions.Literal["combined_queries"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["content_budget_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_impression_share", b"_content_impression_share"
        ],
    ) -> typing_extensions.Literal["content_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["content_rank_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_last_conversion_date", b"_conversion_last_conversion_date"
        ],
    ) -> typing_extensions.Literal["conversion_last_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
        ],
    ) -> typing_extensions.Literal["conversion_last_received_request_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_conversions", b"_conversions"]
    ) -> typing_extensions.Literal["conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal["conversions_from_interactions_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_value", b"_conversions_value"
        ],
    ) -> typing_extensions.Literal["conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversions_value_per_cost", b"_conversions_value_per_cost"
        ],
    ) -> typing_extensions.Literal["conversions_value_per_cost"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_all_conversions", b"_cost_per_all_conversions"
        ],
    ) -> typing_extensions.Literal["cost_per_all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_conversion", b"_cost_per_conversion"
        ],
    ) -> typing_extensions.Literal["cost_per_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions.Literal["cost_per_current_model_attributed_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cross_device_conversions", b"_cross_device_conversions"
        ],
    ) -> typing_extensions.Literal["cross_device_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ctr", b"_ctr"]
    ) -> typing_extensions.Literal["ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
        ],
    ) -> typing_extensions.Literal["current_model_attributed_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_from_interactions_rate"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
        ],
    ) -> typing_extensions.Literal["current_model_attributed_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
        ],
    ) -> typing_extensions.Literal[
        "current_model_attributed_conversions_value_per_cost"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_engagement_rate", b"_engagement_rate"],
    ) -> typing_extensions.Literal["engagement_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_engagements", b"_engagements"]
    ) -> typing_extensions.Literal["engagements"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_gmail_forwards", b"_gmail_forwards"],
    ) -> typing_extensions.Literal["gmail_forwards"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gmail_saves", b"_gmail_saves"]
    ) -> typing_extensions.Literal["gmail_saves"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_gmail_secondary_clicks", b"_gmail_secondary_clicks"
        ],
    ) -> typing_extensions.Literal["gmail_secondary_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_historical_quality_score", b"_historical_quality_score"
        ],
    ) -> typing_extensions.Literal["historical_quality_score"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_average_lead_value_micros", b"_hotel_average_lead_value_micros"
        ],
    ) -> typing_extensions.Literal["hotel_average_lead_value_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_eligible_impressions", b"_hotel_eligible_impressions"
        ],
    ) -> typing_extensions.Literal["hotel_eligible_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_price_difference_percentage", b"_hotel_price_difference_percentage"
        ],
    ) -> typing_extensions.Literal["hotel_price_difference_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_impressions_from_store_reach", b"_impressions_from_store_reach"
        ],
    ) -> typing_extensions.Literal["impressions_from_store_reach"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_interaction_rate", b"_interaction_rate"
        ],
    ) -> typing_extensions.Literal["interaction_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_interactions", b"_interactions"]
    ) -> typing_extensions.Literal["interactions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_invalid_click_rate", b"_invalid_click_rate"
        ],
    ) -> typing_extensions.Literal["invalid_click_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_invalid_clicks", b"_invalid_clicks"],
    ) -> typing_extensions.Literal["invalid_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_message_chat_rate", b"_message_chat_rate"
        ],
    ) -> typing_extensions.Literal["message_chat_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_message_chats", b"_message_chats"],
    ) -> typing_extensions.Literal["message_chats"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_message_impressions", b"_message_impressions"
        ],
    ) -> typing_extensions.Literal["message_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_friendly_clicks_percentage", b"_mobile_friendly_clicks_percentage"
        ],
    ) -> typing_extensions.Literal["mobile_friendly_clicks_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_organic_clicks", b"_organic_clicks"],
    ) -> typing_extensions.Literal["organic_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_clicks_per_query", b"_organic_clicks_per_query"
        ],
    ) -> typing_extensions.Literal["organic_clicks_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_impressions", b"_organic_impressions"
        ],
    ) -> typing_extensions.Literal["organic_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_organic_impressions_per_query", b"_organic_impressions_per_query"
        ],
    ) -> typing_extensions.Literal["organic_impressions_per_query"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_organic_queries", b"_organic_queries"],
    ) -> typing_extensions.Literal["organic_queries"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_percent_new_visitors", b"_percent_new_visitors"
        ],
    ) -> typing_extensions.Literal["percent_new_visitors"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_phone_calls", b"_phone_calls"]
    ) -> typing_extensions.Literal["phone_calls"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_impressions", b"_phone_impressions"
        ],
    ) -> typing_extensions.Literal["phone_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_through_rate", b"_phone_through_rate"
        ],
    ) -> typing_extensions.Literal["phone_through_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_relative_ctr", b"_relative_ctr"]
    ) -> typing_extensions.Literal["relative_ctr"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_absolute_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal[
        "search_budget_lost_absolute_top_impression_share"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
        ],
    ) -> typing_extensions.Literal["search_budget_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_budget_lost_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_click_share", b"_search_click_share"
        ],
    ) -> typing_extensions.Literal["search_click_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
        ],
    ) -> typing_extensions.Literal["search_exact_match_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_impression_share", b"_search_impression_share"
        ],
    ) -> typing_extensions.Literal["search_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions.Literal[
        "search_rank_lost_absolute_top_impression_share"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_impression_share", b"_search_rank_lost_impression_share"
        ],
    ) -> typing_extensions.Literal["search_rank_lost_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
        ],
    ) -> typing_extensions.Literal["search_rank_lost_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_search_top_impression_share", b"_search_top_impression_share"
        ],
    ) -> typing_extensions.Literal["search_top_impression_share"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_speed_score", b"_speed_score"]
    ) -> typing_extensions.Literal["speed_score"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_impression_percentage", b"_top_impression_percentage"
        ],
    ) -> typing_extensions.Literal["top_impression_percentage"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
        ],
    ) -> typing_extensions.Literal[
        "valid_accelerated_mobile_pages_clicks_percentage"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_all_conversions", b"_value_per_all_conversions"
        ],
    ) -> typing_extensions.Literal["value_per_all_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_all_conversions_by_conversion_date",
            b"_value_per_all_conversions_by_conversion_date",
        ],
    ) -> typing_extensions.Literal["value_per_all_conversions_by_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_conversion", b"_value_per_conversion"
        ],
    ) -> typing_extensions.Literal["value_per_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_conversions_by_conversion_date",
            b"_value_per_conversions_by_conversion_date",
        ],
    ) -> typing_extensions.Literal["value_per_conversions_by_conversion_date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions.Literal["value_per_current_model_attributed_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p100_rate", b"_video_quartile_p100_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p100_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p25_rate", b"_video_quartile_p25_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p25_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p50_rate", b"_video_quartile_p50_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p50_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_video_quartile_p75_rate", b"_video_quartile_p75_rate"
        ],
    ) -> typing_extensions.Literal["video_quartile_p75_rate"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_video_view_rate", b"_video_view_rate"],
    ) -> typing_extensions.Literal["video_view_rate"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_video_views", b"_video_views"]
    ) -> typing_extensions.Literal["video_views"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_view_through_conversions", b"_view_through_conversions"
        ],
    ) -> typing_extensions.Literal["view_through_conversions"]: ...

global___Metrics = Metrics
