"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.asset_policy_pb2
import google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2
import google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdTextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    PINNED_FIELD_FIELD_NUMBER: builtins.int
    ASSET_PERFORMANCE_LABEL_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_INFO_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    pinned_field: google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = (
        ...
    )
    asset_performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = (
        ...
    )
    @property
    def policy_summary_info(
        self,
    ) -> google.ads.google_ads.v6.proto.common.asset_policy_pb2.AdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        pinned_field: google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2.ServedAssetFieldTypeEnum.ServedAssetFieldType.V = ...,
        asset_performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = ...,
        policy_summary_info: typing.Optional[
            google.ads.google_ads.v6.proto.common.asset_policy_pb2.AdAssetPolicySummary
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "asset_performance_label",
            b"asset_performance_label",
            "pinned_field",
            b"pinned_field",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___AdTextAsset = AdTextAsset

class AdImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdImageAsset = AdImageAsset

class AdVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ASSET_FIELD_NUMBER: builtins.int
    asset: typing.Text = ...
    def __init__(
        self,
        *,
        asset: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...

global___AdMediaBundleAsset = AdMediaBundleAsset
