"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetCpaOptInRecommendationGoalEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetCpaOptInRecommendationGoal(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetCpaOptInRecommendationGoal.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(0)
        )
        UNKNOWN = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(1)
        )
        SAME_COST = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(2)
        )
        SAME_CONVERSIONS = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(3)
        )
        SAME_CPA = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(4)
        )
        CLOSEST_CPA = (
            TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(5)
        )
    class TargetCpaOptInRecommendationGoal(metaclass=_TargetCpaOptInRecommendationGoal):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(0)
    )
    UNKNOWN = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(1)
    SAME_COST = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(
        2
    )
    SAME_CONVERSIONS = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(3)
    )
    SAME_CPA = TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(
        4
    )
    CLOSEST_CPA = (
        TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___TargetCpaOptInRecommendationGoalEnum = TargetCpaOptInRecommendationGoalEnum
