"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CriterionType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionTypeEnum.CriterionType.V(0)
        UNKNOWN = CriterionTypeEnum.CriterionType.V(1)
        KEYWORD = CriterionTypeEnum.CriterionType.V(2)
        PLACEMENT = CriterionTypeEnum.CriterionType.V(3)
        MOBILE_APP_CATEGORY = CriterionTypeEnum.CriterionType.V(4)
        MOBILE_APPLICATION = CriterionTypeEnum.CriterionType.V(5)
        DEVICE = CriterionTypeEnum.CriterionType.V(6)
        LOCATION = CriterionTypeEnum.CriterionType.V(7)
        LISTING_GROUP = CriterionTypeEnum.CriterionType.V(8)
        AD_SCHEDULE = CriterionTypeEnum.CriterionType.V(9)
        AGE_RANGE = CriterionTypeEnum.CriterionType.V(10)
        GENDER = CriterionTypeEnum.CriterionType.V(11)
        INCOME_RANGE = CriterionTypeEnum.CriterionType.V(12)
        PARENTAL_STATUS = CriterionTypeEnum.CriterionType.V(13)
        YOUTUBE_VIDEO = CriterionTypeEnum.CriterionType.V(14)
        YOUTUBE_CHANNEL = CriterionTypeEnum.CriterionType.V(15)
        USER_LIST = CriterionTypeEnum.CriterionType.V(16)
        PROXIMITY = CriterionTypeEnum.CriterionType.V(17)
        TOPIC = CriterionTypeEnum.CriterionType.V(18)
        LISTING_SCOPE = CriterionTypeEnum.CriterionType.V(19)
        LANGUAGE = CriterionTypeEnum.CriterionType.V(20)
        IP_BLOCK = CriterionTypeEnum.CriterionType.V(21)
        CONTENT_LABEL = CriterionTypeEnum.CriterionType.V(22)
        CARRIER = CriterionTypeEnum.CriterionType.V(23)
        USER_INTEREST = CriterionTypeEnum.CriterionType.V(24)
        WEBPAGE = CriterionTypeEnum.CriterionType.V(25)
        OPERATING_SYSTEM_VERSION = CriterionTypeEnum.CriterionType.V(26)
        APP_PAYMENT_MODEL = CriterionTypeEnum.CriterionType.V(27)
        MOBILE_DEVICE = CriterionTypeEnum.CriterionType.V(28)
        CUSTOM_AFFINITY = CriterionTypeEnum.CriterionType.V(29)
        CUSTOM_INTENT = CriterionTypeEnum.CriterionType.V(30)
        LOCATION_GROUP = CriterionTypeEnum.CriterionType.V(31)
        CUSTOM_AUDIENCE = CriterionTypeEnum.CriterionType.V(32)
        COMBINED_AUDIENCE = CriterionTypeEnum.CriterionType.V(33)
    class CriterionType(metaclass=_CriterionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionTypeEnum.CriterionType.V(0)
    UNKNOWN = CriterionTypeEnum.CriterionType.V(1)
    KEYWORD = CriterionTypeEnum.CriterionType.V(2)
    PLACEMENT = CriterionTypeEnum.CriterionType.V(3)
    MOBILE_APP_CATEGORY = CriterionTypeEnum.CriterionType.V(4)
    MOBILE_APPLICATION = CriterionTypeEnum.CriterionType.V(5)
    DEVICE = CriterionTypeEnum.CriterionType.V(6)
    LOCATION = CriterionTypeEnum.CriterionType.V(7)
    LISTING_GROUP = CriterionTypeEnum.CriterionType.V(8)
    AD_SCHEDULE = CriterionTypeEnum.CriterionType.V(9)
    AGE_RANGE = CriterionTypeEnum.CriterionType.V(10)
    GENDER = CriterionTypeEnum.CriterionType.V(11)
    INCOME_RANGE = CriterionTypeEnum.CriterionType.V(12)
    PARENTAL_STATUS = CriterionTypeEnum.CriterionType.V(13)
    YOUTUBE_VIDEO = CriterionTypeEnum.CriterionType.V(14)
    YOUTUBE_CHANNEL = CriterionTypeEnum.CriterionType.V(15)
    USER_LIST = CriterionTypeEnum.CriterionType.V(16)
    PROXIMITY = CriterionTypeEnum.CriterionType.V(17)
    TOPIC = CriterionTypeEnum.CriterionType.V(18)
    LISTING_SCOPE = CriterionTypeEnum.CriterionType.V(19)
    LANGUAGE = CriterionTypeEnum.CriterionType.V(20)
    IP_BLOCK = CriterionTypeEnum.CriterionType.V(21)
    CONTENT_LABEL = CriterionTypeEnum.CriterionType.V(22)
    CARRIER = CriterionTypeEnum.CriterionType.V(23)
    USER_INTEREST = CriterionTypeEnum.CriterionType.V(24)
    WEBPAGE = CriterionTypeEnum.CriterionType.V(25)
    OPERATING_SYSTEM_VERSION = CriterionTypeEnum.CriterionType.V(26)
    APP_PAYMENT_MODEL = CriterionTypeEnum.CriterionType.V(27)
    MOBILE_DEVICE = CriterionTypeEnum.CriterionType.V(28)
    CUSTOM_AFFINITY = CriterionTypeEnum.CriterionType.V(29)
    CUSTOM_INTENT = CriterionTypeEnum.CriterionType.V(30)
    LOCATION_GROUP = CriterionTypeEnum.CriterionType.V(31)
    CUSTOM_AUDIENCE = CriterionTypeEnum.CriterionType.V(32)
    COMBINED_AUDIENCE = CriterionTypeEnum.CriterionType.V(33)
    def __init__(
        self,
    ) -> None: ...

global___CriterionTypeEnum = CriterionTypeEnum
