"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.asset_pb2
import grpc

from .asset_service_pb2 import *

class AssetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAsset(
        self,
        request: global___GetAssetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.asset_pb2.Asset: ...
    def MutateAssets(
        self,
        request: global___MutateAssetsRequest,
    ) -> global___MutateAssetsResponse: ...

class AssetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAsset(
        self,
        request: global___GetAssetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.asset_pb2.Asset: ...
    @abc.abstractmethod
    def MutateAssets(
        self,
        request: global___MutateAssetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAssetsResponse: ...

def add_AssetServiceServicer_to_server(
    servicer: AssetServiceServicer, server: grpc.Server
) -> None: ...
