"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealTimeBiddingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPT_IN_FIELD_NUMBER: builtins.int
    opt_in: builtins.bool = ...
    def __init__(
        self,
        *,
        opt_in: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_opt_in", b"_opt_in", "opt_in", b"opt_in"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_opt_in", b"_opt_in", "opt_in", b"opt_in"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_opt_in", b"_opt_in"]
    ) -> typing_extensions.Literal["opt_in"]: ...

global___RealTimeBiddingSetting = RealTimeBiddingSetting
