"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2
import grpc

from .keyword_plan_ad_group_keyword_service_pb2 import *

class KeywordPlanAdGroupKeywordServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanAdGroupKeyword(
        self,
        request: global___GetKeywordPlanAdGroupKeywordRequest,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword: ...
    def MutateKeywordPlanAdGroupKeywords(
        self,
        request: global___MutateKeywordPlanAdGroupKeywordsRequest,
    ) -> global___MutateKeywordPlanAdGroupKeywordsResponse: ...

class KeywordPlanAdGroupKeywordServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanAdGroupKeyword(
        self,
        request: global___GetKeywordPlanAdGroupKeywordRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword: ...
    @abc.abstractmethod
    def MutateKeywordPlanAdGroupKeywords(
        self,
        request: global___MutateKeywordPlanAdGroupKeywordsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanAdGroupKeywordsResponse: ...

def add_KeywordPlanAdGroupKeywordServiceServicer_to_server(
    servicer: KeywordPlanAdGroupKeywordServiceServicer, server: grpc.Server
) -> None: ...
