"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RecommendationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RecommendationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RecommendationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RecommendationErrorEnum.RecommendationError.V(0)
        UNKNOWN = RecommendationErrorEnum.RecommendationError.V(1)
        BUDGET_AMOUNT_TOO_SMALL = RecommendationErrorEnum.RecommendationError.V(2)
        BUDGET_AMOUNT_TOO_LARGE = RecommendationErrorEnum.RecommendationError.V(3)
        INVALID_BUDGET_AMOUNT = RecommendationErrorEnum.RecommendationError.V(4)
        POLICY_ERROR = RecommendationErrorEnum.RecommendationError.V(5)
        INVALID_BID_AMOUNT = RecommendationErrorEnum.RecommendationError.V(6)
        ADGROUP_KEYWORD_LIMIT = RecommendationErrorEnum.RecommendationError.V(7)
        RECOMMENDATION_ALREADY_APPLIED = RecommendationErrorEnum.RecommendationError.V(
            8
        )
        RECOMMENDATION_INVALIDATED = RecommendationErrorEnum.RecommendationError.V(9)
        TOO_MANY_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(10)
        NO_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(11)
        DIFFERENT_TYPES_NOT_SUPPORTED = RecommendationErrorEnum.RecommendationError.V(
            12
        )
        DUPLICATE_RESOURCE_NAME = RecommendationErrorEnum.RecommendationError.V(13)
        RECOMMENDATION_ALREADY_DISMISSED = (
            RecommendationErrorEnum.RecommendationError.V(14)
        )
        INVALID_APPLY_REQUEST = RecommendationErrorEnum.RecommendationError.V(15)
    class RecommendationError(metaclass=_RecommendationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RecommendationErrorEnum.RecommendationError.V(0)
    UNKNOWN = RecommendationErrorEnum.RecommendationError.V(1)
    BUDGET_AMOUNT_TOO_SMALL = RecommendationErrorEnum.RecommendationError.V(2)
    BUDGET_AMOUNT_TOO_LARGE = RecommendationErrorEnum.RecommendationError.V(3)
    INVALID_BUDGET_AMOUNT = RecommendationErrorEnum.RecommendationError.V(4)
    POLICY_ERROR = RecommendationErrorEnum.RecommendationError.V(5)
    INVALID_BID_AMOUNT = RecommendationErrorEnum.RecommendationError.V(6)
    ADGROUP_KEYWORD_LIMIT = RecommendationErrorEnum.RecommendationError.V(7)
    RECOMMENDATION_ALREADY_APPLIED = RecommendationErrorEnum.RecommendationError.V(8)
    RECOMMENDATION_INVALIDATED = RecommendationErrorEnum.RecommendationError.V(9)
    TOO_MANY_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(10)
    NO_OPERATIONS = RecommendationErrorEnum.RecommendationError.V(11)
    DIFFERENT_TYPES_NOT_SUPPORTED = RecommendationErrorEnum.RecommendationError.V(12)
    DUPLICATE_RESOURCE_NAME = RecommendationErrorEnum.RecommendationError.V(13)
    RECOMMENDATION_ALREADY_DISMISSED = RecommendationErrorEnum.RecommendationError.V(14)
    INVALID_APPLY_REQUEST = RecommendationErrorEnum.RecommendationError.V(15)
    def __init__(
        self,
    ) -> None: ...

global___RecommendationErrorEnum = RecommendationErrorEnum
