"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BudgetCampaignAssociationStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BudgetCampaignAssociationStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BudgetCampaignAssociationStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(0)
        )
        UNKNOWN = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            1
        )
        ENABLED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            2
        )
        REMOVED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
            3
        )
    class BudgetCampaignAssociationStatus(metaclass=_BudgetCampaignAssociationStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(
        0
    )
    UNKNOWN = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(1)
    ENABLED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(2)
    REMOVED = BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V(3)
    def __init__(
        self,
    ) -> None: ...

global___BudgetCampaignAssociationStatusEnum = BudgetCampaignAssociationStatusEnum
