"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_pb2
import grpc

from .customer_service_pb2 import *

class CustomerServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomer(
        self,
        request: global___GetCustomerRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_pb2.Customer: ...
    def MutateCustomer(
        self,
        request: global___MutateCustomerRequest,
    ) -> global___MutateCustomerResponse: ...
    def ListAccessibleCustomers(
        self,
        request: global___ListAccessibleCustomersRequest,
    ) -> global___ListAccessibleCustomersResponse: ...
    def CreateCustomerClient(
        self,
        request: global___CreateCustomerClientRequest,
    ) -> global___CreateCustomerClientResponse: ...

class CustomerServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomer(
        self,
        request: global___GetCustomerRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_pb2.Customer: ...
    @abc.abstractmethod
    def MutateCustomer(
        self,
        request: global___MutateCustomerRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerResponse: ...
    @abc.abstractmethod
    def ListAccessibleCustomers(
        self,
        request: global___ListAccessibleCustomersRequest,
        context: grpc.ServicerContext,
    ) -> global___ListAccessibleCustomersResponse: ...
    @abc.abstractmethod
    def CreateCustomerClient(
        self,
        request: global___CreateCustomerClientRequest,
        context: grpc.ServicerContext,
    ) -> global___CreateCustomerClientResponse: ...

def add_CustomerServiceServicer_to_server(
    servicer: CustomerServiceServicer, server: grpc.Server
) -> None: ...
