"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobFailureReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobFailureReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobFailureReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(0)
        )
        UNKNOWN = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(
            1
        )
        INSUFFICIENT_MATCHED_TRANSACTIONS = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(2)
        )
        INSUFFICIENT_TRANSACTIONS = (
            OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(3)
        )
    class OfflineUserDataJobFailureReason(metaclass=_OfflineUserDataJobFailureReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(
        0
    )
    UNKNOWN = OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(1)
    INSUFFICIENT_MATCHED_TRANSACTIONS = (
        OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(2)
    )
    INSUFFICIENT_TRANSACTIONS = (
        OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason.V(3)
    )
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobFailureReasonEnum = OfflineUserDataJobFailureReasonEnum
