"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RealTimeBiddingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPT_IN_FIELD_NUMBER: builtins.int
    @property
    def opt_in(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        opt_in: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["opt_in", b"opt_in"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["opt_in", b"opt_in"]
    ) -> None: ...

global___RealTimeBiddingSetting = RealTimeBiddingSetting
