"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchTermMatchTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SearchTermMatchType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            SearchTermMatchType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SearchTermMatchTypeEnum.SearchTermMatchType.V(0)
        UNKNOWN = SearchTermMatchTypeEnum.SearchTermMatchType.V(1)
        BROAD = SearchTermMatchTypeEnum.SearchTermMatchType.V(2)
        EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(3)
        PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(4)
        NEAR_EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(5)
        NEAR_PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(6)
    class SearchTermMatchType(metaclass=_SearchTermMatchType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SearchTermMatchTypeEnum.SearchTermMatchType.V(0)
    UNKNOWN = SearchTermMatchTypeEnum.SearchTermMatchType.V(1)
    BROAD = SearchTermMatchTypeEnum.SearchTermMatchType.V(2)
    EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(3)
    PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(4)
    NEAR_EXACT = SearchTermMatchTypeEnum.SearchTermMatchType.V(5)
    NEAR_PHRASE = SearchTermMatchTypeEnum.SearchTermMatchType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___SearchTermMatchTypeEnum = SearchTermMatchTypeEnum
