"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.policy_pb2
import google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2
import google.ads.google_ads.v5.proto.enums.ad_strength_pb2
import google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v5.proto.enums.policy_review_status_pb2
import google.ads.google_ads.v5.proto.resources.ad_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupAd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    AD_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_FIELD_NUMBER: builtins.int
    AD_STRENGTH_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2.AdGroupAdStatusEnum.AdGroupAdStatus.V = (
        ...
    )
    ad_group: typing.Text = ...
    ad_strength: google.ads.google_ads.v5.proto.enums.ad_strength_pb2.AdStrengthEnum.AdStrength.V = (
        ...
    )
    @property
    def ad(self) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
    @property
    def policy_summary(self) -> global___AdGroupAdPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2.AdGroupAdStatusEnum.AdGroupAdStatus.V = ...,
        ad_group: typing.Text = ...,
        ad: typing.Optional[google.ads.google_ads.v5.proto.resources.ad_pb2.Ad] = ...,
        policy_summary: typing.Optional[global___AdGroupAdPolicySummary] = ...,
        ad_strength: google.ads.google_ads.v5.proto.enums.ad_strength_pb2.AdStrengthEnum.AdStrength.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "ad_strength",
            b"ad_strength",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...

global___AdGroupAd = AdGroupAd

class AdGroupAdPolicySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    review_status: google.ads.google_ads.v5.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        review_status: google.ads.google_ads.v5.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

global___AdGroupAdPolicySummary = AdGroupAdPolicySummary
