"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TEST_ACCOUNT_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def client_customer(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def hidden(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def level(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def time_zone(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def test_account(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def manager(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def descriptive_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        hidden: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        level: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        time_zone: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        test_account: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        manager: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        descriptive_name: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...

global___CustomerClient = CustomerClient
