"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.distance_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DistanceView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    DISTANCE_BUCKET_FIELD_NUMBER: builtins.int
    METRIC_SYSTEM_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    distance_bucket: google.ads.google_ads.v4.proto.enums.distance_bucket_pb2.DistanceBucketEnum.DistanceBucket.V = (
        ...
    )
    @property
    def metric_system(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        distance_bucket: google.ads.google_ads.v4.proto.enums.distance_bucket_pb2.DistanceBucketEnum.DistanceBucket.V = ...,
        metric_system: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["metric_system", b"metric_system"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "distance_bucket",
            b"distance_bucket",
            "metric_system",
            b"metric_system",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___DistanceView = DistanceView
