"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.asset_field_type_pb2
import google.ads.google_ads.v6.proto.enums.asset_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    FIELD_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    asset: typing.Text = ...
    field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.asset_link_status_pb2.AssetLinkStatusEnum.AssetLinkStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        asset: typing.Text = ...,
        field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = ...,
        status: google.ads.google_ads.v6.proto.enums.asset_link_status_pb2.AssetLinkStatusEnum.AssetLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
            "field_type",
            b"field_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...

global___CampaignAsset = CampaignAsset
