"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedItemError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemErrorEnum.FeedItemError.V(0)
        UNKNOWN = FeedItemErrorEnum.FeedItemError.V(1)
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = FeedItemErrorEnum.FeedItemError.V(
            2
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = FeedItemErrorEnum.FeedItemError.V(3)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = FeedItemErrorEnum.FeedItemError.V(4)
        KEY_ATTRIBUTES_NOT_FOUND = FeedItemErrorEnum.FeedItemError.V(5)
        INVALID_URL = FeedItemErrorEnum.FeedItemError.V(6)
        MISSING_KEY_ATTRIBUTES = FeedItemErrorEnum.FeedItemError.V(7)
        KEY_ATTRIBUTES_NOT_UNIQUE = FeedItemErrorEnum.FeedItemError.V(8)
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = FeedItemErrorEnum.FeedItemError.V(9)
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = FeedItemErrorEnum.FeedItemError.V(10)
    class FeedItemError(metaclass=_FeedItemError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemErrorEnum.FeedItemError.V(0)
    UNKNOWN = FeedItemErrorEnum.FeedItemError.V(1)
    CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = FeedItemErrorEnum.FeedItemError.V(2)
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = FeedItemErrorEnum.FeedItemError.V(3)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = FeedItemErrorEnum.FeedItemError.V(4)
    KEY_ATTRIBUTES_NOT_FOUND = FeedItemErrorEnum.FeedItemError.V(5)
    INVALID_URL = FeedItemErrorEnum.FeedItemError.V(6)
    MISSING_KEY_ATTRIBUTES = FeedItemErrorEnum.FeedItemError.V(7)
    KEY_ATTRIBUTES_NOT_UNIQUE = FeedItemErrorEnum.FeedItemError.V(8)
    CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = FeedItemErrorEnum.FeedItemError.V(9)
    SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = FeedItemErrorEnum.FeedItemError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemErrorEnum = FeedItemErrorEnum
