"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BillingSetupErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BillingSetupError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BillingSetupError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BillingSetupErrorEnum.BillingSetupError.V(0)
        UNKNOWN = BillingSetupErrorEnum.BillingSetupError.V(1)
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(
            2
        )
        CANNOT_REMOVE_STARTED_BILLING_SETUP = BillingSetupErrorEnum.BillingSetupError.V(
            3
        )
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = (
            BillingSetupErrorEnum.BillingSetupError.V(4)
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = (
            BillingSetupErrorEnum.BillingSetupError.V(5)
        )
        INVALID_PAYMENTS_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(6)
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = (
            BillingSetupErrorEnum.BillingSetupError.V(7)
        )
        INVALID_START_TIME_TYPE = BillingSetupErrorEnum.BillingSetupError.V(8)
        THIRD_PARTY_ALREADY_HAS_BILLING = BillingSetupErrorEnum.BillingSetupError.V(9)
        BILLING_SETUP_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(10)
        NO_SIGNUP_PERMISSION = BillingSetupErrorEnum.BillingSetupError.V(11)
        CHANGE_OF_BILL_TO_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(12)
        PAYMENTS_PROFILE_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(13)
        PAYMENTS_ACCOUNT_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(14)
        PAYMENTS_PROFILE_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(15)
        PAYMENTS_ACCOUNT_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(16)
        CUSTOMER_NEEDS_INTERNAL_APPROVAL = BillingSetupErrorEnum.BillingSetupError.V(17)
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = (
            BillingSetupErrorEnum.BillingSetupError.V(19)
        )
    class BillingSetupError(metaclass=_BillingSetupError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BillingSetupErrorEnum.BillingSetupError.V(0)
    UNKNOWN = BillingSetupErrorEnum.BillingSetupError.V(1)
    CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(2)
    CANNOT_REMOVE_STARTED_BILLING_SETUP = BillingSetupErrorEnum.BillingSetupError.V(3)
    CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = (
        BillingSetupErrorEnum.BillingSetupError.V(4)
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = (
        BillingSetupErrorEnum.BillingSetupError.V(5)
    )
    INVALID_PAYMENTS_ACCOUNT = BillingSetupErrorEnum.BillingSetupError.V(6)
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = (
        BillingSetupErrorEnum.BillingSetupError.V(7)
    )
    INVALID_START_TIME_TYPE = BillingSetupErrorEnum.BillingSetupError.V(8)
    THIRD_PARTY_ALREADY_HAS_BILLING = BillingSetupErrorEnum.BillingSetupError.V(9)
    BILLING_SETUP_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(10)
    NO_SIGNUP_PERMISSION = BillingSetupErrorEnum.BillingSetupError.V(11)
    CHANGE_OF_BILL_TO_IN_PROGRESS = BillingSetupErrorEnum.BillingSetupError.V(12)
    PAYMENTS_PROFILE_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(13)
    PAYMENTS_ACCOUNT_NOT_FOUND = BillingSetupErrorEnum.BillingSetupError.V(14)
    PAYMENTS_PROFILE_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(15)
    PAYMENTS_ACCOUNT_INELIGIBLE = BillingSetupErrorEnum.BillingSetupError.V(16)
    CUSTOMER_NEEDS_INTERNAL_APPROVAL = BillingSetupErrorEnum.BillingSetupError.V(17)
    PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = (
        BillingSetupErrorEnum.BillingSetupError.V(19)
    )
    def __init__(
        self,
    ) -> None: ...

global___BillingSetupErrorEnum = BillingSetupErrorEnum
