"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterestErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomInterestError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomInterestError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomInterestErrorEnum.CustomInterestError.V(0)
        UNKNOWN = CustomInterestErrorEnum.CustomInterestError.V(1)
        NAME_ALREADY_USED = CustomInterestErrorEnum.CustomInterestError.V(2)
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = (
            CustomInterestErrorEnum.CustomInterestError.V(3)
        )
        TYPE_AND_PARAMETER_NOT_FOUND = CustomInterestErrorEnum.CustomInterestError.V(4)
        TYPE_AND_PARAMETER_ALREADY_EXISTED = (
            CustomInterestErrorEnum.CustomInterestError.V(5)
        )
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE = (
            CustomInterestErrorEnum.CustomInterestError.V(6)
        )
        CANNOT_REMOVE_WHILE_IN_USE = CustomInterestErrorEnum.CustomInterestError.V(7)
        CANNOT_CHANGE_TYPE = CustomInterestErrorEnum.CustomInterestError.V(8)
    class CustomInterestError(metaclass=_CustomInterestError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomInterestErrorEnum.CustomInterestError.V(0)
    UNKNOWN = CustomInterestErrorEnum.CustomInterestError.V(1)
    NAME_ALREADY_USED = CustomInterestErrorEnum.CustomInterestError.V(2)
    CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = (
        CustomInterestErrorEnum.CustomInterestError.V(3)
    )
    TYPE_AND_PARAMETER_NOT_FOUND = CustomInterestErrorEnum.CustomInterestError.V(4)
    TYPE_AND_PARAMETER_ALREADY_EXISTED = CustomInterestErrorEnum.CustomInterestError.V(
        5
    )
    INVALID_CUSTOM_INTEREST_MEMBER_TYPE = CustomInterestErrorEnum.CustomInterestError.V(
        6
    )
    CANNOT_REMOVE_WHILE_IN_USE = CustomInterestErrorEnum.CustomInterestError.V(7)
    CANNOT_CHANGE_TYPE = CustomInterestErrorEnum.CustomInterestError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___CustomInterestErrorEnum = CustomInterestErrorEnum
