"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaUploadError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
        UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
        FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
        UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
        ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
        FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
        EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
        INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    class MediaUploadError(metaclass=_MediaUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaUploadErrorEnum.MediaUploadError.V(0)
    UNKNOWN = MediaUploadErrorEnum.MediaUploadError.V(1)
    FILE_TOO_BIG = MediaUploadErrorEnum.MediaUploadError.V(2)
    UNPARSEABLE_IMAGE = MediaUploadErrorEnum.MediaUploadError.V(3)
    ANIMATED_IMAGE_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(4)
    FORMAT_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(5)
    EXTERNAL_URL_NOT_ALLOWED = MediaUploadErrorEnum.MediaUploadError.V(6)
    INVALID_URL_REFERENCE = MediaUploadErrorEnum.MediaUploadError.V(7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaUploadErrorEnum.MediaUploadError.V(8)
    def __init__(
        self,
    ) -> None: ...

global___MediaUploadErrorEnum = MediaUploadErrorEnum
